SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";

--
-- Database: `db_webuser`
--

DELIMITER $$
--
-- Procedures
--
DROP PROCEDURE IF EXISTS `CreateFullView`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `CreateFullView`(IN db CHAR(100), IN newtbl CHAR(30))
BEGIN

		 SELECT "Start at ", CURRENT_DATE(), CURRENT_TIME();

		 SET @basecol=CONCAT("DBHID INT,PlotName VARCHAR(35),PlotID INT,Family CHAR(32),Genus CHAR(32),SpeciesName CHAR(64),Mnemonic CHAR(10),Subspecies CHAR(64),SpeciesID INT,SubspeciesID INT,",
							 "QuadratName VARCHAR(12),QuadratID INT,PX DECIMAL(16,5),PY DECIMAL(16,5),QX DECIMAL(16,5),QY DECIMAL(16,5),TreeID INT,Tag CHAR(10),StemID INT,StemNumber INT,StemTag VARCHAR(32),PrimaryStem CHAR(20),",
							 "CensusID INT,PlotCensusNumber INT,DBH FLOAT,HOM DECIMAL(10,2),ExactDate DATE");
		 SET @calccol=CONCAT("Date INT,ListOfTSM VARCHAR(256),HighHOM TINYINT(1),LargeStem TINYINT(1),Status ENUM('alive','dead','stem dead','broken below','omitted','missing') DEFAULT 'alive'");
		 SET @allindex=CONCAT("PRIMARY KEY(DBHID), INDEX(SpeciesID), INDEX(SubspeciesID), INDEX(QuadratID), INDEX(TreeID), INDEX(StemID), INDEX(Tag), INDEX(CensusID), INDEX(Genus,SpeciesName),",
							  "INDEX(Mnemonic), INDEX(CensusID), INDEX(PlotCensusNumber), INDEX(StemTag), INDEX(DBH), INDEX(Date), INDEX(Date), INDEX(ListOfTSM), INDEX(Status), INDEX(HighHOM)");
		 
		 SET @vtbl=CONCAT(db,'.',newtbl);
		 SET @dropqry=CONCAT('DROP TABLE IF EXISTS ', @vtbl);
		 SET @createqry=CONCAT('CREATE TABLE ', @vtbl, '(', @basecol, ',', @calccol, ',', @allindex, ') ENGINE=MyISAM;');
		 PREPARE qry FROM @dropqry; EXECUTE qry; PREPARE qry FROM @createqry; EXECUTE qry; 
		 SELECT "Created table at ", CURRENT_DATE(), CURRENT_TIME();
		 
		 SET @insertcol="DBHID,PlotName,     PlotID,  TreeID,  StemID,Tag,StemTag,StemNumber,PlotCensusNumber,Date,ExactDate,DBH,HOM,QuadratName,PX,PY,QX,QY,PrimaryStem,SpeciesID,SubSpeciesID,  CensusID,  QuadratID";
		 SET @selectcol="DBHID,PlotName,Site.PlotID,T.TreeID,S.StemID,Tag,StemTag,StemNumber,PlotCensusNumber,DATEDIFF(CASE WHEN DAYNAME(ExactDate) IS NULL THEN NULL ELSE ExactDate END,'1960-01-01') Date,CASE WHEN DAYNAME(ExactDate) IS NULL THEN NULL ELSE ExactDate END AS ExactDate,DBH,HOM,QuadratName,PX,PY,QX,QY,PrimaryStem,SpeciesID,SubSpeciesID,C.CensusID,Q.QuadratID";
		 SET @bigjoin=CONCAT(db, ".DBH D ",
							 "LEFT JOIN ", db, ".Stem S USING(StemID) ",
							 "LEFT JOIN ", db, ".Tree T ON T.TreeID=S.TreeID ",
							 "LEFT JOIN ", db, ".Quadrat Q ON Q.QuadratID=S.QuadratID ",
							 "LEFT JOIN ", db, ".Census C ON D.CensusID=C.CensusID ",
							 "LEFT JOIN ", db, ".Site ON Site.PlotID=Q.PlotID ORDER BY StemID,CensusID,DBHID");
		 SET @fillqry=CONCAT("INSERT INTO ", @vtbl, " (", @insertcol, ") SELECT ", @selectcol, " FROM ", @bigjoin);
		 PREPARE qry FROM @fillqry; EXECUTE qry; 
		 SELECT "Filled table with DBH, Stem, Tree, Quadrat, and Census at ", CURRENT_DATE(), CURRENT_TIME();
		 

		 
		 SET @fixhom=CONCAT("UPDATE ", @vtbl, " SET HOM=NULL WHERE HOM<0");
		 PREPARE qry FROM @fixhom; EXECUTE qry; 

		 CALL ctfsweb_webuser.UpdateViewFullJoin(@vtbl,CONCAT(db,".ViewTaxonomy"),"'Family','Genus','SpeciesName','SubSpecies','Mnemonic'","'Family','Genus','SpeciesName','SubSpecies','subspMnemonic'",
															   "SpeciesID,SubSpeciesID",CONCAT("WHERE ", @vtbl, ".SubSpeciesID IS NOT NULL"));
		 CALL ctfsweb_webuser.UpdateViewFullJoin(@vtbl,CONCAT(db,".ViewTaxonomy"),"'Family','Genus','SpeciesName','SubSpecies','Mnemonic'","'Family','Genus','SpeciesName','SubSpecies','Mnemonic'",
															   "SpeciesID",CONCAT("WHERE ", @vtbl, ".SubSpeciesID IS NULL"));
		 SELECT "Finished taxonomy at ", CURRENT_DATE(), CURRENT_TIME();
		 
		 CALL ctfsweb_webuser.FindHighHOM(db,newtbl,0);
		 SELECT "Finished HighHOM at ", CURRENT_DATE(), CURRENT_TIME();
		 CALL ctfsweb_webuser.GetListOfTSM(db,newtbl,'DBHAttributes','DBHID',';');
		 SELECT "Finished codes ", CURRENT_DATE(), CURRENT_TIME();
		 CALL ctfsweb_webuser.SetStatus(db,newtbl);
		 SELECT "Finished status and done at ", CURRENT_DATE(), CURRENT_TIME();
		 
	END$$

DROP PROCEDURE IF EXISTS `CreateViewTaxonomy`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `CreateViewTaxonomy`(IN db CHAR(100),IN wsgsite CHAR(150))
BEGIN

	 SET @basecol=CONCAT("ViewID INT AUTO_INCREMENT PRIMARY KEY, SpeciesID INT, SubspeciesID INT, Family CHAR(32), Mnemonic CHAR(10), Genus CHAR(32), SpeciesName CHAR(64), Rank CHAR(20), ",
						 "Subspecies CHAR(64), Authority CHAR(128), IDLevel CHAR(12),  subspMnemonic CHAR(10), subspAuthority VARCHAR(120), FieldFamily CHAR(32), ",
						 "Lifeform CHAR(20), Description TEXT, wsg DECIMAL(10,6), wsglevel enum('local','species','genus','family','none')");
	 SET @calccol=CONCAT("ListOfOldNames VARCHAR(255), Specimens VARCHAR(255), Reference VARCHAR(255)");
	 SET @allindex="INDEX(SpeciesID), INDEX(SubspeciesID), INDEX(IDLevel)";
	 
	 SET @vtbl=CONCAT(db,'.ViewTaxonomy');
	 SET @dropqry=CONCAT('DROP TABLE IF EXISTS ', @vtbl);
	 SET @createqry=CONCAT('CREATE TABLE ', @vtbl, '(', @basecol, ',', @calccol, ',', @allindex, ') ENGINE=MyISAM;');
	 PREPARE qry FROM @dropqry; EXECUTE qry; PREPARE qry FROM @createqry; EXECUTE qry; 
	 
	 SET @findlifeqry=CONCAT("SET @findlifeform=(SELECT COUNT(*) FROM information_schema.COLUMNS WHERE TABLE_SCHEMA='", db, "' AND TABLE_NAME='Species' AND COLUMN_NAME='Lifeform')");
	 PREPARE qry FROM @findlifeqry; EXECUTE qry; 
	 IF @findlifeform = 0 THEN
	   SET @addlifeqry=CONCAT("ALTER TABLE ", db, ".Species ADD COLUMN Lifeform ENUM('Emergent Tree','Tree','Midcanopy Tree','Understory Tree','Shrub','Herb','Liana')");
	   PREPARE qry FROM @addlifeqry; EXECUTE qry; 
	 END IF;
	   
	 SET @insertcol=CONCAT("SpeciesID,  SubspeciesID,Family,  Mnemonic,Genus,SpeciesName,              Rank,    Subspecies,  Authority,IDLevel,subspMnemonic,  subspAuthority,FieldFamily,Lifeform,Description");
	 SET @selectcol=CONCAT("S.SpeciesID,SubspeciesID,Family,S.Mnemonic,Genus,SpeciesName,InfraSpecificLevel,SubspeciesName,S.Authority,IDLevel,  SS.Mnemonic,    SS.Authority,FieldFamily,Lifeform,Description ");
	 SET @join=CONCAT("FROM ", db, ".Species S ",
					  "LEFT JOIN ", db, ".Genus G USING(GenusID) ",
					  "LEFT JOIN ", db, ".Family F ON G.FamilyID=F.FamilyID ",
					  "LEFT JOIN ", db, ".SubSpecies SS ON S.SpeciesID=SS.SpeciesID ");
	 SET @filter="WHERE S.CurrentTaxonFlag=1 AND (SS.CurrentTaxonFlag IS NULL OR SS.CurrentTaxonFlag=1)";
	 SET @fillqry=CONCAT("INSERT INTO ", @vtbl, " (", @insertcol, ") SELECT ", @selectcol, @join, @filter);
	 PREPARE qry FROM @fillqry; EXECUTE qry; 
	 
	 
	 
	 CALL updateViewTax_wsg(db,wsgsite);
	 CALL GetListOfObsolete(db,',');
	 
	END$$

DROP PROCEDURE IF EXISTS `FindHighHOM`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `FindHighHOM`(IN db CHAR(100), IN tbl CHAR(20), IN newcolumn INT)
BEGIN

 IF newcolumn = 1 THEN
   SET @querystr=CONCAT("ALTER TABLE ", db, ".", tbl, " ADD COLUMN HighHOM BOOL, ADD INDEX(HighHOM)");    
   PREPARE query FROM @querystr; EXECUTE query;
 END IF;

 SET @querystr=CONCAT("DROP TABLE IF EXISTS ", db, ".tempMultHOM");
 PREPARE query FROM @querystr; EXECUTE query;
 
 SET @subqry=CONCAT("SELECT TreeID,StemID,CensusID,PlotName,PlotCensusNumber,COUNT(*) AS homs FROM ", db, ".", tbl, 
                    " GROUP BY TreeID,StemID,CensusID,PlotName,PlotCensusNumber HAVING homs>1");
 SET @querystr=CONCAT(
   "CREATE TABLE ", db, ".tempMultHOM ", 
   "SELECT TreeID,StemID,CensusID,VPD.PlotName,VPD.PlotCensusNumber,Genus,SpeciesName,DBHID,DBH,HOM,Date,0 AS HighHOM FROM ", db, ".", tbl, " VPD ", 
   "JOIN (", @subqry, ") AS multhom USING(TreeID,StemID,CensusID) ");
 PREPARE query FROM @querystr; EXECUTE query;
 
 
 SET @addkey=CONCAT("ALTER TABLE ", db, ".tempMultHOM ",
                      "ADD INDEX(TreeID), ADD INDEX(StemID), ADD INDEX(CensusID), ADD INDEX(DBHID), ADD INDEX(HOM), ADD INDEX(HighHOM)");
 SET @setzero=CONCAT("UPDATE ", db, ".tempMultHOM SET HOM=(-1) WHERE HOM IS NULL");
 PREPARE query FROM @addkey; EXECUTE query; PREPARE query FROM @setzero; EXECUTE query;
 
  
 SET @subqry=CONCAT("SELECT TreeID,StemID,CensusID,MAX(HOM) AS HOM FROM ", db, ".tempMultHOM GROUP BY TreeID,StemID,CensusID");
 SET @querystr=CONCAT("UPDATE ", db, ".tempMultHOM JOIN (", @subqry, ") AS maxht USING(TreeID,StemID,CensusID,HOM) SET HighHOM=1");
 PREPARE query FROM @querystr; EXECUTE query;
 
 
 SET @querystr=CONCAT("UPDATE ", db, ".", tbl, " VPD JOIN ", db, ".tempMultHOM tMH USING(DBHID) SET VPD.HighHOM=tMH.HighHOM");
 
 PREPARE query FROM @querystr; EXECUTE query;
 

 SET @querystr=CONCAT("UPDATE ", db, ".", tbl, " SET HighHOM=1 WHERE HighHOM IS NULL");
 PREPARE query FROM @querystr; EXECUTE query;
 

 SET @querystr=CONCAT("DROP TABLE IF EXISTS ", db, ".tempMultHOM");
 PREPARE query FROM @querystr; EXECUTE query;

END$$

DROP PROCEDURE IF EXISTS `GetListOfObsolete`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `GetListOfObsolete`(IN db CHAR(100), IN sep CHAR(1))
getCO: BEGIN

 SET @oldname=CONCAT(db,'.tempOldName');
 SET @oldcount=CONCAT(db,'.tempOldCount');
 SET @co=CONCAT(db,'.CurrentObsolete');
 SET @sp=CONCAT(db,'.Species');
 SET @gen=CONCAT(db,'.Genus');
 SET @fulltbl=CONCAT(db,'.ViewTaxonomy');
 
 SET @drop=CONCAT('DROP TABLE IF EXISTS ', @oldname);
 SET @space=" ";
 SET @create=CONCAT('CREATE TABLE ', @oldname, ' SELECT CONCAT(Genus, "', @space, '", speciesname) AS ', 
                    'Latin,CurrentTaxonFlag,ObsoleteTaxonFlag,Mnemonic,CO.SpeciesID,ObsoleteSpeciesID,ChangeCodeID,ChangeNote ',
                    'FROM ', @sp,  ' S JOIN ', @gen, ' G ON S.GenusID=G.GenusID JOIN ', @co, ' CO ON S.SpeciesID=CO.ObsoleteSpeciesID');
 PREPARE query FROM @drop; EXECUTE query; PREPARE query FROM @create; EXECUTE query; 
 SET @alter=CONCAT("ALTER TABLE ", @oldname, " ADD COLUMN Valid VARCHAR(150)");
 SET @valid=CONCAT("UPDATE ", @oldname, " OLD JOIN ", @sp, " S ON OLD.SpeciesID=S.SpeciesID JOIN ", @gen, " G ON G.GenusID=S.GenusID ",
                   " SET OLD.Valid=CONCAT(Genus,'", @space, "',SpeciesName)");
 PREPARE query FROM @alter; EXECUTE query; PREPARE query FROM @valid; EXECUTE query; 
                   
 SET @drop=CONCAT('DROP TABLE IF EXISTS ', @oldcount);
 SET @create=CONCAT('CREATE TABLE ', @oldcount, ' SELECT SpeciesID,COUNT(*) AS names FROM ', @oldname, ' GROUP BY SpeciesID');
 PREPARE query FROM @drop; EXECUTE query; PREPARE query FROM @create; EXECUTE query; 
 
 SET @count=CONCAT('SET @nospp=(SELECT COUNT(*) FROM ', @oldcount, ')'); 
 PREPARE query FROM @count; EXECUTE query;
 IF @nospp=0 THEN
   LEAVE getCO;
 END IF;
 
 SET @findmax=CONCAT('SET @maxspp=(SELECT MAX(names) FROM ', @oldcount, ')');
 PREPARE query FROM @findmax; EXECUTE query; 
 
 SET @x=1;
 WHILE @x<=@maxspp DO
   SET @alter=CONCAT('ALTER TABLE ', @oldcount, ' ADD COLUMN OldSpID', @x, ' INT, ADD COLUMN OldLatin', @x, ' VARCHAR(50)');
   PREPARE query FROM @alter; EXECUTE query;
   SET @x=@x+1;
 END WHILE;

 SET @spqry=CONCAT('UPDATE ', @oldcount, ' JOIN ', @oldname, ' USING(SpeciesID) SET OldSpID1=ObsoleteSpeciesID, OldLatin1=Latin');
 PREPARE query FROM @spqry; EXECUTE query;
 

 SET @alter=CONCAT('ALTER TABLE ', @oldcount, ' ADD COLUMN ListOfOldNames VARCHAR(500) DEFAULT ""');
 SET @assign=CONCAT('UPDATE ', @oldcount, ' SET ListOfOldNames=OldLatin1 WHERE names=1');
 PREPARE query FROM @alter; EXECUTE query; PREPARE query FROM @assign; EXECUTE query;
 
 IF @maxspp>1 THEN
   SET @x=2;
   WHILE @x<=@maxspp DO
    
     SET @y=1;
     SET @filter='';
     WHILE @y<=@x-1 DO
       SET @filter=CONCAT(@filter, ' OldSpID', @y, '<>ObsoleteSpeciesID');
       IF @y<@x-1 THEN
         SET @filter=CONCAT(@filter, ' AND ');
       END IF;
       SET @y=@y+1;
     END WHILE;
     
     SET @spqry=CONCAT('UPDATE ', @oldcount, ' JOIN ', @oldname, ' USING(SpeciesID) ',
                       'SET OldSpID', @x, '=ObsoleteSpeciesID, OldLatin', @x, '=Latin WHERE ', @filter, ' AND names>=', @x);
     PREPARE query FROM @spqry; EXECUTE query;
     
     
     SET @x=@x+1;
   END WHILE;
 END IF;

 SET @x=2;
 WHILE @x<=@maxspp DO
     SET @y=1;
     SET @fullconcat='';

     WHILE @y<=@x DO
       SET @fullconcat=CONCAT(@fullconcat,'OldLatin',@y);
       IF @y<@x THEN
         SET @fullconcat=CONCAT(@fullconcat,',"',sep,'",');
       END IF;
       SET @y=@y+1;
    END WHILE;
   SET @merge=CONCAT('UPDATE ', @oldcount, ' TMP SET ListOfOldNames=CONCAT(', @fullconcat, ') WHERE names=', @x);
   PREPARE query FROM @merge; EXECUTE query;
   SET @x=@x+1;
 END WHILE;

 SET @finish=CONCAT('UPDATE ', @fulltbl, ' F JOIN ', @oldcount, ' C USING(SpeciesID) SET F.ListOfOldNames=C.ListOfOldNames');
 PREPARE query FROM @finish; EXECUTE query;
 
 SET @drop=CONCAT('DROP TABLE IF EXISTS ', @oldname);
 PREPARE query FROM @drop; EXECUTE query;
 
 SET @drop=CONCAT('DROP TABLE IF EXISTS ', @oldcount);
 PREPARE query FROM @drop; EXECUTE query;
 
END$$

DROP PROCEDURE IF EXISTS `GetListOfTSM`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `GetListOfTSM`(IN dendroDB CHAR(50), IN settbl CHAR(50), IN attribTbl CHAR(30), IN PK CHAR(10), IN sep CHAR(1))
getTSM: BEGIN

 SET @temp=CONCAT(dendroDB,'.temptsm');
 SET @ma=CONCAT(dendroDB,'.',attribTbl);
 SET @tsm=CONCAT(dendroDB,'.TSMAttributes');
 SET @fulltbl=CONCAT(dendroDB,'.',settbl);
 
 SET @drop=CONCAT('DROP TABLE IF EXISTS ', @temp);
 SET @create=CONCAT('CREATE TABLE ', @temp, ' SELECT ', PK, ',COUNT(*) AS codeno FROM ', @ma, ' GROUP BY ', PK);
 SET @addPK=CONCAT('ALTER TABLE ', @temp, ' ADD INDEX(', PK, '), ADD INDEX(codeno)');
 SET @count=CONCAT('SET @nocode=(SELECT COUNT(*) FROM ', @temp, ')'); 
 PREPARE query FROM @drop; EXECUTE query; PREPARE query FROM @create; EXECUTE query; PREPARE query FROM @addPK; EXECUTE query; PREPARE query FROM @count; EXECUTE query;
 IF @nocode=0 THEN
   LEAVE getTSM;
 END IF;
 
 SET @findmax=CONCAT('SET @maxcode=(SELECT MAX(codeno) FROM ', @temp, ')');
 PREPARE query FROM @findmax; EXECUTE query; 
 
 SET @x=1;
 WHILE @x<=@maxcode DO
   SET @alter=CONCAT('ALTER TABLE ', @temp, ' ADD COLUMN TSMID', @x, ' INT, ADD COLUMN code', @x, ' VARCHAR(10)');
   PREPARE query FROM @alter; EXECUTE query;
   SET @x=@x+1;
 END WHILE;
 
 SET @sub=CONCAT(' (SELECT ', PK, ',TSMID FROM ', @ma, ' GROUP BY ', PK, ', TSMID) AS codes ');
 SET @idqry=CONCAT('UPDATE ', @temp, ' JOIN ', @sub, ' USING(', PK, ') SET TSMID1=codes.TSMID');
 SET @codeqry=CONCAT('UPDATE ', @temp, ' TMP JOIN ', @tsm, ' TSM ON TMP.TSMID1=TSM.TSMID SET TMP.code1=TSM.TSMcode');
 PREPARE query FROM @idqry; EXECUTE query; PREPARE query FROM @codeqry; EXECUTE query;
 SET @alter=CONCAT('ALTER TABLE ', @temp, ' ADD COLUMN ListOfTSM VARCHAR(40) DEFAULT ""');
 SET @assign=CONCAT('UPDATE ', @temp, ' SET ListOfTSM=code1 WHERE codeno=1');
 PREPARE query FROM @alter; EXECUTE query; PREPARE query FROM @assign; EXECUTE query;

 IF @maxcode>1 THEN
   SET @x=2;
   WHILE @x<=@maxcode DO
     SET @y=1;
     SET @filter='';
     WHILE @y<=@x-1 DO
       SET @filter=CONCAT(@filter, ' TSMID', @y, '<>TSMID');
       IF @y<@x-1 THEN
         SET @filter=CONCAT(@filter, ' AND ');
       END IF;
       SET @y=@y+1;
     END WHILE;
     SET @codeqry=CONCAT('UPDATE ', @temp, ' JOIN (SELECT ', PK, ',TSMID FROM ', @ma, ') AS codes USING(', PK, ') SET TSMID', @x, '=TSMID WHERE ', @filter);
     PREPARE query FROM @codeqry; EXECUTE query;

     SET @codeqry=CONCAT('UPDATE ', @temp, ' TMP JOIN ', @tsm, ' TSM ON TMP.TSMID', @x, '=TSM.TSMID SET TMP.code', @x, '=TSM.TSMcode');
     PREPARE query FROM @codeqry; EXECUTE query;
     
     SET @x=@x+1;
   END WHILE;
 END IF;
   
 SET @x=2;
 WHILE @x<=@maxcode DO
     SET @y=1;
     SET @fullconcat='';
     SET @assign=CONCAT('UPDATE ', @temp, ' SET ListOfTSM=code1 WHERE codeno=1');

     WHILE @y<=@x DO
       SET @fullconcat=CONCAT(@fullconcat,'code',@y);
       IF @y<@x THEN
         SET @fullconcat=CONCAT(@fullconcat,',"',sep,'",');
       END IF;
       SET @y=@y+1;
    END WHILE;
   SET @merge=CONCAT('UPDATE ', @temp, ' TMP SET ListOfTSM=CONCAT(', @fullconcat, ') WHERE codeno=', @x);
   PREPARE query FROM @merge; EXECUTE query;
   SET @x=@x+1;
 END WHILE;

 SET @capture=CONCAT('UPDATE ', @fulltbl, ' FT JOIN ', @temp, ' TMP USING(', PK, ') SET FT.ListOfTSM=TMP.ListOfTsm');
 PREPARE query FROM @capture; EXECUTE query;
 
 SET @drop=CONCAT('DROP TABLE IF EXISTS ', @temp);
 PREPARE query FROM @drop; EXECUTE query;
 
END$$

DROP PROCEDURE IF EXISTS `SetStatus`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `SetStatus`(IN db CHAR(100), IN tbl CHAR(50))
BEGIN

 SET @vtbl=CONCAT(db,'.',tbl);
 SET @tsm=CONCAT(db,'.TSMAttributes');
 SET @da=CONCAT(db,'.DBHAttributes');
 
 SET @qryOM=CONCAT("UPDATE ", @vtbl, " V JOIN ", @da, " DA USING(DBHID) JOIN ", @tsm, " TSM ON TSM.TSMID=DA.TSMID SET V.Status=TSM.Status WHERE TSM.Status = 'omitted'");  
 SET @qryM=CONCAT("UPDATE ", @vtbl, " V JOIN ", @da, " DA USING(DBHID) JOIN ", @tsm, " TSM ON TSM.TSMID=DA.TSMID SET V.Status=TSM.Status WHERE TSM.Status = 'missing'");  
 SET @qryM2=CONCAT("UPDATE ", @vtbl, " SET Status='missing' WHERE (DBH IS NULL OR DBH<=0) AND (ListOfTSM IS NULL OR ListOfTSM='')");  
 SET @qrySD=CONCAT("UPDATE ", @vtbl, " V JOIN ", @da, " DA USING(DBHID) JOIN ", @tsm, " TSM ON TSM.TSMID=DA.TSMID SET V.Status=TSM.Status WHERE TSM.Status = 'stem dead'");  
 SET @qryBB=CONCAT("UPDATE ", @vtbl, " V JOIN ", @da, " DA USING(DBHID) JOIN ", @tsm, " TSM ON TSM.TSMID=DA.TSMID SET V.Status=TSM.Status WHERE TSM.Status = 'broken below'");  
 SET @qryD=CONCAT("UPDATE ", @vtbl, " V JOIN ", @da, " DA USING(DBHID) JOIN ", @tsm, " TSM ON TSM.TSMID=DA.TSMID SET V.Status=TSM.Status WHERE TSM.Status = 'dead'");  

 PREPARE query FROM @qryOM; EXECUTE query;
 PREPARE query FROM @qryM; EXECUTE query;
 PREPARE query FROM @qryM2; EXECUTE query;
 PREPARE query FROM @qrySD; EXECUTE query;
 PREPARE query FROM @qryBB; EXECUTE query;
 PREPARE query FROM @qryD; EXECUTE query;

END$$

DROP PROCEDURE IF EXISTS `UpdateViewFullJoin`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `UpdateViewFullJoin`(IN vtbl CHAR(50), IN jointbl CHAR(50), IN updatecol CHAR(100), IN selectcol CHAR(100), IN joincol CHAR(50), IN filter CHAR(150))
BEGIN

 SET @fullqry=CONCAT("UPDATE ", vtbl, " LEFT JOIN ", jointbl, " USING(", joincol, ") SET ");
 
 SET @x=1;
 theloop: WHILE 1 DO
    SET @updateqry=CONCAT('SET @Ucol=ELT(', @x, ', ', updatecol, ')');
    SET @selectqry=CONCAT('SET @Scol=ELT(', @x, ', ', selectcol, ')');
    PREPARE query FROM @updateqry; EXECUTE query; PREPARE query FROM @selectqry; EXECUTE query; 
    

    IF @Ucol IS NULL THEN
      LEAVE theloop; 
    ELSE 
      SET @onesection=CONCAT(" ", vtbl, ".", @Ucol, "=", jointbl, ".", @Scol);
      IF @x>1 THEN
        SET @onesection=CONCAT(", ", @onesection);
      END IF;
      SET @fullqry=CONCAT(@fullqry,@onesection);
      SET @x=@x+1;    
    END IF;

 END WHILE;  

 SET @fullqry=CONCAT(@fullqry," ",filter);
 
 PREPARE query FROM @fullqry; EXECUTE query;

END$$

DROP PROCEDURE IF EXISTS `updateViewTax_wsg`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `updateViewTax_wsg`(IN db CHAR(100), IN allsite CHAR(150))
BEGIN
    
    SET @setqry=CONCAT("SET @viewtbl='", db, ".ViewTaxonomy'");
    PREPARE aqry FROM @setqry; EXECUTE aqry;

    SET @startqry=CONCAT("UPDATE ", @viewtbl, " SET wsg=(SELECT AVG(wsg) FROM ctfsweb_webuser.speciesWood), wsglevel='none'");
    PREPARE aqry FROM @startqry; EXECUTE aqry;

    SET @famqry=CONCAT("UPDATE ctfsweb_webuser.Family F JOIN ", @viewtbl, " vW USING(Family) ",
                       "JOIN ctfsweb_webuser.familyWood famW ON famW.FamilyID=F.FamilyID ",
                       "SET vW.wsg=famW.meanwsg, vW.wsglevel='family' WHERE locale='world'");
    PREPARE aqry FROM @famqry; EXECUTE aqry;

    SET @genqry=CONCAT("UPDATE ctfsweb_webuser.Genus G JOIN ", @viewtbl, " vW USING(Genus) ",
                       "JOIN ctfsweb_webuser.genusWood genW ON genW.GenusID=G.GenusID ",
                       "SET vW.wsg=genW.meanwsg, vW.wsglevel='genus' WHERE locale='world'");
    PREPARE aqry FROM @genqry; EXECUTE aqry;

    SET @sppqry=CONCAT("UPDATE ctfsweb_webuser.Genus G JOIN ", @viewtbl, " vW USING(Genus) ",
                       "JOIN ctfsweb_webuser.speciesWood spW ON spW.GenusID=G.GenusID AND spW.species=vW.SpeciesName ",
                       "SET vW.wsg=spW.wsg, vW.wsglevel='species' WHERE locale='world'");
    PREPARE aqry FROM @sppqry; EXECUTE aqry;
   
    SET @x=1;
    theloop: WHILE 1 DO
        SET @getsite=CONCAT('SET @site=ELT(', @x, ', ', allsite, ')');
        PREPARE query FROM @getsite; EXECUTE query; 

        IF @site IS NULL THEN
          LEAVE theloop; 
        ELSE SET @x=@x+1;
        END IF;
        
        
        SET @sppqry=CONCAT("UPDATE ctfsweb_webuser.Genus G JOIN ", @viewtbl, " vW USING(Genus) ",
                           "JOIN ctfsweb_webuser.speciesWood spW ON spW.GenusID=G.GenusID AND spW.species=vW.SpeciesName ",
                           "SET vW.wsg=spW.wsg, vW.wsglevel='local' WHERE locale='", @site, "'");
        PREPARE aqry FROM @sppqry; EXECUTE aqry;
        
        
    END WHILE;  
    
END$$

DELIMITER ;

-- --------------------------------------------------------

--
-- Table structure for table `ci_sessions`
--

DROP TABLE IF EXISTS `ci_sessions`;
CREATE TABLE IF NOT EXISTS `ci_sessions` (
  `session_id` varchar(40) NOT NULL DEFAULT '0',
  `ip_address` varchar(16) NOT NULL DEFAULT '0',
  `user_agent` varchar(120) NOT NULL,
  `last_activity` int(10) unsigned NOT NULL DEFAULT '0',
  `user_data` text,
  PRIMARY KEY (`session_id`),
  KEY `last_activity_idx` (`last_activity`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;


--
-- Table structure for table `DataEntryConfig`
--

DROP TABLE IF EXISTS `DataEntryConfig`;
CREATE TABLE IF NOT EXISTS `DataEntryConfig` (
  `DataEntryConfig_ID` int(11) NOT NULL AUTO_INCREMENT,
  `Plots_ID` int(11) NOT NULL,
  `DatabaseName` varchar(64) NOT NULL,
  `FormType` varchar(40) NOT NULL,
  `ColumnNumber` int(11) DEFAULT NULL,
  `ColumnType` varchar(40) NOT NULL,
  `Attributes` text NOT NULL,
  PRIMARY KEY (`DataEntryConfig_ID`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=458 ;


--
-- Table structure for table `DownloadLink`
--

DROP TABLE IF EXISTS `DownloadLink`;
CREATE TABLE IF NOT EXISTS `DownloadLink` (
  `DownloadLinkID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Title` varchar(80) NOT NULL,
  `Path` varchar(120) NOT NULL,
  `Date` varchar(40) NOT NULL,
  `DatabaseName` varchar(40) NOT NULL,
  `LinkType` varchar(40) NOT NULL,
  PRIMARY KEY (`DownloadLinkID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `Family`
--

DROP TABLE IF EXISTS `Family`;
CREATE TABLE IF NOT EXISTS `Family` (
  `FamilyID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Family` char(32) DEFAULT NULL,
  `ReferenceID` smallint(5) unsigned DEFAULT NULL,
  PRIMARY KEY (`FamilyID`),
  KEY `Ref84175` (`ReferenceID`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=550 ;

--
-- Dumping data for table `Family`
--

INSERT INTO `Family` (`FamilyID`, `Family`, `ReferenceID`) VALUES
(1, 'Acanthaceae', NULL),
(2, 'Actinidiaceae', NULL),
(3, 'Agavaceae', NULL),
(4, 'Alzateaceae', NULL),
(5, 'Amaranthaceae', NULL),
(6, 'Anacardiaceae', NULL),
(7, 'Anisophylleaceae', NULL),
(8, 'Annonaceae', NULL),
(9, 'Apiaceae', NULL),
(10, 'Apocynaceae', NULL),
(11, 'Aquifoliaceae', NULL),
(12, 'Araceae', NULL),
(13, 'Araliaceae', NULL),
(14, 'Araucariaceae', NULL),
(15, 'Arecaceae', NULL),
(16, 'Aristolochiaceae', NULL),
(17, 'Asclepiadaceae', NULL),
(18, 'Asteraceae', NULL),
(19, 'Bataceae', NULL),
(20, 'Begoniaceae', NULL),
(21, 'Betulaceae', NULL),
(22, 'Bignoniaceae', NULL),
(23, 'Bixaceae', NULL),
(24, 'Bombacaceae', NULL),
(25, 'Boraginaceae', NULL),
(26, 'Brunelliaceae', NULL),
(27, 'Burseraceae', NULL),
(28, 'Buxaceae', NULL),
(29, 'Cactaceae', NULL),
(30, 'Campanulaceae', NULL),
(31, 'Canellaceae', NULL),
(32, 'Capparaceae', NULL),
(33, 'Caprifoliaceae', NULL),
(34, 'Caricaceae', NULL),
(35, 'Caryocaraceae', NULL),
(36, 'Casuarinaceae', NULL),
(37, 'Cecropiaceae', NULL),
(38, 'Celastraceae', NULL),
(39, 'Chloranthaceae', NULL),
(40, 'Chrysobalanaceae', NULL),
(41, 'Clethraceae', NULL),
(42, 'Clusiaceae', NULL),
(43, 'Cochlospermaceae', NULL),
(44, 'Combretaceae', NULL),
(45, 'Connaraceae', NULL),
(46, 'Convolvulaceae', NULL),
(47, 'Cornaceae', NULL),
(48, 'Crassulaceae', NULL),
(49, 'Cucurbitaceae', NULL),
(50, 'Cunoniaceae', NULL),
(51, 'Cupressaceae', NULL),
(52, 'Cyatheaceae', NULL),
(53, 'Cycadaceae', NULL),
(54, 'Cyclanthaceae', NULL),
(55, 'Cyperaceae', NULL),
(56, 'Cyrillaceae', NULL),
(57, 'Dichapetalaceae', NULL),
(58, 'Dilleniaceae', NULL),
(59, 'Dioscoreaceae', NULL),
(60, 'Dipterocarpaceae', NULL),
(61, 'Ebenaceae', NULL),
(62, 'Elaeocarpaceae', NULL),
(63, 'Eremolepidaceae', NULL),
(64, 'Ericaceae', NULL),
(65, 'Erythroxylaceae', NULL),
(66, 'Euphorbiaceae', NULL),
(67, 'Euphroniaceae', NULL),
(68, 'Fabaceae', NULL),
(69, 'Fabaceae-caesalpinioideae', NULL),
(70, 'Fabaceae-mimosoideae', NULL),
(71, 'Fabaceae-papilionoideae', NULL),
(72, 'Fagaceae', NULL),
(73, 'Flacourtiaceae', NULL),
(74, 'Garryaceae', NULL),
(75, 'Gentianaceae', NULL),
(76, 'Gesneriaceae', NULL),
(77, 'Gnetaceae', NULL),
(78, 'Heliconiaceae', NULL),
(79, 'Hernandiaceae', NULL),
(80, 'Hippocastanaceae', NULL),
(81, 'Hippocrateaceae', NULL),
(82, 'Hugoniaceae', NULL),
(83, 'Humiriaceae', NULL),
(84, 'Hydrophyllaceae', NULL),
(85, 'Icacinaceae', NULL),
(86, 'Ixonanthaceae', NULL),
(87, 'Juglandaceae', NULL),
(88, 'Krameriaceae', NULL),
(89, 'Lacistemataceae', NULL),
(90, 'Lamiaceae', NULL),
(91, 'Lauraceae', NULL),
(92, 'Lecythidaceae', NULL),
(93, 'Lepidobotryaceae', NULL),
(94, 'Liliaceae', NULL),
(95, 'Linaceae', NULL),
(96, 'Lissocarpaceae', NULL),
(97, 'Loganiaceae', NULL),
(98, 'Loranthaceae', NULL),
(99, 'Lythraceae', NULL),
(100, 'Magnoliaceae', NULL),
(101, 'Malpighiaceae', NULL),
(102, 'Malvaceae', NULL),
(103, 'Marantaceae', NULL),
(104, 'Marcgraviaceae', NULL),
(105, 'Melastomataceae', NULL),
(106, 'Meliaceae', NULL),
(107, 'Menispermaceae', NULL),
(108, 'Monimiaceae', NULL),
(109, 'Moraceae', NULL),
(110, 'Moringaceae', NULL),
(111, 'Musaceae', NULL),
(112, 'Myoporaceae', NULL),
(113, 'Myricaceae', NULL),
(114, 'Myristicaceae', NULL),
(115, 'Myrsinaceae', NULL),
(116, 'Myrtaceae', NULL),
(117, 'Nyctaginaceae', NULL),
(118, 'Ochnaceae', NULL),
(119, 'Olacaceae', NULL),
(120, 'Oleaceae', NULL),
(121, 'Onagraceae', NULL),
(122, 'Opiliaceae', NULL),
(123, 'Orchidaceae', NULL),
(124, 'Oxalidaceae', NULL),
(125, 'Pandanaceae', NULL),
(126, 'Papaveraceae', NULL),
(127, 'Passifloraceae', NULL),
(128, 'Phytolaccaceae', NULL),
(129, 'Pinaceae', NULL),
(130, 'Piperaceae', NULL),
(131, 'Poaceae', NULL),
(132, 'Podocarpaceae', NULL),
(133, 'Polygalaceae', NULL),
(134, 'Polygonaceae', NULL),
(135, 'Proteaceae', NULL),
(136, 'Punicaceae', NULL),
(137, 'Quiinaceae', NULL),
(138, 'Rhabdodendraceae', NULL),
(139, 'Rhamnaceae', NULL),
(140, 'Rhizophoraceae', NULL),
(141, 'Rosaceae', NULL),
(142, 'Rubiaceae', NULL),
(143, 'Rutaceae', NULL),
(144, 'Sabiaceae', NULL),
(145, 'Salicaceae', NULL),
(146, 'Santalaceae', NULL),
(147, 'Sapindaceae', NULL),
(148, 'Sapotaceae', NULL),
(149, 'Saxifragaceae', NULL),
(150, 'Scrophulariaceae', NULL),
(151, 'Simaroubaceae', NULL),
(152, 'Siparunaceae', NULL),
(153, 'Smilacaceae', NULL),
(154, 'Solanaceae', NULL),
(155, 'Staphyleaceae', NULL),
(156, 'Sterculiaceae', NULL),
(157, 'Strelitziaceae', NULL),
(158, 'Styracaceae', NULL),
(159, 'Symplocaceae', NULL),
(160, 'Tamaricaceae', NULL),
(161, 'Tepuianthaceae', NULL),
(162, 'Theaceae', NULL),
(163, 'Theophrastaceae', NULL),
(164, 'Thymelaeaceae', NULL),
(165, 'Ticodendraceae', NULL),
(166, 'Tiliaceae', NULL),
(167, 'Tovariaceae', NULL),
(168, 'Trigoniaceae', NULL),
(169, 'Turneraceae', NULL),
(170, 'Ulmaceae', NULL),
(171, 'Urticaceae', NULL),
(172, 'Velloziaceae', NULL),
(173, 'Verbenaceae', NULL),
(174, 'Violaceae', NULL),
(175, 'Vochysiaceae', NULL),
(176, 'Winteraceae', NULL),
(177, 'Zygophyllaceae', NULL),
(178, 'Duckeodendraceae', NULL),
(179, 'Huaceae', NULL),
(180, 'Pandaceae', NULL),
(181, 'Vitaceae', NULL),
(182, 'Melianthaceae', NULL),
(183, 'Irvingiaceae', NULL),
(184, 'Phyllanthaceae', NULL),
(185, 'Unknown', NULL),
(186, 'Crypteroniaceae', NULL),
(187, 'Hymenocardiaceae', NULL),
(188, 'Alangiaceae', NULL),
(189, 'Aceraceae', NULL),
(190, 'Tetrameristaceae', NULL),
(191, 'Scytopetalaceae', NULL),
(192, 'Sonneratiaceae', NULL),
(193, 'Medusandraceae', NULL),
(194, 'Datiscaceae', NULL),
(195, 'Daphniphyllaceae', NULL),
(196, 'Hoplestigmataceae', NULL),
(197, 'Brassicaceae', NULL),
(198, 'Achariaceae', NULL),
(199, 'Achatocarpaceae', NULL),
(200, 'Acoraceae', NULL),
(201, 'Actiniopteridaceae', NULL),
(202, 'Adiantaceae', NULL),
(203, 'Adoxaceae', NULL),
(204, 'Aextoxicaceae', NULL),
(205, 'Agapanthaceae', NULL),
(206, 'Agdestidaceae', NULL),
(207, 'Aizoaceae', NULL),
(208, 'Akaniaceae', NULL),
(209, 'Alismataceae', NULL),
(210, 'Alliaceae', NULL),
(211, 'Aloaceae', NULL),
(212, 'Alseuosmiaceae', NULL),
(213, 'Alstroemeriaceae', NULL),
(214, 'Altingiaceae', NULL),
(215, 'Amaryllidaceae', NULL),
(216, 'Amborellaceae', NULL),
(217, 'Anarthriaceae', NULL),
(218, 'Ancistrocladaceae', NULL),
(219, 'Anthericaceae', NULL),
(220, 'Aphyllanthaceae', NULL),
(221, 'Apodanthaceae', NULL),
(222, 'Aponogetonaceae', NULL),
(223, 'Argophyllaceae', NULL),
(224, 'Asparagaceae', NULL),
(225, 'Asphodelaceae', NULL),
(226, 'Aspleniaceae', NULL),
(227, 'Asteliaceae', NULL),
(228, 'Asteropeiaceae', NULL),
(229, 'Austrobaileyaceae', NULL),
(230, 'Azollaceae', NULL),
(231, 'Balanopaceae', NULL),
(232, 'Balanophoraceae', NULL),
(233, 'Balsaminaceae', NULL),
(234, 'Barbeuiaceae', NULL),
(235, 'Barbeyaceae', NULL),
(236, 'Basellaceae', NULL),
(237, 'Berberidaceae', NULL),
(238, 'Biebersteiniaceae', NULL),
(239, 'Blandfordiaceae', NULL),
(240, 'Blechnaceae', NULL),
(241, 'Bonnetiaceae', NULL),
(242, 'Boryaceae', NULL),
(243, 'Boweniaceae', NULL),
(244, 'Bromeliaceae', NULL),
(245, 'Bruniaceae', NULL),
(246, 'Burmanniaceae', NULL),
(247, 'Butomaceae', NULL),
(248, 'Byblidaceae', NULL),
(249, 'Cabombaceae', NULL),
(250, 'Calycanthaceae', NULL),
(251, 'Calyceraceae', NULL),
(252, 'Campynemataceae', NULL),
(253, 'Cannabaceae', NULL),
(254, 'Cannaceae', NULL),
(255, 'Cardiopteridaceae', NULL),
(256, 'Carlemanniaceae', NULL),
(257, 'Caryophyllaceae', NULL),
(258, 'Centrolepidaceae', NULL),
(259, 'Cephalotaceae', NULL),
(260, 'Cephalotaxaceae', NULL),
(261, 'Ceratophyllaceae', NULL),
(262, 'Cercidiphyllaceae', NULL),
(263, 'Cheiropleuriaceae', NULL),
(264, 'Circaeasteraceae', NULL),
(265, 'Cistaceae', NULL),
(266, 'Colchicaceae', NULL),
(267, 'Columelliaceae', NULL),
(268, 'Commelinaceae', NULL),
(269, 'Convallariaceae', NULL),
(270, 'Coriariaceae', NULL),
(271, 'Corsiaceae', NULL),
(272, 'Corynocarpaceae', NULL),
(273, 'Costaceae', NULL),
(274, 'Crossosomataceae', NULL),
(275, 'Cymodoceaceae', NULL),
(276, 'Cynomoriaceae', NULL),
(277, 'Cytinaceae', NULL),
(278, 'Dasypogonaceae', NULL),
(279, 'Davalliaceae', NULL),
(280, 'Degeneriaceae', NULL),
(281, 'Dennstaedtiaceae', NULL),
(282, 'Diapensiaceae', NULL),
(283, 'Dicksoniaceae', NULL),
(284, 'Didiereaceae', NULL),
(285, 'Didymelaceae', NULL),
(286, 'Diegodendraceae', NULL),
(287, 'Dioncophyllaceae', NULL),
(288, 'Dipentodontaceae', NULL),
(289, 'Dipsacaceae', NULL),
(290, 'Dipteridaceae', NULL),
(291, 'Dirachmaceae', NULL),
(292, 'Doryanthaceae', NULL),
(293, 'Dracaenaceae', NULL),
(294, 'Droseraceae', NULL),
(295, 'Drosophyllaceae', NULL),
(296, 'Dryopteridaceae', NULL),
(297, 'Ecdeiocoleaceae', NULL),
(298, 'Elaeagnaceae', NULL),
(299, 'Elatinaceae', NULL),
(300, 'Emblingiaceae', NULL),
(301, 'Ephedraceae', NULL),
(302, 'Equisetaceae', NULL),
(303, 'Eremosynaceae', NULL),
(304, 'Eriocaulaceae', NULL),
(305, 'Eriospermaceae', NULL),
(306, 'Escalloniaceae', NULL),
(307, 'Eucommiaceae', NULL),
(308, 'Eupomatiaceae', NULL),
(309, 'Eupteleaceae', NULL),
(310, 'Flagellariaceae', NULL),
(311, 'Fouquieriaceae', NULL),
(312, 'Frankeniaceae', NULL),
(313, 'Geissolomataceae', NULL),
(314, 'Geraniaceae', NULL),
(315, 'Ginkgoaceae', NULL),
(316, 'Gisekiaceae', NULL),
(317, 'Gleicheniaceae', NULL),
(318, 'Gomortegaceae', NULL),
(319, 'Goodeniaceae', NULL),
(320, 'Goupiaceae', NULL),
(321, 'Grammitidaceae', NULL),
(322, 'Griseliniaceae', NULL),
(323, 'Grossulariaceae', NULL),
(324, 'Grubbiaceae', NULL),
(325, 'Gunneraceae', NULL),
(326, 'Gyrostemonaceae', NULL),
(327, 'Haemodoraceae', NULL),
(328, 'Halophytaceae', NULL),
(329, 'Haloragaceae', NULL),
(330, 'Hamamelidaceae', NULL),
(331, 'Hanguanaceae', NULL),
(332, 'Haptanthaceae', NULL),
(333, 'Hectorellaceae', NULL),
(334, 'Helwingiaceae', NULL),
(335, 'Hemerocallidaceae', NULL),
(336, 'Hesperocallidaceae', NULL),
(337, 'Himantandraceae', NULL),
(338, 'Hyacinthaceae', NULL),
(339, 'Hydatellaceae', NULL),
(340, 'Hydnoraceae', NULL),
(341, 'Hydrangeaceae', NULL),
(342, 'Hydrocharitaceae', NULL),
(343, 'Hydrostachyaceae', NULL),
(344, 'Hymenophyllaceae', NULL),
(345, 'Hymenophyllopsidaceae', NULL),
(346, 'Hypericaceae', NULL),
(347, 'Hypoxidaceae', NULL),
(348, 'Illiciaceae', NULL),
(349, 'Iridaceae', NULL),
(350, 'Isoetaceae', NULL),
(351, 'Iteaceae', NULL),
(352, 'Ixerbaceae', NULL),
(353, 'Ixioliriaceae', NULL),
(354, 'Joinvilleaceae', NULL),
(355, 'Juncaceae', NULL),
(356, 'Juncaginaceae', NULL),
(357, 'Lactoridaceae', NULL),
(358, 'Lanariaceae', NULL),
(359, 'Lardizabalaceae', NULL),
(360, 'Laxmanniaceae', NULL),
(361, 'Ledocarpaceae', NULL),
(362, 'Lennoaceae', NULL),
(363, 'Lentibulariaceae', NULL),
(364, 'Limeaceae', NULL),
(365, 'Limnanthaceae', NULL),
(366, 'Limnocharitaceae', NULL),
(367, 'Loasaceae', NULL),
(368, 'Lomandraceae', NULL),
(369, 'Lomariopsidaceae', NULL),
(370, 'Lophopyxidaceae', NULL),
(371, 'Lowiaceae', NULL),
(372, 'Loxsomataceae', NULL),
(373, 'Luzuriagaceae', NULL),
(374, 'Lycopodiaceae', NULL),
(375, 'Malesherbiaceae', NULL),
(376, 'Marattiaceae', NULL),
(377, 'Marsileaceae', NULL),
(378, 'Martyniaceae', NULL),
(379, 'Matoniaceae', NULL),
(380, 'Mayacaceae', NULL),
(381, 'Medusagynaceae', NULL),
(382, 'Melanthiaceae', NULL),
(383, 'Menyanthaceae', NULL),
(384, 'Metaxyaceae', NULL),
(385, 'Misodendraceae', NULL),
(386, 'Mitrastemonaceae', NULL),
(387, 'Molluginaceae', NULL),
(388, 'Montiniaceae', NULL),
(389, 'Morinaceae', NULL),
(390, 'Myrothamnaceae', NULL),
(391, 'Nartheciaceae', NULL),
(392, 'Nelumbonaceae', NULL),
(393, 'Nepenthaceae', NULL),
(394, 'Neuradaceae', NULL),
(395, 'Nymphaeaceae', NULL),
(396, 'Oleandraceae', NULL),
(397, 'Oliniaceae', NULL),
(398, 'Oncothecaceae', NULL),
(399, 'Ophioglossaceae', NULL),
(400, 'Orobanchaceae', NULL),
(401, 'Osmundaceae', NULL),
(402, 'Paeoniaceae', NULL),
(403, 'Paracryphiaceae', NULL),
(404, 'Parkeriaceae', NULL),
(405, 'Parnassiaceae', NULL),
(406, 'Pedaliaceae', NULL),
(407, 'Penaeaceae', NULL),
(408, 'Pentaphragmataceae', NULL),
(409, 'Pentaphylacaceae', NULL),
(410, 'Penthoraceae', NULL),
(411, 'Peridiscaceae', NULL),
(412, 'Petermanniaceae', NULL),
(413, 'Petrosaviaceae', NULL),
(414, 'Phellinaceae', NULL),
(415, 'Philesiaceae', NULL),
(416, 'Philydraceae', NULL),
(417, 'Phrymaceae', NULL),
(418, 'Phyllocladaceae', NULL),
(419, 'Phyllonomaceae', NULL),
(420, 'Physenaceae', NULL),
(421, 'Pittosporaceae', NULL),
(422, 'Plagiogyriaceae', NULL),
(423, 'Plantaginaceae', NULL),
(424, 'Platanaceae', NULL),
(425, 'Platyzomataceae', NULL),
(426, 'Plumbaginaceae', NULL),
(427, 'Podostemaceae', NULL),
(428, 'Polemoniaceae', NULL),
(429, 'Polypodiaceae', NULL),
(430, 'Pontederiaceae', NULL),
(431, 'Portulacaceae', NULL),
(432, 'Posidoniaceae', NULL),
(433, 'Potamogetonaceae', NULL),
(434, 'Primulaceae', NULL),
(435, 'Psilotaceae', NULL),
(436, 'Ptaeroxylaceae', NULL),
(437, 'Pteridaceae', NULL),
(438, 'Pterostemonaceae', NULL),
(439, 'Quintiniaceae', NULL),
(440, 'Rafflesiaceae', NULL),
(441, 'Ranunculaceae', NULL),
(442, 'Rapateaceae', NULL),
(443, 'Resedaceae', NULL),
(444, 'Restionaceae', NULL),
(445, 'Rhipogonaceae', NULL),
(446, 'Rhoipteleaceae', NULL),
(447, 'Rhynchocalycaceae', NULL),
(448, 'Roridulaceae', NULL),
(449, 'Rousseaceae', NULL),
(450, 'Ruppiaceae', NULL),
(451, 'Ruscaceae', NULL),
(452, 'Salvadoraceae', NULL),
(453, 'Salviniaceae', NULL),
(454, 'Sarcobataceae', NULL),
(455, 'Sarcolaenaceae', NULL),
(456, 'Sarraceniaceae', NULL),
(457, 'Saururaceae', NULL),
(458, 'Scheuchzeriaceae', NULL),
(459, 'Schisandraceae', NULL),
(460, 'Schizaeaceae', NULL),
(461, 'Sciadopityaceae', NULL),
(462, 'Selaginellaceae', NULL),
(463, 'Simmondsiaceae', NULL),
(464, 'Sparganiaceae', NULL),
(465, 'Sphaerosepalaceae', NULL),
(466, 'Sphenostemonaceae', NULL),
(467, 'Stachyuraceae', NULL),
(468, 'Stangeriaceae', NULL),
(469, 'Stegnospermataceae', NULL),
(470, 'Stemonaceae', NULL),
(471, 'Stilbaceae', NULL),
(472, 'Strasburgeriaceae', NULL),
(473, 'Stromatopteridaceae', NULL),
(474, 'Stylidiaceae', NULL),
(475, 'Surianaceae', NULL),
(476, 'Taxaceae', NULL),
(477, 'Tecophilaeaceae', NULL),
(478, 'Tetracentraceae', NULL),
(479, 'Tetrachondraceae', NULL),
(480, 'Thelypteridaceae', NULL),
(481, 'Themidaceae', NULL),
(482, 'Thurniaceae', NULL),
(483, 'Tofieldiaceae', NULL),
(484, 'Torricelliaceae', NULL),
(485, 'Trimeniaceae', NULL),
(486, 'Triuridaceae', NULL),
(487, 'Trochodendraceae', NULL),
(488, 'Tropaeolaceae', NULL),
(489, 'Typhaceae', NULL),
(490, 'Vahliaceae', NULL),
(491, 'Valerianaceae', NULL),
(492, 'Vittariaceae', NULL),
(493, 'Vivianiaceae', NULL),
(494, 'Welwitschiaceae', NULL),
(495, 'Woodsiaceae', NULL),
(496, 'Xanthorrhoeaceae', NULL),
(497, 'Xeronemataceae', NULL),
(498, 'Xyridaceae', NULL),
(499, 'Zamiaceae', NULL),
(500, 'Zannichelliaceae', NULL),
(501, 'Zingiberaceae', NULL),
(502, 'Zosteraceae', NULL),
(503, 'Aphanopetalaceae', NULL),
(504, 'Aphloiaceae', NULL),
(505, 'Atherospermataceae', NULL),
(506, 'Berberidopsidaceae', NULL),
(507, 'Calceolariaceae', NULL),
(508, 'Centroplacaceae', NULL),
(509, 'Cleomaceae', NULL),
(510, 'Ctenolophonaceae', NULL),
(511, 'Curtisiaceae', NULL),
(512, 'Desfontainiaceae', NULL),
(513, 'Diervillaceae', NULL),
(514, 'Erythropalaceae', NULL),
(515, 'Francoaceae', NULL),
(516, 'Gelsemiaceae', NULL),
(517, 'Hydroleaceae', NULL),
(518, 'Kirkiaceae', NULL),
(519, 'Koeberliniaceae', NULL),
(520, 'Linderniaceae', NULL),
(521, 'Linnaeaceae', NULL),
(522, 'Maesaceae', NULL),
(523, 'Metteniusaceae', NULL),
(524, 'Muntingiaceae', NULL),
(525, 'Myodocarpaceae', NULL),
(526, 'Nitrariaceae', NULL),
(527, 'Nothofagaceae', NULL),
(528, 'Nyssaceae', NULL),
(529, 'Paulowniaceae', NULL),
(530, 'Pellicieraceae', NULL),
(531, 'Pennantiaceae', NULL),
(532, 'Pentadiplandraceae', NULL),
(533, 'Picramniaceae', NULL),
(534, 'Picrodendraceae', NULL),
(535, 'Plocospermataceae', NULL),
(536, 'Polyosmaceae', NULL),
(537, 'Pottingeriaceae', NULL),
(538, 'Putranjivaceae', NULL),
(539, 'Quillajaceae', NULL),
(540, 'Schlegeliaceae', NULL),
(541, 'Schoepfiaceae', NULL),
(542, 'Setchellanthaceae', NULL),
(543, 'Sladeniaceae', NULL),
(544, 'Sphenocleaceae', NULL),
(545, 'Stemonuraceae', NULL),
(546, 'Tapisciaceae', NULL),
(547, 'Tetracarpaeaceae', NULL),
(548, 'Tetramelaceae', NULL),
(549, 'unplaced', NULL);

-- --------------------------------------------------------

--
-- Table structure for table `familyWood`
--

DROP TABLE IF EXISTS `familyWood`;
CREATE TABLE IF NOT EXISTS `familyWood` (
  `wsgFamID` int(11) NOT NULL AUTO_INCREMENT,
  `FamilyID` int(11) DEFAULT NULL,
  `meanwsg` decimal(10,6) DEFAULT NULL,
  `locale` char(20) DEFAULT NULL,
  PRIMARY KEY (`wsgFamID`),
  KEY `FamilyID` (`FamilyID`),
  KEY `locale` (`locale`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=112 ;

--
-- Dumping data for table `familyWood`
--

INSERT INTO `familyWood` (`wsgFamID`, `FamilyID`, `meanwsg`, `locale`) VALUES
(1, 1, '0.670230', 'world'),
(2, 2, '0.398667', 'world'),
(3, 6, '0.557810', 'world'),
(4, 8, '0.564713', 'world'),
(5, 10, '0.566429', 'world'),
(6, 11, '0.558438', 'world'),
(7, 13, '0.428893', 'world'),
(8, 15, '0.562656', 'world'),
(9, 18, '0.636096', 'world'),
(10, 21, '0.510250', 'world'),
(11, 22, '0.618486', 'world'),
(12, 25, '0.536279', 'world'),
(13, 31, '0.736333', 'world'),
(14, 32, '0.754000', 'world'),
(15, 33, '0.631000', 'world'),
(16, 34, '0.226250', 'world'),
(17, 38, '0.661045', 'world'),
(18, 39, '0.450000', 'world'),
(19, 40, '0.780386', 'world'),
(20, 42, '0.655327', 'world'),
(21, 44, '0.600332', 'world'),
(22, 45, '0.516834', 'world'),
(23, 46, '0.791500', 'world'),
(24, 47, '0.565091', 'world'),
(25, 51, '0.432533', 'world'),
(26, 57, '0.680400', 'world'),
(27, 58, '0.613421', 'world'),
(28, 60, '0.621660', 'world'),
(29, 64, '0.619000', 'world'),
(30, 66, '0.508550', 'world'),
(31, 68, '0.678156', 'world'),
(32, 69, '0.678156', 'world'),
(33, 70, '0.678168', 'world'),
(34, 71, '0.678156', 'world'),
(35, 72, '0.648828', 'world'),
(36, 73, '0.561707', 'world'),
(37, 75, '0.692667', 'world'),
(38, 79, '0.284467', 'world'),
(39, 85, '0.576971', 'world'),
(40, 86, '0.655333', 'world'),
(41, 87, '0.493000', 'world'),
(42, 89, '0.509333', 'world'),
(43, 90, '0.538969', 'world'),
(44, 91, '0.558536', 'world'),
(45, 92, '0.696332', 'world'),
(46, 95, '0.847750', 'world'),
(47, 97, '0.609179', 'world'),
(48, 99, '0.584548', 'world'),
(49, 100, '0.481981', 'world'),
(50, 101, '0.637090', 'world'),
(51, 102, '0.475734', 'world'),
(52, 105, '0.670511', 'world'),
(53, 106, '0.555811', 'world'),
(54, 107, '0.545000', 'world'),
(55, 108, '0.588474', 'world'),
(56, 109, '0.540168', 'world'),
(57, 113, '0.583000', 'world'),
(58, 114, '0.505312', 'world'),
(59, 115, '0.648781', 'world'),
(60, 116, '0.755723', 'world'),
(61, 118, '0.777205', 'world'),
(62, 119, '0.757515', 'world'),
(63, 120, '0.684062', 'world'),
(64, 121, '0.696000', 'world'),
(65, 122, '0.742333', 'world'),
(66, 127, '0.675000', 'world'),
(67, 128, '0.488500', 'world'),
(68, 129, '0.427750', 'world'),
(69, 132, '0.489556', 'world'),
(70, 133, '0.704286', 'world'),
(71, 134, '0.602922', 'world'),
(72, 135, '0.633844', 'world'),
(73, 137, '0.819889', 'world'),
(74, 139, '0.692602', 'world'),
(75, 140, '0.739506', 'world'),
(76, 141, '0.618609', 'world'),
(77, 142, '0.635640', 'world'),
(78, 143, '0.639521', 'world'),
(79, 144, '0.502842', 'world'),
(80, 145, '0.566110', 'world'),
(81, 146, '0.725050', 'world'),
(82, 147, '0.693891', 'world'),
(83, 148, '0.702733', 'world'),
(84, 151, '0.421821', 'world'),
(85, 152, '0.588000', 'world'),
(86, 154, '0.516194', 'world'),
(87, 155, '0.395815', 'world'),
(88, 158, '0.420423', 'world'),
(89, 162, '0.574864', 'world'),
(90, 163, '0.740667', 'world'),
(91, 164, '0.511309', 'world'),
(92, 168, '0.696667', 'world'),
(93, 170, '0.595585', 'world'),
(94, 171, '0.343615', 'world'),
(95, 173, '0.620324', 'world'),
(96, 174, '0.648654', 'world'),
(97, 175, '0.551652', 'world'),
(98, 180, '0.611667', 'world'),
(99, 181, '0.559333', 'world'),
(100, 184, '0.610198', 'world'),
(101, 186, '0.564800', 'world'),
(102, 198, '0.605289', 'world'),
(103, 237, '0.641000', 'world'),
(104, 250, '0.650000', 'world'),
(105, 255, '0.599462', 'world'),
(106, 330, '0.623421', 'world'),
(107, 409, '0.558000', 'world'),
(108, 534, '0.584667', 'world'),
(109, 538, '0.509000', 'world'),
(110, 545, '0.625000', 'world'),
(111, 546, '0.396000', 'world');

-- --------------------------------------------------------

--
-- Table structure for table `Genus`
--

DROP TABLE IF EXISTS `Genus`;
CREATE TABLE IF NOT EXISTS `Genus` (
  `GenusID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Genus` char(32) DEFAULT NULL,
  `ReferenceID` smallint(5) unsigned DEFAULT NULL,
  `Authority` char(32) DEFAULT NULL,
  `FamilyID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`GenusID`),
  KEY `Ref2868` (`FamilyID`),
  KEY `Ref84176` (`ReferenceID`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=21253 ;

--
-- Dumping data for table `Genus`
--

INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(1, 'Abarema', NULL, 'Pittier', 70),
(2, 'Acacia', NULL, 'Mill.', 70),
(3, 'Acalypha', NULL, 'L.', 66),
(4, 'Acanthocereus', NULL, '(Engelm. ex A.Berger) Britton &', 29),
(5, 'Acidoton', NULL, 'P.Browne(SUH)', 66),
(6, 'Acosmium', NULL, 'Schott', 71),
(7, 'Acrocomia', NULL, 'Mart.', 15),
(8, 'Adelia', NULL, 'P.Browne(SUH)', 66),
(9, 'Adelobotrys', NULL, 'DC.', 105),
(10, 'Adenaria', NULL, 'Kunth', 99),
(11, 'Aegiphila', NULL, 'Jacq.', 90),
(12, 'Aiphanes', NULL, 'Willd.', 15),
(13, 'Albizia', NULL, 'Durazz.', 70),
(14, 'Alchornea', NULL, 'Sw.', 66),
(15, 'Alibertia', NULL, 'A.Rich. ex DC.', 142),
(16, 'Allenanthus', NULL, 'Standl.', 142),
(17, 'Allophylus', NULL, 'L.', 147),
(18, 'Alnus', NULL, 'Mill.', 21),
(19, 'Alseis', NULL, 'Schott', 142),
(20, 'Amaioua', NULL, 'Aubl.', 142),
(21, 'Amanoa', NULL, 'Aubl.', 184),
(22, 'Ampelocera', NULL, 'Klotzsch', 170),
(23, 'Amphitecna', NULL, 'Miers', 22),
(24, 'Amyris', NULL, 'P.Browne', 143),
(25, 'Anacardium', NULL, 'L.', 6),
(26, 'Anaxagorea', NULL, 'A.St.-Hil.', 8),
(27, 'Andira', NULL, 'Juss.', 71),
(28, 'Aniba', NULL, 'Aubl.', 91),
(29, 'Annona', NULL, 'L.', 8),
(30, 'Apeiba', NULL, 'Aubl.', 102),
(31, 'Aphelandra', NULL, 'R.Br.', 1),
(32, 'Appunia', NULL, 'Hook.f.', 142),
(33, 'Ardisia', NULL, 'Sw.', 115),
(34, 'Artocarpus', NULL, 'J.R.Forst. & G.Forst.', 109),
(35, 'Aspidosperma', NULL, 'Mart. & Zucc.', 10),
(36, 'Astrocaryum', NULL, 'G.Mey.', 15),
(37, 'Astronium', NULL, 'Jacq.', 6),
(38, 'Attalea', NULL, 'Kunth', 15),
(39, 'Aulomyrcia', NULL, 'O.Berg', 116),
(40, 'Avicennia', NULL, 'L.', 1),
(41, 'Bactris', NULL, 'Jacq.', 15),
(42, 'Balizia', NULL, 'Barneby & J.W. Grimes', 70),
(43, 'Banara', NULL, 'Aubl.', 145),
(44, 'Batocarpus', NULL, 'H.Karst.', 109),
(45, 'Bauhinia', NULL, 'L.', 69),
(46, 'Beilschmiedia', NULL, 'Nees', 91),
(47, 'Bellucia', NULL, 'Neck. ex Raf.', 105),
(48, 'Bertiera', NULL, 'Aubl.', 142),
(49, 'Besleria', NULL, 'L.', 76),
(50, 'Billia', NULL, 'Peyr.', 147),
(51, 'Bixa', NULL, 'L.', 23),
(52, 'Bocconia', NULL, 'L.', 126),
(53, 'Borojoa', NULL, 'Cuatrec.', 142),
(54, 'Bourreria', NULL, 'P.Browne', 25),
(55, 'Bravaisia', NULL, 'DC.', 1),
(56, 'Brosimum', NULL, 'Sw.', 109),
(57, 'Brownea', NULL, 'Jacq.', 69),
(58, 'Brunfelsia', NULL, 'L.', 154),
(59, 'Buchenavia', NULL, 'Eichler', 44),
(60, 'Bucida', NULL, 'L.', 44),
(61, 'Bunchosia', NULL, 'Rich. ex Kunth', 101),
(62, 'Bursera', NULL, 'Jacq. ex L.', 27),
(63, 'Byrsonima', NULL, 'Rich. ex Kunth', 101),
(64, 'Caesalpinia', NULL, 'L.', 69),
(65, 'Calatola', NULL, 'Standl.', 85),
(66, 'Calliandra', NULL, 'Benth.', 70),
(67, 'Callicarpa', NULL, 'L.', 90),
(68, 'Calophyllum', NULL, 'L.', 42),
(69, 'Calycolpus', NULL, 'O.Berg', 116),
(70, 'Calycophyllum', NULL, 'DC.', 142),
(71, 'Calyptranthes', NULL, 'Sw.', 116),
(72, 'Calyptrogyne', NULL, 'H.Wendl.', 15),
(73, 'Campnosperma', NULL, 'Thwaites', 6),
(74, 'Capparis', NULL, 'L.', 32),
(75, 'Carapa', NULL, 'Aubl.', 106),
(76, 'Carica', NULL, 'L.', 34),
(77, 'Caryodaphnopsis', NULL, 'Airy Shaw', 91),
(78, 'Casearia', NULL, 'Jacq.', 145),
(79, 'Cassia', NULL, 'L.', 69),
(80, 'Cassipourea', NULL, 'Aubl.', 140),
(81, 'Castilla', NULL, 'Cerv.', 109),
(82, 'Cavanillesia', NULL, 'Ruiz & Pav.', 102),
(83, 'Cecropia', NULL, 'Loefl.', 171),
(84, 'Cedrela', NULL, 'P.Browne', 106),
(85, 'Ceiba', NULL, 'Mill.', 102),
(86, 'Celtis', NULL, 'L.', 253),
(87, 'Centropogon', NULL, 'C.Presl', 30),
(88, 'Cespedesia', NULL, 'Goudot', 118),
(89, 'Cestrum', NULL, 'L.', 154),
(90, 'Chamaedorea', NULL, 'Willd.', 15),
(91, 'Chamguava', NULL, 'Landrum', 116),
(92, 'Cheiloclinium', NULL, 'Miers', 38),
(93, 'Chimarrhis', NULL, 'Jacq.', 142),
(94, 'Chionanthus', NULL, 'L.', 120),
(95, 'Chloroleucon', NULL, '(Benth.) Record', 70),
(96, 'Chomelia', NULL, 'Jacq.', 142),
(97, 'Chromolucuma', NULL, 'Ducke', 148),
(98, 'Chrysobalanus', NULL, 'L.', 40),
(99, 'Chrysochlamys', NULL, 'Poepp.', 42),
(100, 'Chrysophyllum', NULL, 'L.', 148),
(101, 'Cinnamomum', NULL, 'Schaeff.', 91),
(102, 'Citharexylum', NULL, 'Mill.', 173),
(103, 'Citrus', NULL, 'L.', 143),
(104, 'Clarisia', NULL, 'Ruiz & Pav.', 109),
(105, 'Clavija', NULL, 'Ruiz & Pav.', 163),
(106, 'Clethra', NULL, 'L.', 41),
(107, 'Clidemia', NULL, 'D.Don', 105),
(108, 'Clitoria', NULL, 'L.', 71),
(109, 'Clusia', NULL, 'L.', 42),
(110, 'Cnidoscolus', NULL, 'Pohl', 66),
(111, 'Coccoloba', NULL, 'P.Browne', 134),
(112, 'Cochlospermum', NULL, 'Kunth', 43),
(113, 'Cocos', NULL, 'L.', 15),
(114, 'Cojoba', NULL, 'Britton & Rose', 70),
(115, 'Colpothrinax', NULL, 'Griseb. & H.Wendl.', 15),
(116, 'Colubrina', NULL, 'Rich. ex Brongn.', 139),
(117, 'Compsoneura', NULL, '(DC.) Warb.', 114),
(118, 'Conceveiba', NULL, 'Aubl.', 66),
(119, 'Conchocarpus', NULL, 'J.C. Mikan', 143),
(120, 'Condaminea', NULL, 'DC.', 142),
(121, 'Conocarpus', NULL, 'L.', 44),
(122, 'Conostegia', NULL, 'D.Don', 105),
(123, 'Copaifera', NULL, 'L.', 69),
(124, 'Cordia', NULL, 'L.', 25),
(125, 'Cosmibuena', NULL, 'Ruiz & Pav.', 142),
(126, 'Couepia', NULL, 'Aubl.', 40),
(127, 'Couratari', NULL, 'Aubl.', 92),
(128, 'Couroupita', NULL, 'Aubl.', 92),
(129, 'Coussarea', NULL, 'Aubl.', 142),
(130, 'Coutarea', NULL, 'Aubl.', 142),
(131, 'Crateva', NULL, 'L.', 32),
(132, 'Cremastosperma', NULL, 'R.E.Fr.', 8),
(133, 'Crescentia', NULL, 'L.', 22),
(134, 'Crossopetalum', NULL, 'P.Browne', 38),
(135, 'Croton', NULL, 'L.', 66),
(136, 'Crudia', NULL, 'Schreb.', 69),
(137, 'Cryosophila', NULL, 'Blume', 15),
(138, 'Cryptocarya', NULL, 'R.Br.', 91),
(139, 'Cupania', NULL, 'L.', 147),
(140, 'Curatella', NULL, 'Loefl.', 58),
(141, 'Cyathea', NULL, 'Sm.', 52),
(142, 'Cybianthus', NULL, 'Mart.', 115),
(143, 'Cymbopetalum', NULL, 'Benth.', 8),
(144, 'Cynometra', NULL, 'L.', 69),
(145, 'Cyrilla', NULL, 'Garden ex L.', 56),
(146, 'Dalbergia', NULL, 'L.f.', 71),
(147, 'Daphnopsis', NULL, 'Mart.', 164),
(148, 'Delonix', NULL, 'Raf.', 69),
(149, 'Dendropanax', NULL, 'Decne. & Planch.', 13),
(150, 'Desmopsis', NULL, 'Saff.', 8),
(151, 'Dialium', NULL, 'L.', 69),
(152, 'Dichapetalum', NULL, 'Thouars', 57),
(153, 'Dilodendron', NULL, 'Radlk.', 147),
(154, 'Diospyros', NULL, 'L.', 61),
(155, 'Diphysa', NULL, 'Jacq.', 71),
(156, 'Diplotropis', NULL, 'Benth.', 71),
(157, 'Dipteryx', NULL, 'Schreb.', 71),
(158, 'Discophora', NULL, 'Miers', 545),
(159, 'Drypetes', NULL, 'Vahl', 538),
(160, 'Duguetia', NULL, 'A.St.-Hil.', 8),
(161, 'Dussia', NULL, 'Krug & Urb. ex Taub.', 71),
(162, 'Dystovomita', NULL, '(Engl.) D''Arcy', 42),
(163, 'Ecclinusa', NULL, 'Mart.', 148),
(164, 'Elaeagia', NULL, 'Wedd.', 142),
(165, 'Elaeis', NULL, 'Jacq.', 15),
(166, 'Elaeoluma', NULL, 'Baill.', 148),
(167, 'Endlicheria', NULL, 'Nees', 91),
(168, 'Enterolobium', NULL, 'Mart.', 70),
(169, 'Erblichia', NULL, 'Seem.', 169),
(170, 'Erisma', NULL, 'Rudge', 175),
(171, 'Erythrina', NULL, 'L.', 71),
(172, 'Erythroxylum', NULL, 'P.Browne', 65),
(173, 'Eschweilera', NULL, 'Mart. ex DC.', 92),
(174, 'Esenbeckia', NULL, 'Kunth', 143),
(175, 'Eugenia', NULL, 'L.', 116),
(176, 'Euphorbia', NULL, 'L.', 66),
(177, 'Euterpe', NULL, 'Mart.', 15),
(178, 'Exostema', NULL, '(Pers.) Humb. & Bonpl.', 142),
(179, 'Faramea', NULL, 'Aubl.', 142),
(180, 'Ferdinandusa', NULL, 'Pohl', 142),
(181, 'Ficus', NULL, 'L.', 109),
(182, 'Fissicalyx', NULL, 'Benth.', 71),
(183, 'Flemingia', NULL, 'Hunter ex Ridl.(SUH)', 71),
(184, 'Freziera', NULL, 'Willd.', 409),
(185, 'Galipea', NULL, 'Aubl.', 143),
(186, 'Garcinia', NULL, 'L.', 42),
(187, 'Genipa', NULL, 'L.', 142),
(188, 'Geonoma', NULL, 'Willd.', 15),
(189, 'Gliricidia', NULL, 'Kunth', 71),
(190, 'Gloeospermum', NULL, 'Triana & Planch.', 174),
(191, 'Gmelina', NULL, 'L.', 90),
(192, 'Godmania', NULL, 'Hemsl.', 22),
(193, 'Gonzalagunia', NULL, 'Ruiz & Pav.', 142),
(194, 'Gordonia', NULL, 'Ellis', 162),
(195, 'Gossypium', NULL, 'L.', 102),
(196, 'Graffenrieda', NULL, 'DC.', 105),
(197, 'Grias', NULL, 'L.', 92),
(198, 'Guapira', NULL, 'Aubl.', 117),
(199, 'Guarea', NULL, 'L.', 106),
(200, 'Guatteria', NULL, 'Ruiz & Pav.', 8),
(201, 'Guazuma', NULL, 'Mill.', 102),
(202, 'Guettarda', NULL, 'L.', 142),
(203, 'Gustavia', NULL, 'L.', 92),
(204, 'Gyranthera', NULL, 'Pittier', 102),
(205, 'Hamelia', NULL, 'Jacq.', 142),
(206, 'Hampea', NULL, 'Schltdl.', 102),
(207, 'Hasseltia', NULL, 'Kunth', 145),
(208, 'Hedyosmum', NULL, 'Sw.', 39),
(209, 'Heisteria', NULL, 'Jacq.', 514),
(210, 'Helicostylis', NULL, 'Trecul', 109),
(211, 'Helicteres', NULL, 'L.', 102),
(212, 'Heliocarpus', NULL, 'L.', 102),
(213, 'Henriettea', NULL, 'DC.', 105),
(214, 'Henriettella', NULL, 'Naudin', 105),
(215, 'Hernandia', NULL, 'L.', 79),
(216, 'Herrania', NULL, 'Goudot', 102),
(217, 'Hevea', NULL, 'Aubl.', 66),
(218, 'Hieronyma', NULL, 'Baill.', 66),
(219, 'Hippomane', NULL, 'L.', 66),
(220, 'Hirtella', NULL, 'L.', 40),
(221, 'Homalium', NULL, 'Jacq.', 145),
(222, 'Hortia', NULL, 'Vand.', 143),
(223, 'Humiriastrum', NULL, '(Urb.) Cuatrec.', 83),
(224, 'Hura', NULL, 'L.', 66),
(225, 'Hybanthus', NULL, 'Jacq.', 174),
(226, 'Hymenaea', NULL, 'L.', 69),
(227, 'Hymenolobium', NULL, 'Benth.', 71),
(228, 'Hyperbaena', NULL, 'Miers ex Benth.', 107),
(229, 'Ilex', NULL, 'L.', 11),
(230, 'Inga', NULL, 'Mill.', 70),
(231, 'Iriartea', NULL, 'Ruiz & Pav.', 15),
(232, 'Iryanthera', NULL, 'Warb.', 114),
(233, 'Isertia', NULL, 'Schreb.', 142),
(234, 'Ixora', NULL, 'L.', 142),
(235, 'Jacaranda', NULL, 'Juss.', 22),
(236, 'Jacaratia', NULL, 'A.DC.', 34),
(237, 'Jacquinia', NULL, 'L.', 163),
(238, 'Jatropha', NULL, 'L.', 66),
(239, 'Joosia', NULL, 'H.Karst.', 142),
(240, 'Kigelia', NULL, 'DC.', 22),
(241, 'Klarobelia', NULL, 'Chatrou', 8),
(242, 'Koanophyllon', NULL, 'Arruda', 18),
(243, 'Lacistema', NULL, 'Sw.', 89),
(244, 'Lacmellea', NULL, 'H.Karst.', 10),
(245, 'Ladenbergia', NULL, 'Klotzsch', 142),
(246, 'Laetia', NULL, 'L.', 145),
(247, 'Lafoensia', NULL, 'Vand.', 99),
(248, 'Lagerstroemia', NULL, 'L.', 99),
(249, 'Laguncularia', NULL, 'C.F.Gaertn.', 44),
(250, 'Lantana', NULL, 'L.', 173),
(251, 'Laxoplumeria', NULL, 'Markgr.', 10),
(252, 'Leandra', NULL, 'Raddi', 105),
(253, 'Lecointea', NULL, 'Ducke', 71),
(254, 'Lecythis', NULL, 'Loefl.', 92),
(255, 'Lennea', NULL, 'Klotzsch', 71),
(256, 'Leonia', NULL, 'Ruiz & Pav.', 174),
(257, 'Licania', NULL, 'Aubl.', 40),
(258, 'Licaria', NULL, 'Aubl.', 91),
(259, 'Lindackeria', NULL, 'C.Presl', 198),
(260, 'Lonchocarpus', NULL, 'Kunth', 71),
(261, 'Lozania', NULL, 'S.Mutis ex Caldas', 89),
(262, 'Luehea', NULL, 'Willd.', 102),
(263, 'Lunania', NULL, 'Hook.', 145),
(264, 'Lycianthes', NULL, '(Dunal) Hassl.', 154),
(265, 'Mabea', NULL, 'Aubl.', 66),
(266, 'Machaerium', NULL, 'Pers.', 71),
(267, 'Maclura', NULL, 'Nutt.', 109),
(268, 'Macoubea', NULL, 'Aubl.', 10),
(269, 'Macrocnemum', NULL, 'P.Browne', 142),
(270, 'Macrolobium', NULL, 'Schreb.', 69),
(271, 'Malmea', NULL, 'R.E.Fr.', 8),
(272, 'Malouetia', NULL, 'A.DC.', 10),
(273, 'Malpighia', NULL, 'L.', 101),
(274, 'Mammea', NULL, 'L.', 42),
(275, 'Mangifera', NULL, 'L.', 6),
(276, 'Manihot', NULL, 'Mill.', 66),
(277, 'Manilkara', NULL, 'Adans.', 148),
(278, 'Maprounea', NULL, 'Aubl.', 66),
(279, 'Maquira', NULL, 'Aubl.', 109),
(280, 'Maranthes', NULL, 'Blume', 40),
(281, 'Margaritaria', NULL, 'L.f.', 184),
(282, 'Marila', NULL, 'Sw.', 42),
(283, 'Matayba', NULL, 'Aubl.', 147),
(284, 'Matisia', NULL, 'Bonpl.', 102),
(285, 'Mayna', NULL, 'Aubl.', 198),
(286, 'Maytenus', NULL, 'Molina', 38),
(287, 'Melicoccus', NULL, 'P.Browne', 147),
(288, 'Meliosma', NULL, 'Blume', 144),
(289, 'Miconia', NULL, 'Ruiz & Pav.', 105),
(290, 'Micropholis', NULL, '(Griseb.) Pierre', 148),
(291, 'Mimosa', NULL, 'L.', 70),
(292, 'Mimusops', NULL, 'L.', 148),
(293, 'Minquartia', NULL, 'Aubl.', 119),
(294, 'Mollinedia', NULL, 'Ruiz & Pav.', 108),
(295, 'Morella', NULL, 'Lour.', 113),
(296, 'Morinda', NULL, 'L.', 142),
(297, 'Morisonia', NULL, 'L.', 32),
(298, 'Mortoniodendron', NULL, 'Standl. & Steyerm.', 102),
(299, 'Mosannona', NULL, 'Chatrou', 8),
(300, 'Mosquitoxylum', NULL, 'Krug & Urb.', 6),
(301, 'Mouriri', NULL, 'Aubl.', 105),
(302, 'Muntingia', NULL, 'L.', 102),
(303, 'Myrcia', NULL, 'DC. ex Guill.', 116),
(304, 'Myrciaria', NULL, 'O.Berg', 116),
(305, 'Myriocarpa', NULL, 'Benth.', 171),
(306, 'Myrospermum', NULL, 'Jacq.', 71),
(307, 'Myroxylon', NULL, 'L.f.', 71),
(308, 'Myrsine', NULL, 'L.', 115),
(309, 'Naucleopsis', NULL, 'Miq.', 109),
(310, 'Nectandra', NULL, 'Rol. ex Rottb.', 91),
(311, 'Neea', NULL, 'Ruiz & Pav.', 117),
(312, 'Ochroma', NULL, 'Sw.', 102),
(313, 'Ocotea', NULL, 'Aubl.', 91),
(314, 'Oenocarpus', NULL, 'Mart.', 15),
(315, 'Opuntia', NULL, 'Mill.', 29),
(316, 'Oreopanax', NULL, 'Decne. & Planch.', 13),
(317, 'Ormosia', NULL, 'Jacks.', 71),
(318, 'Ossaea', NULL, 'DC.', 105),
(319, 'Osteophloeum', NULL, 'Warb.', 114),
(320, 'Otoba', NULL, '(DC.) H.Karst.', 114),
(321, 'Ouratea', NULL, 'Aubl.', 118),
(322, 'Oxandra', NULL, 'A.Rich.', 8),
(323, 'Pachira', NULL, 'Aubl.', 102),
(324, 'Palicourea', NULL, 'Aubl.', 142),
(325, 'Panopsis', NULL, 'Salisb. ex Knight', 135),
(326, 'Parathesis', NULL, '(A.DC.) Hook.f.', 115),
(327, 'Parinari', NULL, 'Aubl.', 40),
(328, 'Parkia', NULL, 'R.Br.', 70),
(329, 'Parkinsonia', NULL, 'L.', 69),
(330, 'Parmentiera', NULL, 'Raf.(SUH)', 22),
(331, 'Pavonia', NULL, 'Cav.', 102),
(332, 'Pelliciera', NULL, 'Planch. & Triana ex Benth.', 530),
(333, 'Peltophorum', NULL, '(Vogel) Benth.', 69),
(334, 'Pentagonia', NULL, 'Fabr.(SUH)', 142),
(335, 'Pera', NULL, 'Mutis', 66),
(336, 'Perebea', NULL, 'Aubl.', 109),
(337, 'Pereskia', NULL, 'Mill.', 29),
(338, 'Persea', NULL, 'Mill.', 91),
(339, 'Phoebe', NULL, 'Nees', 91),
(340, 'Photinia', NULL, 'Lindl.', 141),
(341, 'Phyllanthus', NULL, 'L.', 184),
(342, 'Phytelephas', NULL, 'Ruiz & Pav.', 15),
(343, 'Piper', NULL, 'L.', 130),
(344, 'Pithecellobium', NULL, 'Mart.', 70),
(345, 'Pittoniotis', NULL, 'Griseb.', 142),
(346, 'Platymiscium', NULL, 'Vogel', 71),
(347, 'Platypodium', NULL, 'Vogel', 71),
(348, 'Pleuranthodendron', NULL, 'L.O.Williams', 145),
(349, 'Pleurothyrium', NULL, 'Nees', 91),
(350, 'Plinia', NULL, 'L.', 116),
(351, 'Plumeria', NULL, 'L.', 10),
(352, 'Podocarpus', NULL, 'L''Her. ex Pers.', 132),
(353, 'Pogonopus', NULL, 'Klotzsch', 142),
(354, 'Pollalesta', NULL, 'Kunth', 18),
(355, 'Posoqueria', NULL, 'Aubl.', 142),
(356, 'Potalia', NULL, 'Aubl.', 75),
(357, 'Poulsenia', NULL, 'Eggers', 109),
(358, 'Pourouma', NULL, 'Aubl.', 171),
(359, 'Pouteria', NULL, 'Aubl.', 148),
(360, 'Prestoea', NULL, 'Hook.f.', 15),
(361, 'Prioria', NULL, 'Griseb.', 69),
(362, 'Prockia', NULL, 'P.Browne ex L.', 145),
(363, 'Prosopis', NULL, 'L.', 70),
(364, 'Protium', NULL, 'Burm.f.', 27),
(365, 'Pseudima', NULL, 'Radlk.', 147),
(366, 'Pseudobombax', NULL, 'Dugand', 102),
(367, 'Pseudolmedia', NULL, 'Trecul', 109),
(368, 'Pseudosamanea', NULL, 'Harms', 70),
(369, 'Psidium', NULL, 'L.', 116),
(370, 'Psychotria', NULL, 'L.', 142),
(371, 'Pterocarpus', NULL, 'Jacq.', 71),
(372, 'Qualea', NULL, 'Aubl.', 175),
(373, 'Quararibea', NULL, 'Aubl.', 102),
(374, 'Quassia', NULL, 'L.', 151),
(375, 'Quetzalia', NULL, 'Lundell', 38),
(376, 'Quiina', NULL, 'Aubl.', 137),
(377, 'Randia', NULL, 'L.', 142),
(378, 'Raphia', NULL, 'P.Beauv.', 15),
(379, 'Raritebe', NULL, 'Wernham', 142),
(380, 'Rauvolfia', NULL, 'L.', 10),
(381, 'Rhizophora', NULL, 'L.', 140),
(382, 'Rinorea', NULL, 'Aubl.', 174),
(383, 'Rollinia', NULL, 'A.St.-Hil.', 8),
(384, 'Rondeletia', NULL, 'L.', 142),
(385, 'Rosenbergiodendron', NULL, 'Fagerl.', 142),
(386, 'Roupala', NULL, 'Aubl.', 135),
(387, 'Roystonea', NULL, 'O.F.Cook', 15),
(388, 'Rudgea', NULL, 'Salisb.', 142),
(389, 'Ruprechtia', NULL, 'C.A.Mey.', 134),
(390, 'Ruptiliocarpon', NULL, 'Hammel & N. Zamora', 93),
(391, 'Ryania', NULL, 'Vahl', 145),
(392, 'Sacoglottis', NULL, 'Mart.', 83),
(393, 'Salacia', NULL, 'L.', 38),
(394, 'Samanea', NULL, '(DC.) Merr.', 70),
(395, 'Sapindus', NULL, 'L.', 147),
(396, 'Sapium', NULL, 'P.Browne', 66),
(397, 'Sarcaulus', NULL, 'Radlk.', 148),
(398, 'Saurauia', NULL, 'Willd.', 2),
(399, 'Schefflera', NULL, 'J.R.Forst. & G.Forst.', 13),
(400, 'Schizolobium', NULL, 'Vogel', 69),
(401, 'Schoenobiblus', NULL, 'Mart.', 164),
(402, 'Sciadodendron', NULL, 'Griseb.', 13),
(403, 'Sclerolobium', NULL, 'Vogel', 69),
(404, 'Senna', NULL, 'Mill.', 69),
(405, 'Sideroxylon', NULL, 'L.', 148),
(406, 'Simaba', NULL, 'Aubl.', 151),
(407, 'Simarouba', NULL, 'Aubl.', 151),
(408, 'Siparuna', NULL, 'Aubl.', 152),
(409, 'Sloanea', NULL, 'L.', 62),
(410, 'Socratea', NULL, 'H.Karst.', 15),
(411, 'Solanum', NULL, 'L.', 154),
(412, 'Sorocea', NULL, 'A.St.-Hil.', 109),
(413, 'Spachea', NULL, 'A.Juss.', 101),
(414, 'Spathodea', NULL, 'P.Beauv.', 22),
(415, 'Spondias', NULL, 'L.', 6),
(416, 'Stachyarrhena', NULL, 'Hook.f.', 142),
(417, 'Stauranthus', NULL, 'Liebm.', 143),
(418, 'Stemmadenia', NULL, 'Benth.', 10),
(419, 'Sterculia', NULL, 'L.', 102),
(420, 'Strychnos', NULL, 'L.', 97),
(421, 'Stylogyne', NULL, 'A.DC.', 115),
(422, 'Swartzia', NULL, 'Schreb.', 71),
(423, 'Swietenia', NULL, 'Jacq.', 106),
(424, 'Symphonia', NULL, 'L.f.', 42),
(425, 'Symplocos', NULL, 'Jacq.', 159),
(426, 'Synechanthus', NULL, 'H.Wendl.', 15),
(427, 'Syzygium', NULL, 'Gaertn.', 116),
(428, 'Tabebuia', NULL, 'Gomes ex DC.', 22),
(429, 'Tabernaemontana', NULL, 'L.', 10),
(430, 'Tachigali', NULL, 'Aubl.', 69),
(431, 'Talauma', NULL, 'Juss.', 100),
(432, 'Talipariti', NULL, 'Fryxell', 102),
(433, 'Talisia', NULL, 'Aubl.', 147),
(434, 'Tapirira', NULL, 'Aubl.', 6),
(435, 'Tapura', NULL, 'Aubl.', 57),
(436, 'Tecoma', NULL, 'Juss.', 22),
(437, 'Tectona', NULL, 'L.f.', 90),
(438, 'Terminalia', NULL, 'L.', 44),
(439, 'Ternstroemia', NULL, 'Mutis ex L.f.', 409),
(440, 'Tetragastris', NULL, 'Gaertn.', 27),
(441, 'Tetrathylacium', NULL, 'Poepp.', 145),
(442, 'Tetrorchidium', NULL, 'Poepp.', 66),
(443, 'Theobroma', NULL, 'L.', 102),
(444, 'Thevetia', NULL, 'L.', 10),
(445, 'Tibouchina', NULL, 'Aubl.', 105),
(446, 'Tococa', NULL, 'Aubl.', 105),
(447, 'Tocoyena', NULL, 'Aubl.', 142),
(448, 'Tovomita', NULL, 'Aubl.', 42),
(449, 'Trattinnickia', NULL, 'Willd.', 27),
(450, 'Trema', NULL, 'Lour.', 253),
(451, 'Trichanthera', NULL, 'Kunth', 1),
(452, 'Trichilia', NULL, 'P.Browne', 106),
(453, 'Trichospermum', NULL, 'Blume', 102),
(454, 'Triplaris', NULL, 'Loefl. ex L.', 134),
(455, 'Triumfetta', NULL, 'L.', 102),
(456, 'Trophis', NULL, 'P.Browne', 109),
(457, 'Turnera', NULL, 'L.', 169),
(458, 'Turpinia', NULL, 'Vent.', 546),
(459, 'Unonopsis', NULL, 'R.E.Fr.', 8),
(460, 'Urera', NULL, 'Gaudich.', 171),
(461, 'Vantanea', NULL, 'Aubl.', 83),
(462, 'Vasconcellea', NULL, 'A. St.-Hil.', 34),
(463, 'Vatairea', NULL, 'Aubl.', 71),
(464, 'Verbesina', NULL, 'L.', 18),
(465, 'Vernonanthura', NULL, 'H. Rob.', 18),
(466, 'Virola', NULL, 'Aubl.', 114),
(467, 'Vismia', NULL, 'Vand.', 42),
(468, 'Vitex', NULL, 'L.', 90),
(469, 'Vochysia', NULL, 'Aubl.', 175),
(470, 'Waltheria', NULL, 'L.', 102),
(471, 'Warszewiczia', NULL, 'Klotzsch', 142),
(472, 'Welfia', NULL, 'H.Wendl.', 15),
(473, 'Wercklea', NULL, 'Pittier & Standl.', 102),
(474, 'Wettinia', NULL, 'Poepp.', 15),
(475, 'Witheringia', NULL, 'L''Her.', 154),
(476, 'Ximenia', NULL, 'L.', 119),
(477, 'Xylopia', NULL, 'L.', 8),
(478, 'Xylosma', NULL, 'G.Forst.', 145),
(479, 'Zamia', NULL, 'L.', 499),
(480, 'Zanthoxylum', NULL, 'L.', 143),
(481, 'Ziziphus', NULL, 'Mill.', 139),
(482, 'Zuelania', NULL, 'A.Rich.', 145),
(483, 'Zygia', NULL, 'P.Browne', 70),
(484, 'Picramnia', NULL, 'Sw.', 533),
(485, 'Tovomitopsis', NULL, 'Planch. & Triana', 42),
(486, 'Cynodendron', NULL, 'Baehni', 148),
(487, 'Chlorophora', NULL, 'Gaudich.', 109),
(488, 'Cnemidaria', NULL, 'C.Presl', 52),
(489, 'Cyphomandra', NULL, 'Mart. ex Sendtn.', 154),
(490, 'Didymopanax', NULL, 'Decne. & Planch.', 13),
(491, 'Hyeronima', NULL, 'Allemao', 66),
(492, 'Lopimia', NULL, 'Mart.', 102),
(493, 'Olmedia', NULL, 'Ruiz & Pav.', 109),
(494, 'Pochota', NULL, 'Ram.Goyena', 24),
(495, 'Rheedia', NULL, 'L.', 42),
(496, 'Scheelea', NULL, 'H.Karst.', 15),
(497, 'Bombacopsis', NULL, 'Pittier', 102),
(498, 'Agonandra', NULL, 'Miers ex Hook.f.', 122),
(499, 'Aiouea', NULL, 'Aubl.', 91),
(500, 'Ricinus', NULL, 'L.', 66),
(501, 'Shorea', NULL, 'Roxb. ex C.F.Gaertn.', 60),
(502, 'Abuta', NULL, 'Aubl.', 107),
(503, 'Acanthosyris', NULL, '(Eichler) Griseb.', 146),
(504, 'Acer', NULL, 'L.', 147),
(505, 'Acronychia', NULL, 'J.R.Forst. & G.Forst.', 143),
(506, 'Actephila', NULL, 'Blume', 184),
(507, 'Adinandra', NULL, 'Jack', 409),
(508, 'Afrostyrax', NULL, 'Perkins & Gilg', 179),
(509, 'Afzelia', NULL, 'Sm.', 69),
(510, 'Aidia', NULL, 'Lour.', 142),
(511, 'Ailanthus', NULL, 'Desf.', 151),
(512, 'Alangium', NULL, 'Lam.', 47),
(513, 'Alchorneopsis', NULL, 'Mull.Arg.', 66),
(514, 'Allanblackia', NULL, 'Oliv. ex Benth.', 42),
(515, 'Allantospermum', NULL, 'Forman', 86),
(516, 'Allexis', NULL, 'Pierre', 174),
(517, 'Alloplectus', NULL, 'Mart.', 76),
(518, 'Alniphyllum', NULL, 'Matsum.', 158),
(519, 'Alphitonia', NULL, 'Reissek ex Endl.', 139),
(520, 'Alphonsea', NULL, 'Hook.f. & Thomson', 8),
(521, 'Alseodaphne', NULL, 'Nees', 91),
(522, 'Alsodeiopsis', NULL, 'Oliv.', 85),
(523, 'Alsophila', NULL, 'R.Br.', 52),
(524, 'Amphimas', NULL, 'Pierre ex Harms', 69),
(525, 'Amyxa', NULL, 'Tiegh.', 164),
(526, 'Anacolosa', NULL, '(Blume) Blume', 119),
(527, 'Androtium', NULL, 'Stapf', 6),
(528, 'Angylocalyx', NULL, 'Taub.', 71),
(529, 'Anisoptera', NULL, 'Korth.', 60),
(530, 'Anisotes', NULL, 'Nees', 1),
(531, 'Annickia', NULL, 'Setten & Maas', 8),
(532, 'Anogeissus', NULL, '(DC.) Wall.', 44),
(533, 'Anonidium', NULL, 'Engl. & Diels', 8),
(534, 'Anopyxis', NULL, '(Pierre) Engl.', 140),
(535, 'Antherostele', NULL, 'Bremek.', 142),
(536, 'Anthocephalus', NULL, 'A.Rich.', 142),
(537, 'Anthocleista', NULL, 'Afzel. ex R.Br.', 75),
(538, 'Anthodiscus', NULL, 'G.Mey.', 35),
(539, 'Anthonotha', NULL, 'P.Beauv.', 69),
(540, 'Antiaris', NULL, 'Lesch.', 109),
(541, 'Antirhea', NULL, 'Comm. ex Juss.', 142),
(542, 'Antrocaryon', NULL, 'Pierre', 6),
(543, 'Aoranthe', NULL, 'Somers', 142),
(544, 'Aparisthmium', NULL, 'Endl.', 66),
(545, 'Aphanamixis', NULL, 'Blume', 106),
(546, 'Aphananthe', NULL, 'Planch.', 170),
(547, 'Apodytes', NULL, 'E.Mey. ex Arn.', 85),
(548, 'Aporrhiza', NULL, 'Radlk.', 147),
(549, 'Aptandra', NULL, 'Miers', 119),
(550, 'Apuleia', NULL, 'Mart.', 68),
(551, 'Aquilaria', NULL, 'Lam.', 164),
(552, 'Aralia', NULL, 'L.', 13),
(553, 'Aralidium', NULL, 'Miq.', 484),
(554, 'Araliopsis', NULL, 'Engl.', 143),
(555, 'Archidendron', NULL, 'F.Muell.', 70),
(556, 'Areca', NULL, 'L.', 15),
(557, 'Arenga', NULL, 'Labill.', 15),
(558, 'Aromadendron', NULL, 'Blume', 100),
(559, 'Arthrophyllum', NULL, 'Bojer ex DC.(SUH)', 13),
(560, 'Arytera', NULL, 'Blume', 147),
(561, 'Astronia', NULL, 'Blume', 105),
(562, 'Atuna', NULL, 'Raf.', 40),
(563, 'Aulacocalyx', NULL, 'Hook.f.', 142),
(564, 'Austrobuxus', NULL, 'Miq.', 534),
(565, 'Autranella', NULL, 'A.Chev.', 148),
(566, 'Axinaea', NULL, 'Ruiz & Pav.', 105),
(567, 'Azadirachta', NULL, 'A.Juss.', 106),
(568, 'Baccaurea', NULL, 'Lour.', 184),
(569, 'Baikiaea', NULL, 'Benth.', 69),
(570, 'Baillonella', NULL, 'Pierre', 148),
(571, 'Balakata', NULL, 'Esser', 66),
(572, 'Baphia', NULL, 'Afzel. ex Lodd.', 71),
(573, 'Barringtonia', NULL, 'J.R.Forst. & G.Forst.', 92),
(574, 'Barteria', NULL, 'Hook.f.', 127),
(575, 'Bathysa', NULL, 'C.Presl', 142),
(576, 'Belonophora', NULL, 'Hook.f.', 142),
(577, 'Berlinia', NULL, 'Sol. ex Hook.f.', 69),
(578, 'Berrya', NULL, 'Roxb.', 102),
(579, 'Bersama', NULL, 'Fresen.', 182),
(580, 'Bischofia', NULL, 'Blume', 184),
(581, 'Blakea', NULL, 'P.Browne', 105),
(582, 'Blastus', NULL, 'Lour.', 105),
(583, 'Blighia', NULL, 'K.D.Koenig', 147),
(584, 'Blumeodendron', NULL, '(Mull.Arg.) Kurz', 66),
(585, 'Boehmeria', NULL, 'Jacq.', 171),
(586, 'Bouea', NULL, 'Meisn.', 6),
(587, 'Brackenridgea', NULL, 'A.Gray', 118),
(588, 'Brenania', NULL, 'Keay', 142),
(589, 'Breviea', NULL, 'Aubrev. & Pellegr.', 148),
(590, 'Breynia', NULL, 'J.R.Forst. & G.Forst.', 184),
(591, 'Brugmansia', NULL, 'Blume(SUH)', 154),
(592, 'Brunellia', NULL, 'Ruiz & Pav.', 26),
(593, 'Buchanania', NULL, 'Spreng.', 6),
(594, 'Butea', NULL, 'Roxb. ex Willd.', 68),
(595, 'Cabralea', NULL, 'A.Juss.', 106),
(596, 'Caloncoba', NULL, 'Gilg', 198),
(597, 'Calycogonium', NULL, 'DC.', 105),
(598, 'Calycosiphonia', NULL, 'Pierre ex Robbr.', 142),
(599, 'Camellia', NULL, 'L.', 162),
(600, 'Campomanesia', NULL, 'Ruiz & Pav.', 116),
(601, 'Campylospermum', NULL, 'Tiegh.', 118),
(602, 'Cananga', NULL, 'Aubl.(SUH)', 8),
(603, 'Cantleya', NULL, 'Ridl.', 545),
(604, 'Capirona', NULL, 'Spruce', 142),
(605, 'Caraipa', NULL, 'Aubl.', 42),
(606, 'Careya', NULL, 'Roxb.', 92),
(607, 'Carpolobia', NULL, 'G.Don', 133),
(608, 'Carpotroche', NULL, 'Endl.', 198),
(609, 'Caryocar', NULL, 'L.', 35),
(610, 'Caryodendron', NULL, 'H.Karst.', 66),
(611, 'Cassine', NULL, 'L.', 38),
(612, 'Castanopsis', NULL, '(D.Don) Spach', 72),
(613, 'Cathedra', NULL, 'Miers', 119),
(614, 'Cedrelinga', NULL, 'Ducke', 68),
(615, 'Centronia', NULL, 'D.Don', 105),
(616, 'Cephaelis', NULL, 'Sw.', 142),
(617, 'Cephalomappa', NULL, 'Baill.', 66),
(618, 'Champereia', NULL, 'Griff.', 122),
(619, 'Chassalia', NULL, 'Comm. ex Poir.', 142),
(621, 'Cheilosa', NULL, 'Blume', 66),
(622, 'Chione', NULL, 'DC.', 142),
(623, 'Chisocheton', NULL, 'Blume', 106),
(624, 'Chloranthus', NULL, 'Sw.', 39),
(625, 'Chlorocardium', NULL, 'Rohwer, H.G.Richt. & van der Wer', 91),
(626, 'Chukrasia', NULL, 'A.Juss.', 106),
(627, 'Chytranthus', NULL, 'Hook.f.', 147),
(628, 'Cinchona', NULL, 'L.', 142),
(629, 'Citropsis', NULL, '(Engl.) Swingle & M.Kellerm.', 143),
(630, 'Cladogynos', NULL, 'Zipp. ex Span.', 66),
(631, 'Claoxylon', NULL, 'A.Juss.', 66),
(632, 'Clausena', NULL, 'Burm.f.', 143),
(633, 'Cleidion', NULL, 'Blume', 66),
(634, 'Cleistocalyx', NULL, 'Blume', 116),
(635, 'Cleistopholis', NULL, 'Pierre ex Engl.', 8),
(636, 'Cleyera', NULL, 'Thunb.', 409),
(637, 'Codiaeum', NULL, 'A.Juss.', 66),
(638, 'Coelocaryon', NULL, 'Warb.', 114),
(639, 'Coelostegia', NULL, 'Benth.', 102),
(640, 'Coffea', NULL, 'L.', 142),
(641, 'Cola', NULL, 'Schott & Endl.', 102),
(642, 'Colona', NULL, 'Cav.', 102),
(643, 'Comiphyton', NULL, 'Floret', 140),
(644, 'Comocladia', NULL, 'P.Browne', 6),
(645, 'Cotylelobium', NULL, 'Pierre', 60),
(646, 'Coula', NULL, 'Baill.', 514),
(647, 'Coussapoa', NULL, 'Aubl.', 171),
(648, 'Craibia', NULL, 'Harms & Dunn', 68),
(649, 'Crateranthus', NULL, 'Baker f.', 92),
(650, 'Craterispermum', NULL, 'Benth.', 142),
(651, 'Cratoxylum', NULL, 'Blume', 42),
(652, 'Crepidospermum', NULL, 'Hook.f.', 27),
(653, 'Critoniopsis', NULL, 'Sch.Bip.', 18),
(654, 'Crotalaria', NULL, 'L.', 68),
(655, 'Crotonogyne', NULL, 'Mull.Arg.', 66),
(656, 'Crotonogynopsis', NULL, 'Pax', 66),
(657, 'Crypteronia', NULL, 'Blume', 186),
(658, 'Ctenolophon', NULL, 'Oliv.', 510),
(659, 'Cuatresia', NULL, 'Hunz.', 154),
(660, 'Cuviera', NULL, 'Koeler(SUH)', 142),
(661, 'Cyathocalyx', NULL, 'Champ. ex Hook.f. & Thomson', 8),
(662, 'Cyclobalanopsis', NULL, 'Oerst.', 72),
(663, 'Cyrtandra', NULL, 'J.R.Forst. & G.Forst.', 76),
(664, 'Dacryodes', NULL, 'Vahl', 27),
(665, 'Dactyladenia', NULL, 'Welw.', 40),
(666, 'Daphniphyllum', NULL, 'Blume', 195),
(667, 'Dasylepis', NULL, 'Oliv.', 198),
(668, 'Dasymaschalon', NULL, '(Hook.f. & Thomson) Dalla Torre', 8),
(669, 'Debregeasia', NULL, 'Gaudich.', 171),
(670, 'Decaspermum', NULL, 'J.R.Forst. & G.Forst.', 116),
(671, 'Dehaasia', NULL, 'Blume', 91),
(672, 'Deinbollia', NULL, 'Schumach. & Thonn.', 147),
(673, 'Dendrobangia', NULL, 'Rusby', 255),
(674, 'Dendrocnide', NULL, 'Miq.', 171),
(675, 'Dendrokingstonia', NULL, 'Rauschert', 8),
(676, 'Dendrophorbium', NULL, '(Cuatrec.) C. Jeffrey', 18),
(677, 'Deplanchea', NULL, 'Vieill.', 22),
(678, 'Deprea', NULL, 'Raf.', 154),
(679, 'Actinodaphne', NULL, 'Nees', 91),
(680, 'Adenanthera', NULL, 'L.', 70),
(681, 'Aglaia', NULL, 'Lour.', 106),
(682, 'Agrostistachys', NULL, 'Dalzell', 66),
(683, 'Alstonia', NULL, 'R.Br.', 10),
(684, 'Anisophyllea', NULL, 'R.Br. ex Sabine', 7),
(685, 'Antidesma', NULL, 'L.', 184),
(686, 'Aporosa', NULL, 'Blume', 184),
(687, 'Axinandra', NULL, 'Thwaites', 186),
(688, 'Bhesa', NULL, 'Buch.-Ham. ex Arn.', 38),
(689, 'Bombax', NULL, 'L.', 102),
(690, 'Bridelia', NULL, 'Willd.', 184),
(691, 'Byrsophyllum', NULL, 'Hook.f.', 142),
(692, 'Canarium', NULL, 'L.', 27),
(693, 'Canthium', NULL, 'Lam.', 142),
(694, 'Carallia', NULL, 'Roxb.', 140),
(695, 'Caryota', NULL, 'L.', 15),
(696, 'Chaetocarpus', NULL, 'Schreb.(SUH)', 66),
(697, 'Cleistanthus', NULL, 'Hook.f. ex Planch.', 184),
(698, 'Clerodendrum', NULL, 'L.', 90),
(699, 'Desmos', NULL, 'Lour.', 8),
(700, 'Dillenia', NULL, 'Heist. ex Fabr.(SUH)', 58),
(701, 'Dipterocarpus', NULL, 'C.F.Gaertn.', 60),
(702, 'Durio', NULL, 'Adans.', 102),
(703, 'Dysoxylum', NULL, 'Blume', 106),
(704, 'Elaeocarpus', NULL, 'L.', 62),
(705, 'Euonymus', NULL, 'L.', 38),
(706, 'Eurya', NULL, 'Thunb.', 409),
(707, 'Fagraea', NULL, 'Thunb.', 75),
(708, 'Filicium', NULL, 'Thwaites ex Benth.', 147),
(709, 'Glenniea', NULL, 'Hook.f.', 147),
(710, 'Glochidion', NULL, 'J.R.Forst. & G.Forst.', 184),
(711, 'Glycosmis', NULL, 'Correa', 143),
(712, 'Gomphandra', NULL, 'Wall. ex Lindl.', 545),
(713, 'Goniothalamus', NULL, '(Blume) Hook.f. & Thomson', 8),
(714, 'Gyrinops', NULL, 'Gaertn.', 164),
(715, 'Hiptage', NULL, 'Gaertn.', 101),
(716, 'Hopea', NULL, 'Roxb.', 60),
(717, 'Horsfieldia', NULL, 'Willd.', 114),
(718, 'Humboldtia', NULL, 'Vahl', 68),
(719, 'Hydnocarpus', NULL, 'Gaertn.', 198),
(720, 'Isonandra', NULL, 'Wight', 148),
(721, 'Kokoona', NULL, 'Thwaites', 38),
(722, 'Lasianthus', NULL, 'Jack', 142),
(723, 'Leea', NULL, 'L.', 181),
(724, 'Lijndenia', NULL, 'Zoll. & Moritzi', 105),
(725, 'Litchi', NULL, 'Sonn.', 147),
(726, 'Litsea', NULL, 'Lam.', 91),
(727, 'Loeseneriella', NULL, 'A.C.Sm.', 38),
(728, 'Macaranga', NULL, 'Thouars', 66),
(729, 'Madhuca', NULL, 'Ham. ex J.F.Gmel.', 148),
(730, 'Maesa', NULL, 'Forssk.', 522),
(731, 'Mallotus', NULL, 'Lour.', 66),
(732, 'Mastixia', NULL, 'Blume', 528),
(733, 'Melastoma', NULL, 'L.', 105),
(734, 'Memecylon', NULL, 'L.', 105),
(735, 'Mesua', NULL, 'L.', 42),
(736, 'Microtropis', NULL, 'Wall. ex Meisn.', 38),
(737, 'Myristica', NULL, 'Gronov.', 114),
(738, 'Nargedia', NULL, 'Bedd.', 142),
(739, 'Neolitsea', NULL, '(Benth.) Merr.', 91),
(740, 'Nothapodytes', NULL, 'Blume', 85),
(741, 'Nothopegia', NULL, 'Blume', 6),
(742, 'Osmelia', NULL, 'Thwaites', 145),
(743, 'Palaquium', NULL, 'Blanco', 148),
(744, 'Pavetta', NULL, 'L.', 142),
(745, 'Podadenia', NULL, 'Thwaites', 66),
(746, 'Pometia', NULL, 'J.R.Forst. & G.Forst.', 147),
(747, 'Prismatomeris', NULL, 'Thwaites', 142),
(748, 'Prunus', NULL, 'L.', 141),
(749, 'Schumacheria', NULL, 'Vahl', 58),
(750, 'Scolopia', NULL, 'Schreb.', 145),
(751, 'Semecarpus', NULL, 'L.f.', 6),
(752, 'Stemonoporus', NULL, 'Thwaites', 60),
(753, 'Strombosia', NULL, 'Blume', 514),
(754, 'Thottea', NULL, 'Rottb.', 16),
(755, 'Timonius', NULL, 'DC.', 142),
(756, 'Tricalysia', NULL, 'A.Rich. ex DC.', 142),
(757, 'Urandra', NULL, 'Thwaites', 85),
(758, 'Urophyllum', NULL, 'Wall.', 142),
(759, 'Walsura', NULL, 'Roxb.', 106),
(760, 'Wendlandia', NULL, 'Bartl. ex DC.', 142),
(761, 'Derris', NULL, 'Lour.', 71),
(762, 'Desbordesia', NULL, 'Pierre ex Tiegh.', 183),
(763, 'Desplatsia', NULL, 'Bocq.', 102),
(764, 'Dichaetanthera', NULL, 'Endl.', 105),
(765, 'Dichostemma', NULL, 'Pierre', 66),
(766, 'Dicksonia', NULL, 'L''Her.', 283),
(767, 'Dicranolepis', NULL, 'Planch.', 164),
(768, 'Dictyandra', NULL, 'Welw. ex Hook.f.', 142),
(769, 'Dictyoneura', NULL, 'Blume', 147),
(770, 'Didymosalpinx', NULL, 'Keay', 142),
(771, 'Dilkea', NULL, 'Mast.', 127),
(772, 'Dimocarpus', NULL, 'Lour.', 147),
(773, 'Dimorphocalyx', NULL, 'Thwaites', 66),
(774, 'Dinophora', NULL, 'Benth.', 105),
(775, 'Diogoa', NULL, 'Exell & Mendonca', 119),
(776, 'Diplodiscus', NULL, 'Turcz.', 102),
(777, 'Diploknema', NULL, 'Pierre', 148),
(778, 'Diploon', NULL, 'Cronquist', 148),
(779, 'Diplospora', NULL, 'DC.', 142),
(780, 'Discocalyx', NULL, '(A.DC.) Mez', 115),
(781, 'Discoclaoxylon', NULL, '(Mull.Arg.) Pax & K.Hoffm.', 66),
(782, 'Discoglypremna', NULL, 'Prain', 66),
(783, 'Discospermum', NULL, 'Dalzell', 142),
(784, 'Ditta', NULL, 'Griseb.', 66),
(785, 'Dorstenia', NULL, 'L.', 109),
(786, 'Dovyalis', NULL, 'E.Mey. ex Arn.', 145),
(787, 'Dracaena', NULL, 'Vand. ex L.', 94),
(788, 'Dracontium', NULL, 'L.', 12),
(789, 'Dracontomelon', NULL, 'Blume', 6),
(790, 'Drimycarpus', NULL, 'Hook.f.', 6),
(791, 'Dryobalanops', NULL, 'C.F.Gaertn.', 60),
(792, 'Duabanga', NULL, 'Buch.-Ham.', 99),
(793, 'Duboscia', NULL, 'Bocquet', 102),
(794, 'Dulacia', NULL, 'Vell.', 119),
(795, 'Duroia', NULL, 'L.f.', 142),
(796, 'Dyera', NULL, 'Hook.f.', 10),
(797, 'Ehretia', NULL, 'P.Browne', 25),
(798, 'Elaeophorbia', NULL, 'Stapf', 66),
(799, 'Elateriospermum', NULL, 'Blume', 66),
(800, 'Ellipanthus', NULL, 'Hook.f.', 45),
(801, 'Emblica', NULL, 'Gaertn.', 66),
(802, 'Endiandra', NULL, 'R.Br.', 91),
(803, 'Endocomia', NULL, 'W.J.de Wilde', 114),
(804, 'Endodesmia', NULL, 'Benth.', 42),
(805, 'Endospermum', NULL, 'Benth.', 66),
(806, 'Engelhardia', NULL, 'Lesch. ex Blume', 87),
(807, 'Englerophytum', NULL, 'K.Krause', 148),
(808, 'Engomegoma', NULL, 'Breteler', 119),
(809, 'Enicosanthum', NULL, 'Becc.', 8),
(810, 'Entandrophragma', NULL, 'C.E.C.Fisch.', 106),
(811, 'Epiprinus', NULL, 'Griff.', 66),
(812, 'Erato', NULL, 'DC.', 18),
(813, 'Eriobotrya', NULL, 'Lindl.', 141),
(814, 'Eriocoelum', NULL, 'Hook.f.', 147),
(815, 'Eriolaena', NULL, 'DC.', 102),
(816, 'Eriotheca', NULL, 'Schott & Endl.', 102),
(817, 'Erismadelphus', NULL, 'Mildbr.', 175),
(818, 'Erycibe', NULL, 'Roxb.', 46),
(819, 'Erythrochiton', NULL, 'Nees & Mart.', 143),
(820, 'Erythrococca', NULL, 'Benth.', 66),
(821, 'Erythrophleum', NULL, 'Afzel. ex G.Don', 69),
(822, 'Euadenia', NULL, 'Oliv.', 32),
(823, 'Euclinia', NULL, 'Salisb.', 142),
(824, 'Euodia', NULL, 'J.R.Forst. & G.Forst.', 143),
(825, 'Euplassa', NULL, 'Salisb. ex Knight', 135),
(826, 'Eurycoma', NULL, 'Jack', 151),
(827, 'Eurypetalum', NULL, 'Harms', 69),
(828, 'Eusideroxylon', NULL, 'Teijsm. & Binn.', 91),
(829, 'Fagara', NULL, 'L.', 143),
(830, 'Fagerlindia', NULL, 'Tirveng.', 142),
(831, 'Fahrenheitia', NULL, 'Rchb.f. & Zoll.', 66),
(832, 'Fernandoa', NULL, 'Welw. ex Seem.', 22),
(833, 'Firmiana', NULL, 'Marsili', 102),
(834, 'Flacourtia', NULL, 'Comm. ex L''Her.', 145),
(835, 'Fordia', NULL, 'Hemsl.', 68),
(836, 'Fraxinus', NULL, 'L.', 120),
(837, 'Froesia', NULL, 'Pires', 137),
(838, 'Fuchsia', NULL, 'Sw.(SUH)', 121),
(839, 'Funtumia', NULL, 'Stapf', 10),
(840, 'Gaertnera', NULL, 'Retz.(SUH)', 142),
(841, 'Galearia', NULL, 'Zoll. & Moritzi', 180),
(842, 'Ganua', NULL, 'Pierre ex Dubard', 148),
(843, 'Gardenia', NULL, 'Ellis', 142),
(844, 'Gardeniopsis', NULL, 'Miq.', 142),
(845, 'Garuga', NULL, 'Roxb.', 27),
(846, 'Gasteranthus', NULL, 'Benth.', 76),
(847, 'Geissanthus', NULL, 'Hook.f.', 115),
(848, 'Gilbertiodendron', NULL, 'J.Leonard', 69),
(849, 'Gironniera', NULL, 'Gaudich.', 253),
(850, 'Glossocalyx', NULL, 'Benth.', 152),
(851, 'Gluta', NULL, 'L.', 6),
(852, 'Glycydendron', NULL, 'Ducke', 66),
(853, 'Glyphaea', NULL, 'Hook.f.', 102),
(854, 'Glyptopetalum', NULL, 'Thwaites', 38),
(855, 'Gnetum', NULL, 'L.', 77),
(856, 'Gomphia', NULL, 'Schreb.', 118),
(857, 'Gonocaryum', NULL, 'Miq.', 255),
(858, 'Gonystylus', NULL, 'Teijsm. & Binn.', 164),
(859, 'Greenea', NULL, 'Wight & Arn.', 142),
(860, 'Greenwayodendron', NULL, 'Verdc.', 8),
(861, 'Grewia', NULL, 'L.', 102),
(862, 'Guioa', NULL, 'Cav.', 147),
(863, 'Gymnacranthera', NULL, 'Warb.', 114),
(864, 'Gymnosporia', NULL, '(Wight & Arn.) Hook.f.', 38),
(865, 'Gynotroches', NULL, 'Blume', 140),
(866, 'Hallea', NULL, 'J.-F.Leroy', 142),
(867, 'Hannoa', NULL, 'Planch.', 151),
(868, 'Haplostichanthus', NULL, 'F.Muell.', 8),
(869, 'Harmandia', NULL, 'Pierre ex Baill.', 119),
(870, 'Harpullia', NULL, 'Roxb.', 147),
(871, 'Heckeldora', NULL, 'Pierre', 106),
(872, 'Hedyotis', NULL, 'L.', 142),
(873, 'Heinsia', NULL, 'DC.', 142),
(874, 'Helicia', NULL, 'Pers.(SUH)', 135),
(875, 'Heliciopsis', NULL, 'Sleumer', 135),
(876, 'Heritiera', NULL, 'Aiton', 102),
(877, 'Heynea', NULL, 'Roxb. ex Sims', 106),
(878, 'Hibiscus', NULL, 'L.', 102),
(879, 'Hillia', NULL, 'Jacq.', 142),
(880, 'Himatanthus', NULL, 'Willd. ex Schult.', 10),
(881, 'Holoptelea', NULL, 'Planch.', 170),
(882, 'Homalanthus', NULL, 'A.Juss.', 66),
(883, 'Hoplestigma', NULL, 'Pierre', 196),
(884, 'Huertea', NULL, 'Ruiz & Pav.', 155),
(885, 'Hunteria', NULL, 'Roxb.', 10),
(886, 'Hydrangea', NULL, 'L.', 341),
(887, 'Hylodendron', NULL, 'Taub.', 69),
(888, 'Hymenocardia', NULL, 'Wall. ex Lindl.', 184),
(889, 'Hymenodictyon', NULL, 'Wall.', 142),
(890, 'Hymenostegia', NULL, '(Benth.) Harms', 69),
(891, 'Hyospathe', NULL, 'Mart.', 15),
(892, 'Hypobathrum', NULL, 'Blume', 142),
(894, 'Hypodaphnis', NULL, 'Stapf', 91),
(895, 'Hyptianthera', NULL, 'Wight & Arn.', 142),
(896, 'Iguanura', NULL, 'Blume', 15),
(897, 'Indigofera', NULL, 'L.', 68),
(898, 'Intsia', NULL, 'Thouars', 68),
(899, 'Irvingia', NULL, 'Hook.f.', 183),
(900, 'Isolona', NULL, 'Engl.', 8),
(901, 'Itea', NULL, 'L.', 351),
(902, 'Ixonanthes', NULL, 'Jack', 86),
(903, 'Jackiopsis', NULL, 'Ridsdale', 142),
(904, 'Jollydora', NULL, 'Pierre ex Gilg', 45),
(905, 'Julbernardia', NULL, 'Pellegr.', 68),
(906, 'Justicia', NULL, 'L.', 1),
(907, 'Kayea', NULL, 'Wall.', 42),
(908, 'Keayodendron', NULL, 'Leandri', 184),
(909, 'Khaya', NULL, 'A.Juss.', 106),
(910, 'Kibara', NULL, 'Endl.', 108),
(911, 'Kibatalia', NULL, 'G.Don', 10),
(912, 'Kingstonia', NULL, 'Hook.f. & Thomson', 8),
(913, 'Klaineanthus', NULL, 'Pierre ex Prain', 66),
(914, 'Klainedoxa', NULL, 'Pierre ex Engl.', 183),
(915, 'Knema', NULL, 'Lour.', 114),
(916, 'Koilodepas', NULL, 'Hassk.', 66),
(917, 'Koompassia', NULL, 'Maingay', 69),
(918, 'Kopsia', NULL, 'Blume', 10),
(919, 'Kostermanthus', NULL, 'Prance', 40),
(920, 'Kotchubaea', NULL, 'Hook.f.(SUO)', 142),
(921, 'Kydia', NULL, 'Roxb.', 102),
(922, 'Laccodiscus', NULL, 'Radlk.', 147),
(923, 'Lacunaria', NULL, 'Ducke', 137),
(924, 'Lannea', NULL, 'A.Rich.', 6),
(925, 'Lansium', NULL, 'Correa', 106),
(926, 'Lasianthera', NULL, 'P.Beauv.', 545),
(927, 'Lasiodiscus', NULL, 'Hook.f.', 139),
(928, 'Lecaniodiscus', NULL, 'Planch. ex Benth.', 147),
(929, 'Lecomtedoxa', NULL, '(Pierre ex Engl.) Dubard', 148),
(930, 'Lepidobotrys', NULL, 'Engl.', 93),
(931, 'Lepisanthes', NULL, 'Blume', 147),
(932, 'Leptaulus', NULL, 'Benth.', 255),
(933, 'Leptonychia', NULL, 'Turcz.', 102),
(934, 'Leucosyke', NULL, 'Zoll. & Moritzi', 171),
(935, 'Limlia', NULL, 'Masamune & Tomiya', 72),
(936, 'Lindera', NULL, 'Thunb.', 91),
(937, 'Linociera', NULL, 'Sw. ex Schreb.', 120),
(938, 'Lithocarpus', NULL, 'Blume', 72),
(939, 'Lophira', NULL, 'Banks ex C.F.Gaertn.', 118),
(940, 'Lophopetalum', NULL, 'Wight ex Arn.', 38),
(941, 'Loreya', NULL, 'DC.', 105),
(942, 'Lovoa', NULL, 'Harms', 106),
(943, 'Lychnodiscus', NULL, 'Radlk.', 147),
(944, 'Machilus', NULL, 'Nees', 91),
(945, 'Maclurodendron', NULL, 'T.G.Hartley', 143),
(946, 'Macrocarpaea', NULL, 'Gilg', 75),
(947, 'Maesobotrya', NULL, 'Benth.', 184),
(948, 'Maesopsis', NULL, 'Engl.', 139),
(949, 'Magnistipula', NULL, 'Engl.', 40),
(950, 'Magnolia', NULL, 'L.', 100),
(951, 'Majidea', NULL, 'J.Kirk ex Oliv.', 147),
(952, 'Mareya', NULL, 'Baill.', 66),
(953, 'Mareyopsis', NULL, 'Pax & K.Hoffm.', 66),
(954, 'Markea', NULL, 'Rich.', 154),
(955, 'Markhamia', NULL, 'Seem. ex Baill.', 22),
(956, 'Marmaroxylon', NULL, 'Killip', 68),
(957, 'Marsypopetalum', NULL, 'Scheff.', 8),
(958, 'Massularia', NULL, '(K.Schum.) Hoyle', 142),
(959, 'Matthaea', NULL, 'Blume', 108),
(960, 'Medusanthera', NULL, 'Seem.', 545),
(961, 'Meiogyne', NULL, 'Miq.', 8),
(962, 'Melanochyla', NULL, 'Hook.f.', 6),
(963, 'Melanolepis', NULL, 'Rchb.f. & Zoll.', 66),
(964, 'Melia', NULL, 'L.', 106),
(965, 'Melicope', NULL, 'J.R.Forst. & G.Forst.', 143),
(966, 'Melientha', NULL, 'Pierre', 122),
(967, 'Memora', NULL, 'Miers', 22),
(968, 'Meriania', NULL, 'Sw.', 105),
(969, 'Metadina', NULL, 'Bakh.f.', 142),
(970, 'Meyna', NULL, 'Roxb. ex Link', 142),
(971, 'Mezilaurus', NULL, 'Kuntze ex Taub.', 91),
(972, 'Mezzettia', NULL, 'Becc.', 8),
(973, 'Michelia', NULL, 'L.', 100),
(974, 'Microcos', NULL, 'L.', 102),
(975, 'Microdesmis', NULL, 'Hook.f. ex Hook.', 180),
(976, 'Micromelum', NULL, 'Blume', 143),
(977, 'Micropora', NULL, 'Hook.f.', 91),
(978, 'Milicia', NULL, 'Sim', 109),
(979, 'Miliusa', NULL, 'Lesch. ex A.DC.', 8),
(980, 'Millettia', NULL, 'Wight & Arn.', 71),
(981, 'Mischocarpus', NULL, 'Blume', 147),
(982, 'Mitragyna', NULL, 'Korth.', 142),
(983, 'Mitrephora', NULL, '(Blume) Hook.f. & Thomson', 8),
(984, 'Mollia', NULL, 'Mart.', 102),
(985, 'Monocarpia', NULL, 'Miq.', 8),
(986, 'Monodora', NULL, 'Dunal', 8),
(987, 'Moronobea', NULL, 'Aubl.', 42),
(988, 'Morus', NULL, 'L.', 109),
(989, 'Mostuea', NULL, 'Didr.', 516),
(990, 'Moultonianthus', NULL, 'Merr.', 66),
(991, 'Murraya', NULL, 'L.', 143),
(992, 'Musanga', NULL, 'C.Sm. ex R.Br.', 171),
(993, 'Mussaenda', NULL, 'L.', 142),
(994, 'Mussaendopsis', NULL, 'Baill.', 142),
(995, 'Myrcianthes', NULL, 'O.Berg', 116),
(996, 'Myrianthus', NULL, 'P.Beauv.', 171),
(997, 'Myrica', NULL, 'L.', 113),
(998, 'Napoleonaea', NULL, 'P.Beauv.', 92),
(999, 'Nauclea', NULL, 'L.', 142),
(1000, 'Neesia', NULL, 'Blume', 102),
(1001, 'Neobalanocarpus', NULL, 'P.S.Ashton', 60),
(1002, 'Neoboutonia', NULL, 'Mull.Arg.', 66),
(1003, 'Neocinnamomum', NULL, 'H.Liu', 91),
(1004, 'Neolamarckia', NULL, 'Bosser', 142),
(1005, 'Neonauclea', NULL, 'Merr.', 142),
(1006, 'Neoscortechinia', NULL, 'Pax', 66),
(1007, 'Neosprucea', NULL, 'Sleumer', 73),
(1008, 'Neostenanthera', NULL, 'Exell', 8),
(1009, 'Neotrewia', NULL, 'Pax & K.Hoffm.', 66),
(1010, 'Neouvaria', NULL, 'Airy Shaw', 8),
(1011, 'Nephelea', NULL, 'R.M.Tryon', 52),
(1012, 'Nephelium', NULL, 'L.', 147),
(1013, 'Nesogordonia', NULL, 'Baill.', 102),
(1014, 'Newtonia', NULL, 'Baill.', 70),
(1015, 'Nichallea', NULL, 'Bridson', 142),
(1016, 'Norrisia', NULL, 'Gardner', 97),
(1017, 'Nothaphoebe', NULL, 'Blume', 91),
(1018, 'Ochanostachys', NULL, 'Mast.', 119),
(1019, 'Ochna', NULL, 'L.', 118),
(1020, 'Ochthocharis', NULL, 'Blume', 105),
(1021, 'Octoknema', NULL, 'Pierre', 514),
(1022, 'Octomeles', NULL, 'Miq.', 548),
(1023, 'Olax', NULL, 'L.', 119),
(1024, 'Olea', NULL, 'L.', 120),
(1025, 'Omphalea', NULL, 'L.', 66),
(1026, 'Omphalocarpum', NULL, 'P.Beauv.', 148),
(1027, 'Oncoba', NULL, 'Forssk.', 145),
(1028, 'Oncodostigma', NULL, 'Diels', 8),
(1029, 'Oncosperma', NULL, 'Blume', 15),
(1030, 'Ophiobotrys', NULL, 'Gilg', 145),
(1031, 'Ophiocaryon', NULL, 'Endl.', 144),
(1032, 'Opilia', NULL, 'Roxb.', 122),
(1033, 'Orania', NULL, 'Zipp.', 15),
(1034, 'Oreocnide', NULL, 'Miq.', 171),
(1035, 'Oricia', NULL, 'Pierre', 143),
(1036, 'Ormocarpum', NULL, 'P.Beauv.', 71),
(1037, 'Orophea', NULL, 'Blume', 8),
(1038, 'Oroxylum', NULL, 'Vent.', 22),
(1039, 'Osmanthus', NULL, 'Lour.', 120),
(1040, 'Osmoxylon', NULL, 'Miq.', 13),
(1041, 'Oubanguia', NULL, 'Baill.', 92),
(1042, 'Ougeinia', NULL, 'Benth.', 68),
(1043, 'Oxyanthus', NULL, 'DC.', 142),
(1044, 'Pachyelasma', NULL, 'Harms', 68),
(1045, 'Pachypodanthium', NULL, 'Engl. & Diels', 8),
(1046, 'Pancovia', NULL, 'Willd.', 147),
(1047, 'Panda', NULL, 'Pierre', 180),
(1048, 'Pandanus', NULL, 'Parkinson', 125),
(1049, 'Paracroton', NULL, 'Miq.', 66),
(1050, 'Paradrypetes', NULL, 'Kuhlm.', 534),
(1051, 'Paranephelium', NULL, 'Miq.', 147),
(1052, 'Parartocarpus', NULL, 'Baill.', 109),
(1053, 'Parashorea', NULL, 'Kurz', 60),
(1054, 'Parastemon', NULL, 'A.DC.', 40),
(1055, 'Parishia', NULL, 'Hook.f.', 6),
(1056, 'Paropsia', NULL, 'Noronha ex Thouars', 127),
(1057, 'Pasania', NULL, 'Oerst.', 72),
(1058, 'Passiflora', NULL, 'L.', 127),
(1059, 'Patinoa', NULL, 'Cuatrec.', 102),
(1060, 'Paullinia', NULL, 'L.', 147),
(1061, 'Pauridiantha', NULL, 'Hook.f.', 142),
(1062, 'Pausandra', NULL, 'Radlk.', 66),
(1063, 'Pausinystalia', NULL, 'Pierre ex Beille', 142),
(1064, 'Payena', NULL, 'A.DC.', 148),
(1065, 'Peddiea', NULL, 'Harv. ex Hook.', 164),
(1066, 'Pellacalyx', NULL, 'Korth.', 140),
(1067, 'Penianthus', NULL, 'Miers', 107),
(1068, 'Pentace', NULL, 'Hassk.', 102),
(1069, 'Pentaclethra', NULL, 'Benth.', 70),
(1070, 'Pentadesma', NULL, 'Sabine', 42),
(1071, 'Pentaplaris', NULL, 'L.O.Williams & Standl.', 102),
(1072, 'Pentaspadon', NULL, 'Hook.f.', 6),
(1073, 'Perrottetia', NULL, 'Kunth', 38),
(1074, 'Pertusadina', NULL, 'Ridsdale', 142),
(1075, 'Petersianthus', NULL, 'Merr.', 92),
(1076, 'Petitiocodon', NULL, 'Robbr.', 142),
(1077, 'Phaeanthus', NULL, 'Hook.f. & Thomson', 8),
(1078, 'Pholidocarpus', NULL, 'Blume', 15),
(1079, 'Phyllobotryon', NULL, 'Mull.Arg.', 145),
(1080, 'Phyllocosmus', NULL, 'Klotzsch', 86),
(1081, 'Picralima', NULL, 'Pierre', 10),
(1082, 'Picrasma', NULL, 'Blume', 151),
(1083, 'Pierreodendron', NULL, 'A.Chev.(SUH)', 151),
(1084, 'Pimelodendron', NULL, 'Hassk.', 66),
(1085, 'Pinanga', NULL, 'Blume', 15),
(1086, 'Piptadenia', NULL, 'Benth.', 68),
(1087, 'Piptadeniastrum', NULL, 'Brenan', 70),
(1088, 'Piptostigma', NULL, 'Oliv.', 8),
(1089, 'Pipturus', NULL, 'Wedd.', 171),
(1090, 'Pisonia', NULL, 'L.', 117),
(1091, 'Placodiscus', NULL, 'Radlk.', 147),
(1092, 'Planchonella', NULL, 'Tiegh.(SUH)', 148),
(1093, 'Planchonia', NULL, 'Blume', 92),
(1094, 'Platea', NULL, 'Blume', 85),
(1095, 'Pleiocarpa', NULL, 'Benth.', 10),
(1096, 'Ploiarium', NULL, 'Korth.', 241),
(1097, 'Podandrogyne', NULL, 'Ducke', 509),
(1098, 'Poga', NULL, 'Pierre', 7),
(1099, 'Polyalthia', NULL, 'Blume', 8),
(1100, 'Polyceratocarpus', NULL, 'Engl. & Diels', 8),
(1101, 'Polyosma', NULL, 'Blume', 536),
(1102, 'Polysphaeria', NULL, 'Hook.f.', 142),
(1103, 'Popowia', NULL, 'Endl.', 8),
(1104, 'Porterandia', NULL, 'Ridl.', 142),
(1105, 'Pourthiaea', NULL, 'Decne.', 141),
(1106, 'Pradosia', NULL, 'Liais', 148),
(1107, 'Prainea', NULL, 'King ex Hook.f.', 109),
(1108, 'Praravinia', NULL, 'Korth.', 142),
(1109, 'Premna', NULL, 'L.', 90),
(1110, 'Protomegabaria', NULL, 'Hutch.', 184),
(1111, 'Psammisia', NULL, 'Klotzsch', 64),
(1112, 'Pseuderanthemum', NULL, 'Radlk.', 1),
(1113, 'Pseudoclausena', NULL, 'T.P. Clark', 106),
(1114, 'Pseudoeugenia', NULL, 'Scort.', 116),
(1115, 'Pseudomalmea', NULL, 'Chatrou', 8),
(1116, 'Pseudomussaenda', NULL, 'Wernham', 142),
(1117, 'Pseudopiptadenia', NULL, 'Rauschert', 68),
(1118, 'Pseudospondias', NULL, 'Engl.', 6),
(1119, 'Pseuduvaria', NULL, 'Miq.', 8),
(1120, 'Psilanthus', NULL, 'Hook.f.', 142),
(1121, 'Psorospermum', NULL, 'Spach', 42),
(1122, 'Psydrax', NULL, 'Gaertn.', 142),
(1123, 'Pteleocarpa', NULL, 'Oliv.', 25),
(1124, 'Pteleopsis', NULL, 'Engl.', 44),
(1125, 'Pternandra', NULL, 'Jack', 105),
(1126, 'Pterocymbium', NULL, 'R.Br.', 102),
(1127, 'Pterospermum', NULL, 'Schreb.', 102),
(1128, 'Pterygota', NULL, 'Schott & Endl.', 102),
(1129, 'Ptychopetalum', NULL, 'Benth.', 119),
(1130, 'Ptychopyxis', NULL, 'Miq.', 66),
(1131, 'Pycnanthus', NULL, 'Warb.', 114),
(1132, 'Pycnocoma', NULL, 'Benth.', 66),
(1133, 'Pyrenaria', NULL, 'Blume', 162),
(1134, 'Quercus', NULL, 'L.', 72),
(1135, 'Radermachera', NULL, 'Zoll. & Moritzi', 22),
(1136, 'Radlkofera', NULL, 'Gilg', 147),
(1137, 'Rapanea', NULL, 'Aubl.', 115),
(1138, 'Reinwardtiodendron', NULL, 'Koord.', 106),
(1139, 'Rennellia', NULL, 'Korth.', 142),
(1140, 'Rhabdophyllum', NULL, 'Tiegh.', 118),
(1141, 'Rhamnidium', NULL, 'Reissek', 139),
(1142, 'Rhaptopetalum', NULL, 'Oliv.', 92),
(1143, 'Rhodamnia', NULL, 'Jack', 116),
(1144, 'Rhododendron', NULL, 'L.', 64),
(1145, 'Rhodostemonodaphne', NULL, 'Rohwer & Kubitzki', 91),
(1146, 'Rhus', NULL, 'L.', 6),
(1147, 'Richeria', NULL, 'Vahl', 184),
(1148, 'Ricinodendron', NULL, 'Mull.Arg.', 66),
(1149, 'Ritchiea', NULL, 'R.Br. ex G.Don', 32),
(1150, 'Rothmannia', NULL, 'Thunb.', 142),
(1151, 'Rourea', NULL, 'Aubl.', 45),
(1152, 'Ruagea', NULL, 'H.Karst.', 106),
(1153, 'Ruizodendron', NULL, 'R.E.Fr.', 8),
(1154, 'Rungia', NULL, 'Nees', 1),
(1155, 'Ryparosa', NULL, 'Blume', 198),
(1156, 'Rytigynia', NULL, 'Blume', 142),
(1157, 'Saccopetalum', NULL, 'Benn.', 8),
(1158, 'Sageraea', NULL, 'Dalzell', 8),
(1159, 'Sagotia', NULL, 'Baill.', 66),
(1160, 'Samyda', NULL, 'L.(SUH)', 145),
(1161, 'Sandoricum', NULL, 'Cav.', 106),
(1162, 'Santiria', NULL, 'Blume', 27),
(1163, 'Saprosma', NULL, 'Blume', 142),
(1164, 'Saraca', NULL, 'L.', 68),
(1165, 'Sarcocephalus', NULL, 'Afzel. ex Sabine', 142),
(1166, 'Sarcotheca', NULL, 'Blume', 124),
(1167, 'Sauropus', NULL, 'Blume', 184),
(1168, 'Scaphium', NULL, 'Schott & Endl.', 102),
(1169, 'Scaphocalyx', NULL, 'Ridl.', 198),
(1170, 'Scaphopetalum', NULL, 'Mast.', 102),
(1171, 'Schima', NULL, 'Reinw. ex Blume', 162),
(1172, 'Schleichera', NULL, 'Willd.', 147),
(1173, 'Schoepfia', NULL, 'Schreb.', 541),
(1174, 'Schoutenia', NULL, 'Korth.', 102),
(1175, 'Schrebera', NULL, 'Roxb.', 120),
(1176, 'Schumanniophyton', NULL, 'Harms', 142),
(1177, 'Scleropyrum', NULL, 'Arn.', 146),
(1178, 'Scorodocarpus', NULL, 'Becc.', 514),
(1179, 'Scottellia', NULL, 'Oliv.', 198),
(1180, 'Scutinanthe', NULL, 'Thwaites', 27),
(1181, 'Scyphocephalium', NULL, 'Warb.', 114),
(1182, 'Scytopetalum', NULL, 'Pierre ex Engl.', 92),
(1183, 'Sibangea', NULL, 'Oliv.', 538),
(1184, 'Simira', NULL, 'Aubl.', 142),
(1185, 'Sindora', NULL, 'Miq.', 69),
(1186, 'Siphonodon', NULL, 'Griff.', 38),
(1187, 'Smilax', NULL, 'L.', 153),
(1188, 'Sorindeia', NULL, 'Thouars', 6),
(1189, 'Soyauxia', NULL, 'Oliv.', 193),
(1190, 'Sphaeropteris', NULL, 'Bernh.', 52),
(1191, 'Spirotheca', NULL, 'Ulbr.', 24),
(1192, 'Spondianthus', NULL, 'Engl.', 184),
(1193, 'Staudtia', NULL, 'Warb.', 114),
(1194, 'Stelechocarpus', NULL, 'Hook.f. & Thomson', 8),
(1195, 'Stemonurus', NULL, 'Blume', 545),
(1196, 'Stephanopodium', NULL, 'Poepp.', 57),
(1197, 'Stereospermum', NULL, 'Cham.', 22),
(1198, 'Stipularia', NULL, 'P.Beauv.', 142),
(1199, 'Streblus', NULL, 'Lour.', 109),
(1200, 'Strephonema', NULL, 'Hook.f.', 44),
(1201, 'Strombosiopsis', NULL, 'Engl.', 514),
(1202, 'Stryphnodendron', NULL, 'Mart.', 68),
(1203, 'Styrax', NULL, 'L.', 158),
(1204, 'Sumbaviopsis', NULL, 'J.J.Sm.', 66),
(1205, 'Suregada', NULL, 'Roxb. ex Rottler', 66),
(1206, 'Swintonia', NULL, 'Griff.', 6),
(1207, 'Sympetalandra', NULL, 'Stapf', 68),
(1208, 'Synsepalum', NULL, '(A.DC.) Daniell', 148),
(1209, 'Talbotiella', NULL, 'Baker f.', 69),
(1210, 'Tarenna', NULL, 'Gaertn.', 142),
(1211, 'Tarennoidea', NULL, 'Tirveng. & Sastre', 142),
(1212, 'Teijsmanniodendron', NULL, 'Koord.', 90),
(1213, 'Tessmannia', NULL, 'Harms', 68),
(1214, 'Tessmannianthus', NULL, 'Markgr.', 105),
(1215, 'Tetraberlinia', NULL, '(Harms) Hauman', 69),
(1216, 'Tetradium', NULL, 'Lour.', 143),
(1217, 'Tetrameles', NULL, 'R.Br.', 548),
(1218, 'Tetramerista', NULL, 'Miq.', 190),
(1219, 'Tetrapleura', NULL, 'Benth.', 70),
(1220, 'Tetrardisia', NULL, 'Mez', 115),
(1221, 'Thecacoris', NULL, 'A.Juss.', 184),
(1222, 'Thyrsodium', NULL, 'Salzm. ex Benth.', 6),
(1223, 'Tieghemella', NULL, 'Pierre', 148),
(1224, 'Toona', NULL, '(Endl.) M.Roem.', 106),
(1225, 'Topobea', NULL, 'Aubl.', 105),
(1226, 'Tournefortia', NULL, 'L.', 25),
(1227, 'Toxosiphon', NULL, 'Baill.', 143),
(1228, 'Treculia', NULL, 'Decne. ex Trecul', 109),
(1229, 'Trewia', NULL, 'L.', 66),
(1230, 'Trichadenia', NULL, 'Thwaites', 198),
(1231, 'Trichoscypha', NULL, 'Hook.f.', 6),
(1232, 'Trichostachys', NULL, 'Hook.f.', 142),
(1233, 'Tridesmostemon', NULL, 'Engl.', 148),
(1234, 'Trigonachras', NULL, 'Radlk.', 147),
(1235, 'Trigoniastrum', NULL, 'Miq.', 168),
(1236, 'Trigonopleura', NULL, 'Hook.f.', 66),
(1237, 'Trigonostemon', NULL, 'Blume', 66),
(1238, 'Trigynaea', NULL, 'Schltdl.', 8),
(1239, 'Trilepisium', NULL, 'Thouars', 109),
(1240, 'Triomma', NULL, 'Hook.f.', 27),
(1241, 'Tristaniopsis', NULL, 'Brongn. & Gris', 116),
(1242, 'Trivalvaria', NULL, '(Miq.) Miq.', 8),
(1243, 'Trymatococcus', NULL, 'Poepp. & Endl.', 109),
(1244, 'Turraeanthus', NULL, 'Baill.', 106),
(1245, 'Uapaca', NULL, 'Baill.', 184),
(1246, 'Ulmus', NULL, 'L.', 170),
(1247, 'Urobotrya', NULL, 'Stapf', 122),
(1248, 'Uvariastrum', NULL, 'Engl.', 8),
(1249, 'Uvariodendron', NULL, '(Engl. & Diels) R.E.Fr.', 8),
(1250, 'Uvariopsis', NULL, 'Engl.', 8),
(1251, 'Vaccinium', NULL, 'L.', 64),
(1252, 'Vangueriella', NULL, 'Verdc.', 142),
(1253, 'Vatica', NULL, 'L.', 60),
(1254, 'Vepris', NULL, 'Comm. ex A.Juss.', 143),
(1255, 'Vernonia', NULL, 'Schreb.', 18),
(1256, 'Viburnum', NULL, 'L.', 203),
(1257, 'Villaria', NULL, 'Rolfe', 142);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(1258, 'Viticipremna', NULL, 'Lam.', 90),
(1259, 'Voacanga', NULL, 'Thouars', 10),
(1260, 'Vouarana', NULL, 'Aubl.', 147),
(1261, 'Wallenia', NULL, 'Sw.', 115),
(1262, 'Warneckea', NULL, 'Gilg', 105),
(1263, 'Weinmannia', NULL, 'L.', 50),
(1264, 'Whiteodendron', NULL, 'Steenis', 116),
(1265, 'Wittmackanthus', NULL, 'Kuntze', 142),
(1266, 'Wrightia', NULL, 'R.Br.', 10),
(1267, 'Xanthophyllum', NULL, 'Roxb.', 133),
(1268, 'Xanthosoma', NULL, 'Schott', 12),
(1269, 'Xantolis', NULL, 'Raf.', 148),
(1270, 'Xeromphis', NULL, 'Raf.', 142),
(1271, 'Xerospermum', NULL, 'Blume', 147),
(1272, 'Zanha', NULL, 'Hiern', 147),
(1273, 'Zeyherella', NULL, '(Pierre ex Engl.) Aubrev.', 148),
(1274, 'Zollingeria', NULL, 'Kurz', 147),
(1275, 'Asystasia', NULL, 'Blume', 1),
(1276, 'Camptostylus', NULL, 'Gilg', 198),
(1277, 'Calpocalyx', NULL, 'Harms', 68),
(1278, 'Sericanthe', NULL, 'Robbr.', 142),
(1279, 'Korupodendron', NULL, 'Litt & Cheek', 175),
(1280, 'Morelia', NULL, 'A.Rich. ex DC.', 142),
(1281, 'Aalius', NULL, 'Lam. ex Kuntze(SUH)', 184),
(1282, 'Aaronsohnia', NULL, 'Warb. & Eig', 18),
(1283, 'Abatia', NULL, 'Ruiz & Pav.', 145),
(1284, 'Abauria', NULL, 'Becc.', 68),
(1285, 'Abbevillea', NULL, 'O.Berg', 116),
(1286, 'Abbottia', NULL, 'F.Muell.', 142),
(1287, 'Abdra', NULL, 'Greene', 197),
(1288, 'Abdulmajidia', NULL, 'Whitmore', 92),
(1289, 'Abebaia', NULL, 'Baehni', 148),
(1290, 'Abelia', NULL, 'R.Br.', 521),
(1291, 'Abelicea', NULL, 'Baill.', 170),
(1292, 'Abeliophyllum', NULL, 'Nakai', 120),
(1293, 'Abelmoschus', NULL, 'Medik.', 102),
(1294, 'Aberemoa', NULL, 'Aubl.', 8),
(1295, 'Aberia', NULL, 'Hochst.', 145),
(1296, 'Abies', NULL, 'Mill.', 129),
(1297, 'Abildgaardia', NULL, 'Vahl', 55),
(1298, 'Abobra', NULL, 'Naudin', 49),
(1299, 'Aboriella', NULL, 'Bennet', 171),
(1300, 'Abortopetalum', NULL, 'O.Deg.', 102),
(1301, 'Abramsia', NULL, 'Gillespie', 142),
(1302, 'Abroma', NULL, 'Jacq.', 102),
(1303, 'Abromeitia', NULL, 'Mez', 115),
(1304, 'Abronia', NULL, 'Juss.', 117),
(1305, 'Abrotanella', NULL, 'Cass.', 18),
(1306, 'Abrus', NULL, 'Adans.', 68),
(1307, 'Absolmsia', NULL, 'Kuntze', 10),
(1308, 'Abutilon', NULL, 'Mill.', 102),
(1309, 'Abutilothamnus', NULL, 'Ulbr.', 102),
(1310, 'Acaciella', NULL, 'Britton & Rose', 68),
(1311, 'Acaciopsis', NULL, 'Britton & Rose', 68),
(1312, 'Acaena', NULL, 'Mutis ex L.', 141),
(1313, 'Acalyphes', NULL, 'Hassk.', 66),
(1314, 'Acalyphopsis', NULL, 'Pax & K.Hoffm.', 66),
(1315, 'Acamptopappus', NULL, '(A.Gray) A.Gray', 18),
(1316, 'Acanthella', NULL, 'Hook.f.', 105),
(1317, 'Acanthinophyllum', NULL, 'Allemao', 109),
(1318, 'Acanthocardamum', NULL, 'Thell.', 197),
(1319, 'Acanthocaulon', NULL, 'Klotzsch ex Endl.', 66),
(1320, 'Acanthocephalus', NULL, 'Kar. & Kir.', 18),
(1321, 'Acanthochiton', NULL, 'Torr.', 5),
(1322, 'Acanthochlamys', NULL, 'P.C.Kao', 172),
(1323, 'Acanthocladium', NULL, 'F.Muell.', 18),
(1324, 'Acanthocladus', NULL, 'Klotzsch ex Hassk.', 133),
(1325, 'Acanthococos', NULL, 'Barb.Rodr.', 15),
(1326, 'Acanthodesmos', NULL, 'C.D.Adams & duQuesnay', 18),
(1327, 'Acanthodium', NULL, 'Delile', 1),
(1328, 'Acanthogonum', NULL, 'Torr.', 134),
(1329, 'Acantholepis', NULL, 'Less.', 18),
(1330, 'Acantholippia', NULL, 'Griseb.', 173),
(1331, 'Acantholoma', NULL, 'Gaudich. ex Baill.', 66),
(1332, 'Acanthomintha', NULL, '(A.Gray) A.Gray', 90),
(1333, 'Acanthonema', NULL, 'Hook.f.', 76),
(1334, 'Acanthopale', NULL, 'C.B.Clarke', 1),
(1335, 'Acanthopanax', NULL, '(Decne. & Planch.) Witte', 13),
(1336, 'Acanthophaca', NULL, 'Nevski', 68),
(1337, 'Acanthophoenix', NULL, 'H.Wendl.', 15),
(1338, 'Acanthophora', NULL, 'Merr.(SUH)', 13),
(1339, 'Acanthopsis', NULL, 'Harv.', 1),
(1340, 'Acanthopteron', NULL, 'Britton', 68),
(1341, 'Acanthopyxis', NULL, 'Miq. ex Lanj.(SUI)', 66),
(1342, 'Acanthorrhinum', NULL, 'Rothm.', 423),
(1343, 'Acanthorrhiza', NULL, 'H.Wendl.', 15),
(1344, 'Acanthosabal', NULL, 'Prosch.', 15),
(1345, 'Acanthoscyphus', NULL, 'Small', 134),
(1346, 'Acanthosicyos', NULL, 'Welw. ex Hook.f.', 49),
(1347, 'Acanthosicyus', NULL, 'Post & Kuntze(SUO)', 49),
(1348, 'Acanthospermum', NULL, 'Schrank', 18),
(1349, 'Acanthosphaera', NULL, 'Warb.(SUH)', 109),
(1350, 'Acanthostelma', NULL, 'Bidgood & Brummitt', 1),
(1351, 'Acanthostemma', NULL, '(Blume) Blume', 10),
(1352, 'Acanthostyles', NULL, 'R.M.King & H.Rob.', 18),
(1353, 'Acanthothamnus', NULL, 'Brandegee', 38),
(1354, 'Acanthotreculia', NULL, 'Engl.', 109),
(1355, 'Acanthotrichilia', NULL, '(Urb.) O.F.Cook & G.N.Collins', 106),
(1356, 'Acanthura', NULL, 'Lindau', 1),
(1357, 'Acanthus', NULL, 'L.', 1),
(1358, 'Acanthyllis', NULL, 'Pomel', 68),
(1359, 'Acareosperma', NULL, 'Gagnep.', 181),
(1360, 'Acaulimalva', NULL, 'Krapov.', 102),
(1361, 'Acca', NULL, 'O.Berg', 116),
(1362, 'Accara', NULL, 'Landrum', 116),
(1363, 'Accia', NULL, 'A.St.-Hil.', 66),
(1364, 'Acelica', NULL, 'Rizzini', 1),
(1365, 'Acentra', NULL, 'Phil.', 174),
(1366, 'Acerates', NULL, 'Elliott', 10),
(1367, 'Aceratium', NULL, 'DC.', 62),
(1368, 'Aceriphyllum', NULL, 'Engl.(SUH)', 149),
(1369, 'Acetosa', NULL, 'Mill.', 134),
(1370, 'Acetosella', NULL, 'Kuntze(SUH)', 124),
(1371, 'Achaenipodium', NULL, 'Brandegee', 18),
(1372, 'Achaetogeron', NULL, 'A.Gray', 18),
(1373, 'Achetaria', NULL, 'Cham. & Schltdl.', 423),
(1374, 'Achillea', NULL, 'L.', 18),
(1375, 'Achimenes', NULL, 'P.Browne(SUH)', 76),
(1376, 'Achnophora', NULL, 'F.Muell.', 18),
(1377, 'Achnopogon', NULL, 'Maguire, Steyerm. & Wurdack', 18),
(1378, 'Achoriphragma', NULL, 'Sojak', 197),
(1379, 'Achradelpha', NULL, 'O.F.Cook', 148),
(1380, 'Achradotypus', NULL, 'Baill.', 148),
(1381, 'Achras', NULL, 'L.', 148),
(1382, 'Achrouteria', NULL, 'Eyma', 148),
(1383, 'Achuaria', NULL, 'Gereau', 143),
(1384, 'Achudemia', NULL, 'Blume', 171),
(1385, 'Achyrachaena', NULL, 'Schauer', 18),
(1386, 'Achyranthes', NULL, 'L.', 5),
(1387, 'Achyrobaccharis', NULL, 'Sch.Bip. ex Walp.', 18),
(1388, 'Achyrocalyx', NULL, 'Benoist', 1),
(1389, 'Achyrocline', NULL, '(Less.) DC.', 18),
(1390, 'Achyropappus', NULL, 'Kunth', 18),
(1391, 'Achyropsis', NULL, '(Moq.) Hook.f.', 5),
(1392, 'Achyrospermum', NULL, 'Blume', 90),
(1393, 'Achyrothalamus', NULL, 'O.Hoffm.', 18),
(1394, 'Acicalyptus', NULL, 'A.Gray', 116),
(1395, 'Acidocroton', NULL, 'Griseb.', 66),
(1396, 'Aciella', NULL, 'Tiegh.', 98),
(1397, 'Acilepidopsis', NULL, 'H.Rob.', 18),
(1398, 'Acinos', NULL, 'Mill.', 90),
(1399, 'Acioa', NULL, 'Aubl.', 40),
(1400, 'Aciotis', NULL, 'D.Don', 105),
(1401, 'Aciphylla', NULL, 'J.R.Forst. & G.Forst.', 9),
(1402, 'Acisanthera', NULL, 'P.Browne', 105),
(1403, 'Ackama', NULL, 'A.Cunn.', 50),
(1404, 'Acleisanthes', NULL, 'A.Gray', 117),
(1405, 'Acmadenia', NULL, 'Bartl. & H.L.Wendl.', 143),
(1406, 'Acmanthera', NULL, 'Griseb.', 101),
(1407, 'Acmella', NULL, 'Rich. ex Pers.', 18),
(1408, 'Acmena', NULL, 'DC.', 116),
(1409, 'Acmenosperma', NULL, 'Kausel', 116),
(1410, 'Acmispon', NULL, 'Raf.', 68),
(1411, 'Acmopyle', NULL, 'Pilg.', 132),
(1412, 'Acmostemon', NULL, 'Pilg.', 46),
(1413, 'Acmostigma', NULL, 'Raf.', 142),
(1414, 'Acnida', NULL, 'L.', 5),
(1415, 'Acnistus', NULL, 'Schott', 154),
(1416, 'Acoelorrhaphe', NULL, 'H.Wendl.', 15),
(1417, 'Acokanthera', NULL, 'G.Don', 10),
(1418, 'Acomastylis', NULL, 'Greene', 141),
(1419, 'Acomis', NULL, 'F.Muell.', 18),
(1420, 'Aconceveibum', NULL, 'Miq.', 66),
(1421, 'Aconogonon', NULL, '(Meisn.) Rchb.', 134),
(1422, 'Aconogonum', NULL, '(Meisn.) Rchb.(SUO)', 134),
(1423, 'Acorellus', NULL, 'Palla', 55),
(1424, 'Acosmus', NULL, 'Desv.', 101),
(1425, 'Acourtia', NULL, 'D.Don', 18),
(1426, 'Acradenia', NULL, 'Kippist', 143),
(1427, 'Acrandra', NULL, 'O.Berg', 116),
(1428, 'Acranthemum', NULL, 'Tiegh.', 98),
(1429, 'Acranthera', NULL, 'Arn. ex Meisn.', 142),
(1430, 'Acreugenia', NULL, 'Kausel', 116),
(1431, 'Acridocarpus', NULL, 'Guill. & Perr.', 101),
(1432, 'Acrilia', NULL, 'Griseb.', 106),
(1433, 'Acrisione', NULL, 'B.Nord.', 18),
(1434, 'Acrista', NULL, 'O.F.Cook', 15),
(1435, 'Acritopappus', NULL, 'R.M.King & H.Rob.', 18),
(1436, 'Acriulus', NULL, 'Ridl.', 55),
(1437, 'Acrobotrys', NULL, 'K.Schum. & K.Krause', 142),
(1438, 'Acrocarpus', NULL, 'Wight ex Arn.', 68),
(1439, 'Acrocephalus', NULL, 'Benth.', 90),
(1440, 'Acroclinium', NULL, 'A.Gray', 18),
(1441, 'Acrocoelium', NULL, 'Baill.', 85),
(1442, 'Acrodiclidium', NULL, 'Nees & Mart.', 91),
(1443, 'Acrodryon', NULL, 'Spreng.', 142),
(1444, 'Acroglochin', NULL, 'Schrad. ex Schult.', 5),
(1445, 'Acrolobus', NULL, 'Klotzsch', 119),
(1446, 'Acronema', NULL, 'Falc. ex Edgew.', 9),
(1447, 'Acronodia', NULL, 'Blume', 62),
(1448, 'Acrophyllum', NULL, 'Benth.', 50),
(1449, 'Acropogon', NULL, 'Schltr.', 102),
(1450, 'Acroptilon', NULL, 'Cass.', 18),
(1451, 'Acroschizocarpus', NULL, 'Gombocz', 197),
(1452, 'Acrosepalum', NULL, 'Pierre', 102),
(1453, 'Acrostemon', NULL, 'Klotzsch', 64),
(1454, 'Acrostephanus', NULL, 'Tiegh.', 98),
(1455, 'Acrostigma', NULL, 'O.F.Cook & Doyle', 15),
(1456, 'Acrostoma', NULL, 'Didr.', 142),
(1457, 'Acrosynanthus', NULL, 'Urb.', 142),
(1458, 'Acrotome', NULL, 'Benth. ex Endl.', 90),
(1459, 'Acrotrema', NULL, 'Jack', 58),
(1460, 'Acrotriche', NULL, 'R.Br.', 64),
(1461, 'Acrymia', NULL, 'Prain', 90),
(1462, 'Acsmithia', NULL, 'Hoogland', 50),
(1463, 'Actephilopsis', NULL, 'Ridl.', 66),
(1464, 'Actinanthella', NULL, 'Balle', 98),
(1465, 'Actinanthus', NULL, 'Ehrenb.', 9),
(1466, 'Actinidia', NULL, 'Lindl.', 2),
(1467, 'Actinobole', NULL, 'Endl.', 18),
(1468, 'Actinocarya', NULL, 'Benth.', 25),
(1469, 'Actinocheita', NULL, 'F.A.Barkley', 6),
(1470, 'Actinodium', NULL, 'Schauer', 116),
(1471, 'Actinokentia', NULL, 'Dammer', 15),
(1472, 'Actinolema', NULL, 'Fenzl', 9),
(1473, 'Actinomeris', NULL, 'Nutt.', 18),
(1474, 'Actinomorphe', NULL, '(Miq.) Miq.', 13),
(1475, 'Actinophlebia', NULL, 'C.Presl', 52),
(1476, 'Actinophloeus', NULL, '(Becc.) Becc.', 15),
(1477, 'Actinophyllum', NULL, 'Ruiz & Pav.', 13),
(1478, 'Actinorhytis', NULL, 'H.Wendl. & Drude', 15),
(1479, 'Actinoschoenus', NULL, 'Benth.', 55),
(1480, 'Actinoscirpus', NULL, '(Ohwi) R.W.Haines & Lye', 55),
(1481, 'Actinoseris', NULL, '(Endl.) Cabrera', 18),
(1482, 'Actinospermum', NULL, 'Elliott', 18),
(1483, 'Actinostemma', NULL, 'Griff.', 49),
(1484, 'Actinostemon', NULL, 'Mart. ex Klotzsch', 66),
(1485, 'Actinostrobus', NULL, 'Miq.', 51),
(1486, 'Actinotus', NULL, 'Labill.', 9),
(1487, 'Actites', NULL, 'Lander', 18),
(1488, 'Acuan', NULL, 'Medik.', 68),
(1489, 'Acunaeanthus', NULL, 'Borhidi, Komlodi & Moncada', 142),
(1490, 'Acustelma', NULL, 'Baill.', 10),
(1491, 'Adansonia', NULL, 'L.', 102),
(1492, 'Adelanthus', NULL, 'Endl.', 85),
(1493, 'Adelaster', NULL, 'Lindl. ex Veitch', 1),
(1494, 'Adelbertia', NULL, 'Meisn.', 105),
(1495, 'Adeliopsis', NULL, 'Benth.', 107),
(1496, 'Adelocaryum', NULL, 'Brand', 25),
(1497, 'Adelodypsis', NULL, 'Becc.', 15),
(1498, 'Adelonema', NULL, 'Schott', 12),
(1499, 'Adelonenga', NULL, 'Hook.f.', 15),
(1500, 'Adelosa', NULL, 'Blume', 90),
(1501, 'Adelostemma', NULL, 'Hook.f.', 10),
(1502, 'Adelostigma', NULL, 'Steetz', 18),
(1503, 'Ademo', NULL, 'Post & Kuntze', 66),
(1504, 'Adenacanthus', NULL, 'Nees', 1),
(1505, 'Adenandra', NULL, 'Willd.', 143),
(1506, 'Adenanthe', NULL, 'Maguire, Steyerm. & Wurdack', 118),
(1507, 'Adenanthellum', NULL, 'B.Nord.', 18),
(1508, 'Adenanthemum', NULL, 'B.Nord.(SUH)', 18),
(1509, 'Adenanthos', NULL, 'Labill.', 135),
(1510, 'Adenarake', NULL, 'Maguire & Wurdack', 118),
(1511, 'Adenia', NULL, 'Forssk.', 127),
(1512, 'Adenium', NULL, 'Roem. & Schult.', 10),
(1513, 'Adenoa', NULL, 'Arbo', 169),
(1514, 'Adenocalymma', NULL, 'Mart. ex Meisn.', 22),
(1515, 'Adenocarpus', NULL, 'DC.', 68),
(1516, 'Adenocaulon', NULL, 'Hook.', 18),
(1517, 'Adenoceras', NULL, 'Rchb.f. & Zoll. ex Baill.', 66),
(1518, 'Adenochlaena', NULL, 'Boivin ex Baill.', 66),
(1519, 'Adenoclina', NULL, 'Post & Kuntze(SUO)', 66),
(1520, 'Adenocline', NULL, 'Turcz.', 66),
(1521, 'Adenocrepis', NULL, 'Blume', 184),
(1522, 'Adenocritonia', NULL, 'R.M.King & H.Rob.', 18),
(1523, 'Adenodolichos', NULL, 'Harms', 68),
(1524, 'Adenoglossa', NULL, 'B.Nord.', 18),
(1525, 'Adenogyne', NULL, 'Klotzsch', 66),
(1526, 'Adenogynum', NULL, 'Rchb.f. & Zoll.(SUH)', 66),
(1527, 'Adenolisianthus', NULL, 'Gilg', 75),
(1528, 'Adenolobus', NULL, '(Harv. ex Benth.) Torre & Hillc.', 68),
(1529, 'Adenoon', NULL, 'Dalzell', 18),
(1530, 'Adenopappus', NULL, 'Benth.', 18),
(1531, 'Adenopeltis', NULL, 'Bertero ex A.Juss.', 66),
(1532, 'Adenopetalum', NULL, 'Klotzsch & Garcke', 66),
(1533, 'Adenophaedra', NULL, '(Mull.Arg.) Mull.Arg.', 66),
(1534, 'Adenophora', NULL, 'Fisch.', 30),
(1535, 'Adenophyllum', NULL, 'Pers.', 18),
(1536, 'Adenoplea', NULL, 'Radlk.', 150),
(1537, 'Adenoplusia', NULL, 'Radlk.', 150),
(1538, 'Adenopodia', NULL, 'C.Presl', 68),
(1539, 'Adenoporces', NULL, 'Small', 101),
(1540, 'Adenopus', NULL, 'Benth.', 49),
(1541, 'Adenorhopium', NULL, 'Pohl', 66),
(1542, 'Adenorima', NULL, 'Raf.', 66),
(1543, 'Adenoropium', NULL, 'Pohl(SUO)', 66),
(1544, 'Adenosacme', NULL, 'Wall.', 142),
(1545, 'Adenosciadium', NULL, 'H.Wolff', 9),
(1546, 'Adenosma', NULL, 'R.Br.', 423),
(1547, 'Adenostachya', NULL, 'Bremek.', 1),
(1548, 'Adenostegia', NULL, 'Benth.', 150),
(1549, 'Adenostemma', NULL, 'J.R.Forst. & G.Forst.', 18),
(1550, 'Adenostoma', NULL, 'Hook. & Arn.', 141),
(1551, 'Adenostyles', NULL, 'Cass.(SUS)', 18),
(1552, 'Adenothamnus', NULL, 'D.D.Keck', 18),
(1553, 'Adenothola', NULL, 'Lem.', 142),
(1554, 'Adesmia', NULL, 'DC.', 68),
(1555, 'Adhatoda', NULL, 'Mill.', 1),
(1556, 'Adina', NULL, 'Salisb.', 142),
(1557, 'Adinandrella', NULL, 'Exell', 162),
(1558, 'Adinauclea', NULL, 'Ridsdale', 142),
(1559, 'Adinobotrys', NULL, 'Dunn', 68),
(1560, 'Adisa', NULL, 'Steud.', 66),
(1561, 'Adisca', NULL, 'Blume', 66),
(1562, 'Adiscanthus', NULL, 'Ducke', 143),
(1563, 'Adlumia', NULL, 'Raf. ex DC.', 126),
(1564, 'Adolphia', NULL, 'Meisn.', 139),
(1565, 'Adonidia', NULL, 'Becc.', 15),
(1566, 'Adrastaea', NULL, 'DC.', 58),
(1567, 'Adriana', NULL, 'Gaudich.', 66),
(1568, 'Adromischus', NULL, 'Lem.', 48),
(1569, 'Aechmandra', NULL, 'Arn.', 49),
(1570, 'Aechmanthera', NULL, 'Nees', 1),
(1571, 'Aechmolepis', NULL, 'Decne.', 10),
(1572, 'Aedesia', NULL, 'O.Hoffm.', 18),
(1573, 'Aegiceras', NULL, 'Gaertn.', 115),
(1574, 'Aeginetia', NULL, 'L.', 400),
(1575, 'Aegle', NULL, 'Correa', 143),
(1576, 'Aeglopsis', NULL, 'Swingle', 143),
(1577, 'Aegokeras', NULL, 'Raf.', 9),
(1578, 'Aegonychon', NULL, 'Gray', 25),
(1579, 'Aegopicron', NULL, 'Giseke(SUO)', 66),
(1580, 'Aegopodium', NULL, 'L.', 9),
(1581, 'Aegopordon', NULL, 'Boiss.', 18),
(1582, 'Aegopricon', NULL, 'L.f.(SUO)', 66),
(1583, 'Aegopricum', NULL, 'L.(SUS)', 66),
(1584, 'Aellenia', NULL, 'Ulbr.', 5),
(1585, 'Aembilla', NULL, 'Adans.', 145),
(1586, 'Aenictophyton', NULL, 'A.T.Lee', 68),
(1587, 'Aeollanthus', NULL, 'Mart. ex Spreng.', 90),
(1588, 'Aeonium', NULL, 'Webb & Berthel.', 48),
(1589, 'Aequatorium', NULL, 'B.Nord.', 18),
(1590, 'Aeria', NULL, 'O.F.Cook', 15),
(1591, 'Aerisilvaea', NULL, 'Radcl.-Sm.', 184),
(1592, 'Aerva', NULL, 'Forssk.', 5),
(1593, 'Aeschrion', NULL, 'Vell.', 151),
(1594, 'Aeschynanthus', NULL, 'Jack', 76),
(1595, 'Aeschynomene', NULL, 'L.', 68),
(1596, 'Aesculus', NULL, 'L.', 147),
(1597, 'Aetanthus', NULL, '(Eichler) Engl.', 98),
(1598, 'Aetheolaena', NULL, 'Cass.', 18),
(1599, 'Aetheonema', NULL, 'Rchb.', 142),
(1600, 'Aetheorhiza', NULL, 'Cass.', 18),
(1601, 'Aethiocarpa', NULL, 'Vollesen', 102),
(1602, 'Aethionema', NULL, 'R.Br.', 197),
(1603, 'Aethusa', NULL, 'L.', 9),
(1604, 'Aetia', NULL, 'Adans.', 44),
(1605, 'Aetoxylon', NULL, '(Airy Shaw) Airy Shaw', 164),
(1606, 'Affonsea', NULL, 'A.St.-Hil.', 68),
(1607, 'Afgekia', NULL, 'Craib', 68),
(1608, 'Afraegle', NULL, '(Swingle) Engl.', 143),
(1609, 'Afrafzelia', NULL, 'Pierre', 68),
(1610, 'Aframmi', NULL, 'C.Norman', 9),
(1611, 'Afrardisia', NULL, 'Mez', 115),
(1612, 'Afridia', NULL, 'Duthie', 90),
(1613, 'Afrobrunnichia', NULL, 'Hutch. & Dalziel', 134),
(1614, 'Afrocalathea', NULL, 'K.Schum.', 103),
(1615, 'Afrocarpus', NULL, '(Buchholz & N.E.Gray) C.N.Page', 132),
(1616, 'Afrocarum', NULL, 'Rauschert', 9),
(1617, 'Afrocrania', NULL, '(Harms) Hutch.', 47),
(1618, 'Afrofittonia', NULL, 'Lindau', 1),
(1619, 'Afroguatteria', NULL, 'Boutique', 8),
(1620, 'Afrohamelia', NULL, 'Wernham', 142),
(1621, 'Afroknoxia', NULL, 'Verdc.', 142),
(1622, 'Afrolicania', NULL, 'Mildbr.', 40),
(1623, 'Afroligusticum', NULL, 'C.Norman', 9),
(1624, 'Afromendoncia', NULL, 'Gilg ex Lindau', 1),
(1625, 'Afrorhaphidophora', NULL, 'Engl.', 12),
(1626, 'Afrormosia', NULL, 'Harms', 68),
(1627, 'Afrosersalisia', NULL, 'A.Chev.', 148),
(1628, 'Afrosison', NULL, 'H.Wolff', 9),
(1629, 'Afrotrewia', NULL, 'Pax & K.Hoffm.', 66),
(1630, 'Afrotrilepis', NULL, '(Gilly) J.Raynal', 55),
(1631, 'Afrotysonia', NULL, 'Rauschert', 25),
(1632, 'Afrovivella', NULL, 'A.Berger', 48),
(1633, 'Afzeliella', NULL, 'Gilg', 105),
(1634, 'Agalinis', NULL, 'Raf.', 400),
(1635, 'Agallis', NULL, 'Phil.', 197),
(1636, 'Agalma', NULL, 'Miq.', 13),
(1637, 'Agalmanthus', NULL, '(Endl.) Hombr. & Jacquinot', 116),
(1638, 'Agalmyla', NULL, 'Blume', 76),
(1639, 'Agaloma', NULL, 'Raf.', 66),
(1640, 'Aganonerion', NULL, 'Pierre ex Spire', 10),
(1641, 'Aganope', NULL, 'Miq.', 68),
(1642, 'Aganosma', NULL, '(Blume) G.Don', 10),
(1643, 'Agaosizia', NULL, 'Spach', 121),
(1644, 'Agapetes', NULL, 'D.Don ex G.Don', 64),
(1645, 'Agardhia', NULL, 'Spreng.(SUH)', 175),
(1646, 'Agarista', NULL, 'D.Don ex G.Don', 64),
(1647, 'Agastache', NULL, 'Gronov.', 90),
(1648, 'Agastachys', NULL, 'R.Br.', 135),
(1649, 'Agasyllis', NULL, 'Spreng.', 9),
(1650, 'Agatea', NULL, 'A.Gray', 174),
(1651, 'Agathelpis', NULL, 'Choisy', 150),
(1652, 'Agathis', NULL, 'Salisb.', 14),
(1653, 'Agathisanthemum', NULL, 'Klotzsch', 142),
(1654, 'Agathophora', NULL, '(Fenzl) Bunge', 5),
(1655, 'Agathosma', NULL, 'Willd.', 143),
(1656, 'Agati', NULL, 'Adans.', 68),
(1657, 'Agation', NULL, 'Brongn.(SUS)', 174),
(1658, 'Agauria', NULL, '(DC.) Hook.f.', 64),
(1659, 'Agave', NULL, 'L.', 3),
(1660, 'Agelaea', NULL, 'Sol. ex Planch.', 45),
(1661, 'Agelandra', NULL, 'Engl. & Pax(SUO)', 66),
(1662, 'Agelanthus', NULL, 'Tiegh.', 98),
(1663, 'Ageomoron', NULL, 'Raf.', 9),
(1664, 'Ageratella', NULL, 'A.Gray ex S.Watson', 18),
(1665, 'Ageratina', NULL, 'Spach', 18),
(1666, 'Ageratinastrum', NULL, 'Mattf.', 18),
(1667, 'Ageratum', NULL, 'L.', 18),
(1668, 'Agiabampoa', NULL, 'Rose ex O.Hoffm.', 18),
(1669, 'Agianthus', NULL, 'Greene', 197),
(1670, 'Agirta', NULL, 'Baill.', 66),
(1671, 'Aglaodorum', NULL, 'Schott', 12),
(1672, 'Aglaonema', NULL, 'Schott', 12),
(1673, 'Agoneissos', NULL, 'Zoll. ex Nied.', 101),
(1674, 'Agonis', NULL, '(DC.) Sweet', 116),
(1675, 'Agoseris', NULL, 'Raf.', 18),
(1676, 'Agrianthus', NULL, 'Mart. ex DC.', 18),
(1677, 'Agrimonia', NULL, 'L.', 141),
(1678, 'Agriophyllum', NULL, 'M.Bieb.', 5),
(1679, 'Agrocharis', NULL, 'Hochst.', 9),
(1680, 'Aguava', NULL, 'Raf.', 116),
(1681, 'Aguiaria', NULL, 'Ducke', 102),
(1682, 'Agylophora', NULL, 'Neck. ex Raf.(SUI)', 142),
(1683, 'Agyneia', NULL, 'L.', 184),
(1684, 'Agyneja', NULL, 'L.', 184),
(1685, 'Ahernia', NULL, 'Merr.', 198),
(1686, 'Ahzolia', NULL, 'Standl. & Steyerm.', 49),
(1687, 'Aichryson', NULL, 'Webb & Berthel.', 48),
(1688, 'Aidiopsis', NULL, 'Tirveng.', 142),
(1689, 'Aidomene', NULL, 'Stopp', 10),
(1690, 'Aikinia', NULL, 'R.Br.(SUH)', 76),
(1691, 'Ailantopsis', NULL, 'Gagnep.', 106),
(1692, 'Ainsliaea', NULL, 'DC.', 18),
(1693, 'Ainsworthia', NULL, 'Boiss.', 9),
(1694, 'Aiolotheca', NULL, 'DC.', 18),
(1695, 'Aipyanthus', NULL, 'Steven', 25),
(1696, 'Airosperma', NULL, 'K.Schum. & Lauterb.', 142),
(1697, 'Airyantha', NULL, 'Brummitt', 68),
(1698, 'Aisandra', NULL, 'Pierre', 148),
(1699, 'Aistopetalum', NULL, 'Schltr.', 50),
(1700, 'Aitchisonia', NULL, 'Hemsl. ex Aitch.', 142),
(1701, 'Aithales', NULL, 'Webb & Berthel.', 48),
(1702, 'Aitonia', NULL, 'Thunb.(SUH)', 106),
(1703, 'Aizopsis', NULL, 'Grulich', 48),
(1704, 'Ajania', NULL, 'Poljakov', 18),
(1705, 'Ajaniopsis', NULL, 'C.Shih', 18),
(1706, 'Ajuga', NULL, 'L.', 90),
(1707, 'Ajugoides', NULL, 'Makino', 90),
(1708, 'Aklema', NULL, 'Raf.', 66),
(1709, 'Aladenia', NULL, 'Pichon', 10),
(1710, 'Alafia', NULL, 'Thouars', 10),
(1711, 'Alagophyla', NULL, 'Raf.', 76),
(1712, 'Alajja', NULL, 'Ikonn.', 90),
(1713, 'Alatoseta', NULL, 'Compton', 18),
(1714, 'Alberta', NULL, 'E.Mey.', 142),
(1715, 'Albertia', NULL, 'Regel & Schmalh.(SUH)', 9),
(1716, 'Albertinia', NULL, 'Spreng.', 18),
(1717, 'Albertisia', NULL, 'Becc.', 107),
(1718, 'Albertisiella', NULL, 'Pierre ex Aubrev.', 148),
(1719, 'Albovia', NULL, 'Schischk.', 9),
(1720, 'Albraunia', NULL, 'Speta', 423),
(1721, 'Alcantara', NULL, 'Glaz. ex G.M.Barroso', 18),
(1722, 'Alcea', NULL, 'L.', 102),
(1723, 'Alchemilla', NULL, 'L.', 141),
(1724, 'Alcimandra', NULL, 'Dandy', 100),
(1725, 'Alcineanthus', NULL, 'Merr.', 66),
(1726, 'Alciope', NULL, 'DC. ex Lindl.', 18),
(1727, 'Alcmene', NULL, 'Urb.', 8),
(1728, 'Alcoceratothrix', NULL, 'Nied.', 101),
(1729, 'Alcoceria', NULL, 'Fernald', 66),
(1730, 'Aldama', NULL, 'La Llave', 18),
(1731, 'Aldina', NULL, 'Endl.', 68),
(1732, 'Aldinia', NULL, 'Raf.', 66),
(1733, 'Alectoroctonum', NULL, 'Schltdl.', 66),
(1734, 'Alectorolophus', NULL, 'Zinn', 150),
(1735, 'Alectra', NULL, 'Thunb.', 150),
(1736, 'Alectryon', NULL, 'Gaertn.', 147),
(1737, 'Aleisanthia', NULL, 'Ridl.', 142),
(1738, 'Alepidea', NULL, 'F.Delaroche', 9),
(1739, 'Alepidocalyx', NULL, 'Piper', 68),
(1740, 'Alepidocline', NULL, 'S.F.Blake', 18),
(1741, 'Alepis', NULL, 'Tiegh.', 98),
(1742, 'Aletes', NULL, 'J.M.Coult. & Rose', 9),
(1743, 'Aleurites', NULL, 'J.R.Forst. & G.Forst.', 66),
(1744, 'Alevia', NULL, 'Baill.', 66),
(1745, 'Alexa', NULL, 'Moq.', 68),
(1746, 'Alexandra', NULL, 'Bunge', 5),
(1747, 'Alexitoxicon', NULL, 'St.-Lag.', 10),
(1748, 'Alfaroa', NULL, 'Standl.', 87),
(1749, 'Alfonsia', NULL, 'Kunth', 15),
(1750, 'Alfredia', NULL, 'Cass.', 18),
(1751, 'Algernonia', NULL, 'Baill.', 66),
(1752, 'Alhagi', NULL, 'Gagnebin', 68),
(1753, 'Alibrexia', NULL, 'Miers', 154),
(1754, 'Alicabon', NULL, 'Raf.', 154),
(1755, 'Alicastrum', NULL, 'P.Browne', 109),
(1756, 'Aliella', NULL, 'Qaiser & Lack', 18),
(1757, 'Alifana', NULL, 'Raf.', 105),
(1758, 'Alifanus', NULL, 'Adans.', 105),
(1759, 'Alinula', NULL, 'J.Raynal', 55),
(1760, 'Alistilus', NULL, 'N.E.Br.', 68),
(1761, 'Aliteria', NULL, 'Benoist', 109),
(1762, 'Alkanna', NULL, 'Tausch', 25),
(1763, 'Alkekengi', NULL, 'Mill.', 154),
(1764, 'Allaeanthus', NULL, 'Thwaites', 109),
(1765, 'Allaeophania', NULL, 'Thwaites', 142),
(1766, 'Allagopappus', NULL, 'Cass.', 18),
(1767, 'Allagoptera', NULL, 'Nees', 15),
(1768, 'Allagosperma', NULL, 'M.Roem.', 49),
(1769, 'Allamanda', NULL, 'L.', 10),
(1770, 'Allantoma', NULL, 'Miers', 92),
(1771, 'Allardia', NULL, 'Decne.', 18),
(1772, 'Alleizettea', NULL, 'Dubard & Dop', 142),
(1773, 'Alleizettella', NULL, 'Pit.', 142),
(1774, 'Allemanda', NULL, 'L.(SUO)', 10),
(1775, 'Allenia', NULL, 'Ewart(SUH)', 66),
(1776, 'Allenrolfea', NULL, 'Kuntze', 5),
(1777, 'Alliaria', NULL, 'Heist. ex Fabr.', 197),
(1778, 'Allionia', NULL, 'L.', 117),
(1779, 'Allioniella', NULL, 'Rydb.', 117),
(1780, 'Allmania', NULL, 'R.Br. ex Wight', 5),
(1781, 'Allmaniopsis', NULL, 'Suess.', 5),
(1782, 'Allobia', NULL, 'Raf.', 66),
(1783, 'Allobium', NULL, 'Miers', 146),
(1784, 'Alloburkillia', NULL, 'Whitmore', 68),
(1785, 'Allocalyx', NULL, 'Cordem.', 150),
(1786, 'Allocarya', NULL, 'Greene', 25),
(1787, 'Allocaryastrum', NULL, 'Brand', 25),
(1788, 'Allocassine', NULL, 'N.Robson', 38),
(1789, 'Allocasuarina', NULL, 'L.A.S.Johnson', 36),
(1790, 'Allocheilos', NULL, 'W.T.Wang', 76),
(1791, 'Allohemia', NULL, 'Raf.', 98),
(1792, 'Alloispermum', NULL, 'Willd.', 18),
(1793, 'Allomaieta', NULL, 'Gleason', 105),
(1794, 'Allomarkgrafia', NULL, 'Woodson', 10),
(1795, 'Allomorphia', NULL, 'Blume', 105),
(1796, 'Alloneuron', NULL, 'Pilg.', 105),
(1797, 'Allopterigeron', NULL, 'Dunlop', 18),
(1798, 'Allosandra', NULL, 'Raf.', 66),
(1799, 'Allosanthus', NULL, 'Radlk.', 147),
(1800, 'Alloschemone', NULL, 'Schott', 12),
(1801, 'Alloschmidia', NULL, 'H.E.Moore', 15),
(1802, 'Allosidastrum', NULL, '(Hochr.) Krapov., Fryxell & D.M.', 102),
(1803, 'Allospondias', NULL, '(Pierre) Stapf', 6),
(1804, 'Allostigma', NULL, 'W.T.Wang', 76),
(1805, 'Allostis', NULL, 'Raf.', 116),
(1806, 'Allosyncarpia', NULL, 'S.T.Blake', 116),
(1807, 'Allotropa', NULL, 'Torr. & A.Gray', 64),
(1808, 'Allowissadula', NULL, 'D.M.Bates', 102),
(1809, 'Allowoodsonia', NULL, 'Markgr.', 10),
(1810, 'Alloxylon', NULL, 'P.H.Weston & Crisp', 135),
(1811, 'Allozygia', NULL, 'Naudin', 105),
(1812, 'Almaleea', NULL, 'Crisp & P.H.Weston', 68),
(1813, 'Almana', NULL, 'Raf.', 76),
(1814, 'Almeidea', NULL, 'A.St.-Hil.', 143),
(1815, 'Almutaster', NULL, 'A.Love & D.Love', 18),
(1816, 'Alocasia', NULL, '(Schott) G.Don', 12),
(1817, 'Alococarpum', NULL, 'Riedl & Kuber', 9),
(1818, 'Aloitis', NULL, 'Raf.', 75),
(1819, 'Alomia', NULL, 'Kunth', 18),
(1820, 'Alomiella', NULL, 'R.M.King & H.Rob.', 18),
(1821, 'Alona', NULL, 'Lindl.', 154),
(1822, 'Alonsoa', NULL, 'Ruiz & Pav.', 150),
(1823, 'Aloysia', NULL, 'Juss.', 173),
(1824, 'Alpaminia', NULL, 'O.E.Schulz', 197),
(1825, 'Alphandia', NULL, 'Baill.', 66),
(1826, 'Alphonseopsis', NULL, 'Baker f.', 8),
(1827, 'Alposelinum', NULL, 'Pimenov', 9),
(1828, 'Alsmithia', NULL, 'H.E.Moore', 15),
(1829, 'Alsobia', NULL, 'Hanst.', 76),
(1830, 'Alsocydia', NULL, 'Mart. ex J.C.Gomes', 22),
(1831, 'Alsodeia', NULL, 'Thouars', 174),
(1832, 'Alsodeidium', NULL, 'Engl.', 85),
(1833, 'Alsomitra', NULL, '(Blume) M.Roem.', 49),
(1834, 'Altamiranoa', NULL, 'Rose', 48),
(1835, 'Alternanthera', NULL, 'Forssk.', 5),
(1836, 'Althaea', NULL, 'L.', 102),
(1837, 'Althoffia', NULL, 'K.Schum.', 102),
(1838, 'Altora', NULL, 'Adans.', 66),
(1839, 'Alvaradoa', NULL, 'Liebm.', 533),
(1840, 'Alveolina', NULL, 'Tiegh.', 98),
(1841, 'Alvesia', NULL, 'Welw.', 90),
(1842, 'Alvimiantha', NULL, 'Grey-Wilson', 139),
(1843, 'Alvordia', NULL, 'Brandegee', 18),
(1844, 'Alyogyne', NULL, 'Alef.', 102),
(1845, 'Alysicarpus', NULL, 'Desv.', 68),
(1846, 'Alyssoides', NULL, 'Mill.', 197),
(1847, 'Alyssopsis', NULL, 'Boiss.', 197),
(1848, 'Alyssum', NULL, 'L.', 197),
(1849, 'Alyxia', NULL, 'Banks ex R.Br.', 10),
(1850, 'Alzatea', NULL, 'Ruiz & Pav.', 4),
(1851, 'Amalocalyx', NULL, 'Pierre', 10),
(1852, 'Amana', NULL, 'Honda', 94),
(1853, 'Amannia', NULL, 'Blume', 99),
(1854, 'Amaraboya', NULL, 'Linden ex Mast.', 105),
(1855, 'Amaracarpus', NULL, 'Blume', 142),
(1856, 'Amaracus', NULL, 'Gled.', 90),
(1857, 'Amaralia', NULL, 'Welw. ex Hook.f.', 142),
(1858, 'Amaranthus', NULL, 'L.', 5),
(1859, 'Amarolea', NULL, 'Small', 120),
(1860, 'Amaroria', NULL, 'A.Gray', 151),
(1861, 'Amasonia', NULL, 'L.f.', 90),
(1862, 'Amathea', NULL, 'Raf.', 1),
(1863, 'Amatlania', NULL, 'Lundell', 115),
(1864, 'Amatula', NULL, 'Medik.', 154),
(1865, 'Amauria', NULL, 'Benth.', 18),
(1866, 'Amauriella', NULL, 'Rendle', 12),
(1867, 'Ambaiba', NULL, 'Adans.(SUS)', 171),
(1868, 'Ambavia', NULL, 'Le Thomas', 8),
(1869, 'Ambelania', NULL, 'Aubl.', 10),
(1870, 'Amberboa', NULL, '(Pers.) Less.', 18),
(1871, 'Ambinux', NULL, 'Comm. ex Juss.', 66),
(1872, 'Amblyanthera', NULL, 'Mull.Arg.(SUH)', 10),
(1873, 'Amblyanthopsis', NULL, 'Mez', 115),
(1874, 'Amblyanthus', NULL, 'A.DC.', 115),
(1875, 'Amblygonocarpus', NULL, 'Harms', 68),
(1876, 'Amblynotopsis', NULL, 'J.F.Macbr.', 25),
(1877, 'Amblynotus', NULL, '(A.DC.) I.M.Johnst.', 25),
(1878, 'Amblyocalyx', NULL, 'Benth.', 10),
(1879, 'Amblyocarpum', NULL, 'Fisch. & C.A.Mey.', 18),
(1880, 'Amblyoglossum', NULL, 'Turcz.', 10),
(1881, 'Amblyolepis', NULL, 'DC.', 18),
(1882, 'Amblyopappus', NULL, 'Hook. & Arn.', 18),
(1883, 'Amblyopetalum', NULL, '(Griseb.) Malme', 10),
(1884, 'Amblystigma', NULL, 'Benth.', 10),
(1885, 'Amblytropis', NULL, 'Kitag.', 68),
(1886, 'Ambongia', NULL, 'Benoist', 1),
(1887, 'Amboroa', NULL, 'Cabrera', 18),
(1888, 'Ambraria', NULL, 'Fabr.', 142),
(1889, 'Ambroma', NULL, 'L.f.', 102),
(1890, 'Ambrosia', NULL, 'L.', 18),
(1891, 'Ambrosina', NULL, 'Bassi', 12),
(1892, 'Amburana', NULL, 'Schwacke & Taub.', 68),
(1893, 'Ameghinoa', NULL, 'Speg.', 18),
(1894, 'Amelanchier', NULL, 'Medik.', 141),
(1895, 'Amellus', NULL, 'L.', 18),
(1896, 'Amerosedum', NULL, 'A.Love & D.Love', 48),
(1897, 'Amesiodendron', NULL, 'Hu', 147),
(1898, 'Amethystanthus', NULL, 'Nakai', 90),
(1899, 'Amethystea', NULL, 'L.', 90),
(1900, 'Amherstia', NULL, 'Wall.', 68),
(1901, 'Amicia', NULL, 'Kunth', 68),
(1902, 'Ammandra', NULL, 'O.F.Cook', 15),
(1903, 'Ammanella', NULL, 'Miq.', 99),
(1904, 'Ammannia', NULL, 'L.', 99),
(1905, 'Ammi', NULL, 'L.', 9),
(1906, 'Ammianthus', NULL, 'Spruce ex Benth.', 142),
(1907, 'Ammiopsis', NULL, 'Boiss.', 9),
(1908, 'Ammobium', NULL, 'R.Br. ex Sims', 18),
(1909, 'Ammocodon', NULL, 'Standl.', 117),
(1910, 'Ammodaucus', NULL, 'Coss. & Durieu', 9),
(1911, 'Ammodendron', NULL, 'Fisch. ex DC.', 68),
(1912, 'Ammoides', NULL, 'Adans.', 9),
(1913, 'Ammopiptanthus', NULL, 'S.H.Cheng', 68),
(1914, 'Ammoselinum', NULL, 'Torr. & A.Gray', 9),
(1915, 'Ammosperma', NULL, 'Hook.f.', 197),
(1916, 'Ammothamnus', NULL, 'Bunge', 68),
(1917, 'Amolinia', NULL, 'R.M.King & H.Rob.', 18),
(1918, 'Amomis', NULL, 'O.Berg', 116),
(1919, 'Amomyrtella', NULL, 'Kausel', 116),
(1920, 'Amomyrtus', NULL, '(Burret) D.Legrand & Kausel', 116),
(1921, 'Amoora', NULL, 'Roxb.', 106),
(1922, 'Amoreuxia', NULL, 'Moc. & Sesse ex DC.', 43),
(1923, 'Amorpha', NULL, 'L.', 68),
(1924, 'Amorphophallus', NULL, 'Blume ex Decne.', 12),
(1925, 'Amorphospermum', NULL, 'F.Muell.', 148),
(1926, 'Ampalis', NULL, 'Bojer ex Bureau', 109),
(1927, 'Ampelamus', NULL, 'Raf.', 10),
(1928, 'Ampelocissus', NULL, 'Planch.', 181),
(1929, 'Ampelodaphne', NULL, 'Meisn.', 91),
(1930, 'Ampelopsis', NULL, 'Michx.', 181),
(1931, 'Ampelosicyos', NULL, 'Thouars', 49),
(1932, 'Ampelothamnus', NULL, 'Small', 64),
(1933, 'Ampelozizyphus', NULL, 'Ducke', 139),
(1934, 'Amperea', NULL, 'A.Juss.', 66),
(1935, 'Amphania', NULL, 'Banks ex DC.', 162),
(1936, 'Amphiachyris', NULL, '(DC.) Nutt.', 18),
(1937, 'Amphianthus', NULL, 'Torr.', 150),
(1938, 'Amphiasma', NULL, 'Bremek.', 142),
(1939, 'Amphiblemma', NULL, 'Naudin', 105),
(1940, 'Amphibologyne', NULL, 'Brand', 25),
(1941, 'Amphicarpaea', NULL, 'Elliott ex Nutt.', 68),
(1942, 'Amphicome', NULL, 'Royle', 22),
(1943, 'Amphicosmia', NULL, 'Gardner', 52),
(1944, 'Amphidasya', NULL, 'Standl.', 142),
(1945, 'Amphidetes', NULL, 'E.Fourn.', 10),
(1946, 'Amphidoxa', NULL, 'DC.', 18),
(1947, 'Amphiestes', NULL, 'S.Moore', 1),
(1948, 'Amphiglossa', NULL, 'DC.', 18),
(1949, 'Amphilochia', NULL, 'Mart.', 175),
(1950, 'Amphilophium', NULL, 'Kunth', 22),
(1951, 'Amphineurion', NULL, '(A.DC.) Pichon', 10),
(1952, 'Amphiodon', NULL, 'Huber', 68),
(1953, 'Amphipappus', NULL, 'Torr. & A.Gray', 18),
(1954, 'Amphipleis', NULL, 'Raf.', 154),
(1955, 'Amphipterygium', NULL, 'Schiede ex Standl.', 6),
(1956, 'Amphirrhox', NULL, 'Spreng.', 174),
(1957, 'Amphiscirpus', NULL, 'Oteng-Yeb.', 55),
(1958, 'Amphiscopia', NULL, 'Nees', 1),
(1959, 'Amphistelma', NULL, 'Griseb.', 10),
(1960, 'Amphithalea', NULL, 'Eckl. & Zeyh.', 68),
(1961, 'Amphitoma', NULL, 'Gleason', 105),
(1962, 'Amphorella', NULL, 'Brandegee', 10),
(1963, 'Amphoricarpos', NULL, 'Vis.', 18),
(1964, 'Amphoricarpus', NULL, 'Spruce ex Miers', 92),
(1965, 'Amphorocalyx', NULL, 'Baker', 105),
(1966, 'Amphorogyne', NULL, 'Stauffer & Hurl.', 146),
(1967, 'Amsinckia', NULL, 'Lehm.', 25),
(1968, 'Amsonia', NULL, 'Walter', 10),
(1969, 'Amydrium', NULL, 'Schott', 12),
(1970, 'Amyema', NULL, 'Tiegh.', 98),
(1971, 'Amygdalopersica', NULL, 'Daniel', 141),
(1972, 'Amygdalophora', NULL, 'M.Roem.', 141),
(1973, 'Amygdalopsis', NULL, 'M.Roem.(SUH)', 141),
(1974, 'Amygdalus', NULL, 'L.', 141),
(1975, 'Amylocarpus', NULL, 'Barb.Rodr.', 15),
(1976, 'Amylotheca', NULL, 'Tiegh.', 98),
(1977, 'Amyrea', NULL, 'Leandri', 66),
(1978, 'Amyrsia', NULL, 'Raf.', 116),
(1979, 'Anabaena', NULL, 'A.Juss.(SUH)', 66),
(1980, 'Anabaenella', NULL, 'Pax & K.Hoffm.(SUS)', 66),
(1981, 'Anabasis', NULL, 'L.', 5),
(1982, 'Anacampta', NULL, 'Miers', 10),
(1983, 'Anacantha', NULL, '(Iljin) Sojak', 18),
(1984, 'Anacaona', NULL, 'Alain', 49),
(1985, 'Anacyclus', NULL, 'L.', 18),
(1986, 'Anadenanthera', NULL, 'Speg.', 68),
(1987, 'Anadendrum', NULL, 'Schott', 12),
(1988, 'Anaectocalyx', NULL, 'Triana ex Hook.f.', 105),
(1989, 'Anagallidium', NULL, 'Griseb.', 75),
(1990, 'Anagallis', NULL, 'L.', 115),
(1991, 'Anagosperma', NULL, 'Wettst.', 150),
(1992, 'Anagyris', NULL, 'L.', 68),
(1993, 'Anakasia', NULL, 'Philipson', 13),
(1994, 'Anamirta', NULL, 'Colebr.', 107),
(1995, 'Anamomis', NULL, 'Griseb.', 116),
(1996, 'Anantherix', NULL, 'Nutt.', 10),
(1997, 'Anaphalioides', NULL, '(Benth.) Kirp.', 18),
(1998, 'Anaphalis', NULL, 'DC.', 18),
(1999, 'Anaphrenium', NULL, 'E.Mey. ex Endl.', 6),
(2000, 'Anaphyllopsis', NULL, 'A.Hay', 12),
(2001, 'Anaphyllum', NULL, 'Schott', 12),
(2002, 'Anarrhinum', NULL, 'Desf.', 423),
(2003, 'Anarthrophyllum', NULL, 'Benth.', 68),
(2004, 'Anartia', NULL, 'Miers', 10),
(2005, 'Anaspis', NULL, 'Rech.f.', 90),
(2006, 'Anastatica', NULL, 'L.', 197),
(2007, 'Anastrabe', NULL, 'E.Mey. ex Benth.', 150),
(2008, 'Anastraphia', NULL, 'D.Don', 18),
(2009, 'Anatropanthus', NULL, 'Schltr.', 10),
(2010, 'Anatropostylia', NULL, '(Plitmann) Kupicha', 68),
(2011, 'Anaua', NULL, 'Miq.', 66),
(2012, 'Anaueria', NULL, 'Kosterm.', 91),
(2013, 'Anauxanopetalum', NULL, 'Teijsm. & Binn.', 6),
(2014, 'Anaxeton', NULL, 'Gaertn.', 18),
(2015, 'Ancalanthus', NULL, 'Balf.f.(SUO)', 1),
(2016, 'Ancana', NULL, 'F.Muell.', 8),
(2017, 'Ancathia', NULL, 'DC.', 18),
(2018, 'Anchietea', NULL, 'A.St.-Hil.', 174),
(2019, 'Anchomanes', NULL, 'Schott', 12),
(2020, 'Anchonium', NULL, 'DC.', 197),
(2021, 'Anchusa', NULL, 'L.', 25),
(2022, 'Ancistranthus', NULL, 'Lindau', 1),
(2023, 'Ancistrocarphus', NULL, 'A.Gray', 18),
(2024, 'Ancistrocarpus', NULL, 'Oliv.', 102),
(2025, 'Ancistrocarya', NULL, 'Maxim.', 25),
(2026, 'Ancistrodesmus', NULL, 'Naudin', 105),
(2027, 'Ancistrophora', NULL, 'A.Gray', 18),
(2028, 'Ancistrophyllum', NULL, '(G.Mann & H.Wendl.) H.Wendl.', 15),
(2029, 'Ancistrostylis', NULL, 'T.Yamaz.', 150),
(2030, 'Ancistrothyrsus', NULL, 'Harms', 127),
(2031, 'Ancylacanthus', NULL, 'Lindau', 1),
(2032, 'Ancylanthos', NULL, 'Desf.', 142),
(2033, 'Ancylanthus', NULL, 'Steud.', 142),
(2034, 'Ancylobothrys', NULL, 'Pierre', 10),
(2035, 'Ancylobotrys', NULL, 'Pierre(SUO)', 10),
(2036, 'Ancylocladus', NULL, 'Wall.', 10),
(2037, 'Ancylostemon', NULL, 'Craib', 76),
(2038, 'Anda', NULL, 'A.Juss.(SUS)', 66),
(2039, 'Andersonia', NULL, 'R.Br.', 64),
(2040, 'Anderssoniopiper', NULL, 'Trel.', 130),
(2041, 'Andicus', NULL, 'Vell.(SUS)', 66),
(2042, 'Andrachne', NULL, 'L.', 184),
(2043, 'Andradea', NULL, 'Allemao', 117),
(2044, 'Andradia', NULL, 'Sim', 68),
(2045, 'Andresia', NULL, 'Sleumer', 64),
(2046, 'Androcalymma', NULL, 'Dwyer', 68),
(2047, 'Androcentrum', NULL, 'Lem.', 1),
(2048, 'Androcera', NULL, 'Nutt.', 154),
(2049, 'Andrographis', NULL, 'Wall. ex Nees', 1),
(2050, 'Andromeda', NULL, 'L.', 64),
(2051, 'Andromycia', NULL, 'A.Rich.', 12),
(2052, 'Androphoranthus', NULL, 'H.Karst.', 66),
(2053, 'Andropus', NULL, 'Brand', 25),
(2054, 'Androsiphonia', NULL, 'Stapf', 127),
(2055, 'Androstachys', NULL, 'Prain', 534),
(2056, 'Androstylanthus', NULL, 'Ducke', 109),
(2057, 'Androstylium', NULL, 'Miq.', 42),
(2058, 'Androtrichum', NULL, '(Brongn.) Brongn.', 55),
(2059, 'Androtropis', NULL, 'R.Br.', 142),
(2060, 'Androya', NULL, 'H.Perrier', 150),
(2061, 'Andryala', NULL, 'L.', 18),
(2062, 'Andrzeiowskya', NULL, 'Rchb.', 197),
(2063, 'Anechites', NULL, 'Griseb.', 10),
(2064, 'Anelsonia', NULL, 'J.F.Macbr. & Payson', 197),
(2065, 'Anemopaegma', NULL, 'Mart. ex Meisn.', 22),
(2066, 'Anepsias', NULL, 'Schott', 12),
(2067, 'Anerincleistus', NULL, 'Korth.', 105),
(2068, 'Anetanthus', NULL, 'Hiern ex Benth.', 76),
(2069, 'Anethum', NULL, 'L.', 9),
(2070, 'Aneulophus', NULL, 'Benth.', 65),
(2071, 'Angadenia', NULL, 'Miers', 10),
(2072, 'Angasomyrtus', NULL, 'Trudgen & Keighery', 116),
(2073, 'Angelandra', NULL, 'Endl.', 66),
(2074, 'Angelesia', NULL, 'Korth.', 40),
(2075, 'Angelica', NULL, 'L.', 9),
(2076, 'Angelocarpa', NULL, 'Rupr.', 9),
(2077, 'Angelonia', NULL, 'Bonpl.', 423),
(2078, 'Angelphytum', NULL, 'G.M.Barroso', 18),
(2079, 'Angianthus', NULL, 'J.C.Wendl.', 18),
(2080, 'Anginon', NULL, 'Raf.', 9),
(2081, 'Angkalanthus', NULL, 'Balf.f.', 1),
(2082, 'Angolluma', NULL, 'R.Munster', 10),
(2083, 'Angophora', NULL, 'Cav.', 116),
(2084, 'Angoseseli', NULL, 'Chiov.', 9),
(2085, 'Angostura', NULL, 'Roem. & Schult.', 143),
(2086, 'Angostyles', NULL, 'Benth.', 66),
(2087, 'Angostylidium', NULL, '(Mull.Arg.) Pax & K.Hoffm.', 66),
(2088, 'Angostylis', NULL, 'Benth.', 66),
(2089, 'Anguillicarpus', NULL, 'Burkill', 197),
(2090, 'Anguina', NULL, 'Mill.', 49),
(2091, 'Anguria', NULL, 'Jacq.(SUH)', 49),
(2092, 'Anguriopsis', NULL, 'J.R.Johnst.', 49),
(2093, 'Aningeria', NULL, 'Aubrev. & Pellegr.', 148),
(2094, 'Aniotum', NULL, 'Sol. ex Parkinson', 68),
(2095, 'Anisacanthus', NULL, 'Nees', 1),
(2096, 'Anisadenia', NULL, 'Wall. ex Meisn.', 95),
(2097, 'Anisanthera', NULL, 'Raf.', 25),
(2098, 'Anisantherina', NULL, 'Pennell', 150),
(2099, 'Aniseia', NULL, 'Choisy', 46),
(2100, 'Anisepta', NULL, 'Raf.', 66),
(2101, 'Aniserica', NULL, 'N.E.Br.', 64),
(2102, 'Anisocentrum', NULL, 'Turcz.', 105),
(2103, 'Anisochaeta', NULL, 'DC.', 18),
(2104, 'Anisochilus', NULL, 'Wall. ex Benth.', 90),
(2105, 'Anisocoma', NULL, 'Torr. & A.Gray', 18),
(2106, 'Anisocycla', NULL, 'Baill.', 107),
(2107, 'Anisodontea', NULL, 'C.Presl', 102),
(2108, 'Anisodus', NULL, 'Link ex Spreng.', 154),
(2109, 'Anisolobus', NULL, 'A.DC.', 10),
(2110, 'Anisomallon', NULL, 'Baill.', 85),
(2111, 'Anisomeles', NULL, 'R.Br.', 90),
(2112, 'Anisomeria', NULL, 'D.Don', 128),
(2113, 'Anisomeris', NULL, 'C.Presl', 142),
(2114, 'Anisonema', NULL, 'A.Juss.', 184),
(2115, 'Anisopappus', NULL, 'Hook. & Arn.', 18),
(2116, 'Anisophyllum', NULL, 'G.Don(SUO)', 7),
(2117, 'Anisoplectus', NULL, 'Oerst.', 76),
(2118, 'Anisopoda', NULL, 'Baker', 9),
(2119, 'Anisopus', NULL, 'N.E.Br.', 10),
(2120, 'Anisosciadium', NULL, 'DC.', 9),
(2121, 'Anisosepalum', NULL, 'E.Hossain', 1),
(2122, 'Anisosperma', NULL, 'Silva Manso', 49),
(2123, 'Anisostachya', NULL, 'Nees', 1),
(2124, 'Anisostemon', NULL, 'Turcz.', 45),
(2125, 'Anisostichus', NULL, 'Bureau', 22),
(2126, 'Anisothrix', NULL, 'O.Hoffm. ex Kuntze', 18),
(2127, 'Anisotoma', NULL, 'Fenzl', 10),
(2128, 'Anisotome', NULL, 'Hook.f.', 9),
(2129, 'Anistelma', NULL, 'Raf.', 142),
(2130, 'Anna', NULL, 'Pellegr.', 76),
(2131, 'Annaea', NULL, 'Kolak.', 30),
(2132, 'Annesijoa', NULL, 'Pax & K.Hoffm.', 66),
(2133, 'Anneslea', NULL, 'Wall.', 409),
(2134, 'Anneslia', NULL, 'Salisb.', 68),
(2135, 'Annesorhiza', NULL, 'Cham. & Schltdl.', 9),
(2136, 'Annulodiscus', NULL, 'Tardieu', 38),
(2137, 'Anoda', NULL, 'Cav.', 102),
(2138, 'Anodendron', NULL, 'A.DC.', 10),
(2139, 'Anodiscus', NULL, 'Benth.', 76),
(2140, 'Anodopetalum', NULL, 'A.Cunn. ex Endl.', 50),
(2141, 'Anoectocalyx', NULL, 'Hook.f.(SUO)', 105),
(2142, 'Anogra', NULL, 'Spach', 121),
(2143, 'Anomacanthus', NULL, 'R.D.Good', 1),
(2144, 'Anomalanthus', NULL, 'Klotzsch', 64),
(2145, 'Anomalocalyx', NULL, 'Ducke', 66),
(2146, 'Anomalopteris', NULL, '(DC.) G.Don(SUO)', 101),
(2147, 'Anomalopterys', NULL, '(DC.) G.Don', 101),
(2148, 'Anomalosicyos', NULL, 'Gentry', 49),
(2149, 'Anomanthodia', NULL, 'Hook.f.', 142),
(2150, 'Anomianthus', NULL, 'Zoll.', 8),
(2151, 'Anomoctenium', NULL, 'Pichon', 22),
(2152, 'Anomopanax', NULL, 'Harms', 9),
(2153, 'Anomosanthes', NULL, 'Blume', 147),
(2154, 'Anomospermum', NULL, 'Dalzell(SUH)', 107),
(2155, 'Anomostachys', NULL, '(Baill.) Hurus.', 66),
(2156, 'Anomostephium', NULL, 'DC.', 18),
(2157, 'Anomotassa', NULL, 'K.Schum.', 10),
(2158, 'Anoniodes', NULL, 'Schltr.', 62),
(2159, 'Anonocarpus', NULL, 'Ducke', 109),
(2160, 'Anoplanthus', NULL, 'Endl.', 150),
(2161, 'Anoplocaryum', NULL, 'Ledeb.', 25),
(2162, 'Anoplon', NULL, 'Rchb.', 150),
(2163, 'Anosporum', NULL, 'Nees', 55),
(2164, 'Anotea', NULL, '(DC.) Kunth', 102),
(2165, 'Anothea', NULL, 'O.F.Cook', 15),
(2166, 'Anotis', NULL, 'DC.', 142),
(2167, 'Anplectrella', NULL, 'Furtado', 105),
(2168, 'Anplectrum', NULL, 'A.Gray', 105),
(2169, 'Anstrutheria', NULL, 'Gardner', 140),
(2170, 'Antacanthus', NULL, 'A.Rich. ex DC.', 142),
(2171, 'Antagonia', NULL, 'Griseb.', 49),
(2172, 'Antelaea', NULL, 'Gaertn.', 106),
(2173, 'Antennaria', NULL, 'Gaertn.', 18),
(2174, 'Antenoron', NULL, 'Raf.', 134),
(2175, 'Anthacantha', NULL, 'Lem.', 66),
(2176, 'Anthacanthus', NULL, 'Nees', 1),
(2177, 'Anthactinia', NULL, 'Bory ex M.Roem.', 127),
(2178, 'Anthagathis', NULL, 'Harms', 45),
(2179, 'Antheliacanthus', NULL, 'Ridl.', 1),
(2180, 'Anthemis', NULL, 'L.', 18),
(2181, 'Anthericum', NULL, 'L.', 3),
(2182, 'Antheropeas', NULL, 'Rydb.', 18),
(2183, 'Antheroporum', NULL, 'Gagnep.', 68),
(2184, 'Antherothamnus', NULL, 'N.E.Br.', 150),
(2185, 'Antherotoma', NULL, '(Naudin) Hook.f.', 105),
(2186, 'Antherura', NULL, 'Lour.', 142),
(2187, 'Antherylium', NULL, 'Rohr', 99),
(2188, 'Anthobembix', NULL, 'Perkins', 108),
(2189, 'Anthobolus', NULL, 'R.Br.', 146),
(2190, 'Anthocarapa', NULL, 'Pierre', 106),
(2191, 'Anthocercis', NULL, 'Labill.', 154),
(2192, 'Anthochlamys', NULL, 'Fenzl', 5),
(2193, 'Anthoclitandra', NULL, '(Pierre) Pichon', 10),
(2194, 'Anthodon', NULL, 'Ruiz & Pav.', 38),
(2195, 'Antholoma', NULL, 'Labill.', 62),
(2196, 'Anthopteropsis', NULL, 'A.C.Sm.', 64),
(2197, 'Anthopterus', NULL, 'Hook.', 64),
(2198, 'Anthorrhiza', NULL, 'C.R.Huxley & Jebb', 142),
(2199, 'Anthospermum', NULL, 'L.', 142),
(2200, 'Anthostema', NULL, 'Juss.', 66),
(2201, 'Anthostyrax', NULL, 'Pierre', 158),
(2202, 'Anthotroche', NULL, 'Endl.', 154),
(2203, 'Anthriscus', NULL, 'Pers.', 9),
(2204, 'Anthurium', NULL, 'Schott', 12),
(2205, 'Anthyllis', NULL, 'L.', 68),
(2206, 'Antia', NULL, 'O.F.Cook', 15),
(2207, 'Antiaropsis', NULL, 'K.Schum.', 109),
(2208, 'Anticharis', NULL, 'Endl.', 150),
(2209, 'Antidaphne', NULL, 'Poepp. & Endl.', 63),
(2210, 'Antigonon', NULL, 'Endl.', 134),
(2211, 'Antillia', NULL, 'R.M.King & H.Rob.', 18),
(2212, 'Antimion', NULL, 'Raf.', 154),
(2213, 'Antinisa', NULL, '(Tul.) Hutch.', 145),
(2214, 'Antiotrema', NULL, 'Hand.-Mazz.', 25),
(2215, 'Antiphiona', NULL, 'Merxm.', 18),
(2216, 'Antiphytum', NULL, 'DC. ex Meisn.', 25),
(2217, 'Antirhoea', NULL, 'Comm. ex Juss.', 142),
(2218, 'Antirrhinum', NULL, 'L.', 423),
(2219, 'Antirrhoea', NULL, 'Endl.', 142),
(2220, 'Antistrophe', NULL, 'A.DC.', 115),
(2221, 'Antithrixia', NULL, 'DC.', 18),
(2222, 'Antizoma', NULL, 'Miers', 107),
(2223, 'Antongilia', NULL, 'Jum.', 15),
(2224, 'Antonia', NULL, 'Pohl', 97),
(2225, 'Antoniana', NULL, 'Tussac', 142),
(2226, 'Antonina', NULL, 'Vved.', 90),
(2227, 'Antopetitia', NULL, 'A.Rich.', 68),
(2228, 'Antriba', NULL, 'Raf.', 98),
(2229, 'Antrophora', NULL, 'I.M.Johnst.', 25),
(2230, 'Anubias', NULL, 'Schott', 12),
(2231, 'Anulocaulis', NULL, 'Standl.', 117),
(2232, 'Anura', NULL, '(Juz.) Tscherneva', 18),
(2233, 'Anvillea', NULL, 'DC.', 18),
(2234, 'Anvilleina', NULL, 'Maire', 18),
(2235, 'Aonikena', NULL, 'Speg.', 66),
(2236, 'Aotus', NULL, 'Sm.', 68),
(2237, 'Apalochlamys', NULL, '(Cass.) Cass.', 18),
(2238, 'Apaloxylon', NULL, 'Drake', 68),
(2239, 'Apama', NULL, 'Lam.', 16),
(2240, 'Apargidium', NULL, 'Torr. & A.Gray', 18),
(2241, 'Aparinanthus', NULL, 'Fourr.', 142),
(2242, 'Aparine', NULL, 'Guett.', 142),
(2243, 'Aparinella', NULL, 'Fourr.', 142),
(2244, 'Apassalus', NULL, 'Kobuski', 1),
(2245, 'Apatemone', NULL, 'Schott', 12),
(2246, 'Apatitia', NULL, 'Desv.', 105),
(2247, 'Apatophyllum', NULL, 'McGill.', 38),
(2248, 'Apatzingania', NULL, 'Dieterle', 49),
(2249, 'Apemon', NULL, 'Raf.', 154),
(2250, 'Apentostera', NULL, 'Raf.', 150),
(2251, 'Apetahia', NULL, 'Baill.', 30),
(2252, 'Aphaenandra', NULL, 'Miq.', 142),
(2253, 'Aphaerema', NULL, 'Miers', 145),
(2254, 'Aphanactis', NULL, 'Wedd.', 18),
(2255, 'Aphanandrium', NULL, 'Lindau', 1),
(2256, 'Aphandra', NULL, 'Barfod', 15),
(2257, 'Aphanes', NULL, 'L.', 141),
(2258, 'Aphania', NULL, 'Blume', 147),
(2259, 'Aphanisma', NULL, 'Nutt. ex Moq.', 5),
(2260, 'Aphanocalyx', NULL, 'Oliv.', 68),
(2261, 'Aphanocarpus', NULL, 'Steyerm.', 142),
(2262, 'Aphanochilus', NULL, 'Benth.', 90),
(2263, 'Aphanococcus', NULL, 'Radlk.', 147),
(2264, 'Aphanomyrtus', NULL, 'Miq.', 116),
(2265, 'Aphanopetalum', NULL, 'Endl.', 503),
(2266, 'Aphanopleura', NULL, 'Boiss.', 9),
(2267, 'Aphanosperma', NULL, 'T.F.Daniel', 1),
(2268, 'Aphanostelma', NULL, 'Malme', 10),
(2269, 'Aphanostephus', NULL, 'DC.', 18),
(2270, 'Aphanostylis', NULL, 'Pierre', 10),
(2271, 'Aphantochaeta', NULL, 'A.Gray', 18),
(2272, 'Aphelandrella', NULL, 'Mildbr.', 1),
(2273, 'Aphloia', NULL, '(DC.) Benn.', 504),
(2274, 'Aphora', NULL, 'Nutt.', 66),
(2275, 'Aphragmia', NULL, 'Nees', 1),
(2276, 'Aphragmus', NULL, 'Andrz. ex DC.', 197),
(2277, 'Aphyllarum', NULL, 'S.Moore', 12),
(2278, 'Aphyllocladus', NULL, 'Wedd.', 18),
(2279, 'Aphyllodium', NULL, '(DC.) Gagnep.', 68),
(2280, 'Aphyllon', NULL, 'Mitch.', 400),
(2281, 'Apiastrum', NULL, 'Nutt.', 9),
(2282, 'Apilia', NULL, 'Raf.(SUO)', 120),
(2283, 'Apiopetalum', NULL, 'Baill.', 9),
(2284, 'Apios', NULL, 'Fabr.', 68),
(2285, 'Apium', NULL, 'L.', 9),
(2286, 'Aplanodes', NULL, 'Marais', 197),
(2287, 'Aplarina', NULL, 'Raf.', 66),
(2288, 'Apleura', NULL, 'Phil.', 9),
(2289, 'Aplilia', NULL, 'Raf.', 120),
(2290, 'Aploca', NULL, 'Neck. ex Kuntze', 10),
(2291, 'Aplocarya', NULL, 'Lindl.', 154),
(2292, 'Apocaulon', NULL, 'R.S.Cowan', 143),
(2293, 'Apochoris', NULL, 'Duby', 115),
(2294, 'Apocynum', NULL, 'L.', 10),
(2295, 'Apodandra', NULL, 'Pax & K.Hoffm.', 66),
(2296, 'Apodanthera', NULL, 'Arn.', 49),
(2297, 'Apodicarpum', NULL, 'Makino', 9),
(2298, 'Apodina', NULL, 'Tiegh.', 98),
(2299, 'Apodiscus', NULL, 'Hutch.', 66),
(2300, 'Apodocephala', NULL, 'Baker', 18),
(2301, 'Apodostigma', NULL, 'R.Wilczek', 38),
(2302, 'Apoia', NULL, 'Merr.', 148),
(2303, 'Apolepsis', NULL, '(Blume) Hassk.', 1),
(2304, 'Apollonias', NULL, 'Nees', 91),
(2305, 'Apomuria', NULL, 'Bremek.', 142),
(2306, 'Aponoa', NULL, 'Raf.', 76),
(2307, 'Apophyllum', NULL, 'F.Muell.', 32),
(2308, 'Apoplanesia', NULL, 'C.Presl', 68),
(2309, 'Aporosella', NULL, 'Chodat', 184),
(2311, 'Aposeris', NULL, 'Neck. ex Cass.', 18),
(2312, 'Apostates', NULL, 'Lander', 18),
(2313, 'Apoxyanthera', NULL, 'Hochst.', 10),
(2314, 'Appendicularia', NULL, 'DC.', 105),
(2315, 'Appunettia', NULL, 'R.D.Good', 142),
(2316, 'Aprevalia', NULL, 'Baill.', 68),
(2317, 'Aptandropsis', NULL, 'Ducke', 119),
(2318, 'Apterantha', NULL, 'C.H.Wright', 5),
(2319, 'Apterokarpos', NULL, 'Rizzini', 6),
(2320, 'Apteron', NULL, 'Kurz', 139),
(2321, 'Apterosperma', NULL, 'H.T.Chang', 162),
(2322, 'Apterygia', NULL, 'Baehni', 148),
(2323, 'Apteuxis', NULL, 'Griff.', 105),
(2324, 'Aptosimum', NULL, 'Burch. ex Benth.', 150),
(2325, 'Aptotheca', NULL, 'Miers', 10),
(2326, 'Apurimacia', NULL, 'Harms', 68),
(2327, 'Aquartia', NULL, 'Jacq.', 154),
(2328, 'Arabidella', NULL, '(F.Muell.) O.E.Schulz', 197),
(2329, 'Arabidium', NULL, 'Spach', 197),
(2330, 'Arabidopsis', NULL, 'Heynh.', 197),
(2331, 'Arabis', NULL, 'L.', 197),
(2332, 'Arabisa', NULL, 'Rchb.', 197),
(2333, 'Arachis', NULL, 'L.', 68),
(2334, 'Arachne', NULL, '(Endl.) Pojark.', 184),
(2335, 'Arachnimorpha', NULL, 'Desv.', 142),
(2336, 'Arachnocalyx', NULL, 'Compton', 64),
(2337, 'Arachnodes', NULL, 'Gagnep.', 184),
(2338, 'Arachnothryx', NULL, 'Planch.', 142),
(2339, 'Arafoe', NULL, 'Pimenov & Lavrova', 9),
(2340, 'Aragallus', NULL, 'Neck. ex Greene', 68),
(2341, 'Aragoa', NULL, 'Kunth', 423),
(2342, 'Araliorhamnus', NULL, 'H.Perrier', 139),
(2343, 'Arapatiella', NULL, 'Rizzini & A.Mattos', 68),
(2344, 'Arariba', NULL, 'Mart.', 142),
(2345, 'Ararocarpus', NULL, 'Scheff.', 8),
(2346, 'Araucaria', NULL, 'Juss.', 14),
(2347, 'Araujia', NULL, 'Brot.', 10),
(2348, 'Arausiaca', NULL, 'Blume', 15),
(2349, 'Arbelaezaster', NULL, 'Cuatrec.', 18),
(2350, 'Arbulocarpus', NULL, 'Tennant', 142),
(2351, 'Arbutus', NULL, 'L.', 64),
(2352, 'Arcangelisia', NULL, 'Becc.', 107),
(2353, 'Arceuthobium', NULL, 'M.Bieb.', 146),
(2354, 'Arceuthos', NULL, 'Antoine & Kotschy', 51),
(2355, 'Archboldia', NULL, 'E.Beer & H.J.Lam', 90),
(2356, 'Archboldiodendron', NULL, 'Kobuski', 409),
(2357, 'Archeria', NULL, 'Hook.f.', 64),
(2358, 'Archiatriplex', NULL, 'G.L.Chu', 5),
(2359, 'Archibaccharis', NULL, 'Heering', 18),
(2360, 'Archiboehmeria', NULL, 'C.J.Chen', 171),
(2361, 'Archidendropsis', NULL, 'I.C.Nielsen', 68),
(2362, 'Archiphysalis', NULL, 'Kuang', 154),
(2363, 'Archirhodomyrtus', NULL, '(Nied.) Burret', 116),
(2364, 'Archontophoenix', NULL, 'H.Wendl. & Drude', 15),
(2365, 'Arcoa', NULL, 'Urb.', 68),
(2366, 'Arctanthemum', NULL, '(Tzvelev) Tzvelev', 18),
(2367, 'Arcterica', NULL, 'Coville', 64),
(2368, 'Arctium', NULL, 'L.', 18),
(2369, 'Arctocalyx', NULL, 'Fenzl', 76),
(2370, 'Arctocrania', NULL, 'Nakai', 47),
(2371, 'Arctogentia', NULL, 'A.Love', 75),
(2372, 'Arctogeron', NULL, 'DC.', 18),
(2373, 'Arctomecon', NULL, 'Torr. & Frem.', 126),
(2374, 'Arctopus', NULL, 'L.', 9),
(2375, 'Arctostaphylos', NULL, 'Adans.', 64),
(2376, 'Arctotheca', NULL, 'J.C.Wendl.', 18),
(2377, 'Arctotis', NULL, 'L.', 18),
(2378, 'Arctottonia', NULL, 'Trel.', 130),
(2379, 'Arctous', NULL, 'Nied.', 64),
(2380, 'Arculus', NULL, 'Tiegh.', 98),
(2381, 'Arcyosperma', NULL, 'O.E.Schulz', 197),
(2382, 'Arcytophyllum', NULL, 'Willd. ex Schult. & Schult.f.', 142),
(2383, 'Ardinghalia', NULL, 'Comm. ex Juss.', 184),
(2384, 'Ardisiandra', NULL, 'Hook.f.', 115),
(2385, 'Arecastrum', NULL, '(Drude) Becc.', 15),
(2386, 'Arechavaletaia', NULL, 'Speg.', 145),
(2387, 'Aremonia', NULL, 'Neck. ex Nestl.', 141),
(2388, 'Arfeuillea', NULL, 'Pierre ex Radlk.', 147),
(2389, 'Argania', NULL, 'Roem. & Schult.', 148),
(2390, 'Argelia', NULL, 'Decne.', 10),
(2391, 'Argemone', NULL, 'L.', 126),
(2392, 'Argentina', NULL, 'Hill', 141),
(2393, 'Argithamnia', NULL, 'Sw.(SUO)', 66),
(2394, 'Argocoffea', NULL, '(Pierre ex De Wild.) Lebrun(SUI)', 142),
(2395, 'Argocoffeopsis', NULL, 'Lebrun', 142),
(2396, 'Argomuellera', NULL, 'Pax', 66),
(2397, 'Argophilum', NULL, 'Blanco', 106),
(2398, 'Argostemma', NULL, 'Wall.', 142),
(2399, 'Argostemmella', NULL, 'Ridl.', 142),
(2400, 'Argothamnia', NULL, 'Spreng.(SUO)', 66),
(2401, 'Argusia', NULL, 'Boehm.', 25),
(2402, 'Argylia', NULL, 'D.Don', 22),
(2403, 'Argyra', NULL, 'Noronha ex Baill.', 66),
(2404, 'Argyranthemum', NULL, 'Webb', 18),
(2405, 'Argyreia', NULL, 'Lour.', 46),
(2406, 'Argyrella', NULL, 'Naudin', 105),
(2407, 'Argyrocytisus', NULL, '(Maire) Raynaud', 68),
(2408, 'Argyrodendron', NULL, '(Endl.) Klotzsch(SUH)', 66),
(2409, 'Argyroglottis', NULL, 'Turcz.', 18),
(2410, 'Argyrolobium', NULL, 'Eckl. & Zeyh.', 68),
(2411, 'Argyronerium', NULL, 'Pit.', 10),
(2412, 'Argyrophanes', NULL, 'Schltdl.', 18),
(2413, 'Argyrothamnia', NULL, 'Mull.Arg.(SUO)', 66),
(2414, 'Argyrovernonia', NULL, 'MacLeish', 18),
(2415, 'Argyroxiphium', NULL, 'DC.', 18),
(2416, 'Argytamnia', NULL, 'Duchesne(SUO)', 66),
(2417, 'Argythamnia', NULL, 'P.Browne', 66),
(2418, 'Aria', NULL, '(Pers.) Host', 141),
(2419, 'Ariadne', NULL, 'Urb.', 142),
(2420, 'Aridarum', NULL, 'Ridl.', 12),
(2421, 'Arikury', NULL, 'Becc.', 15),
(2422, 'Arikuryroba', NULL, 'Barb.Rodr.', 15),
(2423, 'Arillastrum', NULL, 'Pancher ex Baill.', 116),
(2424, 'Ariopsis', NULL, 'Nimmo', 12),
(2425, 'Ariosorbus', NULL, 'Koidz.', 141),
(2426, 'Arisaema', NULL, 'Mart.', 12),
(2427, 'Arisarum', NULL, 'Mill.', 12),
(2428, 'Arischrada', NULL, 'Pobed.', 90),
(2429, 'Aristeguietia', NULL, 'R.M.King & H.Rob.', 18),
(2430, 'Aristeyera', NULL, 'H.E.Moore', 15),
(2431, 'Aristocapsa', NULL, 'Reveal & Hardham', 134),
(2432, 'Aristogeitonia', NULL, 'Prain', 534),
(2433, 'Aristolochia', NULL, 'L.', 16),
(2434, 'Aristotelia', NULL, 'L''Her.', 62),
(2435, 'Arjona', NULL, 'Cav.', 146),
(2436, 'Arkezostis', NULL, 'Raf.', 49),
(2437, 'Armenteria', NULL, 'Thouars ex Baill.', 8),
(2438, 'Armola', NULL, '(Kirschl.) Montandon', 5),
(2439, 'Armoracia', NULL, 'P.Gaertn., B.Mey. & Scherb.', 197),
(2440, 'Armourea', NULL, 'Lewton', 102),
(2441, 'Arnaldoa', NULL, 'Cabrera', 18),
(2442, 'Arnanthus', NULL, 'Baehni', 148),
(2443, 'Arnebia', NULL, 'Forssk.', 25);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(2444, 'Arnebiola', NULL, 'Chiov.', 25),
(2445, 'Arnhemia', NULL, 'Airy Shaw', 164),
(2446, 'Arnica', NULL, 'L.', 18),
(2447, 'Arnicastrum', NULL, 'Greenm.', 18),
(2448, 'Arnicratea', NULL, 'N.Halle', 38),
(2449, 'Arnoglossum', NULL, 'Raf.', 18),
(2450, 'Arnoldia', NULL, 'Blume', 50),
(2451, 'Arnoseris', NULL, 'Gaertn.', 18),
(2452, 'Arodendron', NULL, 'Werth', 12),
(2453, 'Aronia', NULL, 'Medik.', 141),
(2454, 'Arophyton', NULL, 'Jum.', 12),
(2455, 'Aropsis', NULL, 'Rojas Acosta', 12),
(2456, 'Arpitium', NULL, 'Neck. ex Sweet', 9),
(2457, 'Arrabidaea', NULL, 'DC.', 22),
(2458, 'Arracacia', NULL, 'Bancr.', 9),
(2459, 'Arrhenechthites', NULL, 'Mattf.', 18),
(2460, 'Arrhostoxylum', NULL, 'Nees', 1),
(2461, 'Arrojadocharis', NULL, 'Mattf.', 18),
(2462, 'Arrowsmithia', NULL, 'DC.', 18),
(2463, 'Arrudaria', NULL, 'Macedo', 15),
(2464, 'Artabotrys', NULL, 'R.Br.', 8),
(2465, 'Artanema', NULL, 'D.Don', 423),
(2466, 'Artedia', NULL, 'L.', 9),
(2467, 'Artemisia', NULL, 'L.', 18),
(2468, 'Artemisiopsis', NULL, 'S.Moore', 18),
(2469, 'Arthraerua', NULL, '(Kuntze) Schinz', 5),
(2470, 'Arthraxella', NULL, 'Nakai', 98),
(2471, 'Arthraxon', NULL, 'Tiegh.(SUH)', 131),
(2472, 'Arthrocarpum', NULL, 'Balf.f.', 68),
(2473, 'Arthroclianthus', NULL, 'Baill.', 68),
(2474, 'Arthrocnemum', NULL, 'Moq.', 5),
(2475, 'Arthrophytum', NULL, 'Schrenk', 5),
(2476, 'Arthrosamanea', NULL, 'Britton & Rose', 68),
(2477, 'Arthrosolen', NULL, 'C.A.Mey.', 164),
(2478, 'Arthrostemma', NULL, 'Pav. ex D.Don', 105),
(2479, 'Arthrostylis', NULL, 'R.Br.', 55),
(2480, 'Arthrothamnus', NULL, 'Klotzsch & Garcke', 66),
(2481, 'Artia', NULL, 'Guillaumin', 10),
(2482, 'Artorhiza', NULL, 'Raf.', 154),
(2483, 'Artrolobium', NULL, 'Desv.', 68),
(2484, 'Arum', NULL, 'L.', 12),
(2485, 'Aruncus', NULL, 'L.', 141),
(2486, 'Asaemia', NULL, '(Harv.) Benth.', 18),
(2487, 'Asagraea', NULL, 'Baill.', 68),
(2488, 'Asanthus', NULL, 'R.M.King & H.Rob.', 18),
(2489, 'Asarina', NULL, 'Mill.', 423),
(2490, 'Asarum', NULL, 'L.', 16),
(2491, 'Ascarina', NULL, 'J.R.Forst. & G.Forst.', 39),
(2492, 'Ascarinopsis', NULL, 'Humbert & Capuron', 39),
(2493, 'Aschenbornia', NULL, 'S.Schauer', 18),
(2494, 'Aschersoniodoxa', NULL, 'Gilg & Muschl.', 197),
(2495, 'Aschistanthera', NULL, 'C.Hansen', 105),
(2496, 'Asciadium', NULL, 'Griseb.', 9),
(2497, 'Ascidiogyne', NULL, 'Cuatrec.', 18),
(2498, 'Asclepias', NULL, 'L.', 10),
(2499, 'Asclepiodella', NULL, 'Small', 10),
(2500, 'Asclepiodora', NULL, 'A.Gray', 10),
(2501, 'Ascocarydion', NULL, 'G.Taylor', 90),
(2502, 'Ascolepis', NULL, 'Nees ex Steud.', 55),
(2503, 'Ascopholis', NULL, 'C.E.C.Fisch.', 55),
(2504, 'Ascotheca', NULL, 'Heine', 1),
(2505, 'Asemanthia', NULL, 'Ridl.', 142),
(2506, 'Asemnantha', NULL, 'Hook.f.', 142),
(2507, 'Asephananthes', NULL, 'Bory', 127),
(2508, 'Ashtonia', NULL, 'Airy Shaw', 184),
(2509, 'Asimia', NULL, 'Kunth(SUO)', 8),
(2510, 'Asimina', NULL, 'Adans.', 8),
(2511, 'Asiphonia', NULL, 'Griff.', 16),
(2512, 'Askellia', NULL, 'W.A.Weber', 18),
(2513, 'Asketanthera', NULL, 'Woodson', 10),
(2514, 'Aspalathoides', NULL, '(DC.) K.Koch', 68),
(2515, 'Aspalathus', NULL, 'L.', 68),
(2516, 'Aspalthium', NULL, 'Medik.', 68),
(2517, 'Aspera', NULL, 'Moench', 142),
(2518, 'Asperuginoides', NULL, 'Rauschert', 197),
(2519, 'Asperugo', NULL, 'L.', 25),
(2520, 'Asperula', NULL, 'L.', 142),
(2521, 'Aspicarpa', NULL, 'Rich.', 101),
(2522, 'Aspidanthera', NULL, 'Benth.', 142),
(2523, 'Aspidixia', NULL, 'Tiegh.', 146),
(2524, 'Aspidocarya', NULL, 'Hook.f. & Thomson', 107),
(2525, 'Aspidogenia', NULL, 'Burret', 116),
(2526, 'Aspidoglossum', NULL, 'E.Mey.', 10),
(2527, 'Aspidopterys', NULL, 'A.Juss.', 101),
(2528, 'Aspidostemon', NULL, 'Rohwer & H.G.Richt.', 91),
(2529, 'Aspilia', NULL, 'Thouars', 18),
(2530, 'Aspiliopsis', NULL, 'Greenm.', 18),
(2531, 'Asplundia', NULL, 'Harling', 54),
(2532, 'Asplundianthus', NULL, 'R.M.King & H.Rob.', 18),
(2533, 'Asraoa', NULL, 'J.Joseph', 15),
(2534, 'Assidora', NULL, 'A.Chev.', 142),
(2535, 'Asta', NULL, 'Klotzsch ex O.E.Schulz', 197),
(2536, 'Astartea', NULL, 'DC.', 116),
(2537, 'Astelma', NULL, 'Schltr.(SUS)', 10),
(2538, 'Astemma', NULL, 'Less.', 18),
(2539, 'Astemon', NULL, 'Regel', 90),
(2540, 'Astenolobium', NULL, 'Nevski', 68),
(2541, 'Astephanus', NULL, 'R.Br.', 10),
(2542, 'Aster', NULL, 'L.', 18),
(2543, 'Asteracantha', NULL, 'Nees', 1),
(2544, 'Asterandra', NULL, 'Klotzsch', 184),
(2545, 'Asteranthe', NULL, 'Engl. & Diels', 8),
(2546, 'Asteranthera', NULL, 'Hanst.', 76),
(2547, 'Asteranthopsis', NULL, 'Kuntze', 8),
(2548, 'Asteranthos', NULL, 'Desf.', 92),
(2549, 'Asteranthus', NULL, 'Spreng.', 92),
(2550, 'Asteriastigma', NULL, 'Bedd.', 73),
(2551, 'Asteridea', NULL, 'Lindl.', 18),
(2552, 'Asteriscium', NULL, 'Cham. & Schltdl.', 9),
(2553, 'Asteriscus', NULL, 'Mill.', 18),
(2554, 'Asterochaete', NULL, 'Nees', 55),
(2555, 'Asterochlaena', NULL, 'Garcke', 102),
(2556, 'Asterocytisus', NULL, '(W.D.J.Koch) Schur ex Fuss', 68),
(2557, 'Asterogyne', NULL, 'H.Wendl.', 15),
(2558, 'Asterohyptis', NULL, 'Epling', 90),
(2559, 'Asterolasia', NULL, 'F.Muell.', 143),
(2560, 'Asterolepidion', NULL, 'Ducke', 85),
(2561, 'Asterolinon', NULL, 'Hoffmanns. & Link', 115),
(2562, 'Asteromoea', NULL, 'Blume', 18),
(2563, 'Asteromyrtus', NULL, 'Schauer', 116),
(2564, 'Asterophorum', NULL, 'Sprague', 102),
(2565, 'Asterophyllum', NULL, 'Schimp. & Spenn.', 142),
(2566, 'Asterosedum', NULL, 'Grulich', 48),
(2567, 'Asterostemma', NULL, 'Decne.', 10),
(2568, 'Asterostigma', NULL, 'Fisch. & C.A.Mey.', 12),
(2569, 'Asterostoma', NULL, 'Blume', 105),
(2570, 'Asterotricha', NULL, 'V.V.Botschantz.(SUH)', 197),
(2571, 'Asterotrichion', NULL, 'Klotzsch', 102),
(2572, 'Asthotheca', NULL, 'Miers ex Planch. & Triana', 42),
(2573, 'Astianthus', NULL, 'D.Don', 22),
(2574, 'Astiella', NULL, 'Jovet', 142),
(2575, 'Astilbe', NULL, 'Buch.-Ham. ex G.Don', 149),
(2576, 'Astilboides', NULL, '(Hemsl.) Engl.', 149),
(2577, 'Astiria', NULL, 'Lindl.', 102),
(2578, 'Astoma', NULL, 'DC.(SUH)', 9),
(2579, 'Astomaea', NULL, 'Rchb.', 9),
(2580, 'Astomatopsis', NULL, 'Korovin', 9),
(2581, 'Astracantha', NULL, 'Podlech', 68),
(2582, 'Astraea', NULL, 'Klotzsch(SUH)', 66),
(2583, 'Astragalus', NULL, 'L.', 68),
(2584, 'Astranthium', NULL, 'Nutt.', 18),
(2585, 'Astrantia', NULL, 'L.', 9),
(2586, 'Astripomoea', NULL, 'A.Meeuse', 46),
(2587, 'Astrocalyx', NULL, 'Merr.', 105),
(2588, 'Astrocasia', NULL, 'B.L.Rob. & Millsp.', 184),
(2589, 'Astrochlaena', NULL, 'Hallier f.(SUH)', 46),
(2590, 'Astrococcus', NULL, 'Benth.', 66),
(2591, 'Astrocodon', NULL, 'Fed.', 30),
(2592, 'Astrodaucus', NULL, 'Drude', 9),
(2593, 'Astrogyne', NULL, 'Benth.', 66),
(2594, 'Astroloma', NULL, 'R.Br.', 64),
(2595, 'Astromerremia', NULL, 'Pilg.', 46),
(2596, 'Astronidium', NULL, 'A.Gray', 105),
(2597, 'Astropanax', NULL, 'Seem.', 13),
(2598, 'Astropetalum', NULL, 'Griff.', 6),
(2599, 'Astrophyllum', NULL, 'Torr. & A.Gray', 143),
(2600, 'Astrostemma', NULL, 'Benth.', 10),
(2601, 'Astrothalamus', NULL, 'C.B.Rob.', 171),
(2602, 'Astrotheca', NULL, 'Vesque', 42),
(2603, 'Astrotricha', NULL, 'DC.', 13),
(2604, 'Astrotrichilia', NULL, '(Harms) T.D.Penn. & Styles', 106),
(2605, 'Astydamia', NULL, 'DC.', 9),
(2606, 'Astylis', NULL, 'Wight', 66),
(2607, 'Asyneuma', NULL, 'Griseb. & Schenck', 30),
(2608, 'Asystasiella', NULL, 'Lindau', 1),
(2609, 'Ataenidia', NULL, 'Gagnep.', 103),
(2610, 'Atalantia', NULL, 'Correa', 143),
(2611, 'Atalaya', NULL, 'Blume', 147),
(2612, 'Atamisquea', NULL, 'Miers ex Hook. & Arn.', 32),
(2613, 'Ateixa', NULL, 'Ravenna', 197),
(2614, 'Atelanthera', NULL, 'Hook.f. & Thomson', 197),
(2615, 'Ateleia', NULL, '(DC.) Benth.', 68),
(2616, 'Atelophragma', NULL, 'Rydb.', 68),
(2617, 'Atemnosiphon', NULL, 'Leandri', 164),
(2618, 'Ateramnus', NULL, 'P.Browne', 66),
(2619, 'Athamanta', NULL, 'L.', 9),
(2620, 'Athanasia', NULL, 'L.', 18),
(2621, 'Athenaea', NULL, 'Sendtn.', 154),
(2622, 'Atherandra', NULL, 'Decne.', 10),
(2623, 'Atheranthera', NULL, 'Mast.', 49),
(2624, 'Atherolepis', NULL, 'Hook.f.', 10),
(2625, 'Atherosperma', NULL, 'Labill.', 505),
(2626, 'Atherostemon', NULL, 'Blume', 10),
(2627, 'Athrixia', NULL, 'Ker Gawl.', 18),
(2628, 'Athroandra', NULL, '(Hook.f.) Pax & K.Hoffm.', 66),
(2629, 'Athroisma', NULL, 'DC.', 18),
(2630, 'Athrotaxis', NULL, 'D.Don', 51),
(2631, 'Athyana', NULL, '(Griseb.) Radlk.', 147),
(2632, 'Athysanus', NULL, 'Greene', 197),
(2633, 'Atirbesia', NULL, 'Raf.', 90),
(2634, 'Atitara', NULL, 'O.F.Cook', 15),
(2635, 'Atkinsia', NULL, 'R.A.Howard', 102),
(2636, 'Atkinsonia', NULL, 'F.Muell.', 98),
(2637, 'Atopocarpus', NULL, 'Cuatrec.', 101),
(2638, 'Atopostema', NULL, 'Boutique', 8),
(2639, 'Atractocarpus', NULL, 'Schltr. & K.Krause', 142),
(2640, 'Atractogyne', NULL, 'Pierre', 142),
(2641, 'Atractylis', NULL, 'L.', 18),
(2642, 'Atractylodes', NULL, 'DC.', 18),
(2643, 'Atraphaxis', NULL, 'L.', 134),
(2644, 'Atrichantha', NULL, 'Hilliard & B.L.Burtt', 18),
(2645, 'Atrichodendron', NULL, 'Gagnep.', 154),
(2646, 'Atrichoseris', NULL, 'A.Gray', 18),
(2647, 'Atriplex', NULL, 'L.', 5),
(2648, 'Atropa', NULL, 'L.', 154),
(2649, 'Atropanthe', NULL, 'Pascher', 154),
(2650, 'Atropatenia', NULL, 'F.K.Mey.', 197),
(2651, 'Atroxima', NULL, 'Stapf', 133),
(2652, 'Atrutegia', NULL, 'Bedd.', 8),
(2653, 'Atylosia', NULL, 'Wight & Arn.', 68),
(2654, 'Aubertia', NULL, 'Chapel. ex Baill.', 66),
(2655, 'Aubregrinia', NULL, 'Heine', 148),
(2656, 'Aubrevillea', NULL, 'Pellegr.', 68),
(2657, 'Aubrieta', NULL, 'Adans.', 197),
(2658, 'Aucoumea', NULL, 'Pierre', 27),
(2659, 'Aucuba', NULL, 'Thunb.', 74),
(2660, 'Aucubaephyllum', NULL, 'Ahlb.', 142),
(2661, 'Audibertia', NULL, 'Benth. (1831)(SUH)', 90),
(2662, 'Audibertiella', NULL, 'Briq.', 90),
(2663, 'Auerodendron', NULL, 'Urb.', 139),
(2664, 'Augea', NULL, 'Thunb.', 177),
(2665, 'Augouardia', NULL, 'Pellegr.', 68),
(2666, 'Augusta', NULL, 'Pohl', 142),
(2667, 'Augustea', NULL, 'DC.(SUO)', 142),
(2668, 'Augustinea', NULL, 'Mart.', 15),
(2669, 'Aulacocarpus', NULL, 'O.Berg', 105),
(2670, 'Aulacodiscus', NULL, 'Hook.f.', 142),
(2671, 'Aulacospermum', NULL, 'Ledeb.', 9),
(2672, 'Aulandra', NULL, 'H.J.Lam', 148),
(2673, 'Aulax', NULL, 'Bergius', 135),
(2674, 'Aulaya', NULL, 'Harv.', 150),
(2675, 'Aulojusticia', NULL, 'Lindau', 1),
(2676, 'Aulospermum', NULL, 'J.M.Coult. & Rose', 9),
(2677, 'Aulostephanus', NULL, 'Schltr.', 10),
(2678, 'Aureliana', NULL, 'Sendtn.', 154),
(2679, 'Aureolaria', NULL, 'Raf.', 400),
(2680, 'Auriculardisia', NULL, 'Lundell', 115),
(2681, 'Aurinia', NULL, 'Desv.', 197),
(2682, 'Australina', NULL, 'Gaudich.', 171),
(2683, 'Austroamericium', NULL, 'Hendrych', 146),
(2684, 'Austrobrickellia', NULL, 'R.M.King & H.Rob.', 18),
(2685, 'Austrocedrus', NULL, 'Florin & Boutelje', 51),
(2686, 'Austrocritonia', NULL, 'R.M.King & H.Rob.', 18),
(2687, 'Austrocynoglossum', NULL, 'Popov ex R.R.Mill', 25),
(2688, 'Austrodolichos', NULL, 'Verdc.', 68),
(2689, 'Austroeupatorium', NULL, 'R.M.King & H.Rob.', 18),
(2690, 'Austrogambeya', NULL, 'Aubrev. & Pellegr.', 148),
(2691, 'Austroliabum', NULL, 'H.Rob. & Brettell', 18),
(2692, 'Austromatthaea', NULL, 'L.S.Sm.', 108),
(2693, 'Austromimusops', NULL, 'A.Meeuse', 148),
(2694, 'Austromuellera', NULL, 'C.T.White', 135),
(2695, 'Austromyrtus', NULL, '(Nied.) Burret', 116),
(2696, 'Austropeucedanum', NULL, 'Mathias & Constance', 9),
(2697, 'Austrosteenisia', NULL, 'R.Geesink', 68),
(2698, 'Austrosynotis', NULL, 'C.Jeffrey', 18),
(2699, 'Auticoryne', NULL, 'Turcz.', 116),
(2700, 'Autrandra', NULL, 'Pierre ex Prain', 66),
(2701, 'Autrania', NULL, 'C.Winkl. & Barbey', 18),
(2702, 'Autumnalia', NULL, 'Pimenov', 9),
(2703, 'Auxemma', NULL, 'Miers', 25),
(2704, 'Auzuba', NULL, 'Juss.', 148),
(2705, 'Aveledoa', NULL, 'Pittier', 85),
(2706, 'Avellanita', NULL, 'Phil.', 66),
(2707, 'Avellara', NULL, 'Blanca & C.Diaz', 18),
(2708, 'Averia', NULL, 'Leonard', 1),
(2709, 'Averrhoa', NULL, 'L.', 124),
(2710, 'Averrhoidium', NULL, 'Baill.', 147),
(2711, 'Avetra', NULL, 'H.Perrier', 59),
(2712, 'Avoira', NULL, 'Giseke', 15),
(2713, 'Axanthes', NULL, 'Blume', 142),
(2714, 'Axanthopsis', NULL, 'Korth.', 142),
(2715, 'Axenfeldia', NULL, 'Baill.', 66),
(2716, 'Axinanthera', NULL, 'H.Karst.', 105),
(2717, 'Axinea', NULL, 'Juss.(SUO)', 105),
(2718, 'Axiniphyllum', NULL, 'Benth.', 18),
(2719, 'Axolus', NULL, 'Raf.', 142),
(2720, 'Axyris', NULL, 'L.', 5),
(2721, 'Ayapana', NULL, 'Spach', 18),
(2722, 'Ayapanopsis', NULL, 'R.M.King & H.Rob.', 18),
(2723, 'Aydendron', NULL, 'Nees', 91),
(2724, 'Ayenia', NULL, 'L.', 102),
(2725, 'Aylacophora', NULL, 'Cabrera', 18),
(2726, 'Aylthonia', NULL, 'N.L.Menezes', 172),
(2727, 'Aynia', NULL, 'H.Rob.', 18),
(2728, 'Aytonia', NULL, 'L.f.(SUO)', 106),
(2729, 'Azalea', NULL, 'L.', 64),
(2730, 'Azanza', NULL, 'Alef.', 102),
(2731, 'Azaola', NULL, 'Blanco', 148),
(2732, 'Azara', NULL, 'Ruiz & Pav.', 145),
(2733, 'Azedarach', NULL, 'Mill.', 106),
(2734, 'Azilia', NULL, 'Hedge & Lamond', 9),
(2735, 'Azorella', NULL, 'Lam.', 9),
(2736, 'Azorina', NULL, 'Feer', 30),
(2737, 'Azukia', NULL, 'Takah. ex Ohwi', 68),
(2738, 'Babactes', NULL, 'DC.', 76),
(2739, 'Babbagia', NULL, 'F.Muell.', 5),
(2740, 'Babcockia', NULL, 'Boulos', 18),
(2741, 'Babingtonia', NULL, 'Lindl.', 116),
(2742, 'Baccaureopsis', NULL, 'Pax', 184),
(2743, 'Baccharidastrum', NULL, 'Cabrera', 18),
(2744, 'Baccharidiopsis', NULL, 'G.M.Barroso', 18),
(2745, 'Baccharis', NULL, 'L.', 18),
(2746, 'Baccharoides', NULL, 'Moench', 18),
(2747, 'Bachmannia', NULL, 'Pax', 32),
(2748, 'Backeria', NULL, 'Bakh.f.', 105),
(2749, 'Backhousia', NULL, 'Hook. & Harv.', 116),
(2750, 'Baconia', NULL, 'DC.', 142),
(2751, 'Bacopa', NULL, 'Aubl.', 423),
(2752, 'Bacularia', NULL, 'F.Muell. ex Hook.f.', 15),
(2753, 'Badamia', NULL, 'Gaertn.', 44),
(2754, 'Badiera', NULL, 'DC.', 133),
(2755, 'Badilloa', NULL, 'R.M.King & H.Rob.', 18),
(2756, 'Badula', NULL, 'Juss.', 115),
(2757, 'Badusa', NULL, 'A.Gray', 142),
(2758, 'Baeckea', NULL, 'L.', 116),
(2759, 'Baeolepis', NULL, 'Decne. ex Moq.', 10),
(2760, 'Baeothryon', NULL, 'A.Dietr.', 55),
(2761, 'Baeriopsis', NULL, 'J.T.Howell', 18),
(2762, 'Bafodeya', NULL, 'Prance ex F.White', 40),
(2763, 'Bafutia', NULL, 'C.D.Adams', 18),
(2764, 'Bagassa', NULL, 'Aubl.', 109),
(2765, 'Bahamia', NULL, 'Britton & Rose', 68),
(2766, 'Bahia', NULL, 'Lag.', 18),
(2767, 'Bahianthus', NULL, 'R.M.King & H.Rob.', 18),
(2768, 'Baileya', NULL, 'Harv. & A.Gray', 18),
(2769, 'Baileyoxylon', NULL, 'C.T.White', 198),
(2770, 'Baillandea', NULL, 'Roberty', 46),
(2771, 'Baillonia', NULL, 'Bocq.', 173),
(2772, 'Baissea', NULL, 'A.DC.', 10),
(2773, 'Bakerella', NULL, 'Tiegh.', 98),
(2774, 'Bakeria', NULL, 'Seem.', 13),
(2775, 'Bakeridesia', NULL, 'Hochr.', 102),
(2776, 'Bakeriella', NULL, 'Pierre ex Dubard', 148),
(2777, 'Bakerisideroxylon', NULL, 'Engl.', 148),
(2778, 'Bakerophyton', NULL, '(J.Leonard) Hutch.', 68),
(2779, 'Balaka', NULL, 'Becc.', 15),
(2780, 'Balanites', NULL, 'Delile', 177),
(2781, 'Balanocarpus', NULL, 'Bedd.', 60),
(2782, 'Balanostreblus', NULL, 'Kurz', 109),
(2783, 'Balansaea', NULL, 'Boiss. & Reut.', 9),
(2784, 'Balaustion', NULL, 'Hook.', 116),
(2785, 'Balboa', NULL, 'Planch. & Triana', 42),
(2786, 'Balduina', NULL, 'Nutt.', 18),
(2787, 'Baldwinia', NULL, 'Raf.', 127),
(2788, 'Balfourina', NULL, 'Kuntze', 142),
(2789, 'Balfourodendron', NULL, 'Corr.Mello ex Oliv.', 143),
(2790, 'Balgoya', NULL, 'Morat & Meijden', 133),
(2791, 'Baliospermum', NULL, 'Blume', 66),
(2792, 'Balisaea', NULL, 'Taub.', 68),
(2793, 'Ballantinia', NULL, 'Hook.f. ex E.A.Shaw', 197),
(2794, 'Ballardia', NULL, 'Montrouz.', 116),
(2795, 'Ballochia', NULL, 'Balf.f.', 1),
(2796, 'Ballota', NULL, 'L.', 90),
(2797, 'Balmea', NULL, 'Martinez', 142),
(2798, 'Baloghia', NULL, 'Endl.', 66),
(2799, 'Balonga', NULL, 'Le Thomas', 8),
(2800, 'Balsamita', NULL, 'Mill.', 18),
(2801, 'Balsamocarpon', NULL, 'Clos', 68),
(2802, 'Balsamocitrus', NULL, 'Stapf', 143),
(2803, 'Balsamodendrum', NULL, 'Kunth', 27),
(2804, 'Balsamorhiza', NULL, 'Hook. ex Nutt.', 18),
(2805, 'Balthasaria', NULL, 'Verdc.', 409),
(2806, 'Baltimora', NULL, 'L.', 18),
(2807, 'Bambekea', NULL, 'Cogn.', 49),
(2808, 'Bamboga', NULL, 'Baill.(SUO)', 142),
(2809, 'Bamburanta', NULL, 'L.Linden', 103),
(2810, 'Bamlera', NULL, 'K.Schum. & Lauterb.', 105),
(2811, 'Bampsia', NULL, 'Lisowski & Mielcarek', 150),
(2812, 'Banalia', NULL, 'Moq.(SUH)', 5),
(2813, 'Bandeiraea', NULL, 'Benth.', 68),
(2814, 'Banisteria', NULL, 'L.(SUH)', 101),
(2815, 'Banisterioides', NULL, 'Dubard & Dop', 101),
(2816, 'Banisteriopsis', NULL, 'C.B.Rob. ex Small', 101),
(2817, 'Banksia', NULL, 'L.f.', 135),
(2818, 'Baolia', NULL, 'H.W.Kung & G.L.Chu', 5),
(2819, 'Baphiastrum', NULL, 'Harms', 68),
(2820, 'Baphicacanthus', NULL, 'Bremek.', 1),
(2821, 'Baphiopsis', NULL, 'Benth. ex Baker', 68),
(2822, 'Baphorhiza', NULL, 'Link', 25),
(2823, 'Baprea', NULL, 'Pierre ex Pax & K.Hoffm.', 66),
(2824, 'Baptisia', NULL, 'Vent.', 68),
(2825, 'Barathranthus', NULL, '(Korth.) Miq.', 98),
(2826, 'Barbacenia', NULL, 'Vand.', 172),
(2827, 'Barbaceniopsis', NULL, 'L.B.Sm.', 172),
(2828, 'Barbarea', NULL, 'R.Br.', 197),
(2829, 'Barbeyastrum', NULL, 'Cogn.', 105),
(2830, 'Barbieria', NULL, 'Spreng.', 68),
(2831, 'Barbilus', NULL, 'P.Browne', 106),
(2832, 'Barbosa', NULL, 'Becc.', 15),
(2833, 'Barcella', NULL, '(Trail) Trail ex Drude', 15),
(2834, 'Barcena', NULL, 'Duges', 139),
(2835, 'Bargemontia', NULL, 'Gaudich.', 154),
(2836, 'Barhamia', NULL, 'Klotzsch', 66),
(2837, 'Barjonia', NULL, 'Decne.', 10),
(2838, 'Barkerwebbia', NULL, 'Becc.', 15),
(2839, 'Barkleyanthus', NULL, 'H.Rob. & Brettell', 18),
(2840, 'Barklya', NULL, 'F.Muell.', 68),
(2841, 'Barleria', NULL, 'L.', 1),
(2842, 'Barleriacanthus', NULL, 'Oerst.', 1),
(2843, 'Barlerianthus', NULL, 'Oerst.', 1),
(2844, 'Barleriola', NULL, 'Oerst.', 1),
(2845, 'Barleriosiphon', NULL, 'Oerst.', 1),
(2846, 'Barlerites', NULL, 'Oerst.', 1),
(2847, 'Barnadesia', NULL, 'Mutis ex L.f.', 18),
(2848, 'Barnebya', NULL, 'W.R.Anderson & B.Gates', 101),
(2849, 'Barnettia', NULL, 'Santisuk(SUH)', 22),
(2850, 'Barnhartia', NULL, 'Gleason', 133),
(2851, 'Barola', NULL, 'Adans.(SUS)', 106),
(2852, 'Barongia', NULL, 'Peter G.Wilson & B.Hyland', 116),
(2853, 'Baroniella', NULL, 'Costantin & Gallaud', 10),
(2854, 'Barosma', NULL, 'Willd.', 143),
(2855, 'Barraldeia', NULL, 'Thouars', 140),
(2856, 'Barrettia', NULL, 'Sim', 66),
(2857, 'Barroetea', NULL, 'A.Gray', 18),
(2858, 'Barrosoa', NULL, 'R.M.King & H.Rob.', 18),
(2859, 'Barthea', NULL, 'Hook.f.', 105),
(2860, 'Barthollesia', NULL, 'Silva Manso', 92),
(2861, 'Bartholomaea', NULL, 'Standl. & Steyerm.', 145),
(2862, 'Bartlettia', NULL, 'A.Gray', 18),
(2863, 'Bartlettina', NULL, 'R.M.King & H.Rob.', 18),
(2864, 'Bartlingia', NULL, 'Rchb.', 142),
(2865, 'Bartonia', NULL, 'Muhl. ex Willd.', 75),
(2866, 'Bartramia', NULL, 'Salisb.', 150),
(2867, 'Bartsia', NULL, 'L.', 400),
(2868, 'Barylucuma', NULL, 'Ducke', 148),
(2869, 'Basanacantha', NULL, 'Hook.f.', 142),
(2870, 'Basananthe', NULL, 'Peyr.', 127),
(2871, 'Basedowia', NULL, 'E.Pritz.', 18),
(2872, 'Baseonema', NULL, 'Schltr. & Rendle', 10),
(2873, 'Basicarpus', NULL, 'Tiegh.', 63),
(2874, 'Basileophyta', NULL, 'F.Muell.', 76),
(2875, 'Basilicum', NULL, 'Moench', 90),
(2876, 'Basiloxylon', NULL, 'K.Schum.', 102),
(2877, 'Basisperma', NULL, 'C.T.White', 116),
(2878, 'Basistelma', NULL, 'Bartlett', 10),
(2879, 'Basistemon', NULL, 'Turcz.', 423),
(2880, 'Basselinia', NULL, 'Vieill.', 15),
(2881, 'Bassia', NULL, 'K.Koenig(SUH)', 5),
(2882, 'Bassovia', NULL, 'Aubl.', 154),
(2883, 'Bastardia', NULL, 'Kunth', 102),
(2884, 'Bastardiastrum', NULL, '(Rose) D.M.Bates', 102),
(2885, 'Bastardiopsis', NULL, '(K.Schum.) Hassl.', 102),
(2886, 'Basutica', NULL, 'E.Phillips', 164),
(2887, 'Batania', NULL, 'Hatus.', 107),
(2888, 'Bataprine', NULL, 'Nieuwl.', 142),
(2889, 'Batatas', NULL, 'Choisy', 46),
(2890, 'Batesanthus', NULL, 'N.E.Br.', 10),
(2891, 'Batesia', NULL, 'Spruce ex Benth.', 68),
(2892, 'Batesimalva', NULL, 'Fryxell', 102),
(2893, 'Bathiaea', NULL, 'Drake', 68),
(2894, 'Bathiorhamnus', NULL, 'Capuron', 139),
(2895, 'Bathysograya', NULL, 'Kuntze', 142),
(2896, 'Batidaea', NULL, '(Dumort.) Greene', 141),
(2897, 'Batidophaca', NULL, 'Rydb.', 68),
(2898, 'Batis', NULL, 'P.Browne', 19),
(2899, 'Batopedina', NULL, 'Verdc.', 142),
(2900, 'Battata', NULL, 'Hill', 154),
(2901, 'Baudinia', NULL, 'Lesch. ex DC.', 116),
(2902, 'Baudouinia', NULL, 'Baill.', 68),
(2903, 'Bauera', NULL, 'Banks ex Andr.', 50),
(2904, 'Bauerella', NULL, 'Schindl.(SUH)', 68),
(2905, 'Baueropsis', NULL, 'Hutch.', 68),
(2906, 'Baukea', NULL, 'Vatke', 68),
(2907, 'Baumannia', NULL, 'Spach(SUH)', 121),
(2908, 'Baumea', NULL, 'Gaudich.', 55),
(2909, 'Baumia', NULL, 'Engl. & Gilg', 150),
(2910, 'Baumiella', NULL, 'H.Wolff(SUH)', 9),
(2911, 'Baxtera', NULL, 'Rchb.', 10),
(2912, 'Bayonia', NULL, 'Dugand', 22),
(2913, 'Beata', NULL, 'O.F.Cook', 15),
(2914, 'Beaufortia', NULL, 'R.Br.', 116),
(2915, 'Beaumontia', NULL, 'Wall.', 10),
(2916, 'Beauprea', NULL, 'Brongn. & Gris', 135),
(2917, 'Beaupreopsis', NULL, 'Virot', 135),
(2918, 'Beautempsia', NULL, 'Gaudich.', 32),
(2919, 'Beauvisagea', NULL, 'Pierre', 148),
(2920, 'Bebbia', NULL, 'Greene', 18),
(2921, 'Beccabunga', NULL, 'Hill', 150),
(2922, 'Beccarianthus', NULL, 'Cogn.', 105),
(2923, 'Beccariella', NULL, 'Pierre', 148),
(2924, 'Beccarimnia', NULL, 'Pierre ex Koord.', 148),
(2925, 'Beccarina', NULL, 'Tiegh.(SUS)', 98),
(2926, 'Beccarinda', NULL, 'Kuntze', 76),
(2927, 'Beccariodendron', NULL, 'Warb.', 8),
(2928, 'Beccariophoenix', NULL, 'Jum. & H.Perrier', 15),
(2929, 'Becium', NULL, 'Lindl.', 90),
(2930, 'Becquerelia', NULL, 'Brongn.', 55),
(2931, 'Beddomea', NULL, 'Hook.f.', 106),
(2932, 'Bedfordia', NULL, 'DC.', 18),
(2933, 'Beethovenia', NULL, 'Engel', 15),
(2934, 'Befaria', NULL, 'Mutis ex L.(SUO)', 64),
(2935, 'Begonia', NULL, 'L.', 20),
(2936, 'Begoniella', NULL, 'Oliv.', 20),
(2937, 'Beguea', NULL, 'Capuron', 147),
(2938, 'Behaimia', NULL, 'Griseb.', 68),
(2939, 'Behnia', NULL, 'Didr.', 3),
(2940, 'Behuria', NULL, 'Cham.', 105),
(2941, 'Beirnaertia', NULL, 'Louis ex Troupin', 107),
(2942, 'Beiselia', NULL, 'Forman', 27),
(2943, 'Bejaranoa', NULL, 'R.M.King & H.Rob.', 18),
(2944, 'Bejaria', NULL, 'Mutis ex L.', 64),
(2945, 'Bejaudia', NULL, 'Gagnep.', 15),
(2946, 'Belairia', NULL, 'A.Rich.', 68),
(2947, 'Belandra', NULL, 'S.F.Blake', 10),
(2948, 'Belangera', NULL, 'Cambess.', 50),
(2949, 'Belemia', NULL, 'Pires', 117),
(2950, 'Belencita', NULL, 'H.Karst.', 32),
(2951, 'Belenia', NULL, 'Decne.', 154),
(2952, 'Beliceodendron', NULL, 'Lundell', 68),
(2953, 'Belicia', NULL, 'Lundell', 142),
(2954, 'Belilla', NULL, 'Adans.', 142),
(2955, 'Belladona', NULL, 'Duhamel', 154),
(2956, 'Bellardia', NULL, 'Schreb.(SUH)', 142),
(2957, 'Bellendena', NULL, 'R.Br.', 135),
(2958, 'Bellevalia', NULL, 'Roem. & Schult.(SUH)', 338),
(2959, 'Bellida', NULL, 'Ewart', 18),
(2960, 'Bellingia', NULL, 'Pierre', 147),
(2961, 'Bellinia', NULL, 'Roem. & Schult.', 154),
(2962, 'Belliolum', NULL, 'Tiegh.', 176),
(2963, 'Bellis', NULL, 'L.', 18),
(2964, 'Bellium', NULL, 'L.', 18),
(2965, 'Belloa', NULL, 'J.Remy', 18),
(2966, 'Bellonia', NULL, 'L.', 76),
(2967, 'Bellota', NULL, 'Gay', 91),
(2968, 'Bellynkxia', NULL, 'Mull.Arg.', 142),
(2969, 'Belmontia', NULL, 'E.Mey.', 75),
(2970, 'Beloperone', NULL, 'Nees', 1),
(2971, 'Belostemma', NULL, 'Wall. ex Wight', 10),
(2972, 'Belotia', NULL, 'A.Rich.', 102),
(2973, 'Beltrania', NULL, 'Miranda', 66),
(2974, 'Bemarivea', NULL, 'Choux', 147),
(2975, 'Bembicia', NULL, 'Oliv.', 145),
(2976, 'Bembicidium', NULL, 'Rydb.', 68),
(2977, 'Bemsetia', NULL, 'Raf.', 142),
(2978, 'Bencomia', NULL, 'Webb & Berthel.', 141),
(2979, 'Benedictella', NULL, 'Maire', 68),
(2980, 'Benevidesia', NULL, 'Saldanha & Cogn.', 105),
(2981, 'Benguellia', NULL, 'G.Taylor', 90),
(2982, 'Benincasa', NULL, 'Savi', 49),
(2983, 'Benitoa', NULL, 'D.D.Keck', 18),
(2984, 'Benjaminia', NULL, 'Mart. ex Benj.', 423),
(2985, 'Benkara', NULL, 'Adans.', 142),
(2986, 'Bennettia', NULL, 'R.Br.(SUH)', 180),
(2987, 'Bennettiodendron', NULL, 'Merr.', 145),
(2988, 'Benoicanthus', NULL, 'Heine & A.Raynal', 1),
(2989, 'Benoistia', NULL, 'H.Perrier & Leandri', 66),
(2990, 'Bensonia', NULL, 'Abrams & Bacig.(SUH)', 149),
(2991, 'Bensoniella', NULL, 'C.V.Morton', 149),
(2992, 'Benteca', NULL, 'Adans.', 142),
(2993, 'Benthamantha', NULL, 'Alef.', 68),
(2994, 'Benthamia', NULL, 'Lindl.(SUH)', 123),
(2995, 'Benthamidia', NULL, 'Spach', 47),
(2996, 'Benthamiella', NULL, 'Speg.', 154),
(2997, 'Benthamina', NULL, 'Tiegh.', 98),
(2998, 'Benthamistella', NULL, 'Kuntze', 150),
(2999, 'Bentia', NULL, 'Rolfe', 1),
(3000, 'Bentinckia', NULL, 'Berry ex Roxb.', 15),
(3001, 'Bentinckiopsis', NULL, 'Becc.', 15),
(3002, 'Benzonia', NULL, 'Schumach.', 142),
(3003, 'Bequaertia', NULL, 'R.Wilczek', 38),
(3004, 'Bequaertiodendron', NULL, 'De Wild.', 148),
(3005, 'Berardia', NULL, 'Vill.', 18),
(3006, 'Berberidopsis', NULL, 'Hook.f.', 506),
(3007, 'Berchemia', NULL, 'Neck. ex DC.', 139),
(3008, 'Berchemiella', NULL, 'Nakai', 139),
(3009, 'Berendtia', NULL, 'A.Gray(SUH)', 150),
(3010, 'Berendtiella', NULL, 'Wettst. & Harms', 150),
(3011, 'Berenice', NULL, 'Tul.', 30),
(3012, 'Bergena', NULL, 'Adans.', 92),
(3013, 'Bergenia', NULL, 'Moench', 149),
(3014, 'Bergeronia', NULL, 'Micheli', 68),
(3015, 'Berghesia', NULL, 'Nees', 142),
(3016, 'Berghias', NULL, 'Juss.', 142),
(3017, 'Berginia', NULL, 'Harv.', 1),
(3018, 'Bergkias', NULL, 'Sonn.', 142),
(3019, 'Bergsmia', NULL, 'Blume', 73),
(3020, 'Berhautia', NULL, 'Balle', 98),
(3021, 'Berkheya', NULL, 'Ehrh.', 18),
(3022, 'Berlandiera', NULL, 'DC.', 18),
(3023, 'Bernarda', NULL, 'Adans.(SUO)', 66),
(3024, 'Bernardia', NULL, 'Mill.', 66),
(3025, 'Bernardinia', NULL, 'Planch.', 45),
(3026, 'Bernieria', NULL, 'Baill.', 91),
(3027, 'Bernoullia', NULL, 'Oliv.', 102),
(3028, 'Berroa', NULL, 'Beauverd', 18),
(3029, 'Berteroa', NULL, 'DC.', 197),
(3030, 'Berteroella', NULL, 'O.E.Schulz', 197),
(3031, 'Berthiera', NULL, 'Vent.(SUO)', 142),
(3032, 'Bertholletia', NULL, 'Bonpl.', 92),
(3033, 'Bertolonia', NULL, 'Raddi', 105),
(3034, 'Bertuchia', NULL, 'Dennst.', 142),
(3035, 'Bertya', NULL, 'Planch.', 66),
(3036, 'Berula', NULL, 'Besser & W.D.J.Koch', 9),
(3037, 'Beruniella', NULL, 'Zakirov & Nabiev', 25),
(3038, 'Beschorneria', NULL, 'Kunth', 3),
(3039, 'Bessera', NULL, 'Spreng.(SUH)', 481),
(3040, 'Besseya', NULL, 'Rydb.', 423),
(3041, 'Bestram', NULL, 'Adans.', 184),
(3042, 'Beta', NULL, 'L.', 5),
(3043, 'Betchea', NULL, 'Schltr.', 50),
(3044, 'Betonica', NULL, 'L.', 90),
(3045, 'Betula', NULL, 'L.', 21),
(3046, 'Beurreria', NULL, 'Jacq.(SUO)', 25),
(3047, 'Beyeria', NULL, 'Miq.', 66),
(3048, 'Beyeriopsis', NULL, 'Mull.Arg.', 66),
(3049, 'Beyrichia', NULL, 'Cham. & Schltdl.', 150),
(3050, 'Bia', NULL, 'Klotzsch', 66),
(3051, 'Biancaea', NULL, 'Tod.', 68),
(3052, 'Biarum', NULL, 'Schott', 12),
(3053, 'Biasolettia', NULL, 'W.D.J.Koch(SUH)', 9),
(3054, 'Bidens', NULL, 'L.', 18),
(3055, 'Bienertia', NULL, 'Bunge ex Boiss.', 5),
(3056, 'Bifaria', NULL, 'Tiegh.', 146),
(3057, 'Bifora', NULL, 'Hoffm.', 9),
(3058, 'Bigelovia', NULL, 'Sm.', 120),
(3059, 'Bigelowia', NULL, 'DC.', 18),
(3060, 'Biglandularia', NULL, 'Seem.', 76),
(3061, 'Bignonia', NULL, 'L.', 22),
(3062, 'Bikkia', NULL, 'Reinw.', 142),
(3063, 'Bikkiopsis', NULL, 'Brongn. & Gris', 142),
(3064, 'Bilabium', NULL, 'Miq.', 76),
(3065, 'Bilacunaria', NULL, 'Pimenov & V.N.Tikhom.', 9),
(3066, 'Bilderdykia', NULL, 'Dumort.', 134),
(3067, 'Bilegnum', NULL, 'Brand', 25),
(3068, 'Billardiera', NULL, 'Vahl(SUH)', 421),
(3069, 'Billieturnera', NULL, 'Fryxell', 102),
(3070, 'Billiotia', NULL, 'G.Don(SUO)', 142),
(3071, 'Billiottia', NULL, 'DC.', 142),
(3072, 'Billotia', NULL, 'R.Br. ex G.Don', 116),
(3073, 'Billottia', NULL, 'Colla', 116),
(3074, 'Billya', NULL, 'Cass.(SUH)', 18),
(3075, 'Binectaria', NULL, 'Forssk.', 148),
(3076, 'Bingeria', NULL, 'A.Chev.', 106),
(3077, 'Binia', NULL, 'Noronha ex Thouars(SUI)', 120),
(3078, 'Biophytum', NULL, 'DC.', 124),
(3079, 'Biota', NULL, '(D.Don) Endl.', 51),
(3080, 'Bipontia', NULL, 'S.F.Blake', 18),
(3081, 'Bisboeckelera', NULL, 'Kuntze', 55),
(3082, 'Biscutella', NULL, 'L.', 197),
(3083, 'Bisedmondia', NULL, 'Hutch.', 49),
(3084, 'Biserrula', NULL, 'L.', 68),
(3085, 'Bisglaziovia', NULL, 'Cogn.', 105),
(3086, 'Bisgoeppertia', NULL, 'Kuntze', 75),
(3087, 'Bishopalea', NULL, 'H.Rob.', 18),
(3088, 'Bishopanthus', NULL, 'H.Rob.', 18),
(3089, 'Bishopiella', NULL, 'R.M.King & H.Rob.', 18),
(3090, 'Bishovia', NULL, 'R.M.King & H.Rob.', 18),
(3091, 'Bismarckia', NULL, 'Hildebrandt & H.Wendl.', 15),
(3092, 'Bisnicholsonia', NULL, 'Kuntze', 15),
(3093, 'Bisquamaria', NULL, 'Pichon', 10),
(3094, 'Bisrautanenia', NULL, 'Kuntze', 68),
(3095, 'Bissea', NULL, 'V.R.Fuentes(SUS)', 154),
(3096, 'Bistorta', NULL, '(L.) Adans.', 134),
(3097, 'Biswarea', NULL, 'Cogn.', 49),
(3098, 'Bituminaria', NULL, 'Heist. ex Fabr.', 68),
(3099, 'Biventraria', NULL, 'Small', 10),
(3100, 'Bivinia', NULL, 'Jaub. ex Tul.', 145),
(3101, 'Bivonaea', NULL, 'DC.', 197),
(3102, 'Bivonea', NULL, 'Raf.(SUH)', 66),
(3103, 'Bivonia', NULL, 'Spreng.(SUH)', 66),
(3104, 'Bizonula', NULL, 'Pellegr.', 147),
(3105, 'Blabea', NULL, 'Baehni', 148),
(3106, 'Blaberopus', NULL, 'A.DC.', 10),
(3107, 'Blachia', NULL, 'Baill.', 66),
(3108, 'Blackallia', NULL, 'C.A.Gardner', 139),
(3109, 'Blackiella', NULL, 'Aellen', 5),
(3110, 'Blackstonia', NULL, 'Huds.', 75),
(3111, 'Blaeria', NULL, 'L.', 64),
(3112, 'Blainvillea', NULL, 'Cass.', 18),
(3113, 'Blakeanthus', NULL, 'R.M.King & H.Rob.', 18),
(3114, 'Blakiella', NULL, 'Cuatrec.', 18),
(3115, 'Blanchetia', NULL, 'DC.', 18),
(3116, 'Blanchetiastrum', NULL, 'Hassl.', 102),
(3117, 'Blandibractea', NULL, 'Wernham', 142),
(3118, 'Blastania', NULL, 'Kotschy & Peyr.', 49),
(3119, 'Blastemanthus', NULL, 'Planch.', 118),
(3120, 'Bleasdalea', NULL, 'F.Muell. ex Domin', 135),
(3121, 'Blechum', NULL, 'P.Browne', 1),
(3122, 'Bleekeria', NULL, 'Hassk.', 10),
(3123, 'Bleekrodea', NULL, 'Blume', 109),
(3124, 'Blennoderma', NULL, 'Spach', 121),
(3125, 'Blennodia', NULL, 'R.Br.', 197),
(3126, 'Blennosperma', NULL, 'Less.', 18),
(3127, 'Blennospora', NULL, 'A.Gray', 18),
(3128, 'Blenocoes', NULL, 'Raf.(SUS)', 154),
(3129, 'Blepharacanthus', NULL, 'Nees ex Lindl.', 1),
(3130, 'Blepharandra', NULL, 'Griseb.', 101),
(3131, 'Blepharanthera', NULL, 'Schltr.', 10),
(3132, 'Blepharanthes', NULL, 'Sm.(SUI)', 127),
(3133, 'Blepharidium', NULL, 'Standl.', 142),
(3134, 'Blepharipappus', NULL, 'Hook.', 18),
(3135, 'Blepharis', NULL, 'Juss.', 1),
(3136, 'Blepharispermum', NULL, 'DC.', 18),
(3137, 'Blepharistemma', NULL, 'Wall. ex Benth.', 140),
(3138, 'Blepharitheca', NULL, 'Pichon', 22),
(3139, 'Blepharizonia', NULL, '(A.Gray) Greene', 18),
(3140, 'Blepharocalyx', NULL, 'O.Berg', 116),
(3141, 'Blepharocarya', NULL, 'F.Muell.', 6),
(3142, 'Blepharodon', NULL, 'Decne.', 10),
(3143, 'Blepharolepis', NULL, 'Nees', 55),
(3144, 'Blepharostemma', NULL, 'Fourr.', 142),
(3145, 'Blephilia', NULL, 'Raf.', 90),
(3146, 'Blighiopsis', NULL, 'Van der Veken', 147),
(3147, 'Blinkworthia', NULL, 'Choisy', 46),
(3148, 'Blomia', NULL, 'Miranda', 147),
(3149, 'Blotia', NULL, 'Leandri', 184),
(3150, 'Blumea', NULL, 'DC.', 18),
(3151, 'Blumella', NULL, 'Tiegh.', 98),
(3152, 'Blumeopsis', NULL, 'Gagnep.', 18),
(3153, 'Blutaparon', NULL, 'Raf.', 5),
(3154, 'Blysmocarex', NULL, 'N.A.Ivanova', 55),
(3155, 'Blysmopsis', NULL, 'Oteng-Yeb.', 55),
(3156, 'Blysmus', NULL, 'Panz. ex Schult.', 55),
(3157, 'Blyttia', NULL, 'Arn.', 10),
(3158, 'Boaria', NULL, 'A.DC.', 38),
(3159, 'Bobea', NULL, 'Gaudich.', 142),
(3160, 'Bocagea', NULL, 'A.St.-Hil.', 8),
(3161, 'Bocageopsis', NULL, 'R.E.Fr.', 8),
(3162, 'Bocoa', NULL, 'Aubl.', 68),
(3163, 'Bocquillonia', NULL, 'Baill.', 66),
(3164, 'Boea', NULL, 'Comm. ex Lam.', 76),
(3165, 'Boebera', NULL, 'Willd.', 18),
(3166, 'Boeberastrum', NULL, '(A.Gray) Rydb.', 18),
(3167, 'Boeberoides', NULL, '(DC.) Strother', 18),
(3168, 'Boechera', NULL, 'A.Love & D.Love', 197),
(3169, 'Boeckeleria', NULL, 'T.Durand', 55),
(3170, 'Boehmeriopsis', NULL, 'Kom.', 109),
(3171, 'Boeica', NULL, 'T.Anderson ex C.B.Clarke', 76),
(3172, 'Boeicopsis', NULL, 'H.W.Li', 76),
(3173, 'Boenninghausenia', NULL, 'Rchb. ex Meisn.', 143),
(3174, 'Boerhavia', NULL, 'L.', 117),
(3175, 'Boerlagea', NULL, 'Cogn.', 105),
(3176, 'Boerlagiodendron', NULL, 'Harms', 13),
(3177, 'Bogenhardia', NULL, 'Rchb.', 102),
(3178, 'Bognera', NULL, 'Mayo & Nicolson', 12),
(3179, 'Boholia', NULL, 'Merr.', 142),
(3180, 'Boisduvalia', NULL, 'Spach', 121),
(3181, 'Boivinella', NULL, 'Pierre ex Aubrev. & Pellegr.(SUH', 148),
(3182, 'Bojeria', NULL, 'DC.', 18),
(3183, 'Bolandra', NULL, 'A.Gray', 149),
(3184, 'Bolanosa', NULL, 'A.Gray', 18),
(3185, 'Bolax', NULL, 'Comm. ex Juss.', 9),
(3186, 'Bolboschoenus', NULL, '(Asch.) Palla', 55),
(3187, 'Bolbostemma', NULL, 'Franquet', 49),
(3188, 'Bolboxalis', NULL, 'Small', 124),
(3189, 'Boldoa', NULL, 'Cav. ex Lag.', 117),
(3190, 'Bolelia', NULL, 'Raf.', 30),
(3191, 'Boleum', NULL, 'Desv.', 197),
(3192, 'Bolivaria', NULL, 'Cham. & Schltdl.', 120),
(3193, 'Bollwilleria', NULL, 'Zabel(SUI)', 141),
(3194, 'Bolocephalus', NULL, 'Hand.-Mazz.', 18),
(3195, 'Bolophyta', NULL, 'Nutt.', 18),
(3196, 'Boltonia', NULL, 'L''Her.', 18),
(3197, 'Bolusafra', NULL, 'Kuntze', 68),
(3198, 'Bolusanthus', NULL, 'Harms', 68),
(3199, 'Bolusia', NULL, 'Benth.', 68),
(3200, 'Bombycidendron', NULL, 'Zoll. & Moritzi', 102),
(3201, 'Bombycilaena', NULL, '(DC.) Smoljan.', 18),
(3202, 'Bonafousia', NULL, 'A.DC.', 10),
(3203, 'Bonamia', NULL, 'Thouars', 46),
(3204, 'Bonamica', NULL, 'Vell.', 120),
(3205, 'Bonania', NULL, 'A.Rich.', 66),
(3206, 'Bonannia', NULL, 'Guss.', 9),
(3207, 'Bonanox', NULL, 'Raf.', 46),
(3208, 'Bonatia', NULL, 'Schltr. & K.Krause(SUH)', 142),
(3209, 'Bonaveria', NULL, 'Scop.', 68),
(3210, 'Bonellia', NULL, 'Bertero ex Colla', 163),
(3211, 'Bonetiella', NULL, 'Rzed.', 6),
(3212, 'Bonifacia', NULL, 'Silva Manso ex Steud.', 142),
(3213, 'Boninia', NULL, 'Planch.', 143),
(3214, 'Boninofatsia', NULL, 'Nakai', 13),
(3215, 'Boniodendron', NULL, 'Gagnep.', 147),
(3216, 'Bonnaya', NULL, 'Link & Otto', 150),
(3217, 'Bonnayodes', NULL, 'Blatt. & Hallb.', 150),
(3218, 'Bonnierella', NULL, 'R.Vig.', 13),
(3219, 'Bontia', NULL, 'L.', 150),
(3220, 'Bonyunia', NULL, 'M.R.Schomb. ex Progel', 97),
(3221, 'Bopusia', NULL, 'C.Presl', 150),
(3222, 'Boraginella', NULL, 'Kuntze', 25),
(3223, 'Borago', NULL, 'L.', 25),
(3224, 'Borassodendron', NULL, 'Becc.', 15),
(3225, 'Borassus', NULL, 'L.', 15),
(3226, 'Borbonia', NULL, 'L.', 68),
(3227, 'Borderea', NULL, 'Miegev.', 59),
(3228, 'Boreava', NULL, 'Jaub. & Spach', 197),
(3229, 'Borismene', NULL, 'Barneby', 107),
(3230, 'Borkonstia', NULL, 'Ignatov', 18),
(3231, 'Borneacanthus', NULL, 'Bremek.', 1),
(3232, 'Borneodendron', NULL, 'Airy Shaw', 66),
(3233, 'Bornmuellera', NULL, 'Hausskn.', 197),
(3234, 'Borodinia', NULL, 'N.Busch', 197),
(3235, 'Boronella', NULL, 'Baill.', 143),
(3236, 'Boronia', NULL, 'Sm.', 143),
(3237, 'Borrachinea', NULL, 'Lavy', 25),
(3238, 'Borraginoides', NULL, 'Boehm.', 25),
(3239, 'Borrera', NULL, 'Spreng.(SUO)', 142),
(3240, 'Borreria', NULL, 'G.Mey.', 142),
(3241, 'Borrichia', NULL, 'Adans.', 18),
(3242, 'Borsczowia', NULL, 'Bunge', 5),
(3243, 'Borthwickia', NULL, 'W.W.Sm.', 32),
(3244, 'Boschia', NULL, 'Korth.', 102),
(3245, 'Boschniakia', NULL, 'C.A.Mey. ex Bong.', 400),
(3246, 'Boscia', NULL, 'Lam.', 32),
(3247, 'Bosea', NULL, 'L.', 5),
(3248, 'Bosistoa', NULL, 'F.Muell.', 143),
(3249, 'Bosleria', NULL, 'A.Nelson', 154),
(3250, 'Bosqueia', NULL, 'Thouars ex Baill.', 109),
(3251, 'Bosqueiopsis', NULL, 'De Wild. & T.Durand', 109),
(3252, 'Bosscheria', NULL, 'de Vriese & Teijsm.', 109),
(3253, 'Bossera', NULL, 'Leandri', 66),
(3254, 'Bossiaea', NULL, 'Vent.', 68),
(3255, 'Bostrychanthera', NULL, 'Benth.', 90),
(3256, 'Bostrychode', NULL, 'Miq. ex O.Berg', 116),
(3257, 'Boswellia', NULL, 'Roxb. ex Colebr.', 27),
(3258, 'Bothriocline', NULL, 'Oliv. ex Benth.', 18),
(3259, 'Bothriopodium', NULL, 'Rizzini', 22),
(3260, 'Bothriospermum', NULL, 'Bunge', 25),
(3261, 'Bothriospora', NULL, 'Hook.f.', 142),
(3262, 'Botryanthe', NULL, 'Klotzsch', 66),
(3263, 'Botryarrhena', NULL, 'Ducke', 142),
(3264, 'Botryceras', NULL, 'Willd.', 6),
(3265, 'Botryodendrum', NULL, 'Endl.', 13),
(3266, 'Botryoloranthus', NULL, '(Engl. & K.Krause) Balle', 98),
(3267, 'Botryomeryta', NULL, 'R.Vig.', 13),
(3268, 'Botryopanax', NULL, 'Miq.', 13),
(3269, 'Botryophora', NULL, 'Hook.f.', 66),
(3270, 'Botryopleuron', NULL, 'Hemsl.', 150),
(3271, 'Botryospora', NULL, 'B.D.Jacks.(SUO)', 66),
(3272, 'Botryostege', NULL, 'Stapf', 64),
(3273, 'Botryphora', NULL, 'Post & Kuntze(SUO)', 66),
(3274, 'Botschantzevia', NULL, 'Nabiev', 197),
(3275, 'Bottegoa', NULL, 'Chiov.', 147),
(3276, 'Boucerosia', NULL, 'Wight & Arn.', 10),
(3277, 'Bouchardatia', NULL, 'Baill.', 143),
(3278, 'Bouchea', NULL, 'Cham.', 173),
(3279, 'Bouchetia', NULL, 'Dunal', 154),
(3280, 'Bouetia', NULL, 'A.Chev.', 90),
(3281, 'Bougainvillea', NULL, 'Comm. ex Juss.', 117),
(3282, 'Bourdaria', NULL, 'A.Chev.', 105),
(3283, 'Bourdonia', NULL, 'Greene', 18),
(3284, 'Bourjotia', NULL, 'Pomel', 25),
(3285, 'Bournea', NULL, 'Oliv.', 76),
(3286, 'Bousigonia', NULL, 'Pierre', 10),
(3287, 'Boutiquea', NULL, 'Le Thomas', 8),
(3288, 'Boutonia', NULL, 'Bojer ex Baill.(SUH)', 1),
(3289, 'Bouvardia', NULL, 'Salisb.', 142),
(3290, 'Bovonia', NULL, 'Chiov.', 90),
(3291, 'Bowdichia', NULL, 'Kunth', 68),
(3292, 'Bowkeria', NULL, 'Harv.', 150),
(3293, 'Bowlesia', NULL, 'Ruiz & Pav.', 9),
(3294, 'Bowringia', NULL, 'Champ. ex Benth.', 68),
(3295, 'Boyania', NULL, 'Wurdack', 105),
(3296, 'Boykinia', NULL, 'Nutt.', 149),
(3297, 'Brabejum', NULL, 'L.', 135),
(3298, 'Bracea', NULL, 'Britton(SUH)', 10),
(3299, 'Brachanthemum', NULL, 'DC.', 18),
(3300, 'Brachionostylum', NULL, 'Mattf.', 18),
(3301, 'Brachiostemon', NULL, 'Hand.-Mazz.', 76),
(3302, 'Brachistus', NULL, 'Miers', 154),
(3303, 'Brachyandra', NULL, 'Phil.', 18),
(3304, 'Brachyapium', NULL, '(Baill.) Maire', 9),
(3305, 'Brachybotrys', NULL, 'Maxim. ex Oliv.', 25),
(3306, 'Brachycarpaea', NULL, 'DC.', 197),
(3307, 'Brachycaulos', NULL, 'Dikshit & Panigrahi', 141),
(3308, 'Brachycentrum', NULL, 'Meisn.', 105),
(3309, 'Brachychaeta', NULL, 'Torr. & A.Gray', 18),
(3310, 'Brachychiton', NULL, 'Schott & Endl.', 102),
(3311, 'Brachyclados', NULL, 'Gillies ex D.Don', 18),
(3312, 'Brachycodon', NULL, 'Fed.', 30),
(3313, 'Brachycome', NULL, 'Cass.(SUO)', 18),
(3314, 'Brachycylix', NULL, '(Harms) R.S.Cowan', 68),
(3315, 'Brachycyrtis', NULL, 'Koidz.', 94),
(3316, 'Brachyglottis', NULL, 'J.R.Forst. & G.Forst.', 18),
(3317, 'Brachyhelus', NULL, '(Benth.) Post & Kuntze', 154),
(3318, 'Brachylaena', NULL, 'R.Br.', 18),
(3319, 'Brachylepis', NULL, 'C.A.Mey.', 5),
(3320, 'Brachyloma', NULL, 'Sond.', 64),
(3321, 'Brachylophon', NULL, 'Oliv.', 101),
(3322, 'Brachymeris', NULL, 'DC.', 18),
(3323, 'Brachynema', NULL, 'Benth.', 119),
(3324, 'Brachyonostylum', NULL, 'Mattf.(SUO)', 18),
(3325, 'Brachyotum', NULL, '(DC.) Triana', 105),
(3326, 'Brachyphragma', NULL, 'Rydb.', 68),
(3327, 'Brachypremna', NULL, 'Gleason', 105),
(3328, 'Brachypterys', NULL, 'A.Juss.', 101),
(3329, 'Brachyscome', NULL, 'Cass.', 18),
(3330, 'Brachysema', NULL, 'R.Br.', 68),
(3331, 'Brachystachys', NULL, 'Klotzsch', 66),
(3332, 'Brachystegia', NULL, 'Benth.', 68),
(3333, 'Brachystelma', NULL, 'R.Br.', 10),
(3334, 'Brachystelmaria', NULL, 'Schltr.', 10),
(3335, 'Brachystephanus', NULL, 'Nees', 1),
(3336, 'Brachystigma', NULL, 'Pennell', 150),
(3337, 'Brachythalamus', NULL, 'Gilg', 164),
(3338, 'Brachythrix', NULL, 'Wild & G.V.Pope', 18),
(3339, 'Brachytome', NULL, 'Hook.f.', 142),
(3340, 'Bracteantha', NULL, 'Anderb.', 18),
(3341, 'Bracteanthus', NULL, 'Ducke', 505),
(3342, 'Bracteolanthus', NULL, 'de Wit', 68),
(3343, 'Bradburia', NULL, 'Torr. & A.Gray', 18),
(3344, 'Bradburya', NULL, 'Raf.', 68),
(3345, 'Bradea', NULL, 'Standl. ex Brade', 142),
(3346, 'Bradleia', NULL, 'Cav.(SUO)', 184),
(3347, 'Bradleja', NULL, 'Banks ex Gaertn.', 184),
(3348, 'Bragantia', NULL, 'Vand.', 5),
(3349, 'Brahea', NULL, 'Mart. ex Endl.', 15),
(3350, 'Brami', NULL, 'Adans.', 150),
(3351, 'Bramia', NULL, 'Lam.', 150),
(3352, 'Brandegea', NULL, 'Cogn.', 49),
(3353, 'Brandella', NULL, 'R.R.Mill', 25),
(3354, 'Brandesia', NULL, 'Mart.', 5),
(3355, 'Brandisia', NULL, 'Hook.f. & Thomson', 150),
(3356, 'Brasilia', NULL, 'G.M.Barroso', 18),
(3357, 'Brassaia', NULL, 'Endl.', 13),
(3358, 'Brassaiopsis', NULL, 'Decne. & Planch.', 13),
(3359, 'Brassiantha', NULL, 'A.C.Sm.', 38),
(3360, 'Brassica', NULL, 'L.', 197),
(3361, 'Brassicaria', NULL, 'Pomel', 197),
(3362, 'Brassicella', NULL, 'Fourr. ex O.E.Schulz', 197),
(3363, 'Brassiodendron', NULL, 'C.K.Allen', 91),
(3364, 'Brassiophoenix', NULL, 'Burret', 15),
(3365, 'Braunblanquetia', NULL, 'Eskuche', 150),
(3366, 'Bravoa', NULL, 'Lex.', 3),
(3367, 'Braya', NULL, 'Sternb. & Hoppe', 197),
(3368, 'Brayera', NULL, 'Kunth', 141),
(3369, 'Brayopsis', NULL, 'Gilg & Muschl.', 197),
(3370, 'Brayulinea', NULL, 'Small', 5),
(3371, 'Brazoria', NULL, 'Engelm. & A.Gray', 90),
(3372, 'Brazzeia', NULL, 'Baill.', 92),
(3373, 'Brebissonia', NULL, 'Spach', 121),
(3374, 'Bredemeyera', NULL, 'Willd.', 133),
(3375, 'Bredia', NULL, 'Blume', 105),
(3376, 'Breitungia', NULL, 'A.Love & D.Love', 48),
(3377, 'Bremekampia', NULL, 'Sreem.(SUS)', 1),
(3378, 'Bremontiera', NULL, 'DC.', 68),
(3379, 'Brenierea', NULL, 'Humbert', 68),
(3380, 'Breonadia', NULL, 'Ridsdale', 142),
(3381, 'Breonia', NULL, 'A.Rich. ex DC.', 142),
(3382, 'Breueria', NULL, 'R.Br.', 46),
(3383, 'Breueriopsis', NULL, 'Roberty', 46),
(3384, 'Breuieropsis', NULL, 'Roberty(SUO)', 46),
(3385, 'Brexiella', NULL, 'H.Perrier', 38),
(3386, 'Brexiopsis', NULL, 'H.Perrier', 66),
(3387, 'Breyniopsis', NULL, 'Beille', 184),
(3388, 'Brezia', NULL, 'Moq.', 5),
(3389, 'Brickellia', NULL, 'Elliott', 18),
(3390, 'Brickelliastrum', NULL, 'R.M.King & H.Rob.', 18),
(3391, 'Bridgesia', NULL, 'Bertero ex Cambess.', 147),
(3392, 'Brieya', NULL, 'De Wild.', 8),
(3393, 'Briggsia', NULL, 'Craib', 76),
(3394, 'Briggsiopsis', NULL, 'K.Y.Pan', 76),
(3395, 'Brighamia', NULL, 'A.Gray', 30),
(3396, 'Brignolia', NULL, 'DC.', 142),
(3397, 'Brillantaisia', NULL, 'P.Beauv.', 1),
(3398, 'Brintonia', NULL, 'Greene', 18),
(3399, 'Briquetastrum', NULL, 'Robyns & Lebrun', 90),
(3400, 'Briquetia', NULL, 'Hochr.', 102),
(3401, 'Briquetina', NULL, 'J.F.Macbr.', 85),
(3402, 'Britoa', NULL, 'O.Berg', 116),
(3403, 'Brittenia', NULL, 'Cogn.', 105),
(3404, 'Brittonastrum', NULL, 'Briq.', 90),
(3405, 'Brittonella', NULL, 'Rusby', 101),
(3406, 'Brochoneura', NULL, 'Warb.', 114),
(3407, 'Brochosiphon', NULL, 'Nees', 1),
(3408, 'Brockmania', NULL, 'W.Fitzg.', 102),
(3409, 'Brodriguesia', NULL, 'R.S.Cowan', 68),
(3410, 'Brombya', NULL, 'F.Muell.', 143),
(3411, 'Brongniartia', NULL, 'Kunth', 68),
(3412, 'Brongniartikentia', NULL, 'Becc.', 15),
(3413, 'Brookea', NULL, 'Benth.', 423),
(3414, 'Brosimopsis', NULL, 'S.Moore', 109),
(3415, 'Brossaea', NULL, 'L.(SUO)', 64),
(3416, 'Brossardia', NULL, 'Boiss.', 197),
(3417, 'Brossea', NULL, 'Kuntze(SUO)', 64),
(3418, 'Brotera', NULL, 'Spreng.(SUH)', 90),
(3419, 'Broussonetia', NULL, 'L''Her. ex Vent.', 109),
(3420, 'Browallia', NULL, 'L.', 154),
(3421, 'Browneopsis', NULL, 'Huber', 68),
(3422, 'Brownlowia', NULL, 'Roxb.', 102),
(3423, 'Brucea', NULL, 'J.F.Mill.', 151),
(3424, 'Bruckenthalia', NULL, 'Rchb.', 64),
(3425, 'Bruguiera', NULL, 'Thouars(SUH)', 140),
(3426, 'Bruinsmania', NULL, 'Miq.', 142),
(3427, 'Bruinsmia', NULL, 'Boerl. & Koord.', 158),
(3428, 'Brunella', NULL, 'Mill.', 90),
(3429, 'Brunfelsiopsis', NULL, '(Urb.) Kuntze', 154),
(3430, 'Brunnera', NULL, 'Steven', 25),
(3431, 'Brunnichia', NULL, 'Banks ex Gaertn.', 134),
(3432, 'Brunoniella', NULL, 'Bremek.', 1),
(3433, 'Brya', NULL, 'P.Browne', 68),
(3434, 'Bryantea', NULL, 'Raf.', 91),
(3435, 'Bryanthus', NULL, 'J.G.Gmel.', 64),
(3436, 'Bryaspis', NULL, 'P.A.Duvign.', 68),
(3437, 'Bryodes', NULL, 'Benth.', 423),
(3438, 'Bryomorphe', NULL, 'Harv.', 18),
(3439, 'Bryonia', NULL, 'L.', 49),
(3440, 'Bryonopsis', NULL, 'Arn.', 49),
(3441, 'Bryophyllum', NULL, 'Salisb.', 48),
(3442, 'Bubalina', NULL, 'Raf.', 142),
(3443, 'Bubbia', NULL, 'Tiegh.', 176),
(3444, 'Bubon', NULL, 'L.', 9),
(3445, 'Bubonium', NULL, 'Hill(SUS)', 18),
(3446, 'Bucanion', NULL, 'Steven', 25),
(3447, 'Bucephalandra', NULL, 'Schott', 12),
(3448, 'Bucephalon', NULL, 'L.', 109),
(3449, 'Bucephalora', NULL, 'Pau', 134),
(3450, 'Bucera', NULL, 'P.Browne', 44),
(3451, 'Buceragenia', NULL, 'Greenm.', 1),
(3452, 'Buchenroedera', NULL, 'Eckl. & Zeyh.', 68),
(3453, 'Bucheria', NULL, 'Heynh.', 116),
(3454, 'Buchholzia', NULL, 'Engl.', 32),
(3455, 'Buchia', NULL, 'Kunth', 142),
(3456, 'Buchingera', NULL, 'Boiss. & Hohen.', 197),
(3457, 'Buchnera', NULL, 'L.', 400),
(3458, 'Buchnerodendron', NULL, 'Gurke', 198),
(3459, 'Buchozia', NULL, 'L''Her. ex Juss.', 142),
(3460, 'Bucinella', NULL, 'Wiehler(SUH)', 76),
(3461, 'Bucinellina', NULL, 'Wiehler', 76),
(3462, 'Buckinghamia', NULL, 'F.Muell.', 135),
(3463, 'Buckleya', NULL, 'Torr.', 146),
(3464, 'Bucquetia', NULL, 'DC.', 105),
(3465, 'Buddleja', NULL, 'L.', 150),
(3466, 'Buena', NULL, 'Pohl', 142),
(3467, 'Buergeria', NULL, 'Miq.', 68),
(3468, 'Buettneria', NULL, 'Murray', 102),
(3469, 'Buglossoides', NULL, 'Moench', 25),
(3470, 'Bugranopsis', NULL, 'Pomel', 68),
(3471, 'Buhsia', NULL, 'Bunge', 32),
(3472, 'Bulbostylis', NULL, 'Kunth', 55),
(3473, 'Bulliarda', NULL, 'DC.(SUH)', 48),
(3474, 'Bulnesia', NULL, 'Gay', 177),
(3475, 'Bulweria', NULL, 'F.Muell.', 22),
(3476, 'Bumelia', NULL, 'Sw.', 148),
(3477, 'Bunburya', NULL, 'Meisn. ex Hochst.', 142),
(3478, 'Bungea', NULL, 'C.A.Mey.', 400),
(3479, 'Bunias', NULL, 'L.', 197),
(3480, 'Buniella', NULL, 'Schischk.', 9),
(3481, 'Buniotrinia', NULL, 'Stapf & Wettst.', 9),
(3482, 'Bunium', NULL, 'L.', 9),
(3483, 'Bunophila', NULL, 'Willd. ex Roem. & Schult.', 142),
(3484, 'Buphthalmum', NULL, 'L.', 18),
(3485, 'Bupleuroides', NULL, 'Moench', 142),
(3486, 'Bupleurum', NULL, 'L.', 9),
(3487, 'Buraeavia', NULL, 'Baill.', 66),
(3488, 'Burasaia', NULL, 'Thouars', 107),
(3489, 'Burcardia', NULL, 'Neck. ex Raf.', 116),
(3490, 'Burchellia', NULL, 'R.Br.', 142),
(3491, 'Burckella', NULL, 'Pierre', 148),
(3492, 'Burdachia', NULL, 'Mart. ex A.Juss.', 101),
(3493, 'Bureaua', NULL, 'Kuntze', 66),
(3494, 'Bureava', NULL, 'Baill.', 44),
(3495, 'Bureavella', NULL, 'Pierre', 148),
(3496, 'Burgesia', NULL, 'F.Muell.', 68),
(3497, 'Burkartia', NULL, 'Crisci', 18),
(3498, 'Burkea', NULL, 'Hook.', 68),
(3499, 'Burkillanthus', NULL, 'Swingle', 143),
(3500, 'Burkillia', NULL, 'Ridl.', 68),
(3501, 'Burkilliodendron', NULL, 'Sastry', 68),
(3502, 'Burlemarxia', NULL, 'N.L.Menezes & Semir', 172),
(3503, 'Burmeistera', NULL, 'H.Karst. & Triana', 30),
(3504, 'Burnatastrum', NULL, 'Briq.', 90),
(3505, 'Burneya', NULL, 'Cham. & Schltdl.', 142),
(3506, 'Burragea', NULL, 'Donn.Sm. & Rose', 121),
(3507, 'Burretiodendron', NULL, 'Rehder', 102),
(3508, 'Burretiokentia', NULL, 'Pic.Serm.', 15),
(3509, 'Burroughsia', NULL, 'Moldenke', 173),
(3510, 'Burtonia', NULL, 'R.Br.', 68),
(3511, 'Burttdavya', NULL, 'Hoyle', 142),
(3512, 'Burttia', NULL, 'Baker f. & Exell', 45),
(3513, 'Busbeckia', NULL, 'Hecart(SUI)', 120),
(3514, 'Buseria', NULL, 'T.Durand', 142),
(3515, 'Bushia', NULL, 'Nieuwl.', 5),
(3516, 'Bussea', NULL, 'Harms', 68),
(3517, 'Bustelma', NULL, 'E.Fourn.', 10),
(3518, 'Bustillosia', NULL, 'Clos', 9),
(3519, 'Butayea', NULL, 'De Wild.', 1),
(3520, 'Buteraea', NULL, 'Nees', 1),
(3521, 'Butia', NULL, '(Becc.) Becc.', 15),
(3522, 'Butinia', NULL, 'Boiss.', 9),
(3523, 'Buttonia', NULL, 'McKen ex Benth.', 400),
(3524, 'Butyrospermum', NULL, 'Kotschy', 148),
(3525, 'Buxiphyllum', NULL, 'W.T.Wang & C.Z.Gao', 76),
(3526, 'Buxus', NULL, 'L.', 28),
(3527, 'Byrnesia', NULL, 'Rose', 48),
(3528, 'Byrsanthes', NULL, 'C.Presl', 30),
(3529, 'Byrsanthus', NULL, 'Guill.', 145),
(3530, 'Byrsocarpus', NULL, 'Schumach. & Thonn.', 45),
(3531, 'Bystropogon', NULL, 'L''Her.', 90),
(3532, 'Bythophyton', NULL, 'Hook.f.', 423),
(3533, 'Byttneria', NULL, 'Loefl.', 102),
(3534, 'Cabi', NULL, 'Ducke', 101),
(3535, 'Cabreriella', NULL, 'Cuatrec.', 18),
(3536, 'Cabucala', NULL, 'Pichon', 10),
(3537, 'Cacabus', NULL, 'Bernh.', 154),
(3538, 'Cacalia', NULL, 'L.', 18),
(3539, 'Cacaliopsis', NULL, 'A.Gray', 18),
(3540, 'Caccinia', NULL, 'Savi', 25),
(3541, 'Cachrys', NULL, 'L.', 9),
(3542, 'Cacosmanthus', NULL, 'de Vriese(SUO)', 148),
(3543, 'Cacosmia', NULL, 'Kunth', 18),
(3544, 'Cacoucia', NULL, 'Aubl.', 44),
(3545, 'Cadaba', NULL, 'Forssk.', 32),
(3546, 'Cadamba', NULL, 'Sonn.', 142),
(3547, 'Cadia', NULL, 'Forssk.', 68),
(3548, 'Cadiscus', NULL, 'E.Mey. ex DC.', 18),
(3549, 'Caelodepas', NULL, 'Benth.(SUO)', 66),
(3550, 'Caelospermum', NULL, 'Blume(SUO)', 142),
(3551, 'Caesulia', NULL, 'Roxb.', 18),
(3552, 'Cafe', NULL, 'Adans.(SUS)', 142),
(3553, 'Cailliea', NULL, 'Guill. & Perr.', 68),
(3554, 'Cailliella', NULL, 'Jacq.-Fel.', 105),
(3555, 'Cainito', NULL, 'Adans.', 148),
(3556, 'Cajalbania', NULL, 'Urb.', 68),
(3557, 'Cajanus', NULL, 'DC.', 68),
(3558, 'Cajuputi', NULL, 'Adans.', 116),
(3559, 'Cakile', NULL, 'Mill.', 197),
(3560, 'Calacanthus', NULL, 'T.Anderson ex Benth.', 1),
(3561, 'Caladiopsis', NULL, 'Engl.', 12),
(3562, 'Caladium', NULL, 'Vent.', 12),
(3563, 'Calamintha', NULL, 'Mill.', 90),
(3564, 'Calamosagus', NULL, 'Griff.', 15),
(3565, 'Calampelis', NULL, 'D.Don', 22),
(3566, 'Calamus', NULL, 'L.', 15),
(3567, 'Calanda', NULL, 'K.Schum.', 142),
(3568, 'Calanthus', NULL, 'Oerst. ex Hanst.', 76),
(3569, 'Calantica', NULL, 'Jaub. ex Tul.', 145),
(3570, 'Calappa', NULL, 'Steck', 15),
(3571, 'Calathea', NULL, 'G.Mey.', 103),
(3572, 'Calathiana', NULL, 'Delarbre', 75),
(3573, 'Calathostelma', NULL, 'E.Fourn.', 10),
(3574, 'Calcareoboea', NULL, 'C.Y.Wu', 76),
(3575, 'Calceolaria', NULL, 'L.', 507),
(3576, 'Caldcluvia', NULL, 'D.Don', 50),
(3577, 'Calderonia', NULL, 'Standl.', 142),
(3578, 'Calea', NULL, 'L.', 18),
(3579, 'Calendula', NULL, 'L.', 18),
(3580, 'Caleopsis', NULL, 'Fedde', 18),
(3581, 'Calepina', NULL, 'Adans.', 197),
(3582, 'Caletia', NULL, 'Baill.', 66),
(3583, 'Calia', NULL, 'Berland.', 68),
(3584, 'Calibrachoa', NULL, 'Cerv.', 154),
(3585, 'Calicorema', NULL, 'Hook.f.', 5),
(3586, 'Calicotome', NULL, 'Link', 68),
(3587, 'Calispepla', NULL, 'Vved.', 68),
(3588, 'Calius', NULL, 'Blanco', 109),
(3589, 'Calla', NULL, 'L.', 12),
(3590, 'Callaeolepium', NULL, 'H.Karst.', 10),
(3591, 'Callaeum', NULL, 'Small', 101),
(3592, 'Callianassa', NULL, 'Webb & Berthel.', 150),
(3593, 'Calliandropsis', NULL, 'H.M.Hern. & Guinet', 68),
(3594, 'Calliaspidia', NULL, 'Bremek.', 1),
(3595, 'Callicephalus', NULL, 'C.A.Mey.', 18),
(3596, 'Callichilia', NULL, 'Stapf', 10),
(3597, 'Callichlamys', NULL, 'Miq.', 22),
(3598, 'Callicocca', NULL, 'Schreb.', 142),
(3599, 'Callicoma', NULL, 'Andrews', 50),
(3600, 'Calligonum', NULL, 'L.', 134),
(3601, 'Callilepis', NULL, 'DC.', 18),
(3602, 'Callipeltis', NULL, 'Steven', 142),
(3603, 'Callirhoe', NULL, 'Nutt.', 102),
(3604, 'Callisace', NULL, 'Fisch.', 9),
(3605, 'Callistachys', NULL, 'Vent.', 68),
(3606, 'Callistemon', NULL, 'R.Br.', 116),
(3607, 'Callistephus', NULL, 'Cass.', 18),
(3608, 'Callisthene', NULL, 'Mart.', 175),
(3609, 'Callistylon', NULL, 'Pittier', 68),
(3610, 'Callitris', NULL, 'Vent.', 51),
(3611, 'Callopsis', NULL, 'Engl.', 12),
(3612, 'Callothlaspi', NULL, 'F.K.Mey.', 197),
(3613, 'Calluna', NULL, 'Salisb.', 64),
(3614, 'Calocarpum', NULL, 'Pierre', 148),
(3615, 'Calocedrus', NULL, 'Kurz', 51),
(3616, 'Calocephalus', NULL, 'R.Br.', 18),
(3617, 'Calochone', NULL, 'Keay', 142),
(3618, 'Calochortus', NULL, 'Pursh', 94),
(3619, 'Calococcus', NULL, 'Kurz ex Teijsm.', 184),
(3620, 'Calocrater', NULL, 'K.Schum.', 10),
(3621, 'Calodecaryia', NULL, 'J.-F.Leroy', 106),
(3622, 'Calodendrum', NULL, 'Thunb.', 143),
(3623, 'Calodryum', NULL, 'Desv.', 106),
(3624, 'Calolisianthus', NULL, 'Gilg', 75),
(3625, 'Calomeria', NULL, 'Vent.', 18),
(3626, 'Calonyction', NULL, 'Choisy', 46),
(3627, 'Calopappus', NULL, 'Meyen', 18),
(3628, 'Calophaca', NULL, 'Fisch. ex DC.', 68),
(3629, 'Calophanes', NULL, 'D.Don', 1),
(3630, 'Calophanoides', NULL, '(C.B.Clarke) Ridl.', 1),
(3631, 'Calophysa', NULL, 'DC.', 105),
(3632, 'Caloplectus', NULL, 'Oerst.', 76);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(3633, 'Calopogonium', NULL, 'Desv.', 68),
(3634, 'Calopteryx', NULL, 'A.C.Sm.', 64),
(3635, 'Calopyxis', NULL, 'Tul.', 44),
(3636, 'Calorhabdos', NULL, 'Benth.', 150),
(3637, 'Calosacme', NULL, 'Wall.', 76),
(3638, 'Calosanthes', NULL, 'Blume', 22),
(3639, 'Calospatha', NULL, 'Becc.', 15),
(3640, 'Calospermum', NULL, 'Pierre', 148),
(3641, 'Calostephane', NULL, 'Benth.', 18),
(3642, 'Calostigma', NULL, 'Decne.', 10),
(3643, 'Calotesta', NULL, 'P.O.Karis', 18),
(3644, 'Calothamnus', NULL, 'Labill.', 116),
(3645, 'Calotis', NULL, 'R.Br.', 18),
(3646, 'Calotropis', NULL, 'R.Br.', 10),
(3647, 'Calpicarpum', NULL, 'G.Don', 10),
(3648, 'Calpidia', NULL, 'Thouars', 117),
(3649, 'Calpidochlamys', NULL, 'Diels', 109),
(3650, 'Calpidosicyos', NULL, 'Harms', 49),
(3651, 'Calpigyne', NULL, 'Blume', 66),
(3652, 'Calpurnia', NULL, 'E.Mey.', 68),
(3653, 'Calvaria', NULL, 'Comm. ex C.F.Gaertn.', 148),
(3654, 'Calvelia', NULL, 'Moq.', 5),
(3655, 'Calvoa', NULL, 'Hook.f.', 105),
(3656, 'Calycacanthus', NULL, 'K.Schum.', 1),
(3657, 'Calycadenia', NULL, 'DC.', 18),
(3658, 'Calycampe', NULL, 'O.Berg', 116),
(3659, 'Calycantherum', NULL, 'Klotzsch', 46),
(3660, 'Calycobolus', NULL, 'Willd. ex Schult.', 46),
(3661, 'Calycocarpum', NULL, 'Nutt. ex Spach', 107),
(3662, 'Calycocorsus', NULL, 'F.W.Schmidt', 18),
(3663, 'Calycodendron', NULL, 'A.C.Sm.', 142),
(3664, 'Calycomelia', NULL, 'Kostel.', 120),
(3665, 'Calycomis', NULL, 'R.Br. ex Nees & Sinning(SUS)', 50),
(3666, 'Calycopeplus', NULL, 'Planch.', 66),
(3667, 'Calycophysum', NULL, 'H.Karst. & Triana', 49),
(3668, 'Calycopteris', NULL, 'Lam.', 44),
(3669, 'Calycorectes', NULL, 'O.Berg', 116),
(3670, 'Calycoseris', NULL, 'A.Gray', 18),
(3671, 'Calycosia', NULL, 'A.Gray', 142),
(3672, 'Calycostemma', NULL, 'Hanst.', 76),
(3673, 'Calycothrix', NULL, 'Meisn.', 116),
(3674, 'Calyculogygas', NULL, 'Krapov.', 102),
(3675, 'Calydermos', NULL, 'Ruiz & Pav.', 154),
(3676, 'Calylophis', NULL, 'Spach(SUO)', 121),
(3677, 'Calylophus', NULL, 'Spach', 121),
(3678, 'Calymmatium', NULL, 'O.E.Schulz', 197),
(3679, 'Calymmostachya', NULL, 'Bremek.', 1),
(3680, 'Calyntranthele', NULL, 'Nied.', 101),
(3681, 'Calyplectus', NULL, 'Ruiz & Pav.', 99),
(3682, 'Calypteriopetalon', NULL, 'Hassk.', 66),
(3683, 'Calyptocarpus', NULL, 'Less.', 18),
(3684, 'Calyptosepalum', NULL, 'S.Moore', 66),
(3685, 'Calyptostylis', NULL, 'Arenes', 101),
(3686, 'Calyptraemalva', NULL, 'Krapov.', 102),
(3687, 'Calyptranthus', NULL, 'Blume', 116),
(3688, 'Calyptraria', NULL, 'Naudin', 105),
(3689, 'Calyptrella', NULL, 'Naudin', 105),
(3690, 'Calyptrocalyx', NULL, 'Blume', 15),
(3691, 'Calyptrocarya', NULL, 'Nees', 55),
(3692, 'Calyptrocoryne', NULL, 'Schott', 12),
(3693, 'Calyptrogenia', NULL, 'Burret', 116),
(3694, 'Calyptromyrcia', NULL, 'O.Berg', 116),
(3695, 'Calyptronoma', NULL, 'Griseb.', 15),
(3696, 'Calyptroon', NULL, 'Miq.', 184),
(3697, 'Calyptropsidium', NULL, 'O.Berg', 116),
(3698, 'Calyptrosciadium', NULL, 'Rech.f. & Kuber', 9),
(3699, 'Calyptrosicyos', NULL, 'Keraudren', 49),
(3700, 'Calyptrospatha', NULL, 'Klotzsch ex Baill.', 66),
(3701, 'Calyptrospermum', NULL, 'A.Dietr.(SUS)', 120),
(3702, 'Calyptrostigma', NULL, 'Klotzsch', 66),
(3703, 'Calystegia', NULL, 'R.Br.', 46),
(3704, 'Calythrix', NULL, 'Labill.', 116),
(3705, 'Calythropsis', NULL, 'C.A.Gardner', 116),
(3706, 'Calytrix', NULL, 'Labill.', 116),
(3707, 'Camarea', NULL, 'A.St.-Hil.', 101),
(3708, 'Camarotea', NULL, 'Scott-Elliot', 1),
(3709, 'Cambania', NULL, 'Comm. ex M.Roem.', 106),
(3710, 'Cambessedesia', NULL, 'DC.', 105),
(3711, 'Cambogia', NULL, 'L.', 42),
(3712, 'Camchaya', NULL, 'Gagnep.', 18),
(3713, 'Camelina', NULL, 'Crantz', 197),
(3714, 'Camelinopsis', NULL, 'A.G.Mill.', 197),
(3715, 'Cameraria', NULL, 'L.', 10),
(3716, 'Camerunia', NULL, '(Pichon) Boiteau', 10),
(3717, 'Camirium', NULL, 'Gaertn.', 66),
(3718, 'Camissonia', NULL, 'Link', 121),
(3719, 'Camoensia', NULL, 'Welw. ex Benth.', 68),
(3720, 'Camolenga', NULL, 'Post & Kuntze', 49),
(3721, 'Campana', NULL, 'Post & Kuntze', 22),
(3722, 'Campanea', NULL, 'Decne.(SUO)', 76),
(3723, 'Campanocalyx', NULL, 'Valeton', 142),
(3724, 'Campanolea', NULL, 'Gilg & Schellenb.', 120),
(3725, 'Campanula', NULL, 'L.', 30),
(3726, 'Campanulastrum', NULL, 'Small', 30),
(3727, 'Campanumoea', NULL, 'Blume', 30),
(3728, 'Campbellia', NULL, 'Wight', 150),
(3729, 'Campderia', NULL, 'Benth.', 134),
(3730, 'Campecarpus', NULL, 'H.Wendl. ex Becc.', 15),
(3731, 'Campelepis', NULL, 'Falc.', 10),
(3732, 'Campestigma', NULL, 'Pierre ex Costantin', 10),
(3733, 'Camphoromyrtus', NULL, 'Schauer', 116),
(3734, 'Camphorosma', NULL, 'L.', 5),
(3735, 'Campimia', NULL, 'Ridl.', 105),
(3736, 'Campovassouria', NULL, 'R.M.King & H.Rob.', 18),
(3737, 'Campsiandra', NULL, 'Benth.', 68),
(3738, 'Campsidium', NULL, 'Seem.', 22),
(3739, 'Campsis', NULL, 'Lour.', 22),
(3740, 'Camptacra', NULL, 'N.T.Burb.', 18),
(3741, 'Camptocarpus', NULL, 'Decne.', 10),
(3742, 'Camptolepis', NULL, 'Radlk.', 147),
(3743, 'Camptoloma', NULL, 'Benth.', 150),
(3744, 'Camptophytum', NULL, 'Pierre ex A.Chev.(SUI)', 142),
(3745, 'Camptopus', NULL, 'Hook.f.', 142),
(3746, 'Camptosema', NULL, 'Hook. & Arn.', 68),
(3747, 'Camptostemon', NULL, 'Mast.', 102),
(3748, 'Camptotheca', NULL, 'Decne.', 528),
(3749, 'Campuloclinium', NULL, 'DC.', 18),
(3750, 'Campylanthera', NULL, 'Schott & Endl.', 102),
(3751, 'Campylanthus', NULL, 'Roth', 423),
(3752, 'Campylobotrys', NULL, 'Lem.', 142),
(3753, 'Campylocaryum', NULL, 'DC. ex Meisn.', 25),
(3754, 'Campylochiton', NULL, 'Welw. ex Hiern', 44),
(3755, 'Campylogyne', NULL, 'Welw. ex Hemsl.', 44),
(3756, 'Campylopetalum', NULL, 'Forman', 6),
(3757, 'Campyloptera', NULL, 'Boiss.', 197),
(3758, 'Campylostemon', NULL, 'Welw.', 38),
(3759, 'Campylotheca', NULL, 'Cass.', 18),
(3760, 'Campylotropis', NULL, 'Bunge', 68),
(3761, 'Camunium', NULL, 'Roxb.(SUH)', 106),
(3762, 'Canaca', NULL, 'Guillaumin', 66),
(3763, 'Canacomyrica', NULL, 'Guillaumin', 113),
(3764, 'Canangium', NULL, 'Baill.(SUS)', 8),
(3765, 'Canariastrum', NULL, 'Engl.(SUI)', 184),
(3766, 'Canariellum', NULL, 'Engl.', 27),
(3767, 'Canarina', NULL, 'L.', 30),
(3768, 'Canavalia', NULL, 'DC.', 68),
(3769, 'Canbya', NULL, 'Parry ex A.Gray', 126),
(3770, 'Cancellaria', NULL, '(DC.) Mattei', 102),
(3771, 'Cancrinia', NULL, 'Kar. & Kir.', 18),
(3772, 'Cancriniella', NULL, 'Tzvelev', 18),
(3773, 'Candelabria', NULL, 'Hochst.', 184),
(3774, 'Candolleodendron', NULL, 'R.S.Cowan', 68),
(3775, 'Candollina', NULL, 'Tiegh.', 98),
(3776, 'Canella', NULL, 'P.Browne', 31),
(3777, 'Canephora', NULL, 'Juss.', 142),
(3778, 'Canizaresia', NULL, 'Britton', 68),
(3779, 'Canotia', NULL, 'Torr.', 38),
(3780, 'Canschi', NULL, 'Adans.', 66),
(3781, 'Canscora', NULL, 'Lam.', 75),
(3782, 'Cansjera', NULL, 'Juss.', 122),
(3783, 'Cantalea', NULL, 'Raf.', 154),
(3784, 'Cantharospermum', NULL, 'Wight & Arn.', 68),
(3785, 'Canthiopsis', NULL, 'Seem.', 142),
(3786, 'Canthopsis', NULL, 'Miq.', 142),
(3787, 'Cantuffa', NULL, 'J.F.Gmel.', 68),
(3788, 'Caoutchoua', NULL, 'J.F.Gmel.', 66),
(3789, 'Capanea', NULL, 'Decne.', 76),
(3790, 'Capassa', NULL, 'Klotzsch', 68),
(3791, 'Capellenia', NULL, 'Teijsm. & Binn.', 66),
(3792, 'Caperonia', NULL, 'A.St.-Hil.', 66),
(3793, 'Capitanopsis', NULL, 'S.Moore', 90),
(3794, 'Capitanya', NULL, 'Schweinf. ex Gurke', 90),
(3795, 'Capitellaria', NULL, 'Naudin', 105),
(3796, 'Capitularia', NULL, 'J.V.Suringar', 55),
(3797, 'Capitularina', NULL, 'Kern', 55),
(3798, 'Capnoides', NULL, 'Mill.', 126),
(3799, 'Capnophyllum', NULL, 'Gaertn.', 9),
(3800, 'Capparidastrum', NULL, 'Hutch.', 32),
(3801, 'Capraria', NULL, 'L.', 150),
(3802, 'Caprificus', NULL, 'Gasp.', 109),
(3803, 'Caprosma', NULL, 'G.Don(SUO)', 142),
(3804, 'Capsella', NULL, 'Medik.', 197),
(3805, 'Capsicodendron', NULL, 'Hoehne', 31),
(3806, 'Capsicum', NULL, 'L.', 154),
(3807, 'Captaincookia', NULL, 'N.Halle', 142),
(3808, 'Capurodendron', NULL, 'Aubrev.', 148),
(3809, 'Capuronetta', NULL, 'Markgr.', 10),
(3810, 'Capuronia', NULL, 'Lourteig', 99),
(3811, 'Capuronianthus', NULL, 'J.-F.Leroy', 106),
(3812, 'Capusia', NULL, 'Lecomte', 38),
(3813, 'Caquepira', NULL, 'J.F.Gmel.', 142),
(3814, 'Caracasia', NULL, 'Szyszyl.', 104),
(3815, 'Caragana', NULL, 'Fabr.', 68),
(3816, 'Caralluma', NULL, 'R.Br.', 10),
(3817, 'Caramuri', NULL, 'Aubrev. & Pellegr.', 148),
(3818, 'Carandra', NULL, 'Gaertn.', 142),
(3819, 'Carania', NULL, 'Chiov.', 127),
(3820, 'Carapichea', NULL, 'Aubl.', 142),
(3821, 'Carcia', NULL, 'Raeusch.', 66),
(3822, 'Cardamine', NULL, 'L.', 197),
(3823, 'Cardaminopsis', NULL, '(C.A.Mey.) Hayek', 197),
(3824, 'Cardanthera', NULL, 'Buch.-Ham. ex Benth.(SUS)', 1),
(3825, 'Cardaria', NULL, 'Desv.', 197),
(3826, 'Cardenasia', NULL, 'Rusby', 68),
(3827, 'Cardenasiodendron', NULL, 'F.A.Barkley', 6),
(3828, 'Cardiacanthus', NULL, 'Nees & Schauer', 1),
(3829, 'Cardiochlamys', NULL, 'Oliv.', 46),
(3830, 'Cardiocrinum', NULL, '(Endl.) Lindl.', 94),
(3831, 'Cardiogyne', NULL, 'Bureau', 109),
(3832, 'Cardiopetalum', NULL, 'Schltdl.', 8),
(3833, 'Cardiophyllarium', NULL, 'Choux', 147),
(3834, 'Cardiospermum', NULL, 'L.', 147),
(3835, 'Cardioteucris', NULL, 'C.Y.Wu', 90),
(3836, 'Cardonaea', NULL, 'Aristeg., Maguire & Steyerm.', 18),
(3837, 'Cardopatium', NULL, 'Juss.', 18),
(3838, 'Carduncellus', NULL, 'Adans.', 18),
(3839, 'Carduus', NULL, 'L.', 18),
(3840, 'Cardwellia', NULL, 'F.Muell.', 135),
(3841, 'Carex', NULL, 'L.', 55),
(3842, 'Caribea', NULL, 'Alain', 117),
(3843, 'Carinavalva', NULL, 'Ising', 197),
(3844, 'Cariniana', NULL, 'Casar.', 92),
(3845, 'Carinivalva', NULL, 'Airy Shaw(SUO)', 197),
(3846, 'Carinta', NULL, 'W.Wight', 142),
(3847, 'Carionia', NULL, 'Naudin', 105),
(3848, 'Carissa', NULL, 'L.', 10),
(3849, 'Carissophyllum', NULL, 'Pichon', 75),
(3850, 'Carlephyton', NULL, 'Jum.', 12),
(3851, 'Carlesia', NULL, 'Dunn', 9),
(3852, 'Carlina', NULL, 'L.', 18),
(3853, 'Carlostephania', NULL, 'Bubani', 121),
(3854, 'Carlowrightia', NULL, 'A.Gray', 1),
(3855, 'Carludovica', NULL, 'Ruiz & Pav.', 54),
(3856, 'Carmenocania', NULL, 'Wernham', 142),
(3857, 'Carmichaelia', NULL, 'R.Br.', 68),
(3858, 'Carminatia', NULL, 'Moc. ex DC.', 18),
(3859, 'Carmona', NULL, 'Cav.', 25),
(3860, 'Carnarvonia', NULL, 'F.Muell.', 135),
(3861, 'Carnegieodoxa', NULL, 'Perkins', 108),
(3862, 'Carolofritschia', NULL, 'Engl.', 76),
(3863, 'Caropsis', NULL, '(Rouy & Camus) Rauschert', 9),
(3864, 'Caroxylon', NULL, 'Thunb.', 5),
(3865, 'Carpacoce', NULL, 'Sond.', 142),
(3866, 'Carpentaria', NULL, 'Becc.', 15),
(3867, 'Carpentia', NULL, 'Ewart', 46),
(3868, 'Carpesium', NULL, 'L.', 18),
(3869, 'Carpha', NULL, 'Banks & Sol. ex R.Br.', 55),
(3870, 'Carphalea', NULL, 'Juss.', 142),
(3871, 'Carphephorus', NULL, 'Cass.', 18),
(3872, 'Carphochaete', NULL, 'A.Gray', 18),
(3873, 'Carpinus', NULL, 'L.', 21),
(3874, 'Carpodinopsis', NULL, 'Pichon', 10),
(3875, 'Carpodinus', NULL, 'R.Br. ex G.Don', 10),
(3876, 'Carpodiptera', NULL, 'Griseb.', 102),
(3877, 'Carpolepis', NULL, '(J.W.Dawson) J.W.Dawson', 116),
(3878, 'Carponema', NULL, 'Eckl. & Zeyh.', 197),
(3879, 'Carpothalis', NULL, 'E.Mey.', 142),
(3880, 'Carpoxis', NULL, 'Raf.', 120),
(3881, 'Carpoxylon', NULL, 'H.Wendl. & Drude', 15),
(3882, 'Carramboa', NULL, 'Cuatrec.', 18),
(3883, 'Carrichtera', NULL, 'DC.', 197),
(3884, 'Carrierea', NULL, 'Franch.', 145),
(3885, 'Carrissoa', NULL, 'Baker f.', 68),
(3886, 'Carroa', NULL, 'C.Presl', 68),
(3887, 'Carronia', NULL, 'F.Muell.', 107),
(3888, 'Carruthersia', NULL, 'Seem.', 10),
(3889, 'Carterella', NULL, 'Terrell', 142),
(3890, 'Carterothamnus', NULL, 'R.M.King', 18),
(3891, 'Carthamus', NULL, 'L.', 18),
(3892, 'Cartiera', NULL, 'Greene', 197),
(3893, 'Cartrema', NULL, 'Raf.', 120),
(3894, 'Caruelina', NULL, 'Kuntze', 142),
(3895, 'Carum', NULL, 'L.', 9),
(3896, 'Carumbium', NULL, 'Reinw.', 66),
(3897, 'Carvalhoa', NULL, 'K.Schum.', 10),
(3898, 'Carvia', NULL, 'Bremek.', 1),
(3899, 'Carya', NULL, 'Nutt.', 87),
(3900, 'Caryococca', NULL, 'Willd. ex Roem. & Schult.(SUI)', 142),
(3901, 'Caryodaphne', NULL, 'Blume ex Nees', 91),
(3902, 'Caryolobis', NULL, 'Gaertn.', 60),
(3903, 'Caryolopha', NULL, 'Fisch. ex Trautv.(SUS)', 25),
(3904, 'Caryomene', NULL, 'Barneby & Krukoff', 107),
(3905, 'Caryophyllus', NULL, 'L.', 116),
(3906, 'Caryopteris', NULL, 'Bunge', 90),
(3907, 'Caryospermum', NULL, 'Blume', 38),
(3908, 'Casasia', NULL, 'A.Rich.', 142),
(3909, 'Cascarilla', NULL, 'Adans.(SUH)', 66),
(3910, 'Cascaronia', NULL, 'Griseb.', 68),
(3911, 'Cashalia', NULL, 'Standl.', 68),
(3912, 'Casimirella', NULL, 'Hassl.', 85),
(3913, 'Casimiroa', NULL, 'La Llave', 143),
(3914, 'Caspareopsis', NULL, 'Britton & Rose', 68),
(3915, 'Caspia', NULL, 'Galushko', 5),
(3916, 'Cassandra', NULL, 'D.Don', 64),
(3917, 'Cassebeeria', NULL, 'Dennst.', 105),
(3918, 'Casselia', NULL, 'Nees & Mart.', 173),
(3919, 'Cassidispermum', NULL, 'Hemsl.', 148),
(3920, 'Cassinia', NULL, 'R.Br.', 18),
(3921, 'Cassinopsis', NULL, 'Sond.', 85),
(3922, 'Cassiope', NULL, 'D.Don', 64),
(3923, 'Cassupa', NULL, 'Humb. & Bonpl.', 142),
(3924, 'Cassytha', NULL, 'L.', 91),
(3925, 'Castalis', NULL, 'Cass.', 18),
(3926, 'Castanea', NULL, 'Mill.', 72),
(3927, 'Castanola', NULL, 'Llanos', 45),
(3928, 'Castanospermum', NULL, 'A.Cunn. ex Hook.', 68),
(3929, 'Castanospora', NULL, 'F.Muell.', 147),
(3930, 'Castela', NULL, 'Turpin', 151),
(3931, 'Castelia', NULL, 'Cav.', 173),
(3932, 'Castenedia', NULL, 'R.M.King & H.Rob.', 18),
(3933, 'Castiglionia', NULL, 'Ruiz & Pav.', 66),
(3934, 'Castilleja', NULL, 'Mutis ex L.f.', 400),
(3935, 'Castilloa', NULL, 'Endl.', 109),
(3936, 'Castratella', NULL, 'Naudin', 105),
(3937, 'Casuarina', NULL, 'L.', 36),
(3938, 'Catadysia', NULL, 'O.E.Schulz', 197),
(3939, 'Catagyna', NULL, 'Hutch. & Dalziel', 55),
(3940, 'Catalpa', NULL, 'Scop.', 22),
(3941, 'Catamixis', NULL, 'Thomson', 18),
(3942, 'Catananche', NULL, 'L.', 18),
(3943, 'Catanthera', NULL, 'F.Muell.', 105),
(3944, 'Catappa', NULL, 'Gaertn.', 44),
(3945, 'Catatia', NULL, 'Humbert', 18),
(3946, 'Catenaria', NULL, 'Benth.', 68),
(3947, 'Catenularia', NULL, 'Botsch.(SUH)', 197),
(3948, 'Catenulina', NULL, 'Sojak', 197),
(3949, 'Catesbaea', NULL, 'L.', 142),
(3950, 'Catesbya', NULL, 'Cothen.(SUO)', 142),
(3951, 'Catha', NULL, 'Forssk. ex Schreb.', 38),
(3952, 'Catharanthus', NULL, 'G.Don', 10),
(3953, 'Cathastrum', NULL, 'Turcz.', 38),
(3954, 'Cathaya', NULL, 'Chun & Kuang', 129),
(3955, 'Cathayanthe', NULL, 'Chun', 76),
(3956, 'Cathayeia', NULL, 'Ohwi', 145),
(3957, 'Cathcartia', NULL, 'Hook.f.', 126),
(3958, 'Cathetostemma', NULL, 'Blume', 10),
(3959, 'Cathetus', NULL, 'Lour.', 184),
(3960, 'Cathormion', NULL, '(Benth.) Hassk.', 68),
(3961, 'Catinga', NULL, 'Aubl.', 116),
(3962, 'Catis', NULL, 'O.F.Cook', 15),
(3963, 'Catoblastus', NULL, 'H.Wendl.', 15),
(3964, 'Catocoryne', NULL, 'Hook.f.', 105),
(3965, 'Catoferia', NULL, '(Benth.) Benth.', 90),
(3966, 'Catonia', NULL, 'P.Browne', 105),
(3967, 'Catopheria', NULL, 'Benth.(SUO)', 90),
(3968, 'Catophractes', NULL, 'D.Don', 22),
(3969, 'Catostemma', NULL, 'Benth.', 102),
(3970, 'Catostigma', NULL, 'O.F.Cook & Doyle', 15),
(3971, 'Cattutella', NULL, 'Rchb.', 142),
(3972, 'Catunaregam', NULL, 'Wolf', 142),
(3973, 'Caturus', NULL, 'L.', 66),
(3974, 'Caucaliopsis', NULL, 'H.Wolff', 9),
(3975, 'Caucalis', NULL, 'L.', 9),
(3976, 'Caucanthus', NULL, 'Forssk.', 101),
(3977, 'Caudoleucaena', NULL, 'Britton & Rose', 68),
(3978, 'Caulanthus', NULL, 'S.Watson', 197),
(3979, 'Caulocarpus', NULL, 'Baker', 68),
(3980, 'Caulostramina', NULL, 'Rollins', 197),
(3981, 'Causea', NULL, 'Scop.', 40),
(3982, 'Caustis', NULL, 'R.Br.', 55),
(3983, 'Cavacoa', NULL, 'J.Leonard', 66),
(3984, 'Cavalcantia', NULL, 'R.M.King & H.Rob.', 18),
(3985, 'Cavanilla', NULL, 'Vell.(SUH)', 66),
(3986, 'Cavaraea', NULL, 'Speg.', 68),
(3987, 'Cavea', NULL, 'W.W.Sm. & Small', 18),
(3988, 'Cavendishia', NULL, 'Lindl.', 64),
(3989, 'Cayaponia', NULL, 'Silva Manso', 49),
(3990, 'Cayratia', NULL, 'Juss.', 181),
(3991, 'Ceanothus', NULL, 'L.', 139),
(3992, 'Ceballosia', NULL, 'G.Kunkel(SUI)', 25),
(3993, 'Cecarria', NULL, 'Barlow', 98),
(3994, 'Cecchia', NULL, 'Chiov.', 66),
(3995, 'Cedronella', NULL, 'Moench', 90),
(3996, 'Cedronia', NULL, 'Cuatrec.', 151),
(3997, 'Cedrostis', NULL, 'Post & Kuntze(SUO)', 49),
(3998, 'Cedrus', NULL, 'Trew', 129),
(3999, 'Celaenodendron', NULL, 'Standl.', 534),
(4000, 'Celastrus', NULL, 'L.', 38),
(4001, 'Celerina', NULL, 'Benoist', 1),
(4002, 'Celianella', NULL, 'Jabl.', 184),
(4003, 'Celiantha', NULL, 'Maguire', 75),
(4004, 'Celmisia', NULL, 'Cass.', 18),
(4005, 'Celosia', NULL, 'L.', 5),
(4006, 'Celsia', NULL, 'L.', 150),
(4007, 'Cenarrhenes', NULL, 'Labill.', 135),
(4008, 'Cenesmon', NULL, 'Gagnep.', 66),
(4009, 'Cenocentrum', NULL, 'Gagnep.', 102),
(4010, 'Cenolophium', NULL, 'W.D.J.Koch ex DC.', 9),
(4011, 'Cenostigma', NULL, 'Tul.', 68),
(4012, 'Censcus', NULL, 'Gaertn.', 142),
(4013, 'Centaurea', NULL, 'L.', 18),
(4014, 'Centaurium', NULL, 'Hill', 75),
(4015, 'Centaurodendron', NULL, 'Johow', 18),
(4016, 'Centauropsis', NULL, 'Bojer ex DC.', 18),
(4017, 'Centaurothamnus', NULL, 'Wagenitz & Dittrich', 18),
(4018, 'Centella', NULL, 'L.', 9),
(4019, 'Centema', NULL, 'Hook.f.', 5),
(4020, 'Centemopsis', NULL, 'Schinz', 5),
(4021, 'Centipeda', NULL, 'Lour.', 18),
(4022, 'Centradenia', NULL, 'G.Don', 105),
(4023, 'Centradeniastrum', NULL, 'Cogn.', 105),
(4024, 'Centrandra', NULL, 'H.Karst.', 66),
(4025, 'Centrantheropsis', NULL, 'Bonati', 150),
(4026, 'Centrapalus', NULL, 'Cass.', 18),
(4027, 'Centratherum', NULL, 'Cass.', 18),
(4028, 'Centrilla', NULL, 'Lindau', 1),
(4029, 'Centrodiscus', NULL, 'Mull.Arg.', 66),
(4030, 'Centrolobium', NULL, 'Mart. ex Benth.', 68),
(4031, 'Centroplacus', NULL, 'Pierre', 508),
(4032, 'Centrosema', NULL, '(DC.) Benth.', 68),
(4033, 'Centrosolenia', NULL, 'Benth.', 76),
(4034, 'Centrostachys', NULL, 'Wall.', 5),
(4035, 'Centrostegia', NULL, 'A.Gray', 134),
(4036, 'Centrostemma', NULL, 'Decne.', 10),
(4037, 'Centrostylis', NULL, 'Baill.', 66),
(4038, 'Centunculus', NULL, 'L.', 115),
(4039, 'Ceodes', NULL, 'J.R.Forst. & G.Forst.', 117),
(4040, 'Cepaea', NULL, 'Fabr.', 48),
(4041, 'Cephalacanthus', NULL, 'Lindau', 1),
(4042, 'Cephalandra', NULL, 'Schrad. ex Eckl. & Zeyh.', 49),
(4043, 'Cephalanthus', NULL, 'L.', 142),
(4044, 'Cephalaralia', NULL, 'Harms', 13),
(4045, 'Cephaleis', NULL, 'Vahl(SUO)', 142),
(4046, 'Cephalidium', NULL, 'A.Rich. ex DC.', 142),
(4047, 'Cephalina', NULL, 'Thonn.', 142),
(4048, 'Cephalipterum', NULL, 'A.Gray', 18),
(4049, 'Cephalobembix', NULL, 'Rydb.', 18),
(4050, 'Cephalocarpus', NULL, 'Nees', 55),
(4051, 'Cephalocroton', NULL, 'Hochst.', 66),
(4052, 'Cephalocrotonopsis', NULL, 'Pax', 66),
(4053, 'Cephalodendron', NULL, 'Steyerm.', 142),
(4054, 'Cephalohibiscus', NULL, 'Ulbr.', 102),
(4055, 'Cephalomedinilla', NULL, 'Merr.', 105),
(4056, 'Cephalonema', NULL, 'K.Schum.', 102),
(4057, 'Cephalopappus', NULL, 'Nees & Mart.', 18),
(4058, 'Cephalopentandra', NULL, 'Chiov.', 49),
(4059, 'Cephalophora', NULL, 'Cav.', 18),
(4060, 'Cephalopodium', NULL, 'Korovin', 9),
(4061, 'Cephalorhyncus', NULL, 'Boiss.(SUO)', 18),
(4062, 'Cephalorrhynchus', NULL, 'Boiss.', 18),
(4063, 'Cephaloschefflera', NULL, '(Harms) Merr.', 13),
(4064, 'Cephalosorus', NULL, 'A.Gray', 18),
(4065, 'Cephalosphaera', NULL, 'Warb.', 114),
(4066, 'Cephalostigma', NULL, 'A.DC.', 30),
(4067, 'Cephalostigmaton', NULL, '(Yakovlev) Yakovlev', 68),
(4068, 'Cephalotomandra', NULL, 'H.Karst. & Triana', 117),
(4069, 'Cephalotrophis', NULL, 'Blume', 109),
(4070, 'Ceramanthus', NULL, '(Kunze) Malme(SUH)', 10),
(4071, 'Ceramicalyx', NULL, 'Blume', 105),
(4072, 'Ceramium', NULL, 'Blume', 16),
(4073, 'Ceranthera', NULL, 'Elliott(SUH)', 90),
(4074, 'Ceranthus', NULL, 'Schreb.', 120),
(4075, 'Cerapadus', NULL, 'Buia', 141),
(4076, 'Ceraseidos', NULL, 'Siebold & Zucc.', 141),
(4077, 'Ceraselma', NULL, 'Wittst.', 66),
(4078, 'Cerasiocarpum', NULL, 'Hook.f.', 49),
(4079, 'Cerasus', NULL, 'Mill.', 141),
(4080, 'Ceratanthus', NULL, 'F.Muell. ex G.Taylor', 90),
(4081, 'Ceratephorus', NULL, 'de Vriese(SUO)', 148),
(4082, 'Ceratiola', NULL, 'Michx.', 64),
(4083, 'Ceratites', NULL, 'Miers', 142),
(4084, 'Ceratocapnos', NULL, 'Durieu', 126),
(4085, 'Ceratocarpus', NULL, 'L.', 5),
(4086, 'Ceratocaulos', NULL, '(Bernh.) Rchb.(SUS)', 154),
(4087, 'Ceratocnemum', NULL, 'Coss. & Balansa', 197),
(4088, 'Ceratococcus', NULL, 'Meisn.', 66),
(4089, 'Ceratogyne', NULL, 'Turcz.', 18),
(4090, 'Ceratogynum', NULL, 'Wight', 184),
(4091, 'Ceratoides', NULL, 'Gagnebin(SUS)', 5),
(4092, 'Ceratolobus', NULL, 'Blume', 15),
(4093, 'Ceratominthe', NULL, 'Briq.', 90),
(4094, 'Ceratonia', NULL, 'L.', 68),
(4095, 'Ceratopetalum', NULL, 'Sm.', 50),
(4096, 'Ceratophorus', NULL, 'Sond.', 66),
(4097, 'Ceratophytum', NULL, 'Pittier', 22),
(4098, 'Ceratopyxis', NULL, 'Hook.f.', 142),
(4099, 'Ceratosanthes', NULL, 'Burm. ex Adans.', 49),
(4100, 'Ceratoscyphus', NULL, 'Chun', 76),
(4101, 'Ceratosepalum', NULL, 'Oerst.', 127),
(4102, 'Ceratostema', NULL, 'Juss.', 64),
(4103, 'Cerbera', NULL, 'L.', 10),
(4104, 'Cerberiopsis', NULL, 'Vieill. ex Pancher & Sebert', 10),
(4105, 'Cercestis', NULL, 'Schott', 12),
(4106, 'Cercidiopsis', NULL, 'Britton & Rose', 68),
(4107, 'Cercidium', NULL, 'Tul.', 68),
(4108, 'Cercis', NULL, 'L.', 68),
(4109, 'Cercocarpus', NULL, 'Kunth', 141),
(4110, 'Cercocoma', NULL, 'Wall. ex G.Don', 10),
(4111, 'Cercophora', NULL, 'Miers(SUH)', 92),
(4112, 'Cerinthe', NULL, 'L.', 25),
(4113, 'Ceriops', NULL, 'Arn.', 140),
(4114, 'Ceriosperma', NULL, '(O.E.Schulz) Greuter & Burdet', 197),
(4115, 'Ceriscoides', NULL, '(Hook.f.) Tirveng.', 142),
(4116, 'Ceriscus', NULL, 'Gaertn. ex Nees(SUI)', 142),
(4117, 'Cerocarpus', NULL, 'Colebr. ex Hassk.', 116),
(4118, 'Cerolepis', NULL, 'Pierre', 73),
(4119, 'Ceropegia', NULL, 'L.', 10),
(4120, 'Ceroxylon', NULL, 'Bonpl. ex DC.', 15),
(4121, 'Cerqueiria', NULL, 'O.Berg', 116),
(4122, 'Ceruana', NULL, 'Forssk.', 18),
(4123, 'Cervantesia', NULL, 'Ruiz & Pav.', 146),
(4124, 'Cervia', NULL, 'Rodr. ex Lag.', 25),
(4125, 'Cervicina', NULL, 'Delile', 30),
(4126, 'Ceuthocarpus', NULL, 'Aiello', 142),
(4127, 'Ceuthostoma', NULL, 'L.A.S.Johnson', 36),
(4128, 'Chacaya', NULL, 'Escal.', 139),
(4129, 'Chacoa', NULL, 'R.M.King & H.Rob.', 18),
(4130, 'Chadsia', NULL, 'Bojer', 68),
(4131, 'Chaenactis', NULL, 'DC.', 18),
(4132, 'Chaenesthes', NULL, 'Miers', 154),
(4133, 'Chaenocarpus', NULL, 'Juss.', 142),
(4134, 'Chaenocephalus', NULL, 'Griseb.', 18),
(4135, 'Chaenomeles', NULL, 'Lindl.', 141),
(4136, 'Chaenorhinum', NULL, '(DC.) Rchb.', 423),
(4137, 'Chaenorrhinum', NULL, '(DC.) Rchb.(SUO)', 150),
(4138, 'Chaenostoma', NULL, 'Benth.', 150),
(4139, 'Chaenotheca', NULL, 'Urb.(SUH)', 184),
(4140, 'Chaerophyllopsis', NULL, 'Boissieu', 9),
(4141, 'Chaerophyllum', NULL, 'L.', 9),
(4142, 'Chaetacanthus', NULL, 'Nees', 1),
(4143, 'Chaetachme', NULL, 'Planch.', 170),
(4144, 'Chaetacme', NULL, 'Planch.(SUO)', 170),
(4145, 'Chaetadelpha', NULL, 'A.Gray ex S.Watson', 18),
(4146, 'Chaetaea', NULL, 'Jacq.', 102),
(4147, 'Chaetanthera', NULL, 'Ruiz & Pav.', 18),
(4148, 'Chaetocalyx', NULL, 'DC.', 68),
(4149, 'Chaetochlamys', NULL, 'Lindau', 1),
(4150, 'Chaetocyperus', NULL, 'Nees', 55),
(4151, 'Chaetogastra', NULL, 'DC.', 105),
(4152, 'Chaetolepis', NULL, '(DC.) Miq.', 105),
(4153, 'Chaetopappa', NULL, 'DC.', 18),
(4154, 'Chaetosciadium', NULL, 'Boiss.', 9),
(4155, 'Chaetospira', NULL, 'S.F.Blake', 18),
(4156, 'Chaetospora', NULL, 'R.Br.', 55),
(4157, 'Chaetostachydium', NULL, 'Airy Shaw', 142),
(4158, 'Chaetostachys', NULL, 'Valeton', 142),
(4159, 'Chaetostoma', NULL, 'DC.', 105),
(4160, 'Chaetosus', NULL, 'Benth.', 10),
(4161, 'Chaetothylax', NULL, 'Nees', 1),
(4162, 'Chaetothylopsis', NULL, 'Oerst.', 1),
(4163, 'Chaetymenia', NULL, 'Hook. & Arn.', 18),
(4164, 'Chaiturus', NULL, 'Ehrh. ex Willd.', 90),
(4165, 'Chaixia', NULL, 'Lapeyr.', 76),
(4166, 'Chalarothyrsus', NULL, 'Lindau', 1),
(4167, 'Chalazocarpus', NULL, 'Hiern', 142),
(4168, 'Chalcanthus', NULL, 'Boiss.', 197),
(4169, 'Chalcas', NULL, 'L.', 143),
(4170, 'Chalema', NULL, 'Dieterle', 49),
(4171, 'Chalepophyllum', NULL, 'Hook.f.', 142),
(4172, 'Chamabainia', NULL, 'Wight', 171),
(4173, 'Chamaeacanthus', NULL, 'Chiov.', 150),
(4174, 'Chamaebatia', NULL, 'Benth.', 141),
(4175, 'Chamaebatiaria', NULL, '(Porter) Maxim.', 141),
(4176, 'Chamaechaenactis', NULL, 'Rydb.', 18),
(4177, 'Chamaecladon', NULL, 'Miq.', 12),
(4178, 'Chamaeclitandra', NULL, '(Stapf) Pichon', 10),
(4179, 'Chamaecrista', NULL, 'Moench', 68),
(4180, 'Chamaecyparis', NULL, 'Spach', 51),
(4181, 'Chamaecytisus', NULL, 'Link', 68),
(4182, 'Chamaedaphne', NULL, 'Mitch.(SUH)', 64),
(4183, 'Chamaegeron', NULL, 'Schrenk', 18),
(4184, 'Chamaegigas', NULL, 'Dinter ex Heil', 150),
(4185, 'Chamaegyne', NULL, 'Suess.', 55),
(4186, 'Chamaele', NULL, 'Miq.', 9),
(4187, 'Chamaeleon', NULL, 'Cass.', 18),
(4188, 'Chamaemeles', NULL, 'Lindl.', 141),
(4189, 'Chamaemelum', NULL, 'Mill.', 18),
(4190, 'Chamaenerion', NULL, 'Spach', 121),
(4191, 'Chamaepentas', NULL, 'Bremek.', 142),
(4192, 'Chamaepericlymenum', NULL, 'Hill', 47),
(4193, 'Chamaephoenix', NULL, 'H.Wendl. ex Curtiss', 15),
(4194, 'Chamaepitys', NULL, 'Hill', 90),
(4195, 'Chamaepus', NULL, 'Wagenitz', 18),
(4196, 'Chamaeranthemum', NULL, 'Nees', 1),
(4197, 'Chamaerhodiola', NULL, 'Nakai', 48),
(4198, 'Chamaerhodos', NULL, 'Bunge', 141),
(4199, 'Chamaeriphe', NULL, 'Steck', 15),
(4200, 'Chamaeriphes', NULL, 'Ponted. ex Gaertn.', 15),
(4201, 'Chamaerops', NULL, 'L.', 15),
(4202, 'Chamaesaracha', NULL, '(A.Gray) Benth.', 154),
(4203, 'Chamaesciadium', NULL, 'C.A.Mey.', 9),
(4204, 'Chamaesenna', NULL, '(DC.) Raf. ex Pittier', 68),
(4205, 'Chamaesium', NULL, 'H.Wolff', 9),
(4206, 'Chamaespartium', NULL, 'Adans.', 68),
(4207, 'Chamaesphacos', NULL, 'Schrenk ex Fisch. & C.A.Mey.', 90),
(4208, 'Chamaesyce', NULL, 'Gray', 66),
(4209, 'Chamarea', NULL, 'Eckl. & Zeyh.', 9),
(4210, 'Chamartemisia', NULL, 'Rydb.', 18),
(4211, 'Chambeyronia', NULL, 'Vieill.', 15),
(4212, 'Chamelaucium', NULL, 'Desf.', 116),
(4213, 'Chamerion', NULL, '(Raf.) Raf.', 121),
(4214, 'Chamira', NULL, 'Thunb.', 197),
(4215, 'Chamisme', NULL, 'Raf.', 142),
(4216, 'Chamissoa', NULL, 'Kunth', 5),
(4217, 'Chamissoniophila', NULL, 'Brand', 25),
(4218, 'Championella', NULL, 'Bremek.', 1),
(4219, 'Championia', NULL, 'Gardner', 76),
(4220, 'Chanekia', NULL, 'Lundell', 91),
(4221, 'Changium', NULL, 'H.Wolff', 9),
(4222, 'Chapelieria', NULL, 'A.Rich. ex DC.', 142),
(4223, 'Chapmannia', NULL, 'Torr. & A.Gray', 68),
(4224, 'Chaptalia', NULL, 'Vent.', 18),
(4225, 'Characias', NULL, 'Gray', 66),
(4226, 'Charadrophila', NULL, 'Marloth', 471),
(4227, 'Chardinia', NULL, 'Desf.', 18),
(4228, 'Charia', NULL, 'C.E.C.Fisch.', 106),
(4229, 'Charianthus', NULL, 'D.Don', 105),
(4230, 'Charidia', NULL, 'Baill.', 184),
(4231, 'Charidion', NULL, 'Bong.', 118),
(4232, 'Charieis', NULL, 'Cass.', 18),
(4233, 'Chariessa', NULL, 'Miq.', 85),
(4234, 'Charpentiera', NULL, 'Gaudich.', 5),
(4235, 'Chartocalyx', NULL, 'Regel', 90),
(4236, 'Chartolepis', NULL, 'Cass.', 18),
(4237, 'Chartoloma', NULL, 'Bunge', 197),
(4238, 'Chascanum', NULL, 'E.Mey.', 173),
(4239, 'Chascotheca', NULL, 'Urb.', 184),
(4240, 'Chasmanthera', NULL, 'Hochst.', 107),
(4241, 'Chasmia', NULL, 'Schott ex Spreng.', 22),
(4242, 'Chastenaea', NULL, 'DC.', 105),
(4243, 'Chatinia', NULL, 'Tiegh.', 98),
(4244, 'Chaunanthus', NULL, 'O.E.Schulz', 197),
(4245, 'Chaunochiton', NULL, 'Benth.', 119),
(4246, 'Chaunostoma', NULL, 'Donn.Sm.', 90),
(4247, 'Chavannesia', NULL, 'A.DC.', 10),
(4248, 'Chaydaia', NULL, 'Pit.', 139),
(4249, 'Chayota', NULL, 'Jacq.', 49),
(4250, 'Chazaliella', NULL, 'E.Petit & Verdc.', 142),
(4251, 'Cheesemania', NULL, 'O.E.Schulz', 197),
(4252, 'Cheilopsis', NULL, 'Moq.', 1),
(4253, 'Cheilosandra', NULL, 'Griff. ex Lindl.', 76),
(4254, 'Cheilotheca', NULL, 'Hook.f.', 64),
(4255, 'Cheiranthus', NULL, 'L.', 197),
(4256, 'Cheirodendron', NULL, 'Nutt. ex Seem.', 13),
(4257, 'Cheirolaena', NULL, 'Benth.', 102),
(4258, 'Cheirolophus', NULL, 'Cass.', 18),
(4259, 'Cheirostemon', NULL, 'Humb. & Bonpl.', 102),
(4260, 'Chelidonium', NULL, 'L.', 126),
(4261, 'Chelonanthus', NULL, '(Griseb.) Gilg', 75),
(4262, 'Chelone', NULL, 'L.', 423),
(4263, 'Chelonecarya', NULL, 'Pierre', 85),
(4264, 'Chelonespermum', NULL, 'Hemsl.', 148),
(4265, 'Chelonopsis', NULL, 'Miq.', 90),
(4266, 'Chelyocarpus', NULL, 'Dammer', 15),
(4267, 'Chenolea', NULL, 'Thunb.', 5),
(4268, 'Chenoleoides', NULL, 'Botsch.', 5),
(4269, 'Chenopodiopsis', NULL, 'Hilliard & B.L.Burtt', 150),
(4270, 'Chenopodium', NULL, 'L.', 5),
(4271, 'Chersodoma', NULL, 'Phil.', 18),
(4272, 'Chesnea', NULL, 'Scop.', 142),
(4273, 'Chesneya', NULL, 'Lindl. ex Endl.', 68),
(4274, 'Chetyson', NULL, 'Raf.', 48),
(4275, 'Chevalierodendron', NULL, 'J.-F.Leroy', 109),
(4276, 'Chevreulia', NULL, 'Cass.', 18),
(4277, 'Cheynia', NULL, 'J.Drumm. ex Harv.', 116),
(4278, 'Chiangiodendron', NULL, 'Wendt', 198),
(4279, 'Chiarinia', NULL, 'Chiov.', 147),
(4280, 'Chiastophyllum', NULL, '(Ledeb.) A.Berger', 48),
(4281, 'Chiazospermum', NULL, 'Bernh.', 126),
(4282, 'Chicharronia', NULL, 'A.Rich.', 44),
(4283, 'Chickassia', NULL, 'Wight & Arn.', 106),
(4284, 'Chiclea', NULL, 'Lundell', 148),
(4285, 'Chidlowia', NULL, 'Hoyle', 68),
(4286, 'Chieniodendron', NULL, 'Tsiang & P.T.Li', 8),
(4287, 'Chileranthemum', NULL, 'Oerst.', 1),
(4288, 'Chiliadenus', NULL, 'Cass.', 18),
(4289, 'Chiliandra', NULL, 'Griff.', 76),
(4290, 'Chilianthus', NULL, 'Burch.', 150),
(4291, 'Chiliocephalum', NULL, 'Benth.', 18),
(4292, 'Chiliophyllum', NULL, 'Phil.', 18),
(4293, 'Chiliotrichiopsis', NULL, 'Cabrera', 18),
(4294, 'Chiliotrichum', NULL, 'Cass.', 18),
(4295, 'Chillania', NULL, 'Roiv.', 55),
(4296, 'Chilocalyx', NULL, 'Klotzsch', 32),
(4297, 'Chilocardamum', NULL, 'O.E.Schulz', 197),
(4298, 'Chilocarpus', NULL, 'Blume', 10),
(4299, 'Chiloglossa', NULL, 'Oerst.', 1),
(4300, 'Chilopsis', NULL, 'D.Don', 22),
(4301, 'Chimantaea', NULL, 'Maguire, Steyerm. & Wurdack', 18),
(4302, 'Chimaphila', NULL, 'Pursh', 64),
(4303, 'Chingiacanthus', NULL, 'Hand.-Mazz.', 1),
(4304, 'Chiococca', NULL, 'P.Browne', 142),
(4305, 'Chiogenes', NULL, 'Salisb. ex Torr.', 64),
(4306, 'Chionocharis', NULL, 'I.M.Johnst.', 25),
(4307, 'Chionohebe', NULL, 'B.G.Briggs & Ehrend.', 423),
(4308, 'Chionolaena', NULL, 'DC.', 18),
(4309, 'Chionopappus', NULL, 'Benth.', 18),
(4310, 'Chionophila', NULL, 'Benth.', 423),
(4311, 'Chionothrix', NULL, 'Hook.f.', 5),
(4312, 'Chiovendaea', NULL, 'Speg.', 68),
(4313, 'Chiranthodendron', NULL, 'Larreat.', 102),
(4314, 'Chiridium', NULL, 'Tiegh.', 98),
(4315, 'Chirita', NULL, 'Buch.-Ham. ex D.Don', 76),
(4316, 'Chiritopsis', NULL, 'W.T.Wang', 76),
(4317, 'Chirocalyx', NULL, 'Meisn.', 68),
(4318, 'Chironia', NULL, 'L.', 75),
(4319, 'Chiropetalum', NULL, 'A.Juss.', 66),
(4320, 'Chitonia', NULL, 'Moc. & Sesse', 177),
(4321, 'Chlaenandra', NULL, 'Miq.', 107),
(4322, 'Chlaenosciadium', NULL, 'C.Norman', 9),
(4323, 'Chlainanthus', NULL, 'Briq.', 90),
(4324, 'Chlamydacanthus', NULL, 'Lindau', 1),
(4325, 'Chlamydanthus', NULL, 'C.A.Mey.', 164),
(4326, 'Chlamydites', NULL, 'J.R.Drumm.', 18),
(4327, 'Chlamydoboea', NULL, 'Stapf', 76),
(4328, 'Chlamydocardia', NULL, 'Lindau', 1),
(4329, 'Chlamydocarya', NULL, 'Baill.', 85),
(4330, 'Chlamydocola', NULL, '(K.Schum.) Bodard', 102),
(4331, 'Chlamydojatropha', NULL, 'Pax & K.Hoffm.', 66),
(4332, 'Chlamydophora', NULL, 'Ehrenb. ex Less.', 18),
(4333, 'Chlamydostachya', NULL, 'Mildbr.', 1),
(4334, 'Chloanthes', NULL, 'R.Br.', 90),
(4335, 'Chlora', NULL, 'Adans.', 75),
(4336, 'Chloracantha', NULL, 'G.L.Nesom, Y.B.Suh, D.R.Morgan,', 18),
(4337, 'Chloradenia', NULL, 'Baill.', 66),
(4338, 'Chlorocarpa', NULL, 'Alston', 198),
(4339, 'Chlorochorion', NULL, 'Puff & Robbr.', 142),
(4340, 'Chlorocodon', NULL, 'Hook.f.', 10),
(4341, 'Chlorocrambe', NULL, 'Rydb.', 197),
(4342, 'Chlorocyathus', NULL, 'Oliv.', 10),
(4343, 'Chlorocyperus', NULL, 'Rikli', 55),
(4344, 'Chloroleucum', NULL, '(Benth.) Record(SUO)', 68),
(4345, 'Chloroluma', NULL, 'Baill.', 148),
(4346, 'Chloromyrtus', NULL, 'Pierre', 116),
(4347, 'Chloropatane', NULL, 'Engl.', 66),
(4348, 'Chlorophytum', NULL, 'Ker Gawl.', 3),
(4349, 'Chlorospatha', NULL, 'Engl.', 12),
(4350, 'Chlorostemma', NULL, '(Lange) Fourr.', 142),
(4351, 'Chloroxylon', NULL, 'DC.', 143),
(4352, 'Chnoophora', NULL, 'Kaulf.', 52),
(4353, 'Chocho', NULL, 'Adans.', 49),
(4354, 'Chodanthus', NULL, 'Hassl.', 22),
(4355, 'Chodsha-Kasiana', NULL, 'Rauschert(SUS)', 197),
(4356, 'Choerospondias', NULL, 'B.L.Burtt & A.W.Hill', 6),
(4357, 'Choisya', NULL, 'Kunth', 143),
(4358, 'Chondrachne', NULL, 'R.Br.', 55),
(4359, 'Chondrilla', NULL, 'L.', 18),
(4360, 'Chondrococcus', NULL, 'Steyerm.', 142),
(4361, 'Chondrodendron', NULL, 'Ruiz & Pav.', 107),
(4362, 'Chondrophylla', NULL, 'A.Nelson', 75),
(4363, 'Chondropyxis', NULL, 'D.A.Cooke', 18),
(4364, 'Chondrospermum', NULL, 'Wall. ex G.Don', 120),
(4365, 'Chondrostylis', NULL, 'Boerl.', 66),
(4366, 'Chonemorpha', NULL, 'G.Don', 10),
(4367, 'Chonocentrum', NULL, 'Pierre ex Pax & K.Hoffm.', 184),
(4368, 'Chonopetalum', NULL, 'Radlk.', 147),
(4369, 'Chontalesia', NULL, 'Lundell', 115),
(4370, 'Chordospartium', NULL, 'Cheeseman', 68),
(4371, 'Choretrum', NULL, 'R.Br.', 146),
(4372, 'Choriantha', NULL, 'Riedl', 25),
(4373, 'Choricarpia', NULL, 'Domin', 116),
(4374, 'Choriceras', NULL, 'Baill.', 534),
(4375, 'Chorigyne', NULL, 'R.Erikss.', 54),
(4376, 'Chorilaena', NULL, 'Endl.', 143),
(4377, 'Chorilepidella', NULL, 'Tiegh.', 98),
(4378, 'Chorilepis', NULL, 'Tiegh.', 98),
(4379, 'Chorioluma', NULL, 'Baill.', 148),
(4380, 'Choriophyllum', NULL, 'Benth.', 66),
(4381, 'Choriptera', NULL, 'Botsch.', 5),
(4382, 'Chorisandra', NULL, 'Wight', 184),
(4383, 'Chorisandrachne', NULL, 'Airy Shaw', 66),
(4384, 'Chorisepalum', NULL, 'Gleason & Wodehouse', 75),
(4385, 'Chorisia', NULL, 'Kunth', 102),
(4386, 'Chorisis', NULL, 'DC.', 18),
(4387, 'Chorisiva', NULL, '(A.Gray) Rydb.', 18),
(4388, 'Chorispermum', NULL, 'R.Br.(SUO)', 197),
(4389, 'Chorispora', NULL, 'R.Br. ex DC.', 197),
(4390, 'Choristegeres', NULL, 'Tiegh.', 98),
(4391, 'Choristegia', NULL, 'Tiegh.', 98),
(4392, 'Choristemon', NULL, 'H.B.Will.', 64),
(4393, 'Choristes', NULL, 'Benth.', 142),
(4394, 'Choritaenia', NULL, 'Benth.', 9),
(4395, 'Chorizandra', NULL, 'R.Br.', 55),
(4396, 'Chorizanthe', NULL, 'R.Br. ex Benth.', 134),
(4397, 'Chorizema', NULL, 'Labill.', 68),
(4398, 'Chorizotheca', NULL, 'Mull.Arg.', 66),
(4399, 'Chosenia', NULL, 'Nakai', 145),
(4400, 'Choulettia', NULL, 'Pomel', 142),
(4401, 'Chouxia', NULL, 'Capuron', 147),
(4402, 'Chresta', NULL, 'Vell. ex DC.', 18),
(4403, 'Chrestienia', NULL, 'Montrouz.(SUI)', 1),
(4404, 'Christia', NULL, 'Moench', 68),
(4405, 'Christiana', NULL, 'DC.', 102),
(4406, 'Christisonia', NULL, 'Gardner', 400),
(4407, 'Christolea', NULL, 'Cambess. ex Jacquem.', 197),
(4408, 'Christya', NULL, 'Ward & Harv.', 10),
(4409, 'Chroesthes', NULL, 'Benoist', 1),
(4410, 'Chromolaena', NULL, 'DC.', 18),
(4411, 'Chromolepis', NULL, 'Benth.', 18),
(4412, 'Chronanthus', NULL, 'K.Koch', 68),
(4413, 'Chronopappus', NULL, 'DC.', 18),
(4414, 'Chrozophora', NULL, 'Neck. ex Juss.', 66),
(4415, 'Chrysactinia', NULL, 'A.Gray', 18),
(4416, 'Chrysactinium', NULL, '(Kunth) Wedd.', 18),
(4417, 'Chrysalidocarpus', NULL, 'H.Wendl.', 15),
(4418, 'Chrysallidosperma', NULL, 'H.E.Moore', 15),
(4419, 'Chrysanthellum', NULL, 'Rich.', 18),
(4420, 'Chrysanthemoides', NULL, 'Fabr.', 18),
(4421, 'Chrysanthemum', NULL, 'L.', 18),
(4422, 'Chrysitrix', NULL, 'L.', 55),
(4423, 'Chrysobraya', NULL, 'Hara', 197),
(4424, 'Chrysocephalum', NULL, 'Walp.', 18),
(4425, 'Chrysochamela', NULL, '(Fenzl) Boiss.', 197),
(4426, 'Chrysocoma', NULL, 'L.', 18),
(4427, 'Chrysocoryne', NULL, 'Endl.', 18),
(4428, 'Chrysogonum', NULL, 'L.', 18),
(4429, 'Chrysolaena', NULL, 'H.Rob.', 18),
(4430, 'Chrysolarix', NULL, 'H.E.Moore(SUS)', 129),
(4431, 'Chrysolepis', NULL, 'Hjelmq.', 72),
(4432, 'Chrysopappus', NULL, 'Takht.', 18),
(4433, 'Chrysophae', NULL, 'Koso-Pol.', 9),
(4434, 'Chrysophthalmum', NULL, 'Sch.Bip. ex Walp.', 18),
(4435, 'Chrysopsis', NULL, '(Nutt.) Elliott', 18),
(4436, 'Chrysorhoe', NULL, 'Lindl.', 116),
(4437, 'Chrysoscias', NULL, 'E.Mey.', 68),
(4438, 'Chrysosplenium', NULL, 'L.', 149),
(4439, 'Chrysostachys', NULL, 'Pohl', 44),
(4440, 'Chrysostemon', NULL, 'Klotzsch', 66),
(4441, 'Chrysothamnus', NULL, 'Nutt.', 18),
(4442, 'Chrysothemis', NULL, 'Decne.', 76),
(4443, 'Chrysoxylon', NULL, 'Wedd.(SUH)', 142),
(4444, 'Chrystolia', NULL, 'Montrouz.', 68),
(4445, 'Chthamalia', NULL, 'Decne.', 10),
(4446, 'Chthonocephalus', NULL, 'Steetz', 18),
(4447, 'Chuanminshen', NULL, 'M.L.Sheh & R.H.Shan', 9),
(4448, 'Chucoa', NULL, 'Cabrera', 18),
(4449, 'Chuncoa', NULL, 'Pav. ex Juss.', 44),
(4450, 'Chunechites', NULL, 'Tsiang', 10),
(4451, 'Chuniodendron', NULL, 'Hu', 106),
(4452, 'Chuniophoenix', NULL, 'Burret', 15),
(4453, 'Chuquiraga', NULL, 'Juss.', 18),
(4454, 'Chydenanthus', NULL, 'Miers', 92),
(4455, 'Chylismia', NULL, 'Nutt.', 121),
(4456, 'Chylogala', NULL, 'Fourr.', 66),
(4457, 'Chymococca', NULL, 'Meisn.', 164),
(4458, 'Chymocormus', NULL, 'Harv.', 10),
(4459, 'Chymsydia', NULL, 'Albov', 9),
(4460, 'Chytraculia', NULL, 'P.Browne', 116),
(4461, 'Chytralia', NULL, 'Adans.', 116),
(4462, 'Chytroma', NULL, 'Miers', 92),
(4463, 'Chytropsia', NULL, 'Bremek.', 142),
(4464, 'Cibirhiza', NULL, 'Bruyns', 10),
(4465, 'Cibotarium', NULL, 'O.E.Schulz', 197),
(4466, 'Cicca', NULL, 'L.', 184),
(4467, 'Cicendia', NULL, 'Adans.', 75),
(4468, 'Cicer', NULL, 'L.', 68),
(4469, 'Cicerbita', NULL, 'Wallr.', 18),
(4470, 'Ciceronia', NULL, 'Urb.', 18),
(4471, 'Cichlanthus', NULL, '(Endl.) Tiegh.', 98),
(4472, 'Cichorium', NULL, 'L.', 18),
(4473, 'Ciclospermum', NULL, 'Lag.(SUO)', 9),
(4474, 'Cicuta', NULL, 'L.', 9),
(4475, 'Cieca', NULL, 'Adans.', 66),
(4476, 'Cienfuegosia', NULL, 'Cav.', 102),
(4477, 'Cigarrilla', NULL, 'Aiello', 142),
(4478, 'Ciminalis', NULL, 'Adans.', 75),
(4479, 'Cincinnobotrys', NULL, 'Gilg', 105),
(4480, 'Cineraria', NULL, 'L.', 18),
(4481, 'Cinnadenia', NULL, 'Kosterm.', 91),
(4482, 'Cinnamodendron', NULL, 'Endl.', 31),
(4483, 'Cinnamosma', NULL, 'Baill.', 31),
(4484, 'Cionandra', NULL, 'Griseb.', 49),
(4485, 'Cionomene', NULL, 'Krukoff', 107),
(4486, 'Cionosicyos', NULL, 'Griseb.', 49),
(4487, 'Cionosicys', NULL, 'Griseb.(SUO)', 49),
(4488, 'Cionura', NULL, 'Griseb.', 10),
(4489, 'Cipadessa', NULL, 'Blume', 106),
(4490, 'Circaea', NULL, 'L.', 121),
(4491, 'Cirsium', NULL, 'Mill.', 18),
(4492, 'Cissampelopsis', NULL, '(DC.) Miq.', 18),
(4493, 'Cissampelos', NULL, 'L.', 107),
(4494, 'Cissus', NULL, 'L.', 181),
(4495, 'Cistanche', NULL, 'Hoffmanns. & Link', 400),
(4496, 'Cistanthera', NULL, 'K.Schum.', 102),
(4497, 'Cithareloma', NULL, 'Bunge', 197),
(4498, 'Citronella', NULL, 'D.Don', 255),
(4499, 'Citrullus', NULL, 'Schrad. ex Eckl. & Zeyh.', 49),
(4500, 'Cladandra', NULL, 'O.F.Cook', 15),
(4501, 'Cladanthus', NULL, 'Cass.', 18),
(4502, 'Cladium', NULL, 'P.Browne', 55),
(4503, 'Cladocarpa', NULL, '(H.St.John) H.St.John', 49),
(4504, 'Cladoceras', NULL, 'Bremek.', 142),
(4505, 'Cladochaeta', NULL, 'DC.', 18),
(4506, 'Cladocolea', NULL, 'Tiegh.', 98),
(4507, 'Cladodes', NULL, 'Lour.', 66),
(4508, 'Cladogelonium', NULL, 'Leandri', 66),
(4509, 'Cladomyza', NULL, 'Danser', 146),
(4510, 'Cladosicyos', NULL, 'Hook.f.', 49),
(4511, 'Cladosperma', NULL, 'Griff.', 15),
(4512, 'Cladostachys', NULL, 'D.Don', 5),
(4513, 'Cladostemon', NULL, 'A.Braun & Vatke', 32),
(4514, 'Cladostigma', NULL, 'Radlk.', 46),
(4515, 'Cladothamnus', NULL, 'Bong.', 64),
(4516, 'Cladothrix', NULL, '(Moq.) Hook.f.', 5),
(4517, 'Cladrastis', NULL, 'Raf.', 68),
(4518, 'Clambus', NULL, 'Miers', 184),
(4519, 'Clandestinaria', NULL, 'Spach', 197),
(4520, 'Claoxylopsis', NULL, 'Leandri', 66),
(4521, 'Clappertonia', NULL, 'Meisn.', 102),
(4522, 'Clappia', NULL, 'A.Gray', 18),
(4523, 'Clara', NULL, 'Kunth', 3),
(4524, 'Clarckia', NULL, 'Pursh', 121),
(4525, 'Clarkella', NULL, 'Hook.f.', 142),
(4526, 'Clarkia', NULL, 'Pursh', 121),
(4527, 'Clarorivinia', NULL, 'Pax & K.Hoffm.', 66),
(4528, 'Clastopus', NULL, 'Bunge ex Boiss.', 197),
(4529, 'Clathrospermum', NULL, 'Planch. ex Benth.', 8),
(4530, 'Clathrotropis', NULL, '(Benth.) Harms', 68),
(4531, 'Clausenellia', NULL, 'A.Love & D.Love', 48),
(4532, 'Clausenopsis', NULL, '(Engl.) Engl.', 143),
(4533, 'Clausia', NULL, 'Korn.-Trotzky ex Hayek', 197),
(4534, 'Clavapetalum', NULL, 'Pulle', 85),
(4535, 'Clavenna', NULL, 'Neck. ex Standl.(SUO)', 142),
(4536, 'Clavennaea', NULL, 'Neck. ex Post & Kuntze(SUS)', 142),
(4537, 'Clavimyrtus', NULL, 'Blume', 116),
(4538, 'Clavipodium', NULL, 'Desv. ex Gruning', 66),
(4539, 'Clavistylus', NULL, 'J.J.Sm.', 66),
(4540, 'Cleghornia', NULL, 'Wight', 10),
(4541, 'Cleidiocarpon', NULL, 'Airy Shaw', 66),
(4542, 'Cleisocratera', NULL, 'Korth.', 142),
(4543, 'Cleistanthopsis', NULL, 'Capuron', 86),
(4544, 'Cleistochlamys', NULL, 'Oliv.', 8),
(4545, 'Cleistoloranthus', NULL, 'Merr.', 98),
(4546, 'Clelandia', NULL, 'J.M.Black', 174),
(4547, 'Clemanthus', NULL, 'Klotzsch', 127),
(4548, 'Clematicissus', NULL, 'Planch.', 181),
(4549, 'Clematitaria', NULL, 'Bureau', 22),
(4550, 'Clematoclethra', NULL, '(Franch.) Maxim.', 2),
(4551, 'Clemensia', NULL, 'Schltr.(SUH)', 10),
(4552, 'Clemensiella', NULL, 'Schltr.', 10),
(4553, 'Clementsia', NULL, 'Rose', 48),
(4554, 'Cleobulia', NULL, 'Mart. ex Benth.', 68),
(4555, 'Cleochroma', NULL, 'Miers', 154),
(4556, 'Cleodora', NULL, 'Klotzsch', 66),
(4557, 'Cleome', NULL, 'L.', 509),
(4558, 'Cleomella', NULL, 'DC.', 509),
(4559, 'Cleonia', NULL, 'L.', 90),
(4560, 'Cleophora', NULL, 'Gaertn.', 15),
(4561, 'Clermontia', NULL, 'Gaudich.', 30),
(4562, 'Clerodendranthus', NULL, 'Kudo', 90),
(4563, 'Clevelandia', NULL, 'Greene', 400),
(4564, 'Clianthus', NULL, 'Sol. ex Lindl.', 68),
(4565, 'Clibadium', NULL, 'L.', 18),
(4566, 'Cliffortia', NULL, 'L.', 141),
(4567, 'Cliftonia', NULL, 'Banks ex C.F.Gaertn.', 56),
(4568, 'Climacoptera', NULL, 'Botsch.', 5),
(4569, 'Climacorachis', NULL, 'Hemsl. & Rose', 68),
(4570, 'Clinacanthus', NULL, 'Nees', 1),
(4571, 'Clinogyne', NULL, 'K.Schum.(SUH)', 103),
(4572, 'Clinopodium', NULL, 'L.', 90),
(4573, 'Clinosperma', NULL, 'Becc.', 15),
(4574, 'Clinostemon', NULL, 'Kuhlm. & Samp.', 91),
(4575, 'Clinostigma', NULL, 'H.Wendl.', 15),
(4576, 'Clinostigmopsis', NULL, 'Becc.', 15),
(4577, 'Clintonia', NULL, 'Raf.', 94),
(4578, 'Cliocarpus', NULL, 'Miers', 154),
(4579, 'Cliococca', NULL, 'Bab.', 95),
(4580, 'Clistanthus', NULL, 'Post & Kuntze(SUO)', 184),
(4581, 'Clistax', NULL, 'Mart.', 1),
(4582, 'Clistoyucca', NULL, '(Engelm.) Trel.', 3),
(4583, 'Clistranthus', NULL, 'Poit. ex Baill.', 66),
(4584, 'Clitandra', NULL, 'Benth.', 10),
(4585, 'Clitandropsis', NULL, 'S.Moore', 10),
(4586, 'Clitoriopsis', NULL, 'R.Wilczek', 68),
(4587, 'Cloezia', NULL, 'Brongn. & Gris', 116),
(4588, 'Clonodia', NULL, 'Griseb.', 101),
(4589, 'Clonostachys', NULL, 'Klotzsch', 66),
(4590, 'Clonostylis', NULL, 'S.Moore', 66),
(4591, 'Closaschima', NULL, 'Korth.', 162),
(4592, 'Cluacena', NULL, 'Raf.', 116),
(4593, 'Clusianthemum', NULL, 'Vieill.', 42),
(4594, 'Clusiella', NULL, 'Planch. & Triana', 42),
(4595, 'Clusiophyllea', NULL, 'Baill.', 142),
(4596, 'Clusiophyllum', NULL, 'Mull.Arg.', 66),
(4597, 'Clutia', NULL, 'L.', 66),
(4598, 'Cluytia', NULL, 'Aiton(SUO)', 66),
(4599, 'Cluytiandra', NULL, 'Mull.Arg.(SUS)', 184),
(4600, 'Clybatis', NULL, 'Phil.', 18),
(4601, 'Clymenia', NULL, 'Swingle', 143),
(4602, 'Clyostomanthus', NULL, 'Pichon', 22),
(4603, 'Clypeola', NULL, 'L.', 197),
(4604, 'Clytia', NULL, 'Stokes(SUO)', 66),
(4605, 'Clytostoma', NULL, 'Miers ex Bureau', 22),
(4606, 'Cnemidiscus', NULL, 'Pierre', 147),
(4607, 'Cnemidophacos', NULL, 'Rydb.', 68),
(4608, 'Cnemidostachys', NULL, 'Mart.', 66),
(4609, 'Cneoridium', NULL, 'Hook.f.', 143),
(4610, 'Cneorum', NULL, 'L.', 143),
(4611, 'Cnesmone', NULL, 'Blume', 66),
(4612, 'Cnesmosa', NULL, 'Blume', 66),
(4613, 'Cnestidium', NULL, 'Planch.', 45),
(4614, 'Cnestis', NULL, 'Juss.', 45),
(4615, 'Cnicothamnus', NULL, 'Griseb.', 18),
(4616, 'Cnicus', NULL, 'L.', 18),
(4617, 'Cnidiocarpa', NULL, 'Pimenov', 9),
(4618, 'Cnidium', NULL, 'Cusson ex Juss.', 9),
(4619, 'Coaxana', NULL, 'J.M.Coult. & Rose', 9),
(4620, 'Cobananthus', NULL, 'Wiehler', 76),
(4621, 'Coccanthera', NULL, 'K.Koch & Hanst.', 76),
(4622, 'Coccinia', NULL, 'Wight & Arn.', 49),
(4623, 'Coccoceras', NULL, 'Miq.', 66),
(4624, 'Coccochondra', NULL, 'Rauschert', 142),
(4625, 'Coccocypselum', NULL, 'P.Browne', 142),
(4626, 'Coccoglochidion', NULL, 'K.Schum.', 184),
(4627, 'Coccomelia', NULL, 'Ridl.(SUH)', 40),
(4628, 'Cocconerion', NULL, 'Baill.', 66),
(4629, 'Coccosperma', NULL, 'Klotzsch', 64),
(4630, 'Coccothrinax', NULL, 'Sarg.', 15),
(4631, 'Cocculus', NULL, 'DC.', 107),
(4632, 'Coccus', NULL, 'Mill.', 15),
(4633, 'Cochlanthera', NULL, 'Choisy', 42),
(4634, 'Cochlanthus', NULL, 'Balf.f.', 10),
(4635, 'Cochlearia', NULL, 'L.', 197),
(4636, 'Cochleariella', NULL, 'Y.H.Zhang & Vogt', 197),
(4637, 'Cochleariopsis', NULL, 'Y.H.Zhang(SUH)', 197),
(4638, 'Cochlianthus', NULL, 'Benth.', 68),
(4639, 'Cochlidiosperma', NULL, '(Rchb.) Rchb.', 423),
(4640, 'Cochranea', NULL, 'Miers', 25),
(4641, 'Cockerellia', NULL, 'A.Love & D.Love', 48),
(4642, 'Cocops', NULL, 'O.F.Cook', 15),
(4643, 'Codaria', NULL, 'Kuntze', 142),
(4644, 'Codariocalyx', NULL, 'Hassk.', 68),
(4645, 'Codda-Pana', NULL, 'Adans.', 15),
(4646, 'Coddia', NULL, 'Verdc.', 142),
(4647, 'Codia', NULL, 'J.R.Forst. & G.Forst.', 50),
(4648, 'Codiocarpus', NULL, 'R.A.Howard', 545),
(4649, 'Codochonia', NULL, 'Dunal', 154),
(4650, 'Codon', NULL, 'Royen ex L.', 25),
(4651, 'Codonacanthus', NULL, 'Nees', 1),
(4652, 'Codonandra', NULL, 'H.Karst.', 68),
(4653, 'Codonanthe', NULL, '(Mart.) Hanst.', 76),
(4654, 'Codonanthopsis', NULL, 'Mansf.', 76),
(4655, 'Codonechites', NULL, 'Markgr.', 10),
(4656, 'Codonoboea', NULL, 'Ridl.', 76),
(4657, 'Codonocalyx', NULL, 'Klotzsch ex Baill.', 66),
(4658, 'Codonocephalum', NULL, 'Fenzl', 18),
(4659, 'Codonochlamys', NULL, 'Ulbr.', 102),
(4660, 'Codonopsis', NULL, 'Wall.', 30),
(4661, 'Codonostigma', NULL, 'Klotzsch ex Benth.', 64),
(4662, 'Codonura', NULL, 'K.Schum.', 10),
(4663, 'Coelebogyne', NULL, 'J.Sm.(SUO)', 66),
(4664, 'Coelidium', NULL, 'Vogel ex Walp.', 68),
(4665, 'Coelobogyne', NULL, 'J.Sm.', 66),
(4666, 'Coelocarpum', NULL, 'Balf.f.', 173),
(4667, 'Coelocline', NULL, 'A.DC.', 8),
(4668, 'Coelococcus', NULL, 'H.Wendl.', 15),
(4669, 'Coelodepas', NULL, 'Hassk.(SUO)', 66),
(4670, 'Coelodiscus', NULL, 'Baill.', 66),
(4671, 'Coelonema', NULL, 'Maxim.', 197),
(4672, 'Coeloneurum', NULL, 'Radlk.', 154),
(4673, 'Coelophragmus', NULL, 'O.E.Schulz', 197),
(4674, 'Coelopleurum', NULL, 'Ledeb.', 9),
(4675, 'Coelopyrena', NULL, 'Valeton', 142),
(4676, 'Coelospermum', NULL, 'Blume', 142),
(4677, 'Coelostylis', NULL, '(Juss.) Kuntze', 101),
(4678, 'Coemansia', NULL, 'Marchal(SUH)', 13),
(4679, 'Coespeletia', NULL, 'Cuatrec.', 18),
(4680, 'Cofeanthus', NULL, 'A.Chev.', 142),
(4681, 'Cogniauxia', NULL, 'Baill.', 49),
(4682, 'Cogniauxiella', NULL, 'Baill.', 49),
(4683, 'Cogswellia', NULL, 'Spreng.', 9),
(4684, 'Cohnia', NULL, 'Kunth', 3),
(4685, 'Coilocarpus', NULL, 'F.Muell. ex Domin', 5),
(4686, 'Coilostigma', NULL, 'Klotzsch', 64),
(4687, 'Coincya', NULL, 'Rouy', 197),
(4688, 'Coinochlamys', NULL, 'T.Anderson ex Benth.', 97),
(4689, 'Coldenia', NULL, 'L.', 25),
(4690, 'Colea', NULL, 'Bojer ex Meisn.', 22),
(4691, 'Coleactina', NULL, 'N.Halle', 142),
(4692, 'Coleanthera', NULL, 'Stschegl.', 64),
(4693, 'Colebrookea', NULL, 'Sm.', 90),
(4694, 'Colensoa', NULL, 'Hook.f.', 30),
(4695, 'Coleobotrys', NULL, 'Tiegh.', 98),
(4696, 'Coleochloa', NULL, 'Gilly', 55),
(4697, 'Coleocoma', NULL, 'F.Muell.', 18),
(4698, 'Coleogyne', NULL, 'Torr.', 141),
(4699, 'Coleonema', NULL, 'Bartl. & H.L.Wendl.', 143),
(4700, 'Coleospadix', NULL, 'Becc.', 15),
(4701, 'Coleostachys', NULL, 'A.Juss.', 101),
(4702, 'Coleostephus', NULL, 'Cass.', 18),
(4703, 'Coleus', NULL, 'Lour.', 90),
(4704, 'Colicodendron', NULL, 'Mart.', 32),
(4705, 'Colignonia', NULL, 'Endl.', 117),
(4706, 'Colinil', NULL, 'Adans.', 68),
(4707, 'Colladonia', NULL, 'Spreng.', 142),
(4708, 'Collaea', NULL, 'DC.', 68),
(4709, 'Collandra', NULL, 'Lem.', 76),
(4710, 'Collenucia', NULL, 'Chiov.', 66),
(4711, 'Colletia', NULL, 'Comm. ex Juss.', 139),
(4712, 'Colletoecema', NULL, 'E.Petit', 142),
(4713, 'Colletogyne', NULL, 'Buchet', 12),
(4714, 'Colliguaja', NULL, 'Molina', 66),
(4715, 'Colliguonia', NULL, 'Endl.(SUO)', 117),
(4716, 'Collinia', NULL, '(Liebm.) Liebm. ex Oerst.', 15),
(4717, 'Collinsia', NULL, 'Nutt.', 423),
(4718, 'Collinsonia', NULL, 'L.', 90),
(4719, 'Colmeiroa', NULL, 'Reut.', 184),
(4720, 'Colobanthera', NULL, 'Humbert', 18),
(4721, 'Colobogyne', NULL, 'Gagnep.', 18),
(4722, 'Colocasia', NULL, 'Schott', 12),
(4723, 'Colocynthis', NULL, 'Mill.', 49),
(4724, 'Cologania', NULL, 'Kunth', 68),
(4725, 'Colombobalanus', NULL, 'Nixon & Crepet', 72),
(4726, 'Colophospermum', NULL, 'J.Leonard', 68),
(4727, 'Coloptera', NULL, 'J.M.Coult. & Rose', 9),
(4728, 'Colpias', NULL, 'E.Mey. ex Benth.', 150),
(4729, 'Colpogyne', NULL, 'B.L.Burtt', 76),
(4730, 'Colpoon', NULL, 'Bergius', 146),
(4731, 'Colquhounia', NULL, 'Wall.', 90),
(4732, 'Colsmannia', NULL, 'Lehm.', 25),
(4733, 'Columbia', NULL, 'Pers.', 102),
(4734, 'Columella', NULL, 'Lour.', 181),
(4735, 'Columnea', NULL, 'L.', 76),
(4736, 'Coluria', NULL, 'R.Br.', 141),
(4737, 'Colutea', NULL, 'L.', 68),
(4738, 'Coluteocarpus', NULL, 'Boiss.', 197),
(4739, 'Colvillea', NULL, 'Bojer ex Hook.', 68),
(4740, 'Comaclinium', NULL, 'Scheidw. & Planch.', 18),
(4741, 'Comandra', NULL, 'Nutt.', 146),
(4742, 'Comanthosphace', NULL, 'S.Moore', 90),
(4743, 'Comarella', NULL, 'Rydb.', 141),
(4744, 'Comarobatia', NULL, 'Greene', 141),
(4745, 'Comaropsis', NULL, 'Rich.', 141),
(4746, 'Comarostaphylis', NULL, 'Zucc.', 64),
(4747, 'Comarum', NULL, 'L.', 141),
(4748, 'Comastoma', NULL, 'Toyok.', 75),
(4749, 'Comatocroton', NULL, 'H.Karst.', 66),
(4750, 'Combera', NULL, 'Sandwith', 154),
(4751, 'Combesia', NULL, 'A.Rich.', 48),
(4752, 'Combretocarpus', NULL, 'Hook.f.', 7),
(4753, 'Combretodendron', NULL, 'A.Chev.', 92),
(4754, 'Combretum', NULL, 'Loefl.', 44),
(4755, 'Comesperma', NULL, 'Labill.', 133),
(4756, 'Cometia', NULL, 'Thouars ex Baill.', 66),
(4757, 'Comeurya', NULL, 'Baill.', 6),
(4758, 'Cominsia', NULL, 'Hemsl.', 103),
(4759, 'Commarum', NULL, 'Schrank', 141),
(4760, 'Commersonia', NULL, 'J.R.Forst. & G.Forst.', 102),
(4761, 'Commia', NULL, 'Lour.', 66),
(4762, 'Commianthus', NULL, 'Benth.', 142),
(4763, 'Commicarpus', NULL, 'Standl.', 117),
(4764, 'Commidendrum', NULL, 'DC.', 18),
(4765, 'Commiphora', NULL, 'Jacq.', 27),
(4766, 'Commitheca', NULL, 'Bremek.', 142),
(4767, 'Comolia', NULL, 'DC.', 105),
(4768, 'Comoliopsis', NULL, 'Wurdack', 105),
(4769, 'Comomyrsine', NULL, 'Hook.f.', 115),
(4770, 'Comopyena', NULL, 'Kuntze', 66),
(4771, 'Comoranthus', NULL, 'Knobl.', 120),
(4772, 'Comoroa', NULL, 'Oliv.', 143),
(4773, 'Complaya', NULL, 'Strother', 18),
(4774, 'Comptonanthus', NULL, 'B.Nord.', 18),
(4775, 'Comptonella', NULL, 'Baker f.', 143),
(4776, 'Comptonia', NULL, 'L''Her. ex Aiton', 113),
(4777, 'Comularia', NULL, 'Pichon', 10),
(4778, 'Conami', NULL, 'Aubl.', 184),
(4779, 'Conandrium', NULL, '(K.Schum.) Mez', 115),
(4780, 'Conandron', NULL, 'Siebold & Zucc.', 76),
(4781, 'Conanthus', NULL, 'S.Watson', 25),
(4782, 'Conceveibastrum', NULL, '(Mull.Arg.) Pax & K.Hoffm.', 66),
(4783, 'Conchopetalum', NULL, 'Radlk.', 147),
(4784, 'Conchophyllum', NULL, 'Blume', 10),
(4785, 'Condalia', NULL, 'Ruiz & Pav.(SUH)', 139),
(4786, 'Condaliopsis', NULL, '(Weberb.) Suess.', 139),
(4787, 'Condea', NULL, 'Adans.', 90),
(4788, 'Condylidium', NULL, 'R.M.King & H.Rob.', 18),
(4789, 'Condylocarpon', NULL, 'Desf.', 10),
(4790, 'Condylopodium', NULL, 'R.M.King & H.Rob.', 18),
(4791, 'Condylostylis', NULL, 'Piper', 68),
(4792, 'Congdonia', NULL, 'Jeps.(SUH)', 48),
(4793, 'Congea', NULL, 'Roxb.', 90),
(4794, 'Congolanthus', NULL, 'A.Raynal', 75),
(4795, 'Coniandra', NULL, 'Schrad. ex Eckl. & Zeyh.', 49),
(4796, 'Conimitella', NULL, 'Rydb.', 149),
(4797, 'Coniogeton', NULL, 'Blume', 6),
(4798, 'Conioselinum', NULL, 'Fisch. ex Hoffm.', 9),
(4799, 'Conium', NULL, 'L.', 9),
(4800, 'Connarus', NULL, 'L.', 45);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(4801, 'Conobea', NULL, 'Aubl.', 423),
(4802, 'Conocalyx', NULL, 'Benoist', 1),
(4803, 'Conocephalus', NULL, 'Blume', 171),
(4804, 'Conocliniopsis', NULL, 'R.M.King & H.Rob.', 18),
(4805, 'Conoclinium', NULL, 'DC.', 18),
(4806, 'Conomitra', NULL, 'Fenzl', 10),
(4807, 'Conomorpha', NULL, 'A.DC.', 115),
(4808, 'Conopharyngia', NULL, 'G.Don', 10),
(4809, 'Conopholis', NULL, 'Wallr.', 400),
(4810, 'Conopodium', NULL, 'W.D.J.Koch', 9),
(4811, 'Conosapium', NULL, 'Mull.Arg.', 66),
(4812, 'Conosiphon', NULL, 'Poepp.', 142),
(4813, 'Conospermum', NULL, 'Sm.', 135),
(4814, 'Conostephium', NULL, 'Benth.', 64),
(4815, 'Conostomium', NULL, '(Stapf) Cufod.', 142),
(4816, 'Conothamnus', NULL, 'Lindl.', 116),
(4817, 'Conotrichia', NULL, 'A.Rich.', 142),
(4818, 'Conradia', NULL, 'Mart.', 76),
(4819, 'Conradina', NULL, 'A.Gray', 90),
(4820, 'Conringia', NULL, 'Heist. ex Fabr.', 197),
(4821, 'Contortuplicata', NULL, 'Medik.', 68),
(4822, 'Conuleum', NULL, 'A.Rich.', 152),
(4823, 'Convolvulus', NULL, 'L.', 46),
(4824, 'Conyza', NULL, 'Less.', 18),
(4825, 'Conyzanthus', NULL, 'Tamamsch.', 18),
(4826, 'Conzattia', NULL, 'Rose', 68),
(4827, 'Coombea', NULL, 'P.Royen', 143),
(4828, 'Copedesma', NULL, 'Gleason', 105),
(4829, 'Copernicia', NULL, 'Mart. ex Endl.', 15),
(4830, 'Copioglossa', NULL, 'Miers', 1),
(4831, 'Coprosma', NULL, 'J.R.Forst. & G.Forst.', 142),
(4832, 'Coptocheile', NULL, 'Hoffmanns.', 76),
(4833, 'Coptosapelta', NULL, 'Korth.', 142),
(4834, 'Coptospelta', NULL, 'K.Schum.(SUO)', 142),
(4835, 'Coptosperma', NULL, 'Hook.f.', 142),
(4836, 'Corallobotrys', NULL, 'Hook.f.', 64),
(4837, 'Corallocarpus', NULL, 'Welw. ex Hook.f.', 49),
(4838, 'Corallodendron', NULL, 'Kuntze', 68),
(4839, 'Corallodiscus', NULL, 'Batalin', 76),
(4840, 'Corallospartium', NULL, 'J.B.Armstr.', 68),
(4841, 'Corbassona', NULL, 'Aubrev.', 148),
(4842, 'Corchoropsis', NULL, 'Siebold & Zucc.', 102),
(4843, 'Corchorus', NULL, 'L.', 102),
(4844, 'Cordaea', NULL, 'Spreng.', 68),
(4845, 'Cordeauxia', NULL, 'Hemsl.', 68),
(4846, 'Cordemoya', NULL, 'Baill.', 66),
(4847, 'Cordiada', NULL, 'Vell.', 25),
(4848, 'Cordiera', NULL, 'A.Rich.', 142),
(4849, 'Cordiopsis', NULL, 'Desv.', 25),
(4850, 'Cordisepalum', NULL, 'Verdc.', 46),
(4851, 'Cordobia', NULL, 'Nied.', 101),
(4852, 'Cordyla', NULL, 'Lour.', 68),
(4853, 'Cordylanthus', NULL, 'Nutt. ex Benth.', 400),
(4854, 'Cordyline', NULL, 'Comm. ex R.Br.', 360),
(4855, 'Cordyloblaste', NULL, 'Hensch. ex Moritzi', 159),
(4856, 'Cordylocarpus', NULL, 'Desf.', 197),
(4857, 'Cordylogyne', NULL, 'E.Mey.', 10),
(4858, 'Cordylophorum', NULL, 'Rydb.', 121),
(4859, 'Coreanomecon', NULL, 'Nakai', 126),
(4860, 'Corema', NULL, 'D.Don', 64),
(4861, 'Coreocarpus', NULL, 'Benth.', 18),
(4862, 'Coreopsis', NULL, 'L.', 18),
(4863, 'Corethamnium', NULL, 'R.M.King & H.Rob.', 18),
(4864, 'Corethrodendron', NULL, 'Fisch. & Basiner', 68),
(4865, 'Corethrogyne', NULL, 'DC.', 18),
(4866, 'Coriandropsis', NULL, 'H.Wolff', 9),
(4867, 'Coriandrum', NULL, 'L.', 9),
(4868, 'Coridothymus', NULL, 'Rchb.f.', 90),
(4869, 'Coriophyllus', NULL, 'Rydb.', 9),
(4870, 'Coris', NULL, 'L.', 115),
(4871, 'Corispermum', NULL, 'L.', 5),
(4872, 'Cormiophyllum', NULL, 'Newman', 52),
(4873, 'Cormonema', NULL, 'Reissek ex Endl.', 139),
(4874, 'Cormus', NULL, 'Spach', 141),
(4875, 'Cornelia', NULL, 'Ard.', 99),
(4876, 'Cornera', NULL, 'Furtado', 15),
(4877, 'Cornicina', NULL, 'Boiss.', 68),
(4878, 'Cornuella', NULL, 'Pierre', 148),
(4879, 'Cornulaca', NULL, 'Delile', 5),
(4880, 'Cornus', NULL, 'L.', 47),
(4881, 'Cornutia', NULL, 'L.', 90),
(4882, 'Corollonema', NULL, 'Schltr.', 10),
(4883, 'Coronanthera', NULL, 'Vieill. ex C.B.Clarke', 76),
(4884, 'Coronilla', NULL, 'L.', 68),
(4885, 'Coronopus', NULL, 'Zinn', 197),
(4886, 'Coroya', NULL, 'Pierre', 68),
(4887, 'Corozo', NULL, 'Jacq. ex Giseke', 15),
(4888, 'Correa', NULL, 'Andrews', 143),
(4889, 'Correllia', NULL, 'A.M.Powell', 18),
(4890, 'Correlliana', NULL, 'D''Arcy', 115),
(4891, 'Cortesia', NULL, 'Cav.', 25),
(4892, 'Cortia', NULL, 'DC.', 9),
(4893, 'Cortiella', NULL, 'C.Norman', 9),
(4894, 'Corydalis', NULL, 'DC.', 126),
(4895, 'Corylus', NULL, 'L.', 21),
(4896, 'Corymbium', NULL, 'L.', 18),
(4897, 'Corymbostachys', NULL, 'Lindau', 1),
(4898, 'Corynabutilon', NULL, '(K.Schum.) Kearney', 102),
(4899, 'Corynanthe', NULL, 'Welw.', 142),
(4900, 'Corynanthera', NULL, 'J.W.Green', 116),
(4901, 'Corynella', NULL, 'DC.', 68),
(4902, 'Corynemyrtus', NULL, '(Kiaersk.) Mattos', 116),
(4903, 'Corynephyllum', NULL, 'Rose', 48),
(4904, 'Corynosicyos', NULL, 'F.Muell.(SUI)', 49),
(4905, 'Corynostigma', NULL, 'C.Presl', 121),
(4906, 'Corynostylis', NULL, 'Mart.', 174),
(4907, 'Corynula', NULL, 'Hook.f.', 142),
(4908, 'Corypha', NULL, 'L.', 15),
(4909, 'Coryphadenia', NULL, 'Morley', 105),
(4910, 'Coryphomia', NULL, 'Rojas Acosta', 15),
(4911, 'Coryphothamnus', NULL, 'Steyerm.', 142),
(4912, 'Corysadenia', NULL, 'Griff.', 79),
(4913, 'Corysanthera', NULL, 'Wall. ex Endl.', 76),
(4914, 'Corythea', NULL, 'S.Watson', 66),
(4915, 'Corytholoma', NULL, '(Benth.) Decne.', 76),
(4916, 'Corythophora', NULL, 'R.Knuth', 92),
(4917, 'Corytoplectus', NULL, 'Oerst.', 76),
(4918, 'Coryzadenia', NULL, 'Griff.', 79),
(4919, 'Coscinium', NULL, 'Colebr.', 107),
(4920, 'Cosmelia', NULL, 'R.Br.', 64),
(4921, 'Cosmianthemum', NULL, 'Bremek.', 1),
(4922, 'Cosmiusa', NULL, 'Alef.', 68),
(4923, 'Cosmocalyx', NULL, 'Standl.', 142),
(4924, 'Cosmos', NULL, 'Cav.', 18),
(4925, 'Cosmostigma', NULL, 'Wight', 10),
(4926, 'Cossignia', NULL, 'Comm. ex Lam.(SUO)', 147),
(4927, 'Cossinia', NULL, 'Comm. ex Lam.', 147),
(4928, 'Cossonia', NULL, 'Durieu', 197),
(4929, 'Costaea', NULL, 'A.Rich.', 56),
(4930, 'Costantina', NULL, 'Bullock', 10),
(4931, 'Costarica', NULL, 'L.D.Gomez', 49),
(4932, 'Costera', NULL, 'J.J.Sm.', 64),
(4933, 'Costularia', NULL, 'C.B.Clarke', 55),
(4934, 'Cotema', NULL, 'Britton & P.Wilson', 22),
(4935, 'Cotinus', NULL, 'Mill.', 6),
(4936, 'Cotoneaster', NULL, 'Medik.', 141),
(4937, 'Cotopaxia', NULL, 'Mathias & Constance', 9),
(4938, 'Cottsia', NULL, 'Dubard & Dop', 101),
(4939, 'Cotula', NULL, 'L.', 18),
(4940, 'Cotylanthera', NULL, 'Blume', 75),
(4941, 'Cotyledon', NULL, 'L.', 48),
(4942, 'Cotyliphyllum', NULL, 'Link', 48),
(4943, 'Cotylodiscus', NULL, 'Radlk.', 147),
(4944, 'Cotylonychia', NULL, 'Stapf', 102),
(4945, 'Coudenbergia', NULL, 'Marchal', 13),
(4946, 'Coulejia', NULL, 'Dennst.', 184),
(4947, 'Coulterella', NULL, 'Vasey & Rose', 18),
(4948, 'Coulterophytum', NULL, 'B.L.Rob.', 9),
(4949, 'Couma', NULL, 'Aubl.', 10),
(4950, 'Coumarouna', NULL, 'Aubl.', 68),
(4951, 'Coupoui', NULL, 'Aubl.', 142),
(4952, 'Coupuia', NULL, 'Raf.(SUO)', 142),
(4953, 'Coupuya', NULL, 'Raf.(SUO)', 142),
(4954, 'Couralia', NULL, 'Splitg.', 22),
(4955, 'Courantia', NULL, 'Lem.', 48),
(4956, 'Courbonia', NULL, 'Brongn.', 32),
(4957, 'Coursetia', NULL, 'DC.', 68),
(4958, 'Coursiana', NULL, 'Homolle', 142),
(4959, 'Courtoisina', NULL, 'Sojak', 55),
(4960, 'Cousinia', NULL, 'Cass.', 18),
(4961, 'Cousiniopsis', NULL, 'Nevski', 18),
(4962, 'Coutaportla', NULL, 'Urb.', 142),
(4963, 'Couthovia', NULL, 'A.Gray', 97),
(4964, 'Coutinia', NULL, 'Vell.', 10),
(4965, 'Coutoubea', NULL, 'Aubl.', 75),
(4966, 'Covellia', NULL, 'Gasp.', 109),
(4967, 'Covillea', NULL, 'Vail', 177),
(4968, 'Cowania', NULL, 'D.Don', 141),
(4969, 'Cowellocassia', NULL, 'Britton', 68),
(4970, 'Cowiea', NULL, 'Wernham', 142),
(4971, 'Coxella', NULL, 'Cheeseman & Hemsl.', 9),
(4972, 'Crabbea', NULL, 'Harv.', 1),
(4973, 'Cracca', NULL, 'Benth.', 68),
(4974, 'Cracosna', NULL, 'Gagnep.', 75),
(4975, 'Craibiodendron', NULL, 'W.W.Sm.', 64),
(4976, 'Craigia', NULL, 'W.W.Sm. & W.E.Evans', 102),
(4977, 'Crambe', NULL, 'L.', 197),
(4978, 'Crambella', NULL, 'Maire', 197),
(4979, 'Craniospermum', NULL, 'Lehm.', 25),
(4980, 'Craniotome', NULL, 'Rchb.', 90),
(4981, 'Cranocarpus', NULL, 'Benth.', 68),
(4982, 'Crantzia', NULL, 'Sw.(SUH)', 28),
(4983, 'Craspedia', NULL, 'G.Forst.', 18),
(4984, 'Craspedolobium', NULL, 'Harms', 68),
(4985, 'Craspedostoma', NULL, 'Domke', 164),
(4986, 'Craspidospermum', NULL, 'Bojer ex A.DC.', 10),
(4987, 'Crassocephalum', NULL, 'Moench', 18),
(4988, 'Crassula', NULL, 'L.', 48),
(4989, 'Crataegomespilus', NULL, 'Simon-Louis ex G.Bellair', 141),
(4990, 'Crataegus', NULL, 'L.', 141),
(4991, 'Cratericarpium', NULL, 'Spach', 121),
(4992, 'Crateriphytum', NULL, 'Scheff. ex Koord.', 97),
(4993, 'Craterocapsa', NULL, 'Hilliard & B.L.Burtt', 30),
(4994, 'Craterocoma', NULL, 'Mart. ex DC.', 22),
(4995, 'Craterogyne', NULL, 'Lanj.', 109),
(4996, 'Craterosiphon', NULL, 'Engl. & Gilg', 164),
(4997, 'Craterostemma', NULL, 'K.Schum.', 10),
(4998, 'Craterostigma', NULL, 'Hochst.', 150),
(4999, 'Cratoxylon', NULL, 'Blume(SUO)', 42),
(5000, 'Cratylia', NULL, 'Mart. ex Benth.', 68),
(5001, 'Cratystylis', NULL, 'S.Moore', 18),
(5002, 'Crawfurdia', NULL, 'Wall.', 75),
(5003, 'Creaghia', NULL, 'Scort.', 142),
(5004, 'Creaghiella', NULL, 'Stapf', 105),
(5005, 'Creatantha', NULL, 'Standl.', 142),
(5006, 'Cremanthodium', NULL, 'Benth.', 18),
(5007, 'Cremaspora', NULL, 'Benth.', 142),
(5008, 'Cremastopus', NULL, 'Paul G.Wilson', 49),
(5009, 'Cremastosciadium', NULL, 'Rech.f.', 9),
(5010, 'Cremastus', NULL, 'Miers', 22),
(5011, 'Cremnobates', NULL, 'Ridl.', 50),
(5012, 'Cremnophila', NULL, 'Rose', 48),
(5013, 'Cremnophyton', NULL, 'Brullo & Pavone', 5),
(5014, 'Cremocarpon', NULL, 'Baill.', 142),
(5015, 'Cremochilus', NULL, 'Turcz.', 30),
(5016, 'Cremolobus', NULL, 'DC.', 197),
(5017, 'Cremophyllum', NULL, 'Scheidw.', 66),
(5018, 'Cremosperma', NULL, 'Benth.', 76),
(5019, 'Cremostachys', NULL, 'Tul.', 180),
(5020, 'Crena', NULL, 'Scop.', 99),
(5021, 'Crenaea', NULL, 'Schreb.', 99),
(5022, 'Crenea', NULL, 'Aubl.', 99),
(5023, 'Crenidium', NULL, 'Haegi', 154),
(5024, 'Crenosciadium', NULL, 'Boiss. & Heldr.', 9),
(5025, 'Crenularia', NULL, 'Boiss.', 197),
(5026, 'Creochiton', NULL, 'Blume', 105),
(5027, 'Crepidaria', NULL, 'Haw.', 66),
(5028, 'Crepidiastrum', NULL, 'Nakai', 18),
(5029, 'Crepidopsis', NULL, 'Arv.-Touv.', 18),
(5030, 'Crepidorhopalon', NULL, 'Eb.Fisch.', 150),
(5031, 'Crepinella', NULL, 'Marchal', 13),
(5032, 'Crepinodendron', NULL, 'Pierre', 148),
(5033, 'Crepis', NULL, 'L.', 18),
(5034, 'Cressa', NULL, 'L.', 46),
(5035, 'Crimaea', NULL, 'Vassilcz.', 68),
(5036, 'Crinita', NULL, 'Houtt.', 142),
(5037, 'Crinodendron', NULL, 'Molina', 62),
(5038, 'Crioceras', NULL, 'Pierre', 10),
(5039, 'Cristaria', NULL, 'Sonn.(SUH)', 102),
(5040, 'Cristatella', NULL, 'Nutt.', 509),
(5041, 'Crithmum', NULL, 'L.', 9),
(5042, 'Critonia', NULL, 'P.Browne', 18),
(5043, 'Critoniadelphus', NULL, 'R.M.King & H.Rob.', 18),
(5044, 'Critoniella', NULL, 'R.M.King & H.Rob.', 18),
(5045, 'Crobylanthe', NULL, 'Bremek.', 142),
(5046, 'Crocidium', NULL, 'Hook.', 18),
(5047, 'Crocoxylon', NULL, 'Eckl. & Zeyh.', 38),
(5048, 'Crocyllis', NULL, 'E.Mey. ex Hook.f.', 142),
(5049, 'Croftia', NULL, 'Small', 1),
(5050, 'Croixia', NULL, 'Pierre', 148),
(5051, 'Croizatia', NULL, 'Steyerm.', 184),
(5052, 'Cromidon', NULL, 'Compton', 150),
(5053, 'Cronquistia', NULL, 'R.M.King', 18),
(5054, 'Cronquistianthus', NULL, 'R.M.King & H.Rob.', 18),
(5055, 'Croptilon', NULL, 'Raf.', 18),
(5056, 'Crossandra', NULL, 'Salisb.', 1),
(5057, 'Crossandrella', NULL, 'C.B.Clarke', 1),
(5058, 'Crosslandia', NULL, 'W.Fitzg.', 55),
(5059, 'Crossonephelis', NULL, 'Baill.', 147),
(5060, 'Crossophora', NULL, 'Link', 66),
(5061, 'Crossopteryx', NULL, 'Fenzl', 142),
(5062, 'Crossostemma', NULL, 'Planch. ex Benth.', 127),
(5063, 'Crossostephium', NULL, 'Less.', 18),
(5064, 'Crossostigma', NULL, 'Spach', 121),
(5065, 'Crossostylis', NULL, 'J.R.Forst. & G.Forst.', 140),
(5066, 'Crossothamnus', NULL, 'R.M.King & H.Rob.', 18),
(5067, 'Crotonanthus', NULL, 'Klotzsch ex Schltdl.', 66),
(5068, 'Crotonopsis', NULL, 'Michx.', 66),
(5069, 'Crowea', NULL, 'Sm.', 143),
(5070, 'Crozophora', NULL, 'A.Juss.(SUO)', 66),
(5071, 'Crozophyla', NULL, 'Raf.', 66),
(5072, 'Crucianella', NULL, 'L.', 142),
(5073, 'Cruciata', NULL, 'Mill.', 142),
(5074, 'Crucicaryum', NULL, 'Brand', 25),
(5075, 'Cruckshanksia', NULL, 'Hook. & Arn.', 142),
(5076, 'Cruddasia', NULL, 'Prain', 68),
(5077, 'Crudya', NULL, 'Batsch(SUO)', 68),
(5078, 'Crumenaria', NULL, 'Mart.', 139),
(5079, 'Crupina', NULL, '(Pers.) DC.', 18),
(5080, 'Crusea', NULL, 'Cham. & Schltdl.', 142),
(5081, 'Cruzia', NULL, 'Phil.', 90),
(5082, 'Cryphia', NULL, 'R.Br.', 90),
(5083, 'Cryptadenia', NULL, 'Meisn.', 164),
(5084, 'Cryptandra', NULL, 'Sm.', 139),
(5085, 'Cryptangium', NULL, 'Schrad. ex Nees', 55),
(5086, 'Cryptantha', NULL, 'G.Don', 25),
(5087, 'Cryptanthela', NULL, 'Gagnep.', 46),
(5088, 'Cryptocapnos', NULL, 'Rech.f.', 126),
(5089, 'Cryptocarpus', NULL, 'Kunth', 117),
(5090, 'Cryptocodon', NULL, 'Fed.', 30),
(5091, 'Cryptocoryne', NULL, 'Fisch. ex Wydler', 12),
(5092, 'Cryptodiscus', NULL, 'Schrenk ex Fisch. & C.A.Mey.(SUH', 9),
(5093, 'Cryptogyne', NULL, 'Hook.f.', 148),
(5094, 'Cryptolepis', NULL, 'R.Br.', 10),
(5095, 'Cryptoloma', NULL, 'Hanst.', 76),
(5096, 'Cryptomeria', NULL, 'D.Don', 51),
(5097, 'Cryptophaeseolus', NULL, 'Kuntze', 68),
(5098, 'Cryptophragmium', NULL, 'Nees', 1),
(5099, 'Cryptophysa', NULL, 'Standl. & J.F.Macbr.', 105),
(5100, 'Cryptopodium', NULL, 'Schrad. ex Nees', 55),
(5101, 'Cryptorhiza', NULL, 'Urb.', 116),
(5102, 'Cryptorrhynchus', NULL, 'Nevski', 68),
(5103, 'Cryptosepalum', NULL, 'Benth.', 68),
(5104, 'Cryptospermum', NULL, 'Young ex Pers.', 142),
(5105, 'Cryptospora', NULL, 'Kar. & Kir.', 197),
(5106, 'Cryptostegia', NULL, 'R.Br.', 10),
(5107, 'Cryptostemma', NULL, 'R.Br. ex W.T.Aiton', 18),
(5108, 'Cryptostemon', NULL, 'F.Muell. ex Miq.', 116),
(5109, 'Cryptotaenia', NULL, 'DC.', 9),
(5110, 'Cryptotaeniopsis', NULL, 'Dunn', 9),
(5111, 'Crystallopollen', NULL, 'Steetz', 18),
(5112, 'Ctenadena', NULL, 'Prokh.', 66),
(5113, 'Ctenanthe', NULL, 'Eichler', 103),
(5114, 'Ctenardisia', NULL, 'Ducke', 115),
(5115, 'Ctenocladium', NULL, 'Airy Shaw', 109),
(5116, 'Ctenolepis', NULL, 'Hook.f.', 49),
(5117, 'Ctenomeria', NULL, 'Harv.', 66),
(5118, 'Ctenopaepale', NULL, 'Bremek.', 1),
(5119, 'Ctenophrynium', NULL, 'K.Schum.', 103),
(5120, 'Ctenophyllum', NULL, 'Rydb.', 68),
(5121, 'Ctenopsis', NULL, 'Naudin(SUH)', 49),
(5122, 'Cuatrecasanthus', NULL, 'H.Rob.', 18),
(5123, 'Cuatrecasasia', NULL, 'Standl.', 142),
(5124, 'Cuatrecasasiella', NULL, 'H.Rob.', 18),
(5125, 'Cuatrecasasiodendron', NULL, 'Standl. & Steyerm.', 142),
(5126, 'Cuatrecasea', NULL, 'Dugand', 15),
(5127, 'Cubacroton', NULL, 'Alain', 66),
(5128, 'Cubanola', NULL, 'Aiello', 142),
(5129, 'Cubanthus', NULL, '(Boiss.) Millsp.', 66),
(5130, 'Cubelium', NULL, 'Raf. ex Britton & A.Br.', 174),
(5131, 'Cubilia', NULL, 'Blume', 147),
(5132, 'Cubitanthus', NULL, 'Barringer', 76),
(5133, 'Cubospermum', NULL, 'Lour.', 121),
(5134, 'Cuchumatanea', NULL, 'Seid. & Beaman', 18),
(5135, 'Cucifera', NULL, 'Delile', 15),
(5136, 'Cucullaria', NULL, 'Schreb.(SUS)', 175),
(5137, 'Cucumella', NULL, 'Chiov.', 49),
(5138, 'Cucumeroides', NULL, 'Gaertn.', 49),
(5139, 'Cucumeropsis', NULL, 'Naudin', 49),
(5140, 'Cucumis', NULL, 'L.', 49),
(5141, 'Cucurbita', NULL, 'L.', 49),
(5142, 'Cucurbitella', NULL, 'Walp.', 49),
(5143, 'Cucurbitula', NULL, '(M.Roem.) Post & Kuntze', 49),
(5144, 'Cudrania', NULL, 'Trecul', 109),
(5145, 'Cuervea', NULL, 'Triana ex Miers', 38),
(5146, 'Cufodontia', NULL, 'Woodson', 10),
(5147, 'Culcasia', NULL, 'P.Beauv.', 12),
(5148, 'Culcitium', NULL, 'Bonpl.', 18),
(5149, 'Cullen', NULL, 'Medik.', 68),
(5150, 'Cullenia', NULL, 'Wight', 102),
(5151, 'Cullumia', NULL, 'R.Br.', 18),
(5152, 'Cumetea', NULL, 'Raf.', 116),
(5153, 'Cumingia', NULL, 'Vidal', 102),
(5154, 'Cuminia', NULL, 'Colla', 90),
(5155, 'Cuminum', NULL, 'L.', 9),
(5156, 'Cumminsia', NULL, 'King ex Prain(SUI)', 126),
(5157, 'Cuncea', NULL, 'Buch.-Ham. ex D.Don', 142),
(5158, 'Cunila', NULL, 'Royen ex L.', 90),
(5159, 'Cunina', NULL, 'Gay', 142),
(5160, 'Cunninghamia', NULL, 'R.Br.', 51),
(5161, 'Cunonia', NULL, 'L.', 50),
(5162, 'Cunuria', NULL, 'Baill.', 66),
(5163, 'Cupameni', NULL, 'Adans.', 66),
(5164, 'Cupaniopsis', NULL, 'Radlk.', 147),
(5165, 'Cuphaea', NULL, 'Moench(SUO)', 99),
(5166, 'Cuphea', NULL, 'P.Browne', 99),
(5167, 'Cupheanthus', NULL, 'Seem.', 116),
(5168, 'Cuphocarpus', NULL, 'Decne. & Planch.', 13),
(5169, 'Cuphonotus', NULL, 'O.E.Schulz', 197),
(5170, 'Cupi', NULL, 'Adans.', 142),
(5171, 'Cupia', NULL, '(Schult.) DC.', 142),
(5172, 'Cupirana', NULL, 'Miers', 142),
(5173, 'Cupressus', NULL, 'L.', 51),
(5174, 'Cupuia', NULL, 'Raf.', 142),
(5175, 'Cupulanthus', NULL, 'Hutch.', 68),
(5176, 'Cupulissa', NULL, 'Raf.', 22),
(5177, 'Curanga', NULL, 'Juss.', 150),
(5178, 'Curarea', NULL, 'Barneby & Krukoff', 107),
(5179, 'Curatari', NULL, 'J.F.Gmel.(SUO)', 92),
(5180, 'Curataria', NULL, 'Spreng.(SUO)', 92),
(5181, 'Curcas', NULL, 'Adans.', 66),
(5182, 'Curima', NULL, 'O.F.Cook', 15),
(5183, 'Curinila', NULL, 'Schult.', 10),
(5184, 'Curroria', NULL, 'Planch. ex Benth.', 10),
(5185, 'Curtia', NULL, 'Cham. & Schltdl.', 75),
(5186, 'Curtisia', NULL, 'Aiton', 511),
(5187, 'Curupira', NULL, 'G.A.Black', 119),
(5188, 'Cuscatlania', NULL, 'Standl.', 117),
(5189, 'Cuscuta', NULL, 'L.', 46),
(5190, 'Cusickia', NULL, 'M.E.Jones', 9),
(5191, 'Cusickiella', NULL, 'Rollins', 197),
(5192, 'Cusparia', NULL, 'Humb. ex R.Br.', 143),
(5193, 'Cuspidia', NULL, 'Gaertn.', 18),
(5194, 'Cussonia', NULL, 'Thunb.', 13),
(5195, 'Cwangayana', NULL, 'Rauschert', 13),
(5196, 'Cyamopsis', NULL, 'DC.', 68),
(5197, 'Cyanandrium', NULL, 'Stapf', 105),
(5198, 'Cyananthus', NULL, 'Wall. ex Benth.', 30),
(5199, 'Cyanea', NULL, 'Gaudich.', 30),
(5200, 'Cyanocarpus', NULL, 'F.M.Bailey', 135),
(5201, 'Cyanodaphne', NULL, 'Blume', 91),
(5202, 'Cyanopsis', NULL, 'Cass.', 18),
(5203, 'Cyanostegia', NULL, 'Turcz.', 90),
(5204, 'Cyanostremma', NULL, 'Benth. ex Hook. & Arn.', 68),
(5205, 'Cyanothamnus', NULL, 'Lindl.', 143),
(5206, 'Cyanothyrsus', NULL, 'Harms', 68),
(5207, 'Cyanthillium', NULL, 'Blume', 18),
(5208, 'Cyathanthus', NULL, 'Engl.', 109),
(5209, 'Cyathiscus', NULL, 'Tiegh.', 98),
(5210, 'Cyathobasis', NULL, 'Aellen', 5),
(5211, 'Cyathochaeta', NULL, 'Nees', 55),
(5212, 'Cyathocline', NULL, 'Cass.', 18),
(5213, 'Cyathocoma', NULL, 'Nees', 55),
(5214, 'Cyathodes', NULL, 'Labill.', 64),
(5215, 'Cyathogyne', NULL, 'Mull.Arg.', 184),
(5216, 'Cyathomone', NULL, 'S.F.Blake', 18),
(5217, 'Cyathophora', NULL, 'Raf.', 66),
(5218, 'Cyathopsis', NULL, 'Brongn. & Gris', 64),
(5219, 'Cyathoselinum', NULL, 'Benth.', 9),
(5220, 'Cyathostegia', NULL, '(Benth.) Schery', 68),
(5221, 'Cyathostelma', NULL, 'E.Fourn.', 10),
(5222, 'Cyathostemma', NULL, 'Griff.', 8),
(5223, 'Cyathostemon', NULL, 'Turcz.', 116),
(5224, 'Cyathostyles', NULL, 'Schott ex Meisn.', 154),
(5225, 'Cyathula', NULL, 'Blume', 5),
(5226, 'Cybianthopsis', NULL, '(Mez) Lundell', 115),
(5227, 'Cybistax', NULL, 'Mart. ex Meisn.', 22),
(5228, 'Cycas', NULL, 'L.', 53),
(5229, 'Cyclacanthus', NULL, 'S.Moore', 1),
(5230, 'Cyclachaena', NULL, 'Fresen. ex Schltdl.', 18),
(5231, 'Cycladenia', NULL, 'Benth.', 10),
(5232, 'Cyclamen', NULL, 'L.', 115),
(5233, 'Cyclandrophora', NULL, 'Hassk.', 40),
(5234, 'Cyclanthera', NULL, 'Schrad.', 49),
(5235, 'Cyclantheropsis', NULL, 'Harms', 49),
(5236, 'Cyclanthus', NULL, 'Poit.', 54),
(5237, 'Cyclea', NULL, 'Arn. ex Wight', 107),
(5238, 'Cyclocarpa', NULL, 'Afzel. ex Baker', 68),
(5239, 'Cyclocarya', NULL, 'Iljinsk.', 87),
(5240, 'Cyclocodon', NULL, 'Griff.', 30),
(5241, 'Cyclocotyla', NULL, 'Stapf', 10),
(5242, 'Cyclodiscus', NULL, 'Klotzsch', 16),
(5243, 'Cyclolepis', NULL, 'Gillies ex D.Don', 18),
(5244, 'Cyclolobium', NULL, 'Benth.', 68),
(5245, 'Cycloloma', NULL, 'Moq.', 5),
(5246, 'Cyclophyllum', NULL, 'Hook.f.', 142),
(5247, 'Cyclopia', NULL, 'Vent.', 68),
(5248, 'Cycloptychis', NULL, 'E.Mey. ex Sond.', 197),
(5249, 'Cyclorhiza', NULL, 'M.L.Sheh & R.H.Shan', 9),
(5250, 'Cyclospathe', NULL, 'O.F.Cook', 15),
(5251, 'Cyclospermum', NULL, 'Lag.', 9),
(5252, 'Cyclostegia', NULL, 'Benth.', 90),
(5253, 'Cyclostemon', NULL, 'Blume', 66),
(5254, 'Cyclostigma', NULL, 'Klotzsch ex Seem.(SUH)', 66),
(5255, 'Cyclotrichium', NULL, '(Boiss.) Manden. & Scheng.', 90),
(5256, 'Cycniopsis', NULL, 'Engl.', 150),
(5257, 'Cycnium', NULL, 'E.Mey. ex Benth.', 400),
(5258, 'Cycnopodium', NULL, 'Naudin', 105),
(5259, 'Cydista', NULL, 'Miers', 22),
(5260, 'Cydonia', NULL, 'Mill.', 141),
(5261, 'Cylicodiscus', NULL, 'Harms', 68),
(5262, 'Cylicomorpha', NULL, 'Urb.', 34),
(5263, 'Cylindria', NULL, 'Lour.', 120),
(5264, 'Cylindrocarpa', NULL, 'Regel', 30),
(5265, 'Cylindrocline', NULL, 'Cass.', 18),
(5266, 'Cylindrokelupha', NULL, 'Kosterm.', 68),
(5267, 'Cylindropsis', NULL, 'Pierre', 10),
(5268, 'Cylindrosolenium', NULL, 'Lindau', 1),
(5269, 'Cylindrosperma', NULL, 'Ducke', 10),
(5270, 'Cylista', NULL, 'Aiton', 68),
(5271, 'Cylixylon', NULL, 'Llanos', 10),
(5272, 'Cymaria', NULL, 'Benth.', 90),
(5273, 'Cymatocarpus', NULL, 'O.E.Schulz', 197),
(5274, 'Cymbalaria', NULL, 'Hill', 423),
(5275, 'Cymbaria', NULL, 'L.', 400),
(5276, 'Cymbocarpum', NULL, 'DC. ex C.A.Mey.', 9),
(5277, 'Cymbolaena', NULL, 'Smoljan.', 18),
(5278, 'Cymbonotus', NULL, 'Cass.', 18),
(5279, 'Cymbopappus', NULL, 'B.Nord.', 18),
(5280, 'Cymbosema', NULL, 'Benth.', 68),
(5281, 'Cymbosepalum', NULL, 'Baker', 68),
(5282, 'Cymelonema', NULL, 'C.Presl', 142),
(5283, 'Cymophora', NULL, 'B.L.Rob.', 18),
(5284, 'Cymophyllus', NULL, 'Mack. ex Britton & A.Br.', 55),
(5285, 'Cymopterus', NULL, 'Raf.', 9),
(5286, 'Cynanchica', NULL, 'Fourr.', 142),
(5287, 'Cynanchum', NULL, 'L.', 10),
(5288, 'Cynara', NULL, 'L.', 18),
(5289, 'Cynaropsis', NULL, 'Kuntze', 18),
(5290, 'Cyne', NULL, 'Danser', 98),
(5291, 'Cynocrambe', NULL, 'Hill', 66),
(5292, 'Cynoctonum', NULL, 'J.F.Gmel.', 97),
(5293, 'Cynoglossopsis', NULL, 'Brand', 25),
(5294, 'Cynoglossum', NULL, 'L.', 25),
(5295, 'Cynoglottis', NULL, '(Gusul.) Vural & Kit Tan', 25),
(5296, 'Cynomarathrum', NULL, 'Nutt.', 9),
(5297, 'Cynomyrtus', NULL, 'Scriv.', 116),
(5298, 'Cynorrhiza', NULL, 'Eckl. & Zeyh.', 9),
(5299, 'Cynosciadium', NULL, 'DC.', 9),
(5300, 'Cynoxylon', NULL, 'Raf.', 47),
(5301, 'Cyperus', NULL, 'L.', 55),
(5302, 'Cyphacanthus', NULL, 'Leonard', 1),
(5303, 'Cyphanthera', NULL, 'Miers', 154),
(5304, 'Cyphia', NULL, 'Bergius', 30),
(5305, 'Cyphisia', NULL, 'Rizzini', 1),
(5306, 'Cyphocalyx', NULL, 'Gagnep.(SUH)', 150),
(5307, 'Cyphocardamum', NULL, 'Hedge', 197),
(5308, 'Cyphocarpus', NULL, 'Miers', 30),
(5309, 'Cyphokentia', NULL, 'Brongn.', 15),
(5310, 'Cypholophus', NULL, 'Wedd.', 171),
(5311, 'Cyphomattia', NULL, 'Boiss.', 25),
(5312, 'Cyphomeris', NULL, 'Standl.', 117),
(5313, 'Cyphophoenix', NULL, 'H.Wendl. ex Hook.f.', 15),
(5314, 'Cyphosperma', NULL, 'H.Wendl. ex Hook.f.', 15),
(5315, 'Cyphostemma', NULL, '(Planch.) Alston', 181),
(5316, 'Cyphostyla', NULL, 'Gleason', 105),
(5317, 'Cyphotheca', NULL, 'Diels', 105),
(5318, 'Cyprinia', NULL, 'Browicz', 10),
(5319, 'Cyrillopsis', NULL, 'Kuhlm.', 86),
(5320, 'Cyrilwhitea', NULL, 'Ising', 5),
(5321, 'Cyrtandroidea', NULL, 'F.Br.', 76),
(5322, 'Cyrtandromoea', NULL, 'Zoll.', 150),
(5323, 'Cyrtandropsis', NULL, 'C.B.Clarke ex DC.', 76),
(5324, 'Cyrtanthemum', NULL, 'Oerst.', 76),
(5325, 'Cyrtanthera', NULL, 'Nees', 1),
(5326, 'Cyrtantherella', NULL, 'Oerst.', 1),
(5327, 'Cyrtanthus', NULL, 'Schreb.(SUH)', 215),
(5328, 'Cyrtocarpa', NULL, 'Kunth', 6),
(5329, 'Cyrtoceras', NULL, 'Benn.', 10),
(5330, 'Cyrtocymura', NULL, 'H.Rob.', 18),
(5331, 'Cyrtodeira', NULL, 'Hanst.', 76),
(5332, 'Cyrtogonone', NULL, 'Prain', 66),
(5333, 'Cyrtonema', NULL, 'Schrad. ex Eckl. & Zeyh.', 49),
(5334, 'Cyrtophyllum', NULL, 'Reinw.', 75),
(5335, 'Cyrtosiphonia', NULL, 'Miq.', 10),
(5336, 'Cyrtosperma', NULL, 'Griff.', 12),
(5337, 'Cyrtospermum', NULL, 'Benth.', 6),
(5338, 'Cyrtostachys', NULL, 'Blume', 15),
(5339, 'Cyrtoxiphus', NULL, 'Harms', 68),
(5340, 'Cystacanthus', NULL, 'T.Anderson', 1),
(5341, 'Cysticapnos', NULL, 'Mill.', 126),
(5342, 'Cysticorydalis', NULL, 'Fedde ex Ikonn.', 126),
(5343, 'Cystidospermum', NULL, 'Prokh.', 66),
(5344, 'Cystistemon', NULL, 'Post & Kuntze(SUO)', 25),
(5345, 'Cystium', NULL, '(Steven) Steven', 68),
(5346, 'Cystogyne', NULL, 'Gasp.', 109),
(5347, 'Cystostemma', NULL, 'E.Fourn.', 10),
(5348, 'Cystostemon', NULL, 'Balf.f.', 25),
(5349, 'Cytisophyllum', NULL, 'O.Lang', 68),
(5350, 'Cytisopsis', NULL, 'Jaub. & Spach', 68),
(5351, 'Cytisus', NULL, 'Desf.', 68),
(5352, 'Cyttaranthus', NULL, 'J.Leonard', 66),
(5353, 'Daboecia', NULL, 'D.Don', 64),
(5354, 'Dachel', NULL, 'Adans.', 15),
(5355, 'Dacrycarpus', NULL, '(Endl.) de Laub.', 132),
(5356, 'Dacrydium', NULL, 'Lamb.', 132),
(5357, 'Dacryotrichia', NULL, 'Wild', 18),
(5358, 'Dactimala', NULL, 'Raf.', 148),
(5359, 'Dactylaea', NULL, 'Fedde ex H.Wolff', 9),
(5360, 'Dactylaena', NULL, 'Schrad. ex Schult.f.', 509),
(5361, 'Dactylanthes', NULL, 'Haw.', 66),
(5362, 'Dactyliandra', NULL, '(Hook.f.) Hook.f.', 49),
(5363, 'Dactylicapnos', NULL, 'Wall.', 126),
(5364, 'Dactyliocapnos', NULL, 'Spreng.(SUO)', 126),
(5365, 'Dactyliophora', NULL, 'Tiegh.', 98),
(5366, 'Dactyliota', NULL, '(Blume) Blume', 105),
(5367, 'Dactylocardamum', NULL, 'Al-Shehbaz', 197),
(5368, 'Dactylocladus', NULL, 'Oliv.', 186),
(5369, 'Dactylopetalum', NULL, 'Benth.', 140),
(5370, 'Dactylostegium', NULL, 'Nees', 1),
(5371, 'Dactylostemon', NULL, 'Klotzsch', 66),
(5372, 'Dactylostigma', NULL, 'D.F.Austin', 46),
(5373, 'Daedalacanthus', NULL, 'T.Anderson', 1),
(5374, 'Daemia', NULL, 'Poir.', 10),
(5375, 'Daemonorops', NULL, 'Blume', 15),
(5376, 'Daenikera', NULL, 'Hurl. & Stauffer', 146),
(5377, 'Dahlgrenia', NULL, 'Steyerm.', 15),
(5378, 'Dahlgrenodendron', NULL, 'J.J.M.van der Merwe & A.E.van Wy', 91),
(5379, 'Dahlia', NULL, 'Cav.', 18),
(5380, 'Dahlstedtia', NULL, 'Malme', 68),
(5381, 'Dahuronia', NULL, 'Scop.', 40),
(5382, 'Dais', NULL, 'L.', 164),
(5383, 'Dalanum', NULL, 'Dostal', 90),
(5384, 'Dalbergaria', NULL, 'Tussac', 76),
(5385, 'Dalbergiella', NULL, 'Baker f.', 68),
(5386, 'Dalea', NULL, 'Mill.(SUH)', 68),
(5387, 'Dalechampia', NULL, 'L.', 66),
(5388, 'Dalechampsia', NULL, 'Post & Kuntze', 66),
(5389, 'Dalembertia', NULL, 'Baill.', 66),
(5390, 'Dalenia', NULL, 'Korth.', 105),
(5391, 'Dalhousiea', NULL, 'Wall. ex Benth.', 68),
(5392, 'Dallachya', NULL, 'F.Muell.', 139),
(5393, 'Dalzielia', NULL, 'Turrill', 10),
(5394, 'Dammaropsis', NULL, 'Warb.', 109),
(5395, 'Dammera', NULL, 'Lauterb. & K.Schum.', 15),
(5396, 'Damnacanthus', NULL, 'C.F.Gaertn.', 142),
(5397, 'Damnamenia', NULL, 'Given', 18),
(5398, 'Damnxanthodium', NULL, 'Strother', 18),
(5399, 'Damrongia', NULL, 'Kerr ex Craib', 76),
(5400, 'Danaa', NULL, 'All.', 9),
(5401, 'Danais', NULL, 'Comm. ex Vent.', 142),
(5402, 'Danguya', NULL, 'Benoist', 1),
(5403, 'Danguyodrypetes', NULL, 'Leandri', 66),
(5404, 'Danielia', NULL, 'Lem.', 48),
(5405, 'Daniella', NULL, 'Corr.Mello', 22),
(5406, 'Daniellia', NULL, 'Benn.', 68),
(5407, 'Dankia', NULL, 'Gagnep.', 162),
(5408, 'Dansera', NULL, 'Steenis', 68),
(5409, 'Danserella', NULL, 'Balle(SUI)', 98),
(5410, 'Dansiea', NULL, 'Byrnes', 44),
(5411, 'Danthia', NULL, 'Steud.', 121),
(5412, 'Dantia', NULL, 'Boehm.', 121),
(5413, 'Dapania', NULL, 'Korth.', 124),
(5414, 'Daphnandra', NULL, 'Benth.', 505),
(5415, 'Daphne', NULL, 'L.', 164),
(5416, 'Daphnidium', NULL, 'Nees', 91),
(5417, 'Daphniluma', NULL, 'Baill.', 148),
(5418, 'Daphnimorpha', NULL, 'Nakai', 164),
(5419, 'Darbya', NULL, 'A.Gray', 146),
(5420, 'Darlingia', NULL, 'F.Muell.', 135),
(5421, 'Darmera', NULL, 'Voss', 149),
(5422, 'Darniella', NULL, 'Maire & Weiller', 5),
(5423, 'Darwinia', NULL, 'Rudge', 116),
(5424, 'Darwiniothamnus', NULL, 'Harling', 18),
(5425, 'Dasillipe', NULL, 'Dubard', 148),
(5426, 'Dasiphora', NULL, 'Raf.', 141),
(5427, 'Dasispermum', NULL, 'Raf.', 9),
(5428, 'Dasistoma', NULL, 'Raf.', 150),
(5429, 'Dasoclema', NULL, 'J.Sinclair', 8),
(5430, 'Dasus', NULL, 'Lour.', 142),
(5431, 'Dasyaulus', NULL, 'Thwaites', 148),
(5432, 'Dasycarya', NULL, 'Liebm.', 6),
(5433, 'Dasycephala', NULL, '(DC.) Hook.f.', 142),
(5434, 'Dasycoleum', NULL, 'Turcz.', 106),
(5435, 'Dasycondylus', NULL, 'R.M.King & H.Rob.', 18),
(5436, 'Dasydesmus', NULL, 'Craib', 76),
(5437, 'Dasynotus', NULL, 'I.M.Johnst.', 25),
(5438, 'Dasypetalum', NULL, 'Pierre ex A.Chev.', 73),
(5439, 'Dasyphyllum', NULL, 'Kunth', 18),
(5440, 'Dasys', NULL, 'Lem.', 142),
(5441, 'Dasysphaera', NULL, 'Volkens ex Gilg', 5),
(5442, 'Dasystephana', NULL, 'Adans.', 75),
(5443, 'Dasystoma', NULL, 'Raf.', 150),
(5444, 'Dasytropis', NULL, 'Urb.', 1),
(5445, 'Datisca', NULL, 'L.', 194),
(5446, 'Datura', NULL, 'L.', 154),
(5447, 'Daturicarpa', NULL, 'Stapf', 10),
(5448, 'Daubentonia', NULL, 'DC.', 68),
(5449, 'Daubentoniopsis', NULL, 'Rydb.', 68),
(5450, 'Daucosma', NULL, 'Engelm. & A.Gray', 9),
(5451, 'Daucus', NULL, 'L.', 9),
(5452, 'Daumalia', NULL, 'Arenes', 18),
(5453, 'Daun-Contu', NULL, 'Adans.', 142),
(5454, 'Dauphinea', NULL, 'Hedge', 90),
(5455, 'Daveaua', NULL, 'Willk. ex Mariz', 18),
(5456, 'Davidia', NULL, 'Baill.', 528),
(5457, 'Davidsonia', NULL, 'F.Muell.', 50),
(5458, 'Daviesia', NULL, 'Sm.', 68),
(5459, 'Davilla', NULL, 'Vand.', 58),
(5460, 'Davya', NULL, 'DC.', 105),
(5461, 'Dayaoshania', NULL, 'W.T.Wang', 76),
(5462, 'Deanea', NULL, 'J.M.Coult. & Rose', 9),
(5463, 'Debraea', NULL, 'Roem. & Schult.(SUS)', 175),
(5464, 'Decabelone', NULL, 'Decne.', 10),
(5465, 'Decachaeta', NULL, 'DC.', 18),
(5466, 'Decagonocarpus', NULL, 'Engl.', 143),
(5467, 'Decaisnina', NULL, 'Tiegh.', 98),
(5468, 'Decalepidanthus', NULL, 'Riedl', 25),
(5469, 'Decalepis', NULL, 'Wight & Arn.', 10),
(5470, 'Decaloba', NULL, 'M.Roem.', 127),
(5471, 'Decalobanthus', NULL, 'Ooststr.', 46),
(5472, 'Decalophium', NULL, 'Turcz.', 116),
(5473, 'Decameria', NULL, 'Welw.', 142),
(5474, 'Decamerium', NULL, 'Nutt.', 64),
(5475, 'Decanema', NULL, 'Decne.', 10),
(5476, 'Decanemopsis', NULL, 'Costantin & Gallaud', 10),
(5477, 'Decapenta', NULL, 'Raf.', 142),
(5478, 'Decaphalangium', NULL, 'Melch.', 42),
(5479, 'Decaptera', NULL, 'Turcz.', 197),
(5480, 'Decarinium', NULL, 'Raf.', 66),
(5481, 'Decarydendron', NULL, 'Danguy', 108),
(5482, 'Decaschistia', NULL, 'Wight & Arn.', 102),
(5483, 'Decastelma', NULL, 'Schltr.', 10),
(5484, 'Decastylocarpus', NULL, 'Humbert', 18),
(5485, 'Decateles', NULL, 'Raf.', 148),
(5486, 'Decatoca', NULL, 'F.Muell.', 64),
(5487, 'Decatropis', NULL, 'Hook.f.', 143),
(5488, 'Decazesia', NULL, 'F.Muell.', 18),
(5489, 'Decazyx', NULL, 'Pittier & S.F.Blake', 143),
(5490, 'Deccania', NULL, 'Tirveng.', 142),
(5491, 'Decemium', NULL, 'Raf.', 25),
(5492, 'Deckenia', NULL, 'H.Wendl. ex Seem.', 15),
(5493, 'Deckeria', NULL, 'H.Karst.', 15),
(5494, 'Declieuxia', NULL, 'Kunth', 142),
(5495, 'Decodon', NULL, 'J.F.Gmel.', 99),
(5496, 'Decorsea', NULL, 'R.Vig.', 68),
(5497, 'Decorsella', NULL, 'A.Chev.', 174),
(5498, 'Decussocarpus', NULL, 'de Laub.(SUS)', 132),
(5499, 'Dedeckera', NULL, 'Reveal & J.T.Howell', 134),
(5500, 'Deeringia', NULL, 'R.Br.', 5),
(5501, 'Deeringothamnus', NULL, 'Small', 8),
(5502, 'Deflersia', NULL, 'Schweinf. ex Penz.', 66),
(5503, 'Degenia', NULL, 'Hayek', 197),
(5504, 'Deguelia', NULL, 'Aubl.', 68),
(5505, 'Deherainia', NULL, 'Decne.', 163),
(5506, 'Deianira', NULL, 'Cham. & Schltdl.', 75),
(5507, 'Deidamia', NULL, 'Noronha ex Thouars', 127),
(5508, 'Deinandra', NULL, 'Greene', 18),
(5509, 'Deinostema', NULL, 'T.Yamaz.', 150),
(5510, 'Dekindtia', NULL, 'Gilg', 120),
(5511, 'Dekinia', NULL, 'M.Martens & Galeotti', 90),
(5512, 'Delairea', NULL, 'Lem.', 18),
(5513, 'Delamerea', NULL, 'S.Moore', 18),
(5514, 'Delaportea', NULL, 'Thorel ex Gagnep.', 68),
(5515, 'Delarbrea', NULL, 'Vieill.', 525),
(5516, 'Delastrea', NULL, 'A.DC.', 148),
(5517, 'Delavaya', NULL, 'Franch.', 147),
(5518, 'Delilia', NULL, 'Spreng.', 18),
(5519, 'Delima', NULL, 'L.', 58),
(5520, 'Delissea', NULL, 'Gaudich.', 30),
(5521, 'Delognaea', NULL, 'Cogn.', 49),
(5522, 'Delopyrum', NULL, 'Small', 134),
(5523, 'Delostoma', NULL, 'D.Don', 22),
(5524, 'Delpechia', NULL, 'Montrouz.', 142),
(5525, 'Delphinacanthus', NULL, 'Benoist', 1),
(5526, 'Delphyodon', NULL, 'K.Schum.', 10),
(5527, 'Delpinophytum', NULL, 'Speg.', 197),
(5528, 'Delpya', NULL, 'Pierre ex Radlk.(SUS)', 147),
(5529, 'Delpydora', NULL, 'Pierre', 148),
(5530, 'Deltaria', NULL, 'Steenis', 164),
(5531, 'Deltocheilos', NULL, 'W.T.Wang', 76),
(5532, 'Dematra', NULL, 'Raf.', 66),
(5533, 'Demavendia', NULL, 'Pimenov', 9),
(5534, 'Demidium', NULL, 'DC.', 18),
(5535, 'Democritea', NULL, 'DC.', 142),
(5536, 'Demosthenesia', NULL, 'A.C.Sm.', 64),
(5537, 'Dendranthema', NULL, '(DC.) Des Moul.', 18),
(5538, 'Dendriopoterium', NULL, 'Svent.', 141),
(5539, 'Dendrobenthamia', NULL, 'Hutch.', 47),
(5540, 'Dendrobrychis', NULL, '(DC.) Galushko', 68),
(5541, 'Dendrobryon', NULL, 'Klotzsch ex Pax & K.Hoffm.', 66),
(5542, 'Dendrocacalia', NULL, '(Nakai) Tuyama', 18),
(5543, 'Dendrocousinsia', NULL, 'Millsp.', 66),
(5544, 'Dendroleandria', NULL, 'Arenes', 102),
(5545, 'Dendrolobium', NULL, '(Wight & Arn.) Benth.', 68),
(5546, 'Dendromecon', NULL, 'Benth.', 126),
(5547, 'Dendromyza', NULL, 'Danser', 146),
(5548, 'Dendropemon', NULL, '(Blume) Rchb.', 98),
(5549, 'Dendrophthoe', NULL, 'Mart.', 98),
(5550, 'Dendrophthora', NULL, 'Eichler', 146),
(5551, 'Dendrophyllanthus', NULL, 'S.Moore', 184),
(5552, 'Dendrosenecio', NULL, '(Hauman ex Humbert) B.Nord.', 18),
(5553, 'Dendroseris', NULL, 'D.Don', 18),
(5554, 'Dendrosicus', NULL, 'Raf.', 22),
(5555, 'Dendrosicyos', NULL, 'Balf.f.', 49),
(5556, 'Dendrosida', NULL, 'Fryxell', 102),
(5557, 'Dendrosipanea', NULL, 'Ducke', 142),
(5558, 'Dendrosma', NULL, 'Pancher & Sebert', 143),
(5559, 'Dendrostellera', NULL, '(C.A.Mey.) Tiegh.', 164),
(5560, 'Dendrostigma', NULL, 'Gleason', 73),
(5561, 'Dendrostylis', NULL, 'H.Karst. & Triana', 73),
(5562, 'Dendrotrophe', NULL, 'Miq.', 146),
(5563, 'Denea', NULL, 'O.F.Cook', 15),
(5564, 'Denekia', NULL, 'Thunb.', 18),
(5565, 'Denhamia', NULL, 'Meisn.', 38),
(5566, 'Denisonia', NULL, 'F.Muell.', 90),
(5567, 'Denisophytum', NULL, 'R.Vig.', 68),
(5568, 'Dennettia', NULL, 'Baker f.', 8),
(5569, 'Dentaria', NULL, 'L.', 197),
(5570, 'Dentella', NULL, 'J.R.Forst. & G.Forst.', 142),
(5571, 'Dentillaria', NULL, 'Kuntze', 142),
(5572, 'Dentimetula', NULL, 'Tiegh.', 98),
(5573, 'Dentoceras', NULL, 'Small', 134),
(5574, 'Deonia', NULL, 'Pierre ex Pax', 66),
(5575, 'Depanthus', NULL, 'S.Moore', 76),
(5576, 'Deppea', NULL, 'Cham. & Schltdl.', 142),
(5577, 'Dermatobotrys', NULL, 'Bolus', 150),
(5578, 'Dermatocalyx', NULL, 'Oerst.', 150),
(5579, 'Dermophylla', NULL, 'Silva Manso', 49),
(5580, 'Derwentia', NULL, 'Raf.', 150),
(5581, 'Descurainia', NULL, 'Webb & Berthel.', 197),
(5582, 'Desdemona', NULL, 'S.Moore', 150),
(5583, 'Desfontaena', NULL, 'Vell.', 66),
(5584, 'Desfontaina', NULL, 'Steud.(SUO)', 66),
(5585, 'Desfontainea', NULL, 'Rchb.(SUO)', 66),
(5586, 'Desfontainesia', NULL, 'Hoffmanns.(SUO)', 120),
(5587, 'Desfontainia', NULL, 'Ruiz & Pav.', 512),
(5588, 'Desideria', NULL, 'Pamp.', 197),
(5589, 'Desmanthodium', NULL, 'Benth.', 18),
(5590, 'Desmanthus', NULL, 'Willd.', 68),
(5591, 'Desmaria', NULL, 'Tiegh.', 98),
(5592, 'Desmidorchis', NULL, 'Ehrenb.', 10),
(5593, 'Desmodiastrum', NULL, '(Prain) A.Pramanik & Thoth.', 68),
(5594, 'Desmodiocassia', NULL, 'Britton & Rose', 68),
(5595, 'Desmodium', NULL, 'Desv.', 68),
(5596, 'Desmofischera', NULL, 'Holthuis', 68),
(5597, 'Desmogyne', NULL, 'King & Prain', 64),
(5598, 'Desmoncus', NULL, 'Mart.', 15),
(5599, 'Desmonema', NULL, 'Raf.(SUH)', 66),
(5600, 'Desmoscelis', NULL, 'Naudin', 105),
(5601, 'Desmoschoenus', NULL, 'Hook.f.', 55),
(5602, 'Desmostachys', NULL, 'Miers', 85),
(5603, 'Desmostemon', NULL, 'Thwaites', 66),
(5604, 'Desmothamnus', NULL, 'Small', 64),
(5605, 'Despeleza', NULL, 'Nieuwl.', 68),
(5606, 'Desrousseauxia', NULL, 'Tiegh.', 98),
(5607, 'Detarium', NULL, 'Juss.', 68),
(5608, 'Dethawia', NULL, 'Endl.', 9),
(5609, 'Detzneria', NULL, 'Schltr. ex Diels', 423),
(5610, 'Deuteromallotus', NULL, 'Pax & K.Hoffm.', 66),
(5611, 'Deutzianthus', NULL, 'Gagnep.', 66),
(5612, 'Deverra', NULL, 'DC.', 9),
(5613, 'Dewevrea', NULL, 'Micheli', 68),
(5614, 'Dewevrella', NULL, 'De Wild.', 10),
(5615, 'Deweya', NULL, 'Torr. & A.Gray', 9),
(5616, 'Dewildemania', NULL, 'O.Hoffm.', 18),
(5617, 'Dewindtia', NULL, 'De Wild.', 68),
(5618, 'Dhofaria', NULL, 'A.G.Mill.', 32),
(5619, 'Diacarpa', NULL, 'Sim', 147),
(5620, 'Diacidia', NULL, 'Griseb.', 101),
(5621, 'Diacranthera', NULL, 'R.M.King & H.Rob.', 18),
(5622, 'Diacrodon', NULL, 'Sprague', 142),
(5623, 'Diadenaria', NULL, 'Klotzsch & Garcke', 66),
(5624, 'Dialyanthera', NULL, 'Warb.', 114),
(5625, 'Dialypetalanthus', NULL, 'Kuhlm.', 142),
(5626, 'Dialypetalum', NULL, 'Benth.', 30),
(5627, 'Dialytheca', NULL, 'Exell & Mendonca', 107),
(5628, 'Diamonon', NULL, 'Raf.', 154),
(5629, 'Diamorpha', NULL, 'Nutt.', 48),
(5630, 'Diandriella', NULL, 'Engl.', 12),
(5631, 'Dianthera', NULL, 'L.', 1),
(5632, 'Dianthoseris', NULL, 'Sch.Bip.', 18),
(5633, 'Dianthoveus', NULL, 'Hammel & Wilder', 54),
(5634, 'Diaperia', NULL, 'Nutt.', 18),
(5635, 'Diaphractanthus', NULL, 'Humbert', 18),
(5636, 'Diaphycarpus', NULL, 'Calest.', 9),
(5637, 'Diarthron', NULL, 'Turcz.', 164),
(5638, 'Diascia', NULL, 'Link & Otto', 150),
(5639, 'Diaspananthus', NULL, 'Miq.', 18),
(5640, 'Diasperus', NULL, 'Kuntze', 184),
(5641, 'Diaspis', NULL, 'Nied.', 101),
(5642, 'Diastatea', NULL, 'Scheidw.', 30),
(5643, 'Diastella', NULL, 'Salisb. ex Knight', 135),
(5644, 'Diastema', NULL, 'Benth.', 76),
(5645, 'Diastemella', NULL, 'Oerst.', 76),
(5646, 'Diateinacanthus', NULL, 'Lindau', 1),
(5647, 'Diatenopteryx', NULL, 'Radlk.', 147),
(5648, 'Diatoma', NULL, 'Lour.', 140),
(5649, 'Diatremis', NULL, 'Raf.', 46),
(5650, 'Dibrachion', NULL, 'Regel', 66),
(5651, 'Dibrachionostylus', NULL, 'Bremek.', 142),
(5652, 'Dibrachium', NULL, 'Walp.', 66),
(5653, 'Dicaelosperma', NULL, 'E.G.O.Mull. & Pax(SUO)', 49),
(5654, 'Dicaelospermum', NULL, 'C.B.Clarke(SUO)', 49),
(5655, 'Dicarpellum', NULL, '(Loes.) A.C.Sm.', 38),
(5656, 'Dicarpidium', NULL, 'F.Muell.', 102),
(5657, 'Dicarpophora', NULL, 'Speg.', 10),
(5658, 'Dicella', NULL, 'Griseb.', 101),
(5659, 'Dicellandra', NULL, 'Hook.f.', 105),
(5660, 'Dicellostyles', NULL, 'Benth.', 102),
(5661, 'Dicentra', NULL, 'Borkh. ex Bernh.', 126),
(5662, 'Dicentranthera', NULL, 'T.Anderson', 1),
(5663, 'Dicera', NULL, 'J.R.Forst. & G.Forst.', 62),
(5664, 'Dicerandra', NULL, 'Benth.', 90),
(5665, 'Diceratella', NULL, 'Boiss.', 197),
(5666, 'Dicercoclados', NULL, 'C.Jeffrey & Y.L.Chen', 18),
(5667, 'Dicerma', NULL, 'DC.', 68),
(5668, 'Dicerolepis', NULL, 'Blume', 10),
(5669, 'Dicerospermum', NULL, 'Bakh.f.', 105),
(5670, 'Dichaelia', NULL, 'Harv.', 10),
(5671, 'Dichaetophora', NULL, 'A.Gray', 18),
(5672, 'Dichasianthus', NULL, 'Ovcz. & Yunusov', 197),
(5673, 'Dichazothece', NULL, 'Lindau', 1),
(5674, 'Dichilanthe', NULL, 'Thwaites', 142),
(5675, 'Dichiloboea', NULL, 'Stapf', 76),
(5676, 'Dichilus', NULL, 'DC.', 68),
(5677, 'Dicholactina', NULL, 'Hance', 184),
(5678, 'Dichondra', NULL, 'J.R.Forst. & G.Forst.', 46),
(5679, 'Dichondropsis', NULL, 'Brandegee', 46),
(5680, 'Dichopetalum', NULL, 'F.Muell.(SUH)', 9),
(5681, 'Dichopsis', NULL, 'Thwaites', 148),
(5682, 'Dichorexia', NULL, 'C.Presl', 52),
(5683, 'Dichosciadium', NULL, 'Domin', 9),
(5684, 'Dichostylis', NULL, 'P.Beauv.', 55),
(5685, 'Dichotomanthes', NULL, 'Kurz', 141),
(5686, 'Dichrocephala', NULL, 'L''Her. ex DC.', 18),
(5687, 'Dichromena', NULL, 'Michx.', 55),
(5688, 'Dichromochlamys', NULL, 'Dunlop', 18),
(5689, 'Dichrophyllum', NULL, 'Klotzsch & Garcke', 66),
(5690, 'Dichrospermum', NULL, 'Bremek.', 142),
(5691, 'Dichrostachys', NULL, '(A.DC.) Wight & Arn.', 68),
(5692, 'Dichrotrichum', NULL, 'Reinw. ex de Vriese', 76),
(5693, 'Dichylium', NULL, 'Britton', 66),
(5694, 'Dichynchosia', NULL, 'Mull.Berol.(SUO)', 50),
(5695, 'Dickinsia', NULL, 'Franch.', 9),
(5696, 'Dicladanthera', NULL, 'F.Muell.', 1),
(5697, 'Diclemia', NULL, 'Naudin', 105),
(5698, 'Diclidanthera', NULL, 'Mart.', 133),
(5699, 'Diclidostigma', NULL, 'Kunze', 49),
(5700, 'Diclinanona', NULL, 'Diels', 8),
(5701, 'Dicliptera', NULL, 'Juss.', 1),
(5702, 'Diclis', NULL, 'Benth.', 150),
(5703, 'Dicoelia', NULL, 'Benth.', 66),
(5704, 'Dicoelospermum', NULL, 'C.B.Clarke', 49),
(5705, 'Dicoma', NULL, 'Cass.', 18),
(5706, 'Dicoria', NULL, 'Torr. & A.Gray', 18),
(5707, 'Dicorynia', NULL, 'Benth.', 68),
(5708, 'Dicraeopetalum', NULL, 'Harms', 68),
(5709, 'Dicranacanthus', NULL, 'Oerst.', 1),
(5710, 'Dicranocarpus', NULL, 'A.Gray', 18),
(5711, 'Dicranophlebia', NULL, '(Mart.) Lindl.', 52),
(5712, 'Dicranopygium', NULL, 'Harling', 54),
(5713, 'Dicranostachys', NULL, 'Trecul', 171),
(5714, 'Dicranostigma', NULL, 'Hook.f. & Thomson', 126),
(5715, 'Dicranostyles', NULL, 'Benth.', 46),
(5716, 'Dicraspidia', NULL, 'Standl.', 524),
(5717, 'Dicrastylis', NULL, 'J.L.Drumm. ex Harv.', 90),
(5718, 'Dicraurus', NULL, 'Hook.f.', 5),
(5719, 'Dicrobotryum', NULL, 'Willd. ex Roem. & Schult.', 142),
(5720, 'Dicrosperma', NULL, 'H.Wendl. & Drude ex W.Watson', 15),
(5721, 'Dictamnus', NULL, 'L.', 143),
(5722, 'Dictyanthus', NULL, 'Decne.', 10),
(5723, 'Dictyocalyx', NULL, 'Hook.f.', 154),
(5724, 'Dictyocaryum', NULL, 'H.Wendl.', 15),
(5725, 'Dictyoloma', NULL, 'A.Juss.', 143),
(5726, 'Dictyophleba', NULL, 'Pierre', 10),
(5727, 'Dictyophragmus', NULL, 'O.E.Schulz', 197),
(5728, 'Dictyosperma', NULL, 'H.Wendl. & Drude', 15),
(5729, 'Dictyospora', NULL, 'Hook.f.', 142),
(5730, 'Dicyclophora', NULL, 'Boiss.', 9),
(5731, 'Dicymanthes', NULL, 'Danser', 98),
(5732, 'Dicymbe', NULL, 'Spruce ex Benth.', 68),
(5733, 'Dicymbopsis', NULL, 'Ducke', 68),
(5734, 'Dicypellium', NULL, 'Nees & Mart.', 91),
(5735, 'Dicyrta', NULL, 'Regel', 76),
(5736, 'Didelotia', NULL, 'Baill.', 68),
(5737, 'Didelta', NULL, 'L''Her.', 18),
(5738, 'Diderotia', NULL, 'Baill.', 66),
(5739, 'Didesmandra', NULL, 'Stapf', 58),
(5740, 'Didesmus', NULL, 'Desv.', 197),
(5741, 'Didiplis', NULL, 'Raf.', 99),
(5742, 'Didissandra', NULL, 'C.B.Clarke', 76),
(5743, 'Didonica', NULL, 'Luteyn & Wilbur', 64),
(5744, 'Didymaea', NULL, 'Hook.f.', 142),
(5745, 'Didymanthus', NULL, 'Endl.', 5),
(5746, 'Didymiandrum', NULL, 'Gilly', 55),
(5747, 'Didymocarpus', NULL, 'Wall.', 76),
(5748, 'Didymocheton', NULL, 'Blume', 106),
(5749, 'Didymochlamys', NULL, 'Hook.f.', 142),
(5750, 'Didymocistus', NULL, 'Kuhlm.', 184),
(5751, 'Didymocolpus', NULL, 'S.C.Chen', 172),
(5752, 'Didymodoxa', NULL, 'E.Mey. ex Wedd.', 171),
(5753, 'Didymoecium', NULL, 'Bremek.', 142),
(5754, 'Didymopelta', NULL, 'Regel & Schmalh.', 68),
(5755, 'Didymophysa', NULL, 'Boiss.', 197),
(5756, 'Didymopogon', NULL, 'Bremek.', 142),
(5757, 'Didymosperma', NULL, 'H.Wendl. & Drude ex Hook.f.', 15),
(5758, 'Didyplosandra', NULL, 'Wight ex Bremek.', 1),
(5759, 'Dieffenbachia', NULL, 'Schott', 12),
(5760, 'Dielitzia', NULL, 'P.S.Short', 18),
(5761, 'Dielsantha', NULL, 'E.Wimm.', 30),
(5762, 'Dielsina', NULL, 'Kuntze', 8),
(5763, 'Dielsiocharis', NULL, 'O.E.Schulz', 197),
(5764, 'Dielsiothamnus', NULL, 'R.E.Fr.', 8),
(5765, 'Diemenia', NULL, 'Korth.', 40),
(5766, 'Dierbachia', NULL, 'Spreng.', 154),
(5767, 'Diervilla', NULL, 'Mill.', 513),
(5768, 'Dieterlea', NULL, 'Lott', 49),
(5769, 'Dieudonnaea', NULL, 'Cogn.', 49),
(5770, 'Diflugossa', NULL, 'Bremek.', 1),
(5771, 'Digera', NULL, 'Forssk.', 5),
(5772, 'Digitacalia', NULL, 'Pippen', 18),
(5773, 'Digitalis', NULL, 'L.', 423),
(5774, 'Diglossophyllum', NULL, 'H.Wendl. ex Salomon', 15),
(5775, 'Digomphia', NULL, 'Benth.', 22),
(5776, 'Digoniopterys', NULL, 'Arenes', 101),
(5777, 'Diholcos', NULL, 'Rydb.', 68),
(5778, 'Dillonia', NULL, 'Sacleux', 38),
(5779, 'Dillwynia', NULL, 'Sm.', 68),
(5780, 'Dilobeia', NULL, 'Thouars', 135),
(5781, 'Dilophia', NULL, 'Thomson', 197),
(5782, 'Dimanisa', NULL, 'Raf.', 1),
(5783, 'Dimeresia', NULL, 'A.Gray', 18),
(5784, 'Dimerocarpus', NULL, 'Gagnep.', 109),
(5785, 'Dimerodisus', NULL, 'Gagnep.', 46),
(5786, 'Dimerostemma', NULL, 'Cass.', 18),
(5787, 'Dimetia', NULL, '(Wight & Arn.) Meisn.', 142),
(5788, 'Dimetra', NULL, 'Kerr', 120),
(5789, 'Dimitria', NULL, 'Ravenna', 197),
(5790, 'Dimorphandra', NULL, 'Schott', 68),
(5791, 'Dimorphanthera', NULL, '(Drude) J.J.Sm.', 64),
(5792, 'Dimorphocarpa', NULL, 'Rollins', 197),
(5793, 'Dimorphocladium', NULL, 'Britton', 184),
(5794, 'Dimorphoclamys', NULL, 'Hook.f.', 49),
(5795, 'Dimorphocoma', NULL, 'F.Muell. & Tate', 18),
(5796, 'Dimorphosciadium', NULL, 'Pimenov', 9),
(5797, 'Dimorphostemon', NULL, 'Kitag.', 197),
(5798, 'Dimorphotheca', NULL, 'Moench', 18),
(5799, 'Dinacria', NULL, 'Haw.', 48),
(5800, 'Dinemagonum', NULL, 'A.Juss.', 101),
(5801, 'Dinemandra', NULL, 'A.Juss.', 101),
(5802, 'Dinetopsis', NULL, 'Roberty', 46),
(5803, 'Dinizia', NULL, 'Ducke', 68),
(5804, 'Dinklagea', NULL, 'Gilg', 45),
(5805, 'Dinklageodoxa', NULL, 'Heine & Sandwith', 22),
(5806, 'Dinocanthium', NULL, 'Bremek.', 142),
(5807, 'Dinoseris', NULL, 'Griseb.', 18),
(5808, 'Dintera', NULL, 'Stapf', 423),
(5809, 'Dinteracanthus', NULL, 'C.B.Clarke ex Schinz', 1),
(5810, 'Dioclea', NULL, 'Kunth', 71),
(5811, 'Diodella', NULL, 'Small', 142),
(5812, 'Diodia', NULL, 'L.', 142),
(5813, 'Diodioides', NULL, 'Loefl.', 142),
(5814, 'Diodois', NULL, 'Pohl(SUI)', 142),
(5815, 'Diodontium', NULL, 'F.Muell.', 18),
(5816, 'Diodosperma', NULL, 'H.Wendl.', 15),
(5817, 'Dioecrescis', NULL, 'Tirveng.', 142),
(5818, 'Diogenesia', NULL, 'Sleumer', 64),
(5819, 'Dioicodendron', NULL, 'Steyerm.', 142),
(5820, 'Diolena', NULL, 'Naudin', 105),
(5821, 'Diomma', NULL, 'Engl. ex Harms', 143),
(5822, 'Dioneiodon', NULL, 'Raf.', 142),
(5823, 'Dionycha', NULL, 'Naudin', 105),
(5824, 'Dionychastrum', NULL, 'A.Fern. & R.Fern.', 105),
(5825, 'Dionychia', NULL, 'Hook.f.(SUO)', 105),
(5826, 'Diopogon', NULL, 'Jord. & Fourr.', 48),
(5827, 'Dioscorea', NULL, 'L.', 59),
(5828, 'Dioscoreophyllum', NULL, 'Engl.', 107),
(5829, 'Diosma', NULL, 'L.', 143),
(5830, 'Diosphaera', NULL, 'Buser', 30),
(5831, 'Diostea', NULL, 'Miers', 173),
(5832, 'Diotacanthus', NULL, 'Benth.', 1),
(5833, 'Dioticarpus', NULL, 'Dunn', 60),
(5834, 'Diotocarpus', NULL, 'Hochst.', 142),
(5835, 'Diotocranus', NULL, 'Bremek.', 142),
(5836, 'Dipanax', NULL, 'Seem.', 13),
(5837, 'Dipelta', NULL, 'Maxim.', 521),
(5838, 'Dipetalanthus', NULL, 'A.Chev.', 68),
(5839, 'Diphaca', NULL, 'Lour.', 68),
(5840, 'Diphasia', NULL, 'Pierre', 143),
(5841, 'Diphasiopsis', NULL, 'Mendonca', 143),
(5842, 'Dipholis', NULL, 'A.DC.', 148),
(5843, 'Diphragmus', NULL, 'C.Presl', 142),
(5844, 'Diphyllarium', NULL, 'Gagnep.', 68),
(5845, 'Diplacrum', NULL, 'R.Br.', 55),
(5846, 'Diplacus', NULL, 'Nutt.', 150),
(5847, 'Dipladenia', NULL, 'A.DC.', 10),
(5848, 'Diplandra', NULL, 'Raf.(SUH)', 121),
(5849, 'Diplanthemum', NULL, 'K.Schum.', 102),
(5850, 'Diplanthera', NULL, 'Banks & Sol.', 22),
(5851, 'Diplarpea', NULL, 'Triana', 105),
(5852, 'Diplasia', NULL, 'Pers.', 55),
(5853, 'Diplaspis', NULL, 'Hook.f.', 9),
(5854, 'Diplatia', NULL, 'Tiegh.', 98),
(5855, 'Diplazoptilon', NULL, 'Y.Ling', 18),
(5856, 'Diplectria', NULL, '(Blume) Rchb.', 105),
(5857, 'Diplocarex', NULL, 'Hayata', 55),
(5858, 'Diplochlamys', NULL, 'Mull.Arg.', 66),
(5859, 'Diploclisia', NULL, 'Miers', 107),
(5860, 'Diplocos', NULL, 'Bureau', 109),
(5861, 'Diplocrater', NULL, 'Hook.f.', 142),
(5862, 'Diplocyatha', NULL, 'N.E.Br.', 10),
(5863, 'Diplocyathium', NULL, 'Heinr.Schmidt', 66),
(5864, 'Diplocyclos', NULL, '(Endl.) Post & Kuntze', 49),
(5865, 'Diplocyclus', NULL, 'Post & Kuntze(SUO)', 49),
(5866, 'Diplodon', NULL, 'Spreng.', 99),
(5867, 'Diplodonta', NULL, 'H.Karst.', 105),
(5868, 'Diplofatsia', NULL, 'Nakai', 13),
(5869, 'Diploglottis', NULL, 'Hook.f.', 147),
(5870, 'Diplokeleba', NULL, 'N.E.Br.', 147),
(5871, 'Diplolaena', NULL, 'R.Br.', 143),
(5872, 'Diplolegnon', NULL, 'Rusby', 76),
(5873, 'Diplolepis', NULL, 'R.Br.', 10),
(5874, 'Diplolophium', NULL, 'Turcz.', 9),
(5875, 'Diplomorpha', NULL, 'Griff.(SUH)', 184),
(5876, 'Diplopanax', NULL, 'Hand.-Mazz.', 47),
(5877, 'Diplopeltis', NULL, 'Endl.', 147),
(5878, 'Diplophractum', NULL, 'Desf.', 102),
(5879, 'Diplophragma', NULL, '(Wight & Arn.) Meisn.', 142),
(5880, 'Diplopilosa', NULL, 'Dvorak', 197),
(5881, 'Diploptera', NULL, 'C.A.Gardner', 135),
(5882, 'Diplopterys', NULL, 'A.Juss.', 101),
(5883, 'Diplorhynchus', NULL, 'Welw. ex Ficalho & Hiern', 10),
(5884, 'Diplosporopsis', NULL, 'Wernham', 142),
(5885, 'Diplostephium', NULL, 'Kunth', 18),
(5886, 'Diplostigma', NULL, 'K.Schum.', 10),
(5887, 'Diplostylis', NULL, 'Sond.', 66),
(5888, 'Diplotaenia', NULL, 'Boiss.', 9),
(5889, 'Diplotaxis', NULL, 'DC.', 197),
(5890, 'Diplothemium', NULL, 'Mart.', 15),
(5891, 'Diplothorax', NULL, 'Gagnep.', 109),
(5892, 'Diplousodon', NULL, 'Meisn.(SUO)', 99),
(5893, 'Diplukion', NULL, 'Raf.', 154),
(5894, 'Diplusodon', NULL, 'Pohl', 99),
(5895, 'Diplycosia', NULL, 'Blume', 64),
(5896, 'Dipodophyllum', NULL, 'Tiegh.', 98),
(5897, 'Dipoma', NULL, 'Franch.', 197),
(5898, 'Diporidium', NULL, 'H.L.Wendl.', 118),
(5899, 'Diposis', NULL, 'DC.', 9),
(5900, 'Dipteracanthus', NULL, 'Nees', 1),
(5901, 'Dipteranthemum', NULL, 'F.Muell.', 5),
(5902, 'Dipterocome', NULL, 'Fisch. & C.A.Mey.', 18),
(5903, 'Dipterocypsela', NULL, 'S.F.Blake', 18),
(5904, 'Dipterodendron', NULL, 'Radlk.', 147),
(5905, 'Dipteronia', NULL, 'Oliv.', 147),
(5906, 'Dipteropeltis', NULL, 'Hallier f.', 46),
(5907, 'Dipterosperma', NULL, 'Hassk.', 22),
(5908, 'Dipterygium', NULL, 'Decne.', 32),
(5909, 'Diptychandra', NULL, 'Tul.', 68),
(5910, 'Diptychocarpus', NULL, 'Trautv.', 197),
(5911, 'Dipyrena', NULL, 'Hook.', 173),
(5912, 'Dirca', NULL, 'L.', 164),
(5913, 'Dircaea', NULL, 'Decne.', 76),
(5914, 'Dirhamphis', NULL, 'Krapov.', 102),
(5915, 'Dirhynchosia', NULL, 'Blume', 50),
(5916, 'Dirichletia', NULL, 'Klotzsch', 142),
(5917, 'Disaccanthus', NULL, 'Greene', 197),
(5918, 'Disaster', NULL, 'Gilli', 139),
(5919, 'Discalyxia', NULL, 'Markgr.', 10),
(5920, 'Discanthera', NULL, 'Torr. & A.Gray', 49),
(5921, 'Discaria', NULL, 'Hook.', 139),
(5922, 'Dischidanthus', NULL, 'Tsiang', 10),
(5923, 'Dischidia', NULL, 'R.Br.', 10),
(5924, 'Dischidiopsis', NULL, 'Schltr.', 10),
(5925, 'Dischisma', NULL, 'Choisy', 150),
(5926, 'Dischistocalyx', NULL, 'T.Anderson ex Benth.', 1),
(5927, 'Disciphania', NULL, 'Eichler', 107),
(5928, 'Discipiper', NULL, 'Trel. & Stehle', 130),
(5929, 'Discocapnos', NULL, 'Cham. & Schltdl.', 126),
(5930, 'Discocarpus', NULL, 'Klotzsch', 184),
(5931, 'Discocleidion', NULL, '(Mull.Arg.) Pax & K.Hoffm.', 66),
(5932, 'Discocnide', NULL, 'Chew', 171),
(5933, 'Discocoffea', NULL, 'A.Chev.', 142),
(5934, 'Discolobium', NULL, 'Benth.', 68),
(5935, 'Discoluma', NULL, 'Baill.', 148),
(5936, 'Discoma', NULL, 'O.F.Cook', 15),
(5937, 'Discophis', NULL, 'Raf.', 66),
(5938, 'Discopleura', NULL, 'DC.', 9),
(5939, 'Discoplis', NULL, 'Raf.', 66),
(5940, 'Discopodium', NULL, 'Hochst.', 154),
(5941, 'Discovium', NULL, 'Raf.', 197),
(5942, 'Diselma', NULL, 'Hook.f.', 51),
(5943, 'Disemma', NULL, 'Labill.', 127),
(5944, 'Disepalum', NULL, 'Hook.f.', 8),
(5945, 'Diskion', NULL, 'Raf.', 154),
(5946, 'Disodea', NULL, 'Pers.', 142),
(5947, 'Disparago', NULL, 'Gaertn.', 18),
(5948, 'Disperma', NULL, 'J.F.Gmel.(SUH)', 1),
(5949, 'Disphenia', NULL, 'C.Presl', 52),
(5950, 'Dissiliaria', NULL, 'F.Muell.', 534),
(5951, 'Dissocarpus', NULL, 'F.Muell.', 5),
(5952, 'Dissochaeta', NULL, 'Blume', 105),
(5953, 'Dissomeria', NULL, 'Hook.f. ex Benth.', 145),
(5954, 'Dissosperma', NULL, 'Sojak', 126),
(5955, 'Dissothrix', NULL, 'A.Gray', 18),
(5956, 'Dissotis', NULL, 'Benth.', 105),
(5957, 'Distemon', NULL, 'Wedd.(SUH)', 171),
(5958, 'Distemonanthus', NULL, 'Benth.', 68),
(5959, 'Distephania', NULL, 'Gagnep.', 118),
(5960, 'Distephanus', NULL, '(Cass.) Cass.', 18),
(5961, 'Disterigma', NULL, '(Klotzsch) Nied.', 64),
(5962, 'Distichella', NULL, 'Tiegh.', 146),
(5963, 'Distichocalyx', NULL, 'Benth.(SUO)', 1),
(5964, 'Distichoselinum', NULL, 'Garcia-Martin & Silvestre', 9),
(5965, 'Distichostemon', NULL, 'F.Muell.', 147),
(5966, 'Distictella', NULL, 'Kuntze', 22),
(5967, 'Distictis', NULL, 'Bureau(SUH)', 22),
(5968, 'Distoecha', NULL, 'Phil.', 18),
(5969, 'Distomocarpus', NULL, 'O.E.Schulz', 197),
(5970, 'Distrianthes', NULL, 'Danser', 98),
(5971, 'Disynaphia', NULL, 'Hook. & Arn. ex DC.', 18),
(5972, 'Disynstemon', NULL, 'R.Vig.', 68),
(5973, 'Ditassa', NULL, 'R.Br.', 10);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(5974, 'Ditaxis', NULL, 'Vahl ex A.Juss.', 66),
(5975, 'Dithecina', NULL, 'Tiegh.', 98),
(5976, 'Dithecoluma', NULL, 'Baill.', 148),
(5977, 'Dithyrea', NULL, 'Harv.', 197),
(5978, 'Dithyrostegia', NULL, 'A.Gray', 18),
(5979, 'Ditmaria', NULL, 'Spreng.(SUH)', 175),
(5980, 'Ditrichospermum', NULL, 'Bremek.', 1),
(5981, 'Ditritra', NULL, 'Raf.', 66),
(5982, 'Ditrysinia', NULL, 'Raf.', 66),
(5983, 'Dittoceras', NULL, 'Hook.f.', 10),
(5984, 'Dittostigma', NULL, 'Phil.', 154),
(5985, 'Dittrichia', NULL, 'Greuter', 18),
(5986, 'Diyaminauclea', NULL, 'Ridsdale', 142),
(5987, 'Dizygostemon', NULL, '(Benth.) Radlk. ex Wettst.', 423),
(5988, 'Dizygotheca', NULL, 'N.E.Br.', 13),
(5989, 'Djaloniella', NULL, 'P.Taylor', 75),
(5990, 'Dobinea', NULL, 'Buch.-Ham. ex D.Don', 6),
(5991, 'Docanthe', NULL, 'O.F.Cook(SUI)', 15),
(5992, 'Docynia', NULL, 'Decne.', 141),
(5993, 'Dodartia', NULL, 'L.', 417),
(5994, 'Dodecadenia', NULL, 'Nees', 91),
(5995, 'Dodecahema', NULL, 'Reveal & Hardham', 134),
(5996, 'Dodecas', NULL, 'L.f.', 99),
(5997, 'Dodecastemon', NULL, 'Hassk.', 66),
(5998, 'Dodecastigma', NULL, 'Ducke', 66),
(5999, 'Dodonaea', NULL, 'Mill.', 147),
(6000, 'Doerpfeldia', NULL, 'Urb.', 139),
(6001, 'Doga', NULL, '(Baill.) Baill. ex Nakai', 68),
(6002, 'Dolia', NULL, 'Lindl.', 154),
(6003, 'Dolianthus', NULL, 'C.H.Wright', 142),
(6004, 'Dolichandra', NULL, 'Cham.', 22),
(6005, 'Dolichandrone', NULL, '(Fenzl) Seem.', 22),
(6006, 'Dolichanthera', NULL, 'Schltr. & K.Krause', 142),
(6007, 'Dolichlasium', NULL, 'Lag.', 18),
(6008, 'Dolichodelphys', NULL, 'K.Schum. & K.Krause', 142),
(6009, 'Dolichodiera', NULL, 'Hanst.', 76),
(6010, 'Dolichoglottis', NULL, 'B.Nord.', 18),
(6011, 'Dolichokentia', NULL, 'Becc.', 15),
(6012, 'Dolicholobium', NULL, 'A.Gray', 142),
(6013, 'Dolicholoma', NULL, 'D.Fang & W.T.Wang', 76),
(6014, 'Dolicholus', NULL, 'Medik.', 68),
(6015, 'Dolichometra', NULL, 'K.Schum.', 142),
(6016, 'Dolichopsis', NULL, 'Hassl.', 68),
(6017, 'Dolichopterys', NULL, 'Kosterm.', 101),
(6018, 'Dolichorhynchus', NULL, 'Hedge & Kit Tan', 197),
(6019, 'Dolichorrhiza', NULL, '(Pojark.) Galushko', 18),
(6020, 'Dolichos', NULL, 'L.', 68),
(6021, 'Dolichosiphon', NULL, 'Phil.', 154),
(6022, 'Dolichostegia', NULL, 'Schltr.', 10),
(6023, 'Dolichostigma', NULL, 'Miers', 154),
(6024, 'Dolichostylis', NULL, 'Turcz.', 197),
(6025, 'Dolichothrix', NULL, 'Hilliard & B.L.Burtt', 18),
(6026, 'Dolichoura', NULL, 'Brade', 105),
(6027, 'Dolichovigna', NULL, 'Hayata', 68),
(6028, 'Doliocarpus', NULL, 'Rol.', 58),
(6029, 'Dollinera', NULL, 'Endl.', 68),
(6030, 'Dolomiaea', NULL, 'DC.', 18),
(6031, 'Dolosanthus', NULL, 'Klatt', 18),
(6032, 'Doma', NULL, 'Poir.', 15),
(6033, 'Dombeya', NULL, 'Cav.', 102),
(6034, 'Domeykoa', NULL, 'Phil.', 9),
(6035, 'Dominella', NULL, 'E.Wimm.', 30),
(6036, 'Dominia', NULL, 'Fedde', 9),
(6037, 'Domkeocarpa', NULL, 'Markgr.', 10),
(6038, 'Domohinea', NULL, 'Leandri', 66),
(6039, 'Donax', NULL, 'Lour.', 103),
(6040, 'Dondia', NULL, 'Adans.', 5),
(6041, 'Dondisia', NULL, 'DC.', 142),
(6042, 'Donella', NULL, 'Pierre ex Baill.', 148),
(6043, 'Doniophyton', NULL, 'Wedd.', 18),
(6044, 'Donkelaaria', NULL, 'Lem.', 142),
(6045, 'Donnellsmithia', NULL, 'J.M.Coult. & Rose', 9),
(6046, 'Dontostemon', NULL, 'Andrz. ex C.A.Mey.', 197),
(6047, 'Doona', NULL, 'Thwaites', 60),
(6048, 'Dopatrium', NULL, 'Buch.-Ham.', 423),
(6049, 'Doratolepis', NULL, 'Schltdl.', 18),
(6050, 'Doratoxylon', NULL, 'Thouars ex Hook.f.', 147),
(6051, 'Dorcoceras', NULL, 'Bunge', 76),
(6052, 'Dorema', NULL, 'D.Don', 9),
(6053, 'Doricera', NULL, 'Verdc.', 142),
(6054, 'Dorisia', NULL, 'Gillespie', 142),
(6055, 'Dorobaea', NULL, 'Cass.', 18),
(6056, 'Doronicum', NULL, 'L.', 18),
(6057, 'Dorothea', NULL, 'Wernham', 142),
(6058, 'Dorycnium', NULL, 'Mill.', 68),
(6059, 'Dorycnopsis', NULL, 'Boiss.', 68),
(6060, 'Doryphora', NULL, 'Endl.', 505),
(6061, 'Dorystaechas', NULL, 'Boiss. & Heldr. ex Benth.', 90),
(6062, 'Dorystephania', NULL, 'Warb.', 10),
(6063, 'Doryxylon', NULL, 'Zoll.', 66),
(6064, 'Dossifluga', NULL, 'Bremek.', 1),
(6065, 'Douarrea', NULL, 'Montrouz.', 142),
(6066, 'Douepea', NULL, 'Cambess.', 197),
(6067, 'Douma', NULL, 'Poir.', 15),
(6068, 'Douradoa', NULL, 'Sleumer', 119),
(6069, 'Downingia', NULL, 'Torr.', 30),
(6070, 'Doxantha', NULL, 'Miers', 22),
(6071, 'Doyerea', NULL, 'Grosourdy', 49),
(6072, 'Draba', NULL, 'L.', 197),
(6073, 'Drabastrum', NULL, '(F.Muell.) O.E.Schulz', 197),
(6074, 'Drabella', NULL, 'Nabelek(SUH)', 197),
(6075, 'Drabopsis', NULL, 'K.Koch', 197),
(6076, 'Dracamine', NULL, 'Nieuwl.', 197),
(6077, 'Dracocephalum', NULL, 'L.', 90),
(6078, 'Dracontioides', NULL, 'Engl.', 12),
(6079, 'Dracophyllum', NULL, 'Labill.', 64),
(6080, 'Dracopsis', NULL, 'Cass.', 18),
(6081, 'Dracosciadium', NULL, 'Hilliard & B.L.Burtt', 9),
(6082, 'Dracunculus', NULL, 'Mill.', 12),
(6083, 'Drakebrockmania', NULL, 'A.C.White & B.Sloane', 10),
(6084, 'Draparnaudia', NULL, 'Montrouz.', 116),
(6085, 'Draperia', NULL, 'Torr.', 25),
(6086, 'Drapetes', NULL, 'Banks ex Lam.', 164),
(6087, 'Drebbelia', NULL, 'Zoll.', 119),
(6088, 'Dregea', NULL, 'E.Mey.', 10),
(6089, 'Drejerella', NULL, 'Lindau', 1),
(6090, 'Drepadenium', NULL, 'Raf.', 66),
(6091, 'Drepananthus', NULL, 'Maingay ex Hook.f.', 8),
(6092, 'Drepanocarpus', NULL, 'G.Mey.', 68),
(6093, 'Drepanocaryum', NULL, 'Pojark.', 90),
(6094, 'Drepanostemma', NULL, 'Jum. & H.Perrier', 10),
(6095, 'Dressleriopsis', NULL, 'Dwyer', 142),
(6096, 'Dresslerothamnus', NULL, 'H.Rob.', 18),
(6097, 'Driessenia', NULL, 'Korth.', 105),
(6098, 'Drimys', NULL, 'J.R.Forst. & G.Forst.', 176),
(6099, 'Droceloncia', NULL, 'J.Leonard', 66),
(6100, 'Droguetia', NULL, 'Gaudich.', 171),
(6101, 'Droogmansia', NULL, 'De Wild.', 68),
(6102, 'Drosodendron', NULL, 'Roem.', 116),
(6103, 'Drudeophytum', NULL, 'J.M.Coult. & Rose', 9),
(6104, 'Drummondia', NULL, 'DC.', 149),
(6105, 'Drummondita', NULL, 'Harv.', 143),
(6106, 'Druparia', NULL, 'Silva Manso', 49),
(6107, 'Drusa', NULL, 'DC.', 9),
(6108, 'Dryadanthe', NULL, 'Endl.', 141),
(6109, 'Dryadodaphne', NULL, 'S.Moore', 505),
(6110, 'Dryandra', NULL, 'R.Br.', 135),
(6111, 'Dryas', NULL, 'L.', 141),
(6112, 'Drymocallis', NULL, 'Fourr. ex Rydb.', 141),
(6113, 'Drymonia', NULL, 'Mart.', 76),
(6114, 'Drymophloeus', NULL, 'Zipp.', 15),
(6115, 'Dryopetalon', NULL, 'A.Gray', 197),
(6116, 'Dryparia', NULL, 'Post & Kuntze(SUO)', 49),
(6117, 'Duania', NULL, 'Noronha', 66),
(6118, 'Dubardella', NULL, 'H.J.Lam', 162),
(6119, 'Dubautia', NULL, 'Gaudich.', 18),
(6120, 'Dubouzetia', NULL, 'Pancher ex Brongn. & Gris', 62),
(6121, 'Dubyaea', NULL, 'DC.', 18),
(6122, 'Duchassaingia', NULL, 'Walp.', 68),
(6123, 'Duchesnea', NULL, 'Sm.', 141),
(6124, 'Duchola', NULL, 'Adans.', 66),
(6125, 'Duckeanthus', NULL, 'R.E.Fr.', 8),
(6126, 'Duckeodendron', NULL, 'Kuhlm.', 154),
(6127, 'Duckera', NULL, 'F.A.Barkley(SUS)', 6),
(6128, 'Duckesia', NULL, 'Cuatrec.', 83),
(6129, 'Ducrosia', NULL, 'Boiss.', 9),
(6130, 'Dudleya', NULL, 'Britton & Rose', 48),
(6131, 'Dufrenoya', NULL, 'Chatin', 146),
(6132, 'Dugaldia', NULL, '(Cass.) Cass.', 18),
(6133, 'Dugandiodendron', NULL, 'Lozano', 100),
(6134, 'Dugesia', NULL, 'A.Gray', 18),
(6135, 'Duggena', NULL, 'Vahl(SUI)', 142),
(6136, 'Dugortia', NULL, 'Scop.', 40),
(6137, 'Duhaldea', NULL, 'DC.', 18),
(6138, 'Duhamelia', NULL, 'Pers.', 142),
(6139, 'Duidaea', NULL, 'S.F.Blake', 18),
(6140, 'Duidania', NULL, 'Standl.', 142),
(6141, 'Dukea', NULL, 'Dwyer', 142),
(6142, 'Dulcamara', NULL, 'Moench', 154),
(6143, 'Dulichium', NULL, 'Pers.', 55),
(6144, 'Dumartroya', NULL, 'Gaudich.', 109),
(6145, 'Dumasia', NULL, 'DC.', 68),
(6146, 'Dumoria', NULL, 'A.Chev.', 148),
(6147, 'Dunalia', NULL, 'Spreng.(SUH)', 154),
(6148, 'Dunbaria', NULL, 'Wight & Arn.', 68),
(6149, 'Dunnia', NULL, 'Tutcher', 142),
(6150, 'Dunniella', NULL, 'Rauschert(SUS)', 171),
(6151, 'Duosperma', NULL, 'Dayton', 1),
(6152, 'Duparquetia', NULL, 'Baill.', 68),
(6153, 'Duperrea', NULL, 'Pierre ex Pit.', 142),
(6154, 'Dupineta', NULL, 'Raf.', 105),
(6155, 'Dupinia', NULL, 'Scop.', 162),
(6156, 'Durandea', NULL, 'Planch.', 95),
(6157, 'Durandeeldia', NULL, 'Kuntze', 66),
(6158, 'Duranta', NULL, 'L.', 173),
(6159, 'Duravia', NULL, '(S.Watson) Greene', 134),
(6160, 'Duriala', NULL, '(R.H.Anderson) Ulbr.', 5),
(6161, 'Durringtonia', NULL, 'R.J.F.Hend. & Guymer', 142),
(6162, 'Duseniella', NULL, 'K.Schum.', 18),
(6163, 'Dutaillyea', NULL, 'Baill.', 143),
(6164, 'Duvalia', NULL, 'Haw.', 10),
(6165, 'Duvaliandra', NULL, 'M.G.Gilbert', 10),
(6166, 'Duvaliella', NULL, 'F.Heim', 60),
(6167, 'Duvaua', NULL, 'Kunth', 6),
(6168, 'Duvaucellia', NULL, 'Bowdich', 142),
(6169, 'Duvernoia', NULL, 'E.Mey. ex Nees', 1),
(6170, 'Duvigneaudia', NULL, 'J.Leonard', 66),
(6171, 'Dychotria', NULL, 'Raf.', 142),
(6172, 'Dyctiospora', NULL, 'Reinw. ex Korth.', 142),
(6173, 'Dymondia', NULL, 'Compton', 18),
(6174, 'Dypsidium', NULL, 'Baill.', 15),
(6175, 'Dypsis', NULL, 'Noronha ex Mart.', 15),
(6176, 'Dyschoriste', NULL, 'Nees', 1),
(6177, 'Dyscritogyne', NULL, 'R.M.King & H.Rob.', 18),
(6178, 'Dyscritothamnus', NULL, 'B.L.Rob.', 18),
(6179, 'Dysoda', NULL, 'Lour.', 142),
(6180, 'Dysodidendron', NULL, 'Gardner', 142),
(6181, 'Dysodiopsis', NULL, '(A.Gray) Rydb.', 18),
(6182, 'Dysolobium', NULL, '(Benth.) Prain', 68),
(6183, 'Dysophylla', NULL, 'Blume', 90),
(6184, 'Dysopsis', NULL, 'Baill.', 66),
(6185, 'Dysosmia', NULL, 'Miq.', 142),
(6186, 'Dyspemptemorion', NULL, 'Bremek.', 1),
(6187, 'Dysphania', NULL, 'R.Br.', 5),
(6188, 'Dyssochroma', NULL, 'Miers', 154),
(6189, 'Dyssodia', NULL, 'Cav.', 18),
(6190, 'Dystaenia', NULL, 'Kitag.', 9),
(6191, 'Eadesia', NULL, 'F.Muell.', 154),
(6192, 'Earleocassia', NULL, 'Britton', 68),
(6193, 'Eastwoodia', NULL, 'Brandegee', 18),
(6194, 'Eatonella', NULL, 'A.Gray', 18),
(6195, 'Eatoniopteris', NULL, 'J.Bommer', 52),
(6196, 'Ebandoua', NULL, 'Pellegr.', 45),
(6197, 'Ebelia', NULL, 'Rchb.', 142),
(6198, 'Ebenopsis', NULL, 'Britton & Rose', 68),
(6199, 'Ebenus', NULL, 'L.', 68),
(6200, 'Eberhardtia', NULL, 'Lecomte', 148),
(6201, 'Ebermaiera', NULL, 'Nees', 1),
(6202, 'Eburopetalum', NULL, 'Becc.', 8),
(6203, 'Ecastaphyllum', NULL, 'P.Browne', 68),
(6204, 'Ecballium', NULL, 'A.Rich.', 49),
(6205, 'Ecbolium', NULL, 'Kurz', 1),
(6206, 'Eccremocarpus', NULL, 'Ruiz & Pav.', 22),
(6207, 'Ecdysanthera', NULL, 'Hook. & Arn.', 10),
(6208, 'Echeandia', NULL, 'Ortega', 3),
(6209, 'Echeveria', NULL, 'DC.', 48),
(6210, 'Echidnium', NULL, 'Schott', 12),
(6211, 'Echidnopsis', NULL, 'Hook.f.', 10),
(6212, 'Echinacanthus', NULL, 'Nees', 1),
(6213, 'Echinacea', NULL, 'Moench', 18),
(6214, 'Echinocalyx', NULL, 'Benth.', 68),
(6215, 'Echinocarpus', NULL, 'Blume', 62),
(6216, 'Echinocassia', NULL, 'Britton & Rose', 68),
(6217, 'Echinocitrus', NULL, 'Tanaka', 143),
(6218, 'Echinocodon', NULL, 'D.Y.Hong', 30),
(6219, 'Echinocoryne', NULL, 'H.Rob.', 18),
(6220, 'Echinocroton', NULL, 'F.Muell.', 66),
(6221, 'Echinocystis', NULL, 'Torr. & A.Gray', 49),
(6222, 'Echinodendrum', NULL, 'A.Rich.', 142),
(6223, 'Echinoglochin', NULL, '(A.Gray) Brand', 25),
(6224, 'Echinopaepale', NULL, 'Bremek.', 1),
(6225, 'Echinopanax', NULL, 'Decne. & Planch.', 13),
(6226, 'Echinopepon', NULL, 'Naudin', 49),
(6227, 'Echinophora', NULL, 'L.', 9),
(6228, 'Echinops', NULL, 'L.', 18),
(6229, 'Echinopsilon', NULL, 'Moq.', 5),
(6230, 'Echinopterys', NULL, 'A.Juss.', 101),
(6231, 'Echinosophora', NULL, 'Nakai', 68),
(6232, 'Echinospartum', NULL, '(Spach) Fourr.', 68),
(6233, 'Echinospermum', NULL, 'Sw. ex Lehm.', 25),
(6234, 'Echinosphaera', NULL, 'Sieber ex Steud.', 66),
(6235, 'Echinostephia', NULL, '(Diels) Domin', 107),
(6236, 'Echinothamnus', NULL, 'Engl.', 127),
(6237, 'Echiochilon', NULL, 'Desf.', 25),
(6238, 'Echiochilopsis', NULL, 'Caball.', 25),
(6239, 'Echioides', NULL, 'Ortega(SUH)', 25),
(6240, 'Echiopsis', NULL, 'Rchb.', 25),
(6241, 'Echiostachys', NULL, 'Levyns', 25),
(6242, 'Echites', NULL, 'P.Browne', 10),
(6243, 'Echium', NULL, 'L.', 25),
(6244, 'Ecklonea', NULL, 'Steud.', 55),
(6245, 'Eclipta', NULL, 'L.', 18),
(6246, 'Ecliptostelma', NULL, 'Brandegee', 10),
(6247, 'Ecpoma', NULL, 'K.Schum.', 142),
(6248, 'Ectadiopsis', NULL, 'Benth.', 10),
(6249, 'Ectadium', NULL, 'E.Mey.', 10),
(6250, 'Ecteinanthus', NULL, 'T.Anderson', 1),
(6251, 'Ectinocladus', NULL, 'Benth.', 10),
(6252, 'Ectopopterys', NULL, 'W.R.Anderson', 101),
(6253, 'Ectozoma', NULL, 'Miers', 154),
(6254, 'Edbakeria', NULL, 'R.Vig.', 68),
(6255, 'Eddya', NULL, 'Torr. & A.Gray', 25),
(6256, 'Edechi', NULL, 'Loefl.', 142),
(6257, 'Edgaria', NULL, 'C.B.Clarke', 49),
(6258, 'Edgeworthia', NULL, 'Meisn.', 164),
(6259, 'Edisonia', NULL, 'Small', 10),
(6260, 'Edithcolea', NULL, 'N.E.Br.', 10),
(6261, 'Edithea', NULL, 'Standl.', 142),
(6262, 'Edmondia', NULL, 'Cass.', 18),
(6263, 'Edraianthus', NULL, '(A.DC.) DC.', 30),
(6264, 'Edrastima', NULL, 'Raf.', 142),
(6265, 'Edwardsia', NULL, 'Salisb.', 68),
(6266, 'Efulensia', NULL, 'C.H.Wright', 127),
(6267, 'Eganthus', NULL, 'Tiegh.', 119),
(6268, 'Egleria', NULL, 'G.Eiten', 55),
(6269, 'Eglerodendron', NULL, 'Aubrev. & Pellegr.', 148),
(6270, 'Egletes', NULL, 'Cass.', 18),
(6271, 'Ehrenbergia', NULL, 'Spreng.', 142),
(6272, 'Eichlerago', NULL, 'Carrick', 90),
(6273, 'Eichleria', NULL, 'Progel', 45),
(6274, 'Eichlerina', NULL, 'Tiegh.', 98),
(6275, 'Eichlerodendron', NULL, 'Briq.', 145),
(6276, 'Eigia', NULL, 'Sojak', 197),
(6277, 'Einadia', NULL, 'Raf.', 5),
(6278, 'Einsteinia', NULL, 'Ducke', 142),
(6279, 'Eionitis', NULL, 'Bremek.', 142),
(6280, 'Eirmocephala', NULL, 'H.Rob.', 18),
(6281, 'Eisocreochiton', NULL, 'Quisumb. & Merr.', 105),
(6282, 'Eitenia', NULL, 'R.M.King & H.Rob.', 18),
(6283, 'Eizia', NULL, 'Standl.', 142),
(6284, 'Ekebergia', NULL, 'Sparrm.', 106),
(6285, 'Ekmania', NULL, 'Gleason', 18),
(6286, 'Ekmanianthe', NULL, 'Urb.', 22),
(6287, 'Ekmaniocharis', NULL, 'Urb.', 105),
(6288, 'Elachanthemum', NULL, 'Y.Ling & Y.R.Ling', 18),
(6289, 'Elachanthus', NULL, 'F.Muell.', 18),
(6290, 'Elachocroton', NULL, 'F.Muell.', 66),
(6291, 'Elacholoma', NULL, 'F.Muell. & Tate', 417),
(6292, 'Elachyptera', NULL, 'A.C.Sm.', 38),
(6293, 'Elaeococca', NULL, 'Comm. ex Juss.', 66),
(6294, 'Elaeodendron', NULL, 'J.Jacq.', 38),
(6295, 'Elaeophora', NULL, 'Ducke', 66),
(6296, 'Elaeopleurum', NULL, 'Korovin', 9),
(6297, 'Elaeoselinum', NULL, 'W.D.J.Koch ex DC.', 9),
(6298, 'Elaeosticta', NULL, 'Fenzl', 9),
(6299, 'Elaphandra', NULL, 'Strother', 18),
(6300, 'Elaphanthera', NULL, 'N.Halle', 146),
(6301, 'Elaphrium', NULL, 'Jacq.', 27),
(6302, 'Elaterioides', NULL, 'Kuntze', 66),
(6303, 'Elateriopsis', NULL, 'Ernst', 49),
(6304, 'Elaterispermum', NULL, 'Rchb.', 66),
(6305, 'Elaterium', NULL, 'Mill.', 49),
(6306, 'Elatinoides', NULL, '(Chav.) Wettst.', 150),
(6307, 'Elatostema', NULL, 'J.R.Forst. & G.Forst.', 171),
(6308, 'Elatostematoides', NULL, 'B.L.Rob.', 171),
(6309, 'Elattospermum', NULL, 'Soler.', 142),
(6310, 'Elattostachys', NULL, 'Radlk.', 147),
(6311, 'Elburzia', NULL, 'Hedge', 197),
(6312, 'Elcaja', NULL, 'Forssk.', 106),
(6313, 'Elcomarhiza', NULL, 'Barb.Rodr.', 10),
(6314, 'Eleiodoxa', NULL, '(Becc.) Burret', 15),
(6315, 'Eleiosina', NULL, 'Raf.', 141),
(6316, 'Eleiotis', NULL, 'DC.', 68),
(6317, 'Elengi', NULL, 'Adans.', 148),
(6318, 'Eleocharis', NULL, 'R.Br.', 55),
(6319, 'Eleogiton', NULL, 'Link(SUH)', 55),
(6320, 'Elephantomene', NULL, 'Barneby & Krukoff', 107),
(6321, 'Elephantopus', NULL, 'L.', 18),
(6322, 'Elephantorrhiza', NULL, 'Benth.', 68),
(6323, 'Elephantusia', NULL, 'Willd.', 15),
(6324, 'Eleutharrhena', NULL, 'Forman', 107),
(6325, 'Eleutherandra', NULL, 'Slooten', 198),
(6326, 'Eleutheranthera', NULL, 'Poit. ex Bosc', 18),
(6327, 'Eleutheranthus', NULL, 'K.Schum.(SUO)', 142),
(6328, 'Eleutherococcus', NULL, 'Maxim.', 13),
(6329, 'Eleutheropetalum', NULL, 'H.Wendl.', 15),
(6330, 'Eleutherospermum', NULL, 'K.Koch', 9),
(6331, 'Eleutherostemon', NULL, 'Herzog', 64),
(6332, 'Eleutherostigma', NULL, 'Pax & K.Hoffm.', 66),
(6333, 'Eleutherostylis', NULL, 'Burret', 102),
(6334, 'Eleuthranthes', NULL, 'F.Muell.', 142),
(6335, 'Eliaea', NULL, 'Cambess.(SUO)', 42),
(6336, 'Eliea', NULL, 'Cambess.', 42),
(6337, 'Eligmocarpus', NULL, 'Capuron', 68),
(6338, 'Elingamita', NULL, 'G.T.S.Baylis', 115),
(6339, 'Elisia', NULL, 'Milano', 154),
(6340, 'Elissarrhena', NULL, 'Miers', 107),
(6341, 'Elizabetha', NULL, 'R.H.Schomb. ex Benth.', 68),
(6342, 'Elizaldia', NULL, 'Willk.', 25),
(6343, 'Elleimataenia', NULL, 'Koso-Pol.', 9),
(6344, 'Ellenbergia', NULL, 'Cuatrec.', 18),
(6345, 'Ellertonia', NULL, 'Wight', 10),
(6346, 'Elliottia', NULL, 'Muhl. ex Elliott', 64),
(6347, 'Ellipeia', NULL, 'Hook.f. & Thomson', 8),
(6348, 'Ellipeiopsis', NULL, 'R.E.Fr.', 8),
(6349, 'Ellisia', NULL, 'L.', 25),
(6350, 'Ellisiophyllum', NULL, 'Maxim.', 150),
(6351, 'Ellobium', NULL, 'Lilja', 121),
(6352, 'Ellobum', NULL, 'Blume', 76),
(6353, 'Elmera', NULL, 'Rydb.', 149),
(6354, 'Elmerrillia', NULL, 'Dandy', 100),
(6355, 'Elsholtzia', NULL, 'Willd.', 90),
(6356, 'Eluteria', NULL, 'Steud.', 66),
(6357, 'Elutheria', NULL, 'M.Roem.(SUH)', 106),
(6358, 'Elvasia', NULL, 'DC.', 118),
(6359, 'Elvira', NULL, 'Cass.', 18),
(6360, 'Elyna', NULL, 'Schrad.', 55),
(6361, 'Elynanthus', NULL, 'Nees', 55),
(6362, 'Elytranthe', NULL, '(Blume) Blume', 98),
(6363, 'Elytraria', NULL, 'Michx.', 1),
(6364, 'Elytropappus', NULL, 'Cass.', 18),
(6365, 'Elytropus', NULL, 'Mull.Arg.', 10),
(6366, 'Embadium', NULL, 'J.M.Black', 25),
(6367, 'Embelia', NULL, 'Burm.f.', 115),
(6368, 'Embergeria', NULL, 'Boulos', 18),
(6369, 'Emblemantha', NULL, 'B.C.Stone', 115),
(6370, 'Embothrium', NULL, 'J.R.Forst. & G.Forst.', 135),
(6371, 'Embryogonia', NULL, 'Blume', 44),
(6372, 'Emelianthe', NULL, 'Danser', 98),
(6373, 'Emex', NULL, 'Neck. ex Campd.', 134),
(6374, 'Emicocarpus', NULL, 'K.Schum. & Schltr.', 10),
(6375, 'Emilia', NULL, '(Cass.) Cass.', 18),
(6376, 'Emiliella', NULL, 'S.Moore', 18),
(6377, 'Emiliomarcetia', NULL, 'T.Durand & H.Durand', 6),
(6378, 'Eminia', NULL, 'Taub.', 68),
(6379, 'Eminium', NULL, '(Blume) Schott', 12),
(6380, 'Emmenanthe', NULL, 'Benth.', 84),
(6381, 'Emmenopterys', NULL, 'Oliv.', 142),
(6382, 'Emmenopteryx', NULL, 'Dalla Torre & Harms(SUO)', 142),
(6383, 'Emmenosperma', NULL, 'F.Muell.', 139),
(6384, 'Emmeorhiza', NULL, 'Pohl ex Endl.', 142),
(6385, 'Emmotum', NULL, 'Desv. ex Ham.', 85),
(6386, 'Emorya', NULL, 'Torr.', 150),
(6387, 'Empedoclesia', NULL, 'Sleumer', 64),
(6388, 'Empetrum', NULL, 'L.', 64),
(6389, 'Emplectanthus', NULL, 'N.E.Br.', 10),
(6390, 'Emplectocladus', NULL, 'Torr.', 141),
(6391, 'Empleuridium', NULL, 'Sond. & Harv.', 143),
(6392, 'Empleurum', NULL, 'Aiton', 143),
(6393, 'Empogona', NULL, 'Hook.f.', 142),
(6394, 'Emularia', NULL, 'Raf.', 1),
(6395, 'Emurtia', NULL, 'Raf.', 116),
(6396, 'Enaimon', NULL, 'Raf.', 120),
(6397, 'Enallagma', NULL, '(Miers) Baill.', 22),
(6398, 'Enantia', NULL, 'Oliv.(SUH)', 8),
(6399, 'Enantiophylla', NULL, 'J.M.Coult. & Rose', 9),
(6400, 'Enantiosparton', NULL, 'K.Koch', 68),
(6401, 'Enarthrocarpus', NULL, 'Labill.', 197),
(6402, 'Enaulophyton', NULL, 'Steenis', 105),
(6403, 'Encelia', NULL, 'Adans.', 18),
(6404, 'Enceliopsis', NULL, '(A.Gray) A.Nelson', 18),
(6405, 'Encephalosphaera', NULL, 'Lindau', 1),
(6406, 'Enchidium', NULL, 'Jack', 66),
(6407, 'Enchosanthera', NULL, 'King & Stapf ex Guillaumin', 105),
(6408, 'Enchylaena', NULL, 'R.Br.', 5),
(6409, 'Enchysia', NULL, 'C.Presl', 30),
(6410, 'Encliandra', NULL, 'Zucc.', 121),
(6411, 'Encopa', NULL, 'Griseb.(SUH)', 150),
(6412, 'Encopea', NULL, 'C.Presl', 142),
(6413, 'Encopella', NULL, 'Pennell', 423),
(6414, 'Endadenium', NULL, 'L.C.Leach', 66),
(6415, 'Endemal', NULL, 'Pritz.(SUO)', 197),
(6416, 'Endertia', NULL, 'Steenis & de Wit', 68),
(6417, 'Endesmia', NULL, 'R.Br.', 116),
(6418, 'Endlichera', NULL, 'C.Presl', 142),
(6419, 'Endocellion', NULL, 'Turcz. ex Herder', 18),
(6420, 'Endogonia', NULL, 'Turcz.', 25),
(6421, 'Endoisila', NULL, 'Raf.', 66),
(6422, 'Endolasia', NULL, 'Turcz.', 142),
(6423, 'Endolithodes', NULL, 'Bartl.(SUI)', 142),
(6424, 'Endoloma', NULL, 'Raf.', 22),
(6425, 'Endomallus', NULL, 'Gagnep.', 68),
(6426, 'Endopappus', NULL, 'Sch.Bip.', 18),
(6427, 'Endopleura', NULL, 'Cuatrec.', 83),
(6428, 'Endopogon', NULL, 'Nees(SUH)', 1),
(6429, 'Endosamara', NULL, 'R.Geesink', 68),
(6430, 'Endosiphon', NULL, 'T.Anderson ex Benth.', 1),
(6431, 'Endostemon', NULL, 'N.E.Br.', 90),
(6432, 'Endotricha', NULL, 'Aubrev. & Pellegr.(SUH)', 148),
(6433, 'Endressia', NULL, 'J.Gay', 9),
(6434, 'Endusa', NULL, 'Miers', 119),
(6435, 'Engelmannia', NULL, 'A.Gray ex Nutt.', 18),
(6436, 'Englerastrum', NULL, 'Briq.', 90),
(6437, 'Englerella', NULL, 'Pierre', 148),
(6438, 'Engleria', NULL, 'O.Hoffm.', 18),
(6439, 'Englerina', NULL, 'Tiegh.', 98),
(6440, 'Englerocharis', NULL, 'Muschl.', 197),
(6441, 'Englerodaphne', NULL, 'Gilg', 164),
(6442, 'Englerodendron', NULL, 'Harms', 68),
(6443, 'Englerodoxa', NULL, 'Hoerold', 64),
(6444, 'Englerophoenix', NULL, 'Kuntze', 15),
(6445, 'Enicosanthellum', NULL, 'Ban', 8),
(6446, 'Enicostema', NULL, 'Blume', 75),
(6447, 'Enkianthus', NULL, 'Lour.', 64),
(6448, 'Enkleia', NULL, 'Griff.', 164),
(6449, 'Enkylia', NULL, 'Griff.', 49),
(6450, 'Enkylista', NULL, 'Hook.f.(SUO)', 142),
(6451, 'Enneastemon', NULL, 'Exell', 8),
(6452, 'Enneatypus', NULL, 'Herzog', 134),
(6453, 'Enosanthes', NULL, 'A.Cunn. ex Schauer(SUI)', 116),
(6454, 'Enriquebeltrania', NULL, 'Rzed.', 66),
(6455, 'Ensete', NULL, 'Horan.', 111),
(6456, 'Enslenia', NULL, 'Nutt.', 10),
(6457, 'Entada', NULL, 'Adans.', 70),
(6458, 'Entadopsis', NULL, 'Britton', 70),
(6459, 'Entelea', NULL, 'R.Br.', 102),
(6460, 'Enterospermum', NULL, 'Hiern', 142),
(6461, 'Entrecasteauxia', NULL, 'Montrouz.', 154),
(6462, 'Enydra', NULL, 'Lour.', 18),
(6463, 'Eomecon', NULL, 'Hance', 126),
(6464, 'Eopepon', NULL, 'Naudin', 49),
(6465, 'Eora', NULL, 'O.F.Cook', 15),
(6466, 'Eosanthe', NULL, 'Urb.', 142),
(6467, 'Epacris', NULL, 'Cav.', 64),
(6468, 'Epaltes', NULL, 'Cass.', 18),
(6469, 'Eperua', NULL, 'Aubl.', 68),
(6470, 'Ephaiola', NULL, 'Raf.', 154),
(6471, 'Ephedranthus', NULL, 'S.Moore', 8),
(6472, 'Ephippiandra', NULL, 'Decne.', 108),
(6473, 'Ephippiocarpa', NULL, 'Markgr.', 10),
(6474, 'Epiblepharis', NULL, 'Tiegh.', 118),
(6475, 'Epicarpurus', NULL, 'Blume', 109),
(6476, 'Epicharis', NULL, 'Blume', 106),
(6477, 'Epicion', NULL, 'Small', 10),
(6478, 'Epiclastopelma', NULL, 'Lindau', 1),
(6479, 'Epicoila', NULL, 'Raf.', 98),
(6480, 'Epidendroides', NULL, 'Sol.', 142),
(6481, 'Epifagus', NULL, 'Nutt.', 400),
(6482, 'Epigaea', NULL, 'L.', 64),
(6483, 'Epigynum', NULL, 'Wight', 10),
(6484, 'Epilasia', NULL, '(Bunge) Benth.', 18),
(6485, 'Epilobium', NULL, 'L.', 121),
(6486, 'Epiluma', NULL, 'Baill.', 148),
(6487, 'Epimeredi', NULL, 'Adans.', 90),
(6488, 'Epinetrum', NULL, 'Hiern', 107),
(6489, 'Epipetrum', NULL, 'Phil.', 59),
(6490, 'Epipremnopsis', NULL, 'Engl.', 12),
(6491, 'Epipremnum', NULL, 'Schott', 12),
(6492, 'Epirhizanthes', NULL, 'Blume', 133),
(6493, 'Epischoenus', NULL, 'C.B.Clarke', 55),
(6494, 'Episcia', NULL, 'Mart.', 76),
(6495, 'Episcothamnus', NULL, 'H.Rob.', 18),
(6496, 'Episteira', NULL, 'Raf.', 184),
(6497, 'Epistemma', NULL, 'D.V.Field & J.B.Hall', 10),
(6498, 'Epistylium', NULL, 'Sw.', 184),
(6499, 'Episyzygium', NULL, 'Suess. & A.Ludw.', 116),
(6500, 'Epitaberna', NULL, 'K.Schum.(SUH)', 142),
(6501, 'Epithema', NULL, 'Blume', 76),
(6502, 'Epithinia', NULL, 'Jack', 142),
(6503, 'Epitriche', NULL, 'Turcz.', 18),
(6504, 'Epixiphium', NULL, '(A.Gray) Munz', 423),
(6505, 'Eplateia', NULL, 'Raf.', 154),
(6506, 'Epleienda', NULL, 'Raf.', 116),
(6507, 'Eplejenda', NULL, 'Post & Kuntze', 116),
(6508, 'Eplingia', NULL, 'L.O.Williams', 90),
(6509, 'Epurga', NULL, 'Fourr.', 66),
(6510, 'Eraeliss', NULL, 'Forssk.', 184),
(6511, 'Eranthemum', NULL, 'L.', 1),
(6512, 'Ercilla', NULL, 'A.Juss.', 128),
(6513, 'Erechtites', NULL, 'Raf.', 18),
(6514, 'Ereicotis', NULL, '(DC.) Kuntze', 142),
(6515, 'Eremaea', NULL, 'Lindl.', 116),
(6516, 'Eremaeopsis', NULL, 'Kuntze', 116),
(6517, 'Eremalche', NULL, 'Greene', 102),
(6518, 'Eremanthus', NULL, 'Less.', 18),
(6519, 'Eremia', NULL, 'D.Don', 64),
(6520, 'Eremiastrum', NULL, 'A.Gray', 18),
(6521, 'Eremiella', NULL, 'Compton', 64),
(6522, 'Eremiopsis', NULL, 'N.E.Br.', 64),
(6523, 'Eremobium', NULL, 'Boiss.', 197),
(6524, 'Eremoblastus', NULL, 'Botsch.', 197),
(6525, 'Eremocarpus', NULL, 'Benth.', 66),
(6526, 'Eremocarya', NULL, 'Greene', 25),
(6527, 'Eremocharis', NULL, 'Phil.', 9),
(6528, 'Eremochion', NULL, 'Gilli', 5),
(6529, 'Eremocitrus', NULL, 'Swingle', 143),
(6530, 'Eremodaucus', NULL, 'Bunge', 9),
(6531, 'Eremodraba', NULL, 'O.E.Schulz', 197),
(6532, 'Eremogeton', NULL, 'Standl. & L.O.Williams', 150),
(6533, 'Eremolepis', NULL, 'Griseb.', 63),
(6534, 'Eremoluma', NULL, 'Baill.', 148),
(6535, 'Eremomastax', NULL, 'Lindau', 1),
(6536, 'Eremopanax', NULL, 'Baill.', 13),
(6537, 'Eremophea', NULL, 'Paul G.Wilson', 5),
(6538, 'Eremophila', NULL, 'R.Br.', 150),
(6539, 'Eremophyton', NULL, 'Beg.', 197),
(6540, 'Eremopyxis', NULL, 'Baill.', 116),
(6541, 'Eremosemium', NULL, 'Greene', 5),
(6542, 'Eremosis', NULL, '(DC.) Gleason', 18),
(6543, 'Eremosparton', NULL, 'Fisch. & C.A.Mey.', 68),
(6544, 'Eremospatha', NULL, '(G.Mann & H.Wendl.) H.Wendl.', 15),
(6545, 'Eremosperma', NULL, 'Chiov.', 46),
(6546, 'Eremostachys', NULL, 'Bunge', 90),
(6547, 'Eremothamnus', NULL, 'O.Hoffm.', 18),
(6548, 'Eremotropa', NULL, 'Andres', 64),
(6549, 'Eresimus', NULL, 'Raf.', 142),
(6550, 'Ergocarpon', NULL, 'C.C.Towns.', 9),
(6551, 'Eriachaenium', NULL, 'Sch.Bip.', 18),
(6552, 'Eriadenia', NULL, 'Miers', 10),
(6553, 'Eriandra', NULL, 'P.Royen & Steenis', 133),
(6554, 'Eriandrostachys', NULL, 'Baill.', 147),
(6555, 'Erianthemum', NULL, 'Tiegh.', 98),
(6556, 'Erianthera', NULL, 'Benth.(SUH)', 90),
(6557, 'Erica', NULL, 'L.', 64),
(6558, 'Ericameria', NULL, 'Nutt.', 18),
(6559, 'Ericentrodea', NULL, 'S.F.Blake & Sherff', 18),
(6560, 'Erichsenia', NULL, 'Hemsl.', 68),
(6561, 'Ericinella', NULL, 'Klotzsch', 64),
(6562, 'Ericomyrtus', NULL, 'Turcz.', 116),
(6563, 'Erigenia', NULL, 'Nutt.', 9),
(6564, 'Erigeron', NULL, 'L.', 18),
(6565, 'Erinacea', NULL, 'Adans.', 68),
(6566, 'Erinocarpus', NULL, 'Nimmo ex J.Graham', 102),
(6567, 'Erinus', NULL, 'L.', 423),
(6568, 'Eriocaucanthus', NULL, 'Chiov.', 101),
(6569, 'Eriocephalus', NULL, 'L.', 18),
(6570, 'Eriochiton', NULL, '(R.H.Anderson) A.J.Scott', 5),
(6571, 'Eriochlamys', NULL, 'Sond. & F.Muell.', 18),
(6572, 'Eriocnema', NULL, 'Naudin', 105),
(6573, 'Eriococcus', NULL, 'Hassk.', 184),
(6574, 'Eriocycla', NULL, 'Lindl.', 9),
(6575, 'Eriodendron', NULL, 'DC.', 102),
(6576, 'Eriodictyon', NULL, 'Benth.', 25),
(6577, 'Erioglossum', NULL, 'Blume', 147),
(6578, 'Eriogonella', NULL, 'Goodman', 134),
(6579, 'Eriogonum', NULL, 'Michx.', 134),
(6580, 'Eriogynia', NULL, 'Hook.', 141),
(6581, 'Eriolobus', NULL, '(DC.) M.Roem.', 141),
(6582, 'Erione', NULL, 'Schott & Endl.', 102),
(6583, 'Eriope', NULL, 'Kunth ex Benth.', 90),
(6584, 'Eriophorella', NULL, 'Holub', 55),
(6585, 'Eriophoropsis', NULL, 'Palla', 55),
(6586, 'Eriophorum', NULL, 'L.', 55),
(6587, 'Eriophyllum', NULL, 'Lag.', 18),
(6588, 'Eriophyton', NULL, 'Benth.', 90),
(6589, 'Eriopidion', NULL, 'Harley', 90),
(6590, 'Erioscirpus', NULL, 'Palla', 55),
(6591, 'Eriosema', NULL, '(DC.) Rchb.', 68),
(6592, 'Eriosemopsis', NULL, 'Robyns', 142),
(6593, 'Eriosolena', NULL, 'Blume', 164),
(6594, 'Eriosphaera', NULL, 'Less.(SUH)', 18),
(6595, 'Eriospora', NULL, 'Hochst. ex A.Rich.', 55),
(6596, 'Eriostemon', NULL, 'Sm.', 143),
(6597, 'Eriostoma', NULL, 'Boivin ex Baill.(SUI)', 142),
(6598, 'Eriostrobilus', NULL, 'Bremek.', 1),
(6599, 'Eriostylos', NULL, 'C.C.Towns.', 5),
(6600, 'Eriosynaphe', NULL, 'DC.', 9),
(6601, 'Eriothymus', NULL, '(Benth.) Rchb.', 90),
(6602, 'Eriotrix', NULL, 'Cass.', 18),
(6603, 'Erioxylum', NULL, 'Rose & Standl.', 102),
(6604, 'Eriphia', NULL, 'P.Browne', 76),
(6605, 'Erismanthus', NULL, 'Wall. ex Mull.Arg.', 66),
(6606, 'Erithalis', NULL, 'G.Forst.(SUH)', 142),
(6607, 'Eritrichium', NULL, 'Schrad. ex Gaudin', 25),
(6608, 'Erlangea', NULL, 'Sch.Bip.', 18),
(6609, 'Ermanea', NULL, 'Cham.', 197),
(6610, 'Ermaniopsis', NULL, 'Hara', 197),
(6611, 'Ernestia', NULL, 'DC.', 105),
(6612, 'Ernestimeyera', NULL, 'Kuntze(SUS)', 142),
(6613, 'Ernodea', NULL, 'Sw.', 142),
(6614, 'Erodiophyllum', NULL, 'F.Muell.', 18),
(6615, 'Erophila', NULL, 'DC.', 197),
(6616, 'Erosmia', NULL, 'A.Juss.', 142),
(6617, 'Erotium', NULL, 'Blanco', 102),
(6618, 'Erpetina', NULL, 'Naudin', 105),
(6619, 'Erpetion', NULL, 'Sweet', 174),
(6620, 'Errazurizia', NULL, 'Phil.', 68),
(6621, 'Ertela', NULL, 'Adans.', 143),
(6622, 'Eruca', NULL, 'Mill.', 197),
(6623, 'Erucago', NULL, 'Mill.', 197),
(6624, 'Erucastrum', NULL, '(DC.) C.Presl', 197),
(6625, 'Ervatamia', NULL, '(A.DC.) Stapf', 10),
(6626, 'Ervum', NULL, 'L.', 68),
(6627, 'Erymophyllum', NULL, 'Paul G.Wilson', 18),
(6628, 'Eryngiophyllum', NULL, 'Greenm.', 18),
(6629, 'Eryngium', NULL, 'L.', 9),
(6630, 'Erysimum', NULL, 'L.', 197),
(6631, 'Erythea', NULL, 'S.Watson', 15),
(6632, 'Erythracanthus', NULL, 'Nees', 1),
(6633, 'Erythradenia', NULL, '(B.L.Rob.) R.M.King & H.Rob.', 18),
(6634, 'Erythraea', NULL, 'L.', 75),
(6635, 'Erythranthus', NULL, 'Oerst. ex Hanst.', 76),
(6636, 'Erythrocarpus', NULL, 'Blume', 66),
(6637, 'Erythrocephalum', NULL, 'Benth.', 18),
(6638, 'Erythrochlamys', NULL, 'Gurke', 90),
(6639, 'Erythrochylus', NULL, 'Reinw. ex Blume', 66),
(6640, 'Erythrocoma', NULL, 'Greene', 141),
(6641, 'Erythrodanum', NULL, 'Thouars', 142),
(6642, 'Erythrogyne', NULL, 'Gasp.', 109),
(6643, 'Erythronium', NULL, 'L.', 94),
(6644, 'Erythropalum', NULL, 'Blume', 514),
(6645, 'Erythrophysa', NULL, 'E.Mey. ex Arn.', 147),
(6646, 'Erythrophysopsis', NULL, 'Verdc.', 147),
(6647, 'Erythropsis', NULL, 'Lindl. ex Schott & Endl.', 102),
(6648, 'Erythropyxis', NULL, 'Engl.', 92),
(6649, 'Erythroselinum', NULL, 'Chiov.', 9),
(6650, 'Erythrospermum', NULL, 'Lam.', 198),
(6651, 'Erythrostigma', NULL, 'Hassk.', 45),
(6652, 'Erytropyxis', NULL, 'Pierre', 92),
(6653, 'Eschholtzia', NULL, 'Rchb.(SUO)', 126),
(6654, 'Escholtzia', NULL, 'Dumort.(SUO)', 126),
(6655, 'Eschscholtzia', NULL, 'Bernh.(SUO)', 126),
(6656, 'Eschscholzia', NULL, 'Cham.', 126),
(6657, 'Eschweileria', NULL, 'Zipp. ex Boerl.', 13),
(6658, 'Escobedia', NULL, 'Ruiz & Pav.', 400),
(6659, 'Esfandiaria', NULL, 'Charif & Aellen', 5),
(6660, 'Eskemukerjea', NULL, 'Malick & Sengupta', 134),
(6661, 'Esmeraldia', NULL, 'E.Fourn.', 10),
(6662, 'Espadaea', NULL, 'A.Rich.', 154),
(6663, 'Espejoa', NULL, 'DC.', 18),
(6664, 'Espeletia', NULL, 'Mutis ex Humb. & Bonpl.', 18),
(6665, 'Espeletiopsis', NULL, 'Cuatrec.', 18),
(6666, 'Esquirolia', NULL, 'H.Lev.', 120),
(6667, 'Esquiroliella', NULL, 'H.Lev.', 197),
(6668, 'Esterhazya', NULL, 'J.C.Mikan', 400),
(6669, 'Esula', NULL, '(Pers.) Haw.', 66),
(6670, 'Etaballia', NULL, 'Benth.', 68),
(6671, 'Ethesia', NULL, 'Raf.(SUH)', 1),
(6672, 'Ethulia', NULL, 'L.f.', 18),
(6673, 'Etiosedum', NULL, 'A.Love & D.Love', 48),
(6674, 'Etorloba', NULL, 'Raf.', 22),
(6675, 'Etubila', NULL, 'Raf.', 98),
(6676, 'Euaraliopsis', NULL, 'Hutch.', 13),
(6677, 'Euathronia', NULL, 'Nutt. ex A.Gray', 142),
(6678, 'Eubasis', NULL, 'Salisb.', 74),
(6679, 'Eubrachion', NULL, 'Hook.f.', 63),
(6680, 'Eucalypton', NULL, 'St.-Lag.', 116),
(6681, 'Eucalyptopsis', NULL, 'C.T.White', 116),
(6682, 'Eucalyptus', NULL, 'L''Her.', 116),
(6683, 'Eucapnia', NULL, 'Raf.', 154),
(6684, 'Eucarya', NULL, 'T.L.Mitch.', 146),
(6685, 'Euceraea', NULL, 'Mart.', 145),
(6686, 'Euchaetis', NULL, 'Bartl. & H.L.Wendl.', 143),
(6687, 'Eucharidium', NULL, 'Fisch. & C.A.Mey.', 121),
(6688, 'Eucheila', NULL, 'O.F.Cook(SUI)', 15),
(6689, 'Euchilopsis', NULL, 'F.Muell.', 68),
(6690, 'Euchiton', NULL, 'Cass.', 18),
(6691, 'Euchlora', NULL, 'Eckl. & Zeyh.', 68),
(6692, 'Euchorium', NULL, 'Ekman & Radlk.', 147),
(6693, 'Euchresta', NULL, 'Benn.', 68),
(6694, 'Euclea', NULL, 'L.', 61),
(6695, 'Euclidium', NULL, 'R.Br.', 197),
(6696, 'Eucodonia', NULL, 'Hanst.', 76),
(6697, 'Eucolum', NULL, 'Salisb.', 76),
(6698, 'Eucorymbia', NULL, 'Stapf', 10),
(6699, 'Eucryphia', NULL, 'Cav.', 50),
(6700, 'Eucrypta', NULL, 'Nutt.', 25),
(6701, 'Eudema', NULL, 'Humb. & Bonpl.', 197),
(6702, 'Euforbia', NULL, 'Ten.(SUO)', 66),
(6703, 'Eugeissona', NULL, 'Griff.', 15),
(6704, 'Eugeniopsis', NULL, 'O.Berg', 116),
(6705, 'Euglypha', NULL, 'Chodat & Hassl.', 16),
(6706, 'Euhemus', NULL, 'Raf.', 90),
(6707, 'Euhesperida', NULL, 'Brullo & Furnari', 90),
(6708, 'Euklisia', NULL, 'Rydb. ex Small', 197),
(6709, 'Eukylista', NULL, 'Benth.', 142),
(6710, 'Eulenburgia', NULL, 'Pax', 49),
(6711, 'Euleria', NULL, 'Urb.', 6),
(6712, 'Eulobus', NULL, 'Nutt.', 121),
(6713, 'Eulophus', NULL, 'Nutt. ex DC.', 9),
(6714, 'Eumachia', NULL, 'DC.', 142),
(6715, 'Eumecanthus', NULL, 'Klotzsch & Garcke', 66),
(6716, 'Eumolpe', NULL, 'Decne. ex Jacques & Herincq', 76),
(6717, 'Eumorphanthus', NULL, 'A.C.Sm.', 142),
(6718, 'Eumorphia', NULL, 'DC.', 18),
(6719, 'Eunomia', NULL, 'DC.', 197),
(6720, 'Euosmia', NULL, 'Kunth', 142),
(6721, 'Eupatoriadelphus', NULL, 'R.M.King & H.Rob.', 18),
(6722, 'Eupatoriastrum', NULL, 'Greenm.', 18),
(6723, 'Eupatorina', NULL, 'R.M.King & H.Rob.', 18),
(6724, 'Eupatoriopsis', NULL, 'Hieron.', 18),
(6725, 'Eupatorium', NULL, 'L.', 18),
(6726, 'Euphora', NULL, 'Griff.', 106),
(6727, 'Euphorbiastrum', NULL, 'Klotzsch & Garcke', 66),
(6728, 'Euphorbiodendron', NULL, 'Millsp.', 66),
(6729, 'Euphorbiopsis', NULL, 'H.Lev.', 66),
(6730, 'Euphorbium', NULL, 'Hill', 66),
(6731, 'Euphoria', NULL, 'Comm. ex Juss.', 147),
(6732, 'Euphorianthus', NULL, 'Radlk.', 147),
(6733, 'Euphrasia', NULL, 'L.', 400),
(6734, 'Euphronia', NULL, 'Mart. & Zucc.', 67),
(6735, 'Euphrosyne', NULL, 'DC.', 18),
(6736, 'Euploca', NULL, 'Nutt.', 25),
(6737, 'Eupritchardia', NULL, 'Kuntze', 15),
(6738, 'Eupteron', NULL, 'Miq.', 13),
(6739, 'Eupyrena', NULL, 'Wight & Arn.', 142),
(6740, 'Eureiandra', NULL, 'Hook.f.', 49),
(6741, 'Eurhotia', NULL, 'Neck.(SUI)', 142),
(6742, 'Euroschinus', NULL, 'Hook.f.', 6),
(6743, 'Eurotia', NULL, 'Adans.(SUS)', 5),
(6744, 'Euryandra', NULL, 'Hook.f.(SUO)', 49),
(6745, 'Euryangium', NULL, 'Kauffman', 9),
(6746, 'Eurybiopsis', NULL, 'DC.', 18),
(6747, 'Eurycarpus', NULL, 'Botsch.', 197),
(6748, 'Eurycorymbus', NULL, 'Hand.-Mazz.', 147),
(6749, 'Eurydochus', NULL, 'Maguire & Wurdack', 18),
(6750, 'Eurygania', NULL, 'Klotzsch', 64),
(6751, 'Eurynome', NULL, 'DC.', 142),
(6752, 'Euryomyrtus', NULL, 'Schauer', 116),
(6753, 'Euryops', NULL, '(Cass.) Cass.', 18),
(6754, 'Eurysolen', NULL, 'Prain', 90),
(6755, 'Eurytaenia', NULL, 'Torr. & A.Gray', 9),
(6756, 'Euscaphis', NULL, 'Siebold & Zucc.', 155),
(6757, 'Eusiphon', NULL, 'Benoist', 1),
(6758, 'Eustegia', NULL, 'R.Br.', 10),
(6759, 'Eusteralis', NULL, 'Raf.', 90),
(6760, 'Eustoma', NULL, 'Salisb.', 75),
(6761, 'Eusynetra', NULL, 'Raf.', 76),
(6762, 'Eutaxia', NULL, 'R.Br.', 68),
(6763, 'Eutetras', NULL, 'A.Gray', 18),
(6764, 'Euthamia', NULL, '(Nutt.) Elliott', 18),
(6765, 'Euthamnus', NULL, 'Schltr.', 76),
(6766, 'Euthemis', NULL, 'Jack', 118),
(6767, 'Eutheta', NULL, 'Standl.', 150),
(6768, 'Eutrema', NULL, 'R.Br.', 197),
(6769, 'Eutrophia', NULL, 'Klotzsch', 66),
(6770, 'Euxena', NULL, 'Calest.', 197),
(6771, 'Euxylophora', NULL, 'Huber', 143),
(6772, 'Euzomodendron', NULL, 'Coss.', 197),
(6773, 'Evacidium', NULL, 'Pomel', 18),
(6774, 'Evandra', NULL, 'R.Br.', 55),
(6775, 'Evanesca', NULL, 'Raf.', 116),
(6776, 'Evax', NULL, 'Gaertn.', 18),
(6777, 'Evea', NULL, 'Aubl.', 142),
(6778, 'Everardia', NULL, 'Ridl.', 55),
(6779, 'Everettia', NULL, 'Merr.', 105),
(6780, 'Everettiodendron', NULL, 'Merr.', 184),
(6781, 'Eversmannia', NULL, 'Bunge', 68),
(6782, 'Evodia', NULL, 'Lam.(SUO)', 143),
(6783, 'Evodianthus', NULL, 'Oerst.', 54),
(6784, 'Evodiella', NULL, 'Linden', 143),
(6785, 'Evodiopanax', NULL, '(Harms) Nakai', 13),
(6786, 'Evoista', NULL, 'Raf.', 154),
(6787, 'Evolvulus', NULL, 'L.', 46),
(6788, 'Evonymopsis', NULL, 'H.Perrier', 38),
(6789, 'Evosmia', NULL, 'Humb. & Bonpl.', 142),
(6790, 'Ewartia', NULL, 'Beauverd', 18),
(6791, 'Ewartiothamnus', NULL, 'Anderb.', 18),
(6792, 'Ewyckia', NULL, 'Blume', 105),
(6793, 'Exaculum', NULL, 'Caruel', 75),
(6794, 'Exacum', NULL, 'L.', 75),
(6795, 'Exallage', NULL, 'Bremek.', 142),
(6796, 'Exandra', NULL, 'Standl.', 142),
(6797, 'Excavatia', NULL, 'Markgr.', 10),
(6798, 'Excentrodendron', NULL, 'H.T.Chang & R.H.Miao', 102),
(6799, 'Excoecaria', NULL, 'L.', 66),
(6800, 'Excoecariopsis', NULL, 'Pax', 66),
(6801, 'Exechostylus', NULL, 'K.Schum.', 142),
(6802, 'Exellia', NULL, 'Boutique', 8),
(6803, 'Exellodendron', NULL, 'Prance', 40),
(6804, 'Exitelia', NULL, 'Blume', 40),
(6805, 'Exoacantha', NULL, 'Labill.', 9),
(6806, 'Exocarpos', NULL, 'Labill.', 146),
(6807, 'Exocarya', NULL, 'Benth.', 55),
(6808, 'Exochaenium', NULL, 'Griseb.', 75),
(6809, 'Exochogyne', NULL, 'C.B.Clarke', 55),
(6810, 'Exochorda', NULL, 'Lindl.', 141),
(6811, 'Exodeconus', NULL, 'Raf.', 154),
(6812, 'Exogonium', NULL, 'Choisy', 46),
(6813, 'Exolobus', NULL, 'E.Fourn.', 10),
(6814, 'Exomiocarpon', NULL, 'Lawalree', 18),
(6815, 'Exomis', NULL, 'Fenzl ex Moq.', 5),
(6816, 'Exorrhiza', NULL, 'Becc.', 15),
(6817, 'Exospermum', NULL, 'Tiegh.', 176),
(6818, 'Exostemma', NULL, 'DC.(SUO)', 142),
(6819, 'Exostemon', NULL, 'Post & Kuntze(SUO)', 142),
(6820, 'Exostyles', NULL, 'Schott', 68),
(6821, 'Exothea', NULL, 'Macfad.', 147),
(6822, 'Exsertanthera', NULL, 'Pichon', 22),
(6823, 'Eylesia', NULL, 'S.Moore', 150),
(6824, 'Eysenhardtia', NULL, 'Kunth', 68),
(6825, 'Eystathes', NULL, 'Lour.', 133),
(6826, 'Faberia', NULL, 'Hemsl.', 18),
(6827, 'Fabiana', NULL, 'Ruiz & Pav.', 154),
(6828, 'Fabricia', NULL, 'Gaertn.(SUH)', 116),
(6829, 'Fabrisinapis', NULL, 'C.C.Towns.', 197),
(6830, 'Facelis', NULL, 'Cass.', 18),
(6831, 'Factorovskya', NULL, 'Eig', 68),
(6832, 'Fadenia', NULL, 'Aellen & C.C.Towns.', 5),
(6833, 'Fadogia', NULL, 'Schweinf.', 142),
(6834, 'Fadogiella', NULL, 'Robyns', 142),
(6835, 'Fagaropsis', NULL, 'Mildbr. ex Siebenl.', 143),
(6836, 'Fagelia', NULL, 'Neck. ex DC.', 68),
(6837, 'Fagonia', NULL, 'L.', 177),
(6838, 'Fagopyrum', NULL, 'Mill.', 134),
(6839, 'Faguetia', NULL, 'Marchand', 6),
(6840, 'Fagus', NULL, 'L.', 72),
(6841, 'Faidherbia', NULL, 'A.Chev.', 68),
(6842, 'Faika', NULL, 'Philipson', 108),
(6843, 'Fairchildia', NULL, 'Britton & Rose', 68),
(6844, 'Falcaria', NULL, 'Fabr.', 9),
(6845, 'Falcatifolium', NULL, 'de Laub.', 132),
(6846, 'Falconeria', NULL, 'Royle(SUH)', 66),
(6847, 'Falkia', NULL, 'L.f.', 46),
(6848, 'Fallopia', NULL, 'Adans.', 134),
(6849, 'Fallugia', NULL, 'Endl.', 141),
(6850, 'Famarea', NULL, 'Vitman(SUO)', 142),
(6851, 'Fanninia', NULL, 'Harv.', 10),
(6852, 'Faradaya', NULL, 'F.Muell.', 90),
(6853, 'Farfugium', NULL, 'Lindl.', 18),
(6854, 'Farinopsis', NULL, 'Chrtek & Sojak', 141),
(6855, 'Faroa', NULL, 'Welw.', 75),
(6856, 'Farquharia', NULL, 'Stapf', 10),
(6857, 'Farreria', NULL, 'Balf.f. & W.W.Sm.', 164),
(6858, 'Farringtonia', NULL, 'Gleason', 105),
(6859, 'Farsetia', NULL, 'Turra', 197),
(6860, 'Fatoua', NULL, 'Gaudich.', 109),
(6861, 'Fatrea', NULL, 'Juss.', 44),
(6862, 'Fatsia', NULL, 'Decne. & Planch.', 13),
(6863, 'Faucherea', NULL, 'Lecomte', 148),
(6864, 'Faujasia', NULL, 'Cass.', 18),
(6865, 'Faulia', NULL, 'Raf.', 120),
(6866, 'Faurea', NULL, 'Harv.', 135),
(6867, 'Faustia', NULL, 'Font Quer & Rothm.', 90),
(6868, 'Favargera', NULL, 'A.Love & D.Love', 75),
(6869, 'Fawcettia', NULL, 'F.Muell.', 107),
(6870, 'Faxonanthus', NULL, 'Greenm.', 150),
(6871, 'Faxonia', NULL, 'Brandegee', 18),
(6872, 'Feddea', NULL, 'Urb.', 18),
(6873, 'Fedorouia', NULL, 'Yakovlev', 68),
(6874, 'Fedorovia', NULL, 'Kolak.', 30),
(6875, 'Fedtschenkiella', NULL, 'Kudr.', 90),
(6876, 'Fedtschenkoa', NULL, 'Regel & Schmalh.', 197),
(6877, 'Feeria', NULL, 'Buser', 30),
(6878, 'Fegimanra', NULL, 'Pierre', 6),
(6879, 'Feijoa', NULL, 'O.Berg', 116),
(6880, 'Feldstonia', NULL, 'P.S.Short', 18),
(6881, 'Felicia', NULL, 'Cass.', 18),
(6882, 'Feliciadamia', NULL, 'Bullock', 105),
(6883, 'Feliciana', NULL, 'Benth.(SUO)', 116),
(6884, 'Felicianea', NULL, 'Cambess.', 116),
(6885, 'Felipponia', NULL, 'Hicken', 12),
(6886, 'Felipponiella', NULL, 'Hicken', 12),
(6887, 'Femeniasia', NULL, 'Susanna', 18),
(6888, 'Fenerivia', NULL, 'Diels', 8),
(6889, 'Fenixanthes', NULL, 'Raf.', 90),
(6890, 'Fenixia', NULL, 'Merr.', 18),
(6891, 'Fenzlia', NULL, 'Endl.(SUH)', 116),
(6892, 'Ferdinanda', NULL, 'Benth.(SUO)', 22),
(6893, 'Ferdinandea', NULL, 'Pohl', 142),
(6894, 'Ferdinandia', NULL, 'Welw. ex Seem.(SUO)', 22),
(6895, 'Ferdinandoa', NULL, 'Seem.(SUO)', 22),
(6896, 'Fereiria', NULL, 'Vell. ex Vand.', 142),
(6897, 'Feretia', NULL, 'Delile', 142),
(6898, 'Fergania', NULL, 'Pimenov', 9),
(6899, 'Fergusonia', NULL, 'Hook.f.', 142),
(6900, 'Fernaldia', NULL, 'Woodson', 10),
(6901, 'Fernandia', NULL, 'Baill.(SUO)', 22),
(6902, 'Fernelia', NULL, 'Comm. ex Lam.', 142),
(6903, 'Feronia', NULL, 'Correa', 143),
(6904, 'Feroniella', NULL, 'Swingle', 143),
(6905, 'Ferreirea', NULL, 'Allemao', 68),
(6906, 'Ferreyranthus', NULL, 'H.Rob. & Brettell', 18),
(6907, 'Ferreyrella', NULL, 'S.F.Blake', 18),
(6908, 'Ferula', NULL, 'L.', 9),
(6909, 'Ferulago', NULL, 'W.D.J.Koch', 9),
(6910, 'Ferulopsis', NULL, 'Kitag.', 9),
(6911, 'Feuillaea', NULL, 'Gled.(SUO)', 49),
(6912, 'Feuillea', NULL, 'Kuntze(SUO)', 49),
(6913, 'Fevillea', NULL, 'L.', 49),
(6914, 'Fezia', NULL, 'Pit.', 197),
(6915, 'Fibigia', NULL, 'Medik.', 197),
(6916, 'Fibocentrum', NULL, 'Pierre ex Glaz.(SUI)', 148),
(6917, 'Fibraurea', NULL, 'Lour.', 107),
(6918, 'Ficalhoa', NULL, 'Hiern', 543),
(6919, 'Ficinia', NULL, 'Schrad.', 55),
(6920, 'Fiebrigia', NULL, 'Fritsch', 76),
(6921, 'Fiebrigiella', NULL, 'Harms', 68),
(6922, 'Figuierea', NULL, 'Montrouz.', 142),
(6923, 'Filaginella', NULL, 'Opiz(SUS)', 18),
(6924, 'Filago', NULL, 'L.', 18),
(6925, 'Filarum', NULL, 'Nicolson', 12),
(6926, 'Filetia', NULL, 'Miq.', 1),
(6927, 'Filifolium', NULL, 'Kitam.', 18),
(6928, 'Filipendula', NULL, 'Mill.', 141),
(6929, 'Fillaeopsis', NULL, 'Harms', 68),
(6930, 'Fimbristemma', NULL, 'Turcz.', 10),
(6931, 'Fimbristylis', NULL, 'Vahl', 55),
(6932, 'Fimbrolina', NULL, 'Raf.', 76),
(6933, 'Findlaya', NULL, 'Hook.f.(SUH)', 64),
(6934, 'Finetia', NULL, 'Gagnep.(SUS)', 44),
(6935, 'Finlaysonia', NULL, 'Wall.', 10),
(6936, 'Finschia', NULL, 'Warb.', 135),
(6937, 'Fintelmannia', NULL, 'Kunth', 55),
(6938, 'Fioria', NULL, 'Mattei', 102),
(6939, 'Fischeria', NULL, 'DC.', 10),
(6940, 'Fishlockia', NULL, 'Britton & Rose', 68),
(6941, 'Fissendocarpa', NULL, '(Haines) Bennet', 121),
(6942, 'Fissilia', NULL, 'Comm. ex Juss.', 119),
(6943, 'Fissipetalum', NULL, 'Merr.', 46),
(6944, 'Fissistigma', NULL, 'Griff.', 8),
(6945, 'Fitchia', NULL, 'Hook.f.', 18),
(6946, 'Fittingia', NULL, 'Mez', 115),
(6947, 'Fittonia', NULL, 'Coem.', 1),
(6948, 'Fitzalania', NULL, 'F.Muell.', 8),
(6949, 'Fitzgeraldia', NULL, 'F.Muell.', 8),
(6950, 'Fitzroya', NULL, 'Hook.f. ex Lindl.', 51),
(6951, 'Fitzwillia', NULL, 'P.S.Short', 18),
(6952, 'Flabellaria', NULL, 'Cav.', 101),
(6953, 'Flabellariopsis', NULL, 'R.Wilczek', 101),
(6954, 'Flagellarisaema', NULL, 'Nakai', 12),
(6955, 'Flagenium', NULL, 'Baill.', 142),
(6956, 'Flanagania', NULL, 'Schltr.', 10),
(6957, 'Flaveria', NULL, 'Juss.', 18),
(6958, 'Fleischmannia', NULL, 'Sch.Bip.', 18),
(6959, 'Fleischmanniana', NULL, 'Sch.Bip.(SUO)', 18),
(6960, 'Fleischmanniopsis', NULL, 'R.M.King & H.Rob.', 18),
(6961, 'Fleurya', NULL, 'Gaudich.', 171),
(6962, 'Fleurydora', NULL, 'A.Chev.', 118),
(6963, 'Flexanthera', NULL, 'Rusby', 142),
(6964, 'Flindersia', NULL, 'R.Br.', 143),
(6965, 'Florestina', NULL, 'Cass.', 18),
(6966, 'Floscaldasia', NULL, 'Cuatrec.', 18),
(6967, 'Flosmutisia', NULL, 'Cuatrec.', 18),
(6968, 'Flourensia', NULL, 'DC.', 18),
(6969, 'Flueckigera', NULL, 'Kuntze', 128),
(6970, 'Flueggea', NULL, 'Willd.', 184),
(6971, 'Fluggeopsis', NULL, 'K.Schum.', 184),
(6972, 'Flyriella', NULL, 'R.M.King & H.Rob.', 18),
(6973, 'Fockea', NULL, 'Endl.', 10),
(6974, 'Foeniculum', NULL, 'Mill.', 9),
(6975, 'Foersteria', NULL, 'Scop.', 184),
(6976, 'Foetidia', NULL, 'Comm. ex Lam.', 92),
(6977, 'Fokienia', NULL, 'A.Henry & H.H.Thomas', 51),
(6978, 'Foleyola', NULL, 'Maire', 197),
(6979, 'Folliculigera', NULL, 'Pasq.', 68),
(6980, 'Folotsia', NULL, 'Costantin & Bois', 10),
(6981, 'Fontainea', NULL, 'Heckel', 66),
(6982, 'Fontainesia', NULL, 'Post & Kuntze(SUO)', 120),
(6983, 'Fontanesia', NULL, 'Labill.', 120),
(6984, 'Fontbrunea', NULL, 'Pierre', 148),
(6985, 'Fontquera', NULL, 'Maire', 18),
(6986, 'Fontqueriella', NULL, 'Rothm.', 154),
(6987, 'Forchhammeria', NULL, 'Liebm.', 32),
(6988, 'Forcipella', NULL, 'Baill.', 1),
(6989, 'Fordiophyton', NULL, 'Stapf', 105),
(6990, 'Forestiera', NULL, 'Poir.', 120),
(6991, 'Formania', NULL, 'W.W.Sm. & Small', 18),
(6992, 'Formanodendron', NULL, 'Nixon & Crepet', 72),
(6993, 'Formosia', NULL, 'Pichon', 10),
(6994, 'Forsgardia', NULL, 'Vell.', 44),
(6995, 'Forsskaolea', NULL, 'L.', 171),
(6996, 'Forsteria', NULL, 'Steud.', 184),
(6997, 'Forsteronia', NULL, 'G.Mey.', 10),
(6998, 'Forsythia', NULL, 'Vahl', 120),
(6999, 'Forsythiopsis', NULL, 'Baker', 1),
(7000, 'Fortunella', NULL, 'Swingle', 143),
(7001, 'Fortuynia', NULL, 'Shuttlew. ex Boiss.', 197),
(7002, 'Foscarenia', NULL, 'Vell. ex Vand.', 142),
(7003, 'Fourniera', NULL, 'J.Bommer ex E.Fourn.', 52),
(7004, 'Fournieria', NULL, 'Tiegh.', 118),
(7005, 'Fourraea', NULL, 'Greuter & Burdet', 197),
(7006, 'Foveolaria', NULL, 'Ruiz & Pav.', 158),
(7007, 'Foveolina', NULL, 'Kallersjo', 18),
(7008, 'Fragaria', NULL, 'L.', 141),
(7009, 'Fragariopsis', NULL, 'A.St.-Hil.', 66),
(7010, 'Franchetella', NULL, 'Pierre', 148),
(7011, 'Franchetia', NULL, 'Baill.', 142),
(7012, 'Franciella', NULL, 'Guillaumin(SUH)', 142),
(7013, 'Franciscea', NULL, 'Pohl', 154),
(7014, 'Franciscodendron', NULL, 'B.Hyland & Steenis', 102),
(7015, 'Francisia', NULL, 'Endl.', 116),
(7016, 'Francoa', NULL, 'Cav.', 515),
(7017, 'Francoeuria', NULL, 'Cass.', 18),
(7018, 'Frangula', NULL, 'Mill.', 139),
(7019, 'Franklandia', NULL, 'R.Br.', 135),
(7020, 'Franklinia', NULL, 'W.Bartram ex Marshall', 162),
(7021, 'Frankoa', NULL, 'Rchb.(SUO)', 182),
(7022, 'Franseria', NULL, 'Cav.', 18),
(7023, 'Frantzia', NULL, 'Pittier', 49),
(7024, 'Frasera', NULL, 'Walter', 75),
(7025, 'Fraunhofera', NULL, 'Mart.', 38),
(7026, 'Fraxinoides', NULL, 'Medik.', 120),
(7027, 'Fredolia', NULL, '(Coss. & Durieu ex Bunge) Ulbr.', 5),
(7028, 'Freeria', NULL, 'Merr.', 85),
(7029, 'Fregirardia', NULL, 'Dunal ex Delile', 154),
(7030, 'Freireodendron', NULL, 'Mull.Arg.', 66),
(7031, 'Fremontia', NULL, 'Torr.', 5),
(7032, 'Fremontodendron', NULL, 'Coville', 102),
(7033, 'Fremya', NULL, 'Brongn. & Gris', 116),
(7034, 'Frerea', NULL, 'Dalzell', 10),
(7035, 'Freycinetia', NULL, 'Gaudich.', 125),
(7036, 'Freyera', NULL, 'Rchb.', 9),
(7037, 'Freyeria', NULL, 'Scop.(SUS)', 120),
(7038, 'Freylinia', NULL, 'Colla', 150),
(7039, 'Fridericia', NULL, 'Mart.', 22),
(7040, 'Friedlandia', NULL, 'Cham. & Schltdl.', 99),
(7041, 'Friedrichsthalia', NULL, 'Fenzl', 25),
(7042, 'Friesodielsia', NULL, 'Steenis', 8),
(7043, 'Fritillaria', NULL, 'L.', 94),
(7044, 'Fritschiantha', NULL, 'Kuntze', 76),
(7045, 'Fritzschia', NULL, 'Cham.', 105),
(7046, 'Froehlichia', NULL, 'D.Dietr.(SUO)', 142),
(7047, 'Froelichia', NULL, 'Moench', 5),
(7048, 'Froelichiella', NULL, 'R.E.Fr.', 5),
(7049, 'Froesiodendron', NULL, 'R.E.Fr.', 8),
(7050, 'Frommia', NULL, 'H.Wolff', 9),
(7051, 'Froriepia', NULL, 'K.Koch', 9),
(7052, 'Fructesca', NULL, 'DC. ex Meisn.', 142),
(7053, 'Fryxellia', NULL, 'D.M.Bates', 102),
(7054, 'Fuernrohria', NULL, 'K.Koch', 9),
(7055, 'Fuerstia', NULL, 'T.C.E.Fr.', 90),
(7056, 'Fugosia', NULL, 'Juss.', 102),
(7057, 'Fuirena', NULL, 'Rottb.', 55),
(7058, 'Fulcaldea', NULL, 'Poir.', 18),
(7059, 'Fulchironia', NULL, 'Lesch.', 15),
(7060, 'Fumaria', NULL, 'L.', 126),
(7061, 'Fumariola', NULL, 'Korsh.', 126),
(7062, 'Funastrum', NULL, 'E.Fourn.', 10),
(7063, 'Funckia', NULL, 'Dennst.', 44),
(7064, 'Funifera', NULL, 'Leandro ex C.A.Mey.', 164),
(7065, 'Furarium', NULL, 'Rizzini', 98),
(7066, 'Furcatella', NULL, 'Baum.-Bod.(SUI)', 142),
(7067, 'Furcilla', NULL, 'Tiegh.(SUH)', 98),
(7068, 'Furcraea', NULL, 'Vent.', 3),
(7069, 'Furtadoa', NULL, 'M.Hotta', 12),
(7070, 'Fusaea', NULL, '(Baill.) Saff.', 8),
(7071, 'Fusanus', NULL, 'L.(SUH)', 146),
(7072, 'Fusispermum', NULL, 'Cuatrec.', 174),
(7073, 'Fusticus', NULL, 'Raf.', 109),
(7074, 'Gabunia', NULL, 'K.Schum. ex Stapf', 10),
(7075, 'Gadellia', NULL, 'Schulkina', 30),
(7076, 'Gaedawakka', NULL, 'Kuntze', 66),
(7077, 'Gagea', NULL, 'Salisb.', 94),
(7078, 'Gagnebina', NULL, 'Neck. ex DC.', 68),
(7079, 'Gagria', NULL, 'Kral', 197),
(7080, 'Gahnia', NULL, 'J.R.Forst. & G.Forst.', 55),
(7081, 'Gaiadendron', NULL, 'G.Don', 98),
(7082, 'Gaillardia', NULL, 'Foug.', 18),
(7083, 'Gaillionia', NULL, 'Endl.(SUO)', 142),
(7084, 'Gaillonia', NULL, 'A.Rich. ex DC.(SUH)', 142),
(7085, 'Galactia', NULL, 'P.Browne', 68),
(7086, 'Galactites', NULL, 'Moench', 18),
(7087, 'Galactodendron', NULL, 'Kunth', 109),
(7088, 'Galactophora', NULL, 'Woodson', 10),
(7089, 'Galactoxylon', NULL, 'Pierre', 148),
(7090, 'Galagania', NULL, 'Lipsky', 9),
(7091, 'Galapagoa', NULL, 'Hook.f.', 25),
(7092, 'Galarhoeus', NULL, 'Haw.', 66),
(7093, 'Galatella', NULL, '(Cass.) Cass.', 18),
(7094, 'Galeana', NULL, 'La Llave', 18),
(7095, 'Galega', NULL, 'L.', 68),
(7096, 'Galeobdolon', NULL, 'Huds.', 90),
(7097, 'Galeomma', NULL, 'Rauschert', 18),
(7098, 'Galeopsis', NULL, 'L.', 90),
(7099, 'Galianthe', NULL, 'Griseb.', 142),
(7100, 'Galilea', NULL, 'Parl.', 55),
(7101, 'Galiniera', NULL, 'Delile', 142),
(7102, 'Galinsoga', NULL, 'Ruiz & Pav.', 18),
(7103, 'Galitzkya', NULL, 'V.V.Botschantz.', 197),
(7104, 'Galium', NULL, 'L.', 142),
(7105, 'Gallardoa', NULL, 'Hicken', 101),
(7106, 'Gallesia', NULL, 'Casar.', 128),
(7107, 'Gallienia', NULL, 'Dubard & Dop', 142),
(7108, 'Gallion', NULL, 'Pohl(SUO)', 142),
(7109, 'Gallium', NULL, 'Mill.(SUO)', 142),
(7110, 'Galoglychia', NULL, 'Gasp.', 109),
(7111, 'Galopina', NULL, 'Thunb.', 142),
(7112, 'Galphimia', NULL, 'Cav.', 101),
(7113, 'Galpinia', NULL, 'N.E.Br.', 99),
(7114, 'Galpinsia', NULL, 'Britton', 121),
(7115, 'Galurus', NULL, 'Spreng.', 66),
(7116, 'Galvania', NULL, 'Vand.', 142),
(7117, 'Galvezia', NULL, 'Dombey ex Juss.', 423),
(7118, 'Gamanthus', NULL, 'Bunge', 5),
(7119, 'Gamatopea', NULL, 'Bremek.', 142),
(7120, 'Gambelia', NULL, 'Nutt.', 423),
(7121, 'Gambeya', NULL, 'Pierre', 148),
(7122, 'Gambeyobotrys', NULL, 'Aubrev.', 148),
(7123, 'Gamblea', NULL, 'C.B.Clarke', 13),
(7124, 'Gamochaeta', NULL, 'Wedd.', 18),
(7125, 'Gamochaetopsis', NULL, 'Anderb. & Freire', 18),
(7126, 'Gamogyne', NULL, 'N.E.Br.', 12),
(7127, 'Gamopoda', NULL, 'Baker', 107),
(7128, 'Gamosepalum', NULL, 'Hausskn.', 197),
(7129, 'Gamwellia', NULL, 'Baker', 68),
(7130, 'Ganguebina', NULL, 'Vell.(SUO)', 142),
(7131, 'Ganitrus', NULL, 'Gaertn.', 62),
(7132, 'Ganophyllum', NULL, 'Blume', 147),
(7133, 'Gantelbua', NULL, 'Bremek.', 1),
(7134, 'Garapatica', NULL, 'H.Karst.', 142),
(7135, 'Garberia', NULL, 'A.Gray', 18),
(7136, 'Garcia', NULL, 'Rohr', 66),
(7137, 'Garcibarrigoa', NULL, 'Cuatrec.', 18),
(7138, 'Garcilassa', NULL, 'Poepp.', 18),
(7139, 'Gardena', NULL, 'Adans.(SUO)', 142),
(7140, 'Gardeniola', NULL, 'Cham.', 142),
(7141, 'Gardneria', NULL, 'Wall.', 97),
(7142, 'Gardnerina', NULL, 'R.M.King & H.Rob.', 18),
(7143, 'Gardnerodoxa', NULL, 'Sandwith', 22),
(7144, 'Gardoquia', NULL, 'Ruiz & Pav.', 90),
(7145, 'Garhadiolus', NULL, 'Jaub. & Spach', 18),
(7146, 'Garnieria', NULL, 'Brongn. & Gris', 135),
(7147, 'Garretia', NULL, 'Welw.', 106),
(7148, 'Garrettia', NULL, 'H.R.Fletcher', 90),
(7149, 'Garrya', NULL, 'Douglas ex Lindl.', 74),
(7150, 'Garuleum', NULL, 'Cass.', 18),
(7151, 'Gasteranthopsis', NULL, 'Oerst.', 76),
(7152, 'Gastonia', NULL, 'Comm. ex Lam.', 13),
(7153, 'Gastranthus', NULL, 'Moritz ex Benth. & Hook.', 1),
(7154, 'Gastrococos', NULL, 'Morales', 15),
(7155, 'Gastrocotyle', NULL, 'Bunge', 25),
(7156, 'Gastrolepis', NULL, 'Tiegh.', 545),
(7157, 'Gastrolobium', NULL, 'R.Br.', 68),
(7158, 'Gastromeria', NULL, 'D.Don', 150),
(7159, 'Gatesia', NULL, 'A.Gray(SUH)', 1),
(7160, 'Gatnaia', NULL, 'Gagnep.', 184),
(7161, 'Gaudichaudia', NULL, 'Kunth', 101),
(7162, 'Gaultheria', NULL, 'Kalm ex L.', 64);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(7163, 'Gaumerocassia', NULL, 'Britton', 68),
(7164, 'Gaura', NULL, 'L.', 121),
(7165, 'Gaurella', NULL, 'Small', 121),
(7166, 'Gauridium', NULL, 'Spach', 121),
(7167, 'Gauropsis', NULL, 'C.Presl', 121),
(7168, 'Gaussia', NULL, 'H.Wendl.', 15),
(7169, 'Gavarretia', NULL, 'Baill.', 66),
(7170, 'Gaya', NULL, 'Gaudin(SUH)', 102),
(7171, 'Gayella', NULL, 'Pierre', 148),
(7172, 'Gaylussacia', NULL, 'Kunth', 64),
(7173, 'Gayoides', NULL, '(Endl.) Small', 102),
(7174, 'Gayophytum', NULL, 'A.Juss.', 121),
(7175, 'Gazania', NULL, 'Gaertn.', 18),
(7176, 'Geanthemum', NULL, '(R.E.Fr.) Saff.', 8),
(7177, 'Gearum', NULL, 'N.E.Br.', 12),
(7178, 'Geblera', NULL, 'Fisch. & C.A.Mey.', 184),
(7179, 'Geigeria', NULL, 'Griess.', 18),
(7180, 'Geijera', NULL, 'Schott', 143),
(7181, 'Geisarina', NULL, 'Raf.', 120),
(7182, 'Geiseleria', NULL, 'Klotzsch', 66),
(7183, 'Geissaspis', NULL, 'Wight & Arn.', 68),
(7184, 'Geissois', NULL, 'Labill.', 50),
(7185, 'Geissolepis', NULL, 'B.L.Rob.', 18),
(7186, 'Geissomeria', NULL, 'Lindl.', 1),
(7187, 'Geissopappus', NULL, 'Benth.', 18),
(7188, 'Geissospermum', NULL, 'Allemao', 10),
(7189, 'Geleznowia', NULL, 'Turcz.', 143),
(7190, 'Gelibia', NULL, 'Hutch.', 13),
(7191, 'Gelonium', NULL, 'Roxb. ex Willd.(SUH)', 66),
(7192, 'Gelpkea', NULL, 'Blume', 116),
(7193, 'Gelsemium', NULL, 'Juss.', 516),
(7194, 'Gembanga', NULL, 'Blume', 15),
(7195, 'Geminaria', NULL, 'Raf.', 184),
(7196, 'Gendarussa', NULL, 'Nees', 1),
(7197, 'Genesiphylla', NULL, 'L''Her.', 184),
(7198, 'Genetyllis', NULL, 'DC.', 116),
(7199, 'Genianthus', NULL, 'Hook.f.', 10),
(7200, 'Geniosporum', NULL, 'Wall. ex Benth.', 90),
(7201, 'Geniostemon', NULL, 'Engelm. & A.Gray', 75),
(7202, 'Geniostoma', NULL, 'J.R.Forst. & G.Forst.', 97),
(7203, 'Genipella', NULL, 'A.Rich. ex DC.(SUI)', 142),
(7204, 'Genista', NULL, 'L.', 68),
(7205, 'Genistella', NULL, 'Ortega', 68),
(7206, 'Genistidium', NULL, 'I.M.Johnst.', 68),
(7207, 'Gentiana', NULL, 'L.', 75),
(7208, 'Gentianella', NULL, 'Moench', 75),
(7209, 'Gentianodes', NULL, 'A.Love & D.Love', 75),
(7210, 'Gentianopsis', NULL, 'Ma', 75),
(7211, 'Gentianothamnus', NULL, 'Humbert', 75),
(7212, 'Gentilia', NULL, 'Chev. & Beille', 184),
(7213, 'Gentingia', NULL, 'J.T.Johanss. & K.M.Wong', 142),
(7214, 'Gentlea', NULL, 'Lundell', 115),
(7215, 'Gentrya', NULL, 'Breedlove & Heckard', 400),
(7216, 'Geobalanus', NULL, 'Small', 40),
(7217, 'Geocardia', NULL, 'Standl.', 142),
(7218, 'Geocaryum', NULL, 'Coss.', 9),
(7219, 'Geocaulon', NULL, 'Fernald', 146),
(7220, 'Geochorda', NULL, 'Cham. & Schltdl.', 423),
(7221, 'Geococcus', NULL, 'J.L.Drumm. ex Harv.', 197),
(7222, 'Geoffraya', NULL, 'Bonati', 150),
(7223, 'Geoffroea', NULL, 'Jacq.', 68),
(7224, 'Geoherpum', NULL, 'Willd. ex Schult.', 142),
(7225, 'Geopanax', NULL, 'Hemsl.', 13),
(7226, 'Geophila', NULL, 'D.Don', 142),
(7227, 'Geoprumnon', NULL, 'Rydb.', 68),
(7228, 'Geraea', NULL, 'Torr. & A.Gray', 18),
(7229, 'Gerardia', NULL, 'Benth.', 1),
(7230, 'Gerardiina', NULL, 'Engl.', 400),
(7231, 'Gerardiopsis', NULL, 'Engl.', 150),
(7232, 'Gerascanthus', NULL, 'P.Browne', 25),
(7233, 'Gerbera', NULL, 'L.', 18),
(7234, 'Gerontogea', NULL, 'Cham. & Schltdl.', 142),
(7235, 'Geropogon', NULL, 'L.', 18),
(7236, 'Gerrardanthus', NULL, 'Harv. ex Hook.f.', 49),
(7237, 'Gerrardina', NULL, 'Oliv.', 145),
(7238, 'Gertrudia', NULL, 'K.Schum.', 73),
(7239, 'Gesnera', NULL, 'Mart.', 76),
(7240, 'Gesneria', NULL, 'L.', 76),
(7241, 'Gesnouinia', NULL, 'Gaudich.', 171),
(7242, 'Gestroa', NULL, 'Becc.', 73),
(7243, 'Getonia', NULL, 'Roxb.', 44),
(7244, 'Geum', NULL, 'L.', 141),
(7245, 'Geunsia', NULL, 'Blume', 90),
(7246, 'Gevuina', NULL, 'Molina', 135),
(7247, 'Ghiesbreghtia', NULL, 'A.Gray(SUH)', 150),
(7248, 'Ghikaea', NULL, 'Volkens & Schweinf.', 150),
(7249, 'Ghinia', NULL, 'Schreb.', 173),
(7250, 'Giadotrum', NULL, 'Pichon', 10),
(7251, 'Gibbaria', NULL, 'Cass.', 18),
(7252, 'Gibbsia', NULL, 'Rendle', 171),
(7253, 'Gibsoniothamnus', NULL, 'L.O.Williams', 540),
(7254, 'Giesleria', NULL, 'Regel', 76),
(7255, 'Gifola', NULL, 'Cass.', 18),
(7256, 'Gigalobium', NULL, 'P.Browne', 68),
(7257, 'Gigasiphon', NULL, 'Drake', 68),
(7258, 'Gijefa', NULL, '(M.Roem.) Post & Kuntze', 49),
(7259, 'Gilberta', NULL, 'Turcz.', 18),
(7260, 'Gilbertiella', NULL, 'Boutique', 8),
(7261, 'Gilesia', NULL, 'F.Muell.', 102),
(7262, 'Gilgiodaphne', NULL, 'Domke', 164),
(7263, 'Gilibertia', NULL, 'Ruiz & Pav.(SUH)', 13),
(7264, 'Gillbeea', NULL, 'F.Muell.', 50),
(7265, 'Gillenia', NULL, 'Moench', 141),
(7266, 'Gillespiea', NULL, 'A.C.Sm.', 142),
(7267, 'Gilletiella', NULL, 'De Wild. & T.Durand(SUH)', 1),
(7268, 'Gilletiodendron', NULL, 'Vermoesen', 68),
(7269, 'Gilmania', NULL, 'Coville', 134),
(7270, 'Gilruthia', NULL, 'Ewart', 18),
(7271, 'Gimbernatea', NULL, 'Ruiz & Pav.', 44),
(7272, 'Ginalloa', NULL, 'Korth.', 146),
(7273, 'Gingidia', NULL, 'J.W.Dawson', 9),
(7274, 'Gingidium', NULL, 'J.R.Forst. & G.Forst.(SUH)', 9),
(7275, 'Ginnania', NULL, 'M.Roem.(SUH)', 106),
(7276, 'Ginora', NULL, 'L.', 99),
(7277, 'Ginoria', NULL, 'Jacq.', 99),
(7278, 'Giorgiella', NULL, 'De Wild.', 127),
(7279, 'Giraldiella', NULL, 'Dammer', 94),
(7280, 'Girardinia', NULL, 'Gaudich.', 171),
(7281, 'Girgensohnia', NULL, 'Bunge', 5),
(7282, 'Gitara', NULL, 'Pax & K.Hoffm.', 66),
(7283, 'Githopsis', NULL, 'Nutt.', 30),
(7284, 'Givotia', NULL, 'Griff.', 66),
(7285, 'Gjellerupia', NULL, 'Lauterb.', 122),
(7286, 'Gladiopappus', NULL, 'Humbert', 18),
(7287, 'Glandonia', NULL, 'Griseb.', 101),
(7288, 'Glandularia', NULL, 'J.F.Gmel.', 173),
(7289, 'Glaribraya', NULL, 'Hara', 197),
(7290, 'Glastaria', NULL, 'Boiss.', 197),
(7291, 'Glaucium', NULL, 'Mill.', 126),
(7292, 'Glaucocarpum', NULL, 'Rollins', 197),
(7293, 'Glaucocochlearia', NULL, '(O.E.Schulz) Pobed.', 197),
(7294, 'Glaucosciadium', NULL, 'B.L.Burtt & P.H.Davis', 9),
(7295, 'Glaucothea', NULL, 'O.F.Cook', 15),
(7296, 'Glaux', NULL, 'L.', 115),
(7297, 'Glaziostelma', NULL, 'E.Fourn.', 10),
(7298, 'Glaziova', NULL, 'Bureau', 22),
(7299, 'Glaziovianthus', NULL, 'G.M.Barroso', 18),
(7300, 'Gleadovia', NULL, 'Gamble & Prain', 400),
(7301, 'Gleasonia', NULL, 'Standl.', 142),
(7302, 'Glechoma', NULL, 'L.', 90),
(7303, 'Glechon', NULL, 'Spreng.', 90),
(7304, 'Gleditschia', NULL, 'Scop.', 68),
(7305, 'Gleditsia', NULL, 'L.', 68),
(7306, 'Glehnia', NULL, 'F.Schmidt ex Miq.', 9),
(7307, 'Glekia', NULL, 'Hilliard', 150),
(7308, 'Glia', NULL, 'Sond.', 9),
(7309, 'Glionnetia', NULL, 'Tirveng.', 142),
(7310, 'Gliopsis', NULL, 'Rauschert(SUS)', 9),
(7311, 'Globimetula', NULL, 'Tiegh.', 98),
(7312, 'Globulariopsis', NULL, 'Compton', 150),
(7313, 'Globulostylis', NULL, 'Wernham', 142),
(7314, 'Glochidionopsis', NULL, 'Blume', 184),
(7315, 'Glochidotheca', NULL, 'Fenzl', 9),
(7316, 'Glochisandra', NULL, 'Wight', 184),
(7317, 'Glockeria', NULL, 'Nees(SUH)', 1),
(7318, 'Gloeocarpus', NULL, 'Radlk.', 147),
(7319, 'Gloneria', NULL, 'Andre', 142),
(7320, 'Glosarithys', NULL, 'Rizzini', 1),
(7321, 'Glosocomia', NULL, 'D.Don(SUO)', 30),
(7322, 'Glossanthus', NULL, 'Klein ex Benth.', 76),
(7323, 'Glossarion', NULL, 'Maguire & Wurdack', 18),
(7324, 'Glossidea', NULL, 'Tiegh.', 98),
(7325, 'Glossocardia', NULL, 'Cass.', 18),
(7326, 'Glossocarya', NULL, 'Wall. ex Griff.', 90),
(7327, 'Glossochilus', NULL, 'Nees', 1),
(7328, 'Glossocomia', NULL, 'Rchb.(SUO)', 30),
(7329, 'Glossogyne', NULL, 'Cass.', 18),
(7330, 'Glossolepis', NULL, 'Gilg', 147),
(7331, 'Glossoloma', NULL, 'Hanst.', 76),
(7332, 'Glossoma', NULL, 'Schreb.', 105),
(7333, 'Glossonema', NULL, 'Decne.', 10),
(7334, 'Glossopappus', NULL, 'Kunze', 18),
(7335, 'Glossopholis', NULL, 'Pierre', 107),
(7336, 'Glossostelma', NULL, 'Schltr.', 10),
(7337, 'Glossostemon', NULL, 'Desf.', 102),
(7338, 'Glossostephanus', NULL, 'E.Mey.', 10),
(7339, 'Glossostigma', NULL, 'Wight & Arn.', 417),
(7340, 'Glossostipula', NULL, 'Lorence', 142),
(7341, 'Glottidium', NULL, 'Desv.', 68),
(7342, 'Gloxinia', NULL, 'L''Her.', 76),
(7343, 'Gluema', NULL, 'Aubrev. & Pellegr.', 148),
(7344, 'Glumicalyx', NULL, 'Hiern', 150),
(7345, 'Glutago', NULL, 'Comm. ex Poir.', 98),
(7346, 'Glycanthes', NULL, 'Raf.', 76),
(7347, 'Glycideras', NULL, 'DC.', 18),
(7348, 'Glycine', NULL, 'Willd.', 68),
(7349, 'Glycoxylon', NULL, 'Ducke', 148),
(7350, 'Glycyrrhiza', NULL, 'L.', 68),
(7351, 'Glyphostylus', NULL, 'Gagnep.', 66),
(7352, 'Glyptocarpa', NULL, 'Hu', 162),
(7353, 'Glyptocaryopsis', NULL, 'Brand', 25),
(7354, 'Glyptopleura', NULL, 'Eaton', 18),
(7355, 'Glyptostrobus', NULL, 'Endl.', 51),
(7356, 'Gnaphaliothamnus', NULL, 'Kirp.', 18),
(7357, 'Gnaphalium', NULL, 'L.', 18),
(7358, 'Gnaphalodes', NULL, 'Mill.', 18),
(7359, 'Gnephosis', NULL, 'Cass.', 18),
(7360, 'Gnidia', NULL, 'L.', 164),
(7361, 'Gnoteris', NULL, 'Raf.(SUS)', 90),
(7362, 'Gochnatia', NULL, 'Kunth', 18),
(7363, 'Godefroya', NULL, 'Gagnep.', 184),
(7364, 'Godetia', NULL, 'Spach', 121),
(7365, 'Godoya', NULL, 'Ruiz & Pav.', 118),
(7366, 'Goebelia', NULL, 'Bunge ex Boiss.', 68),
(7367, 'Goeldinia', NULL, 'Huber', 92),
(7368, 'Goeppertia', NULL, 'Griseb.(SUH)', 75),
(7369, 'Goerziella', NULL, 'Urb.', 5),
(7370, 'Goethalsia', NULL, 'Pittier', 102),
(7371, 'Goethartia', NULL, 'Herzog', 171),
(7372, 'Goethea', NULL, 'Nees', 102),
(7373, 'Goetzea', NULL, 'Wydler', 154),
(7374, 'Golaea', NULL, 'Chiov.', 1),
(7375, 'Goldbachia', NULL, 'DC.', 197),
(7376, 'Goldfussia', NULL, 'Nees', 1),
(7377, 'Goldmanella', NULL, 'Greenm.', 18),
(7378, 'Goldmania', NULL, 'Rose ex Micheli', 68),
(7379, 'Gomara', NULL, 'Ruiz & Pav.(SUH)', 76),
(7380, 'Gomaranthus', NULL, 'Rauschert', 76),
(7381, 'Gomaria', NULL, 'Spreng.(SUO)', 76),
(7382, 'Gomezia', NULL, 'Mutis(SUO)', 142),
(7383, 'Gomidesia', NULL, 'O.Berg', 116),
(7384, 'Gomosia', NULL, 'Lam.(SUO)', 142),
(7385, 'Gomoza', NULL, 'Cothen.(SUO)', 142),
(7386, 'Gomozia', NULL, 'Mutis ex L.f.', 142),
(7387, 'Gomphiluma', NULL, 'Baill.', 148),
(7388, 'Gomphocalyx', NULL, 'Baker', 142),
(7389, 'Gomphocarpus', NULL, 'R.Br.', 10),
(7390, 'Gomphogyne', NULL, 'Griff.', 49),
(7391, 'Gompholobium', NULL, 'Sm.', 68),
(7392, 'Gomphopetalum', NULL, 'Turcz.', 9),
(7393, 'Gomphosia', NULL, 'Wedd.', 142),
(7394, 'Gomphostemma', NULL, 'Wall. ex Benth.', 90),
(7395, 'Gomphostigma', NULL, 'Turcz.', 150),
(7396, 'Gomphotis', NULL, 'Raf.', 116),
(7397, 'Gomphrena', NULL, 'L.', 5),
(7398, 'Gomutus', NULL, 'Correa', 15),
(7399, 'Gonatanthus', NULL, 'Klotzsch', 12),
(7400, 'Gonatogyne', NULL, 'Klotzsch ex Mull.Arg.', 184),
(7401, 'Gonatopus', NULL, 'Hook.f. ex Engl.', 12),
(7402, 'Gongrodiscus', NULL, 'Radlk.', 147),
(7403, 'Gongronema', NULL, '(Endl.) Decne.', 10),
(7404, 'Gongrospermum', NULL, 'Radlk.', 147),
(7405, 'Gongrostylus', NULL, 'R.M.King & H.Rob.', 18),
(7406, 'Gongrothamnus', NULL, 'Steetz', 18),
(7407, 'Gongylocarpus', NULL, 'Schltdl. & Cham.', 121),
(7408, 'Gongylolepis', NULL, 'R.H.Schomb.', 18),
(7409, 'Gongylosciadium', NULL, 'Rech.f.', 9),
(7410, 'Gongylosperma', NULL, 'King & Gamble', 10),
(7411, 'Gonianthes', NULL, 'A.Rich.(SUH)', 142),
(7412, 'Gonioanthela', NULL, 'Malme', 10),
(7413, 'Goniocaulon', NULL, 'Cass.', 18),
(7414, 'Goniocladus', NULL, 'Burret', 15),
(7415, 'Goniodiscus', NULL, 'Kuhlm.', 38),
(7416, 'Goniogyna', NULL, 'DC.', 68),
(7417, 'Gonioma', NULL, 'E.Mey.', 10),
(7418, 'Goniorrhachis', NULL, 'Taub.', 68),
(7419, 'Goniosperma', NULL, 'Burret', 15),
(7420, 'Goniostemma', NULL, 'Wight', 10),
(7421, 'Gonocalyx', NULL, 'Planch. & Linden', 64),
(7422, 'Gonocrypta', NULL, 'Baill.', 10),
(7423, 'Gonocytisus', NULL, 'Spach', 68),
(7424, 'Gonolobus', NULL, 'Michx.', 10),
(7425, 'Gonoptera', NULL, 'Turcz.', 177),
(7426, 'Gonopyrum', NULL, 'Fisch. & C.A.Mey.', 134),
(7427, 'Gonospermum', NULL, 'Less.', 18),
(7428, 'Gonostegia', NULL, 'Turcz.', 171),
(7429, 'Gonosuke', NULL, 'Raf.', 109),
(7430, 'Gonotheca', NULL, 'Blume ex DC.', 142),
(7431, 'Gonsii', NULL, 'Adans.(SUS)', 68),
(7432, 'Gontscharovia', NULL, 'Boriss.', 90),
(7433, 'Gonyanera', NULL, 'Korth.', 142),
(7434, 'Gonypetalum', NULL, 'Ule', 57),
(7435, 'Gonzalea', NULL, 'Pers.', 142),
(7436, 'Goodallia', NULL, 'Benth.', 164),
(7437, 'Goodia', NULL, 'Salisb.', 68),
(7438, 'Goodmania', NULL, 'Reveal & Ertter', 134),
(7439, 'Gorceixia', NULL, 'Baker', 18),
(7440, 'Gorgonidium', NULL, 'Schott', 12),
(7441, 'Gormania', NULL, 'Britton', 48),
(7442, 'Gorodkovia', NULL, 'Botsch. & Karav.', 197),
(7443, 'Gorteria', NULL, 'L.', 18),
(7444, 'Gosela', NULL, 'Choisy', 150),
(7445, 'Gossweilera', NULL, 'S.Moore', 18),
(7446, 'Gossweilerodendron', NULL, 'Harms', 68),
(7447, 'Gossypianthus', NULL, 'Hook.', 5),
(7448, 'Gossypioides', NULL, 'Skovst. ex J.B.Hutch.', 102),
(7449, 'Gossypiospermum', NULL, '(Griseb.) Urb.', 145),
(7450, 'Gothofreda', NULL, 'Vent.', 10),
(7451, 'Gouania', NULL, 'Jacq.', 139),
(7452, 'Goughia', NULL, 'Wight', 195),
(7453, 'Gouldia', NULL, 'A.Gray', 142),
(7454, 'Gourliea', NULL, 'Gillies ex Hook. & Arn.', 68),
(7455, 'Goyazia', NULL, 'Taub.', 76),
(7456, 'Goyazianthus', NULL, 'R.M.King & H.Rob.', 18),
(7457, 'Grabowskia', NULL, 'Schltdl.', 154),
(7458, 'Graciela', NULL, 'Rzed.', 18),
(7459, 'Graderia', NULL, 'Benth.', 400),
(7460, 'Graeffea', NULL, 'Seem.', 102),
(7461, 'Graeffenrieda', NULL, 'D.Dietr.(SUO)', 105),
(7462, 'Graellsia', NULL, 'Boiss.', 197),
(7463, 'Grajalesia', NULL, 'Miranda', 117),
(7464, 'Grammadenia', NULL, 'Benth.', 115),
(7465, 'Grammanthes', NULL, 'DC.', 48),
(7466, 'Grammatotheca', NULL, 'C.Presl', 30),
(7467, 'Grammica', NULL, 'Lour.', 46),
(7468, 'Grammosciadium', NULL, 'DC.', 9),
(7469, 'Grammosolen', NULL, 'Haegi', 154),
(7470, 'Grammosperma', NULL, 'O.E.Schulz', 197),
(7471, 'Granadilla', NULL, 'Mill.', 127),
(7472, 'Grandidiera', NULL, 'Jaub.', 198),
(7473, 'Grangea', NULL, 'Adans.', 18),
(7474, 'Grangeopsis', NULL, 'Humbert', 18),
(7475, 'Grangeria', NULL, 'Comm. ex Juss.', 40),
(7476, 'Grantia', NULL, 'Boiss.(SUH)', 18),
(7477, 'Graphandra', NULL, 'J.B.Imlay', 1),
(7478, 'Graphardisia', NULL, '(Mez) Lundell', 115),
(7479, 'Graphistemma', NULL, '(Champ. ex Benth.) Champ. ex Ben', 10),
(7480, 'Graphistylis', NULL, 'B.Nord.', 18),
(7481, 'Graptopetalum', NULL, 'Rose', 48),
(7482, 'Graptophyllum', NULL, 'Nees', 1),
(7483, 'Gratiola', NULL, 'L.', 423),
(7484, 'Gratwickia', NULL, 'F.Muell.', 18),
(7485, 'Grauanthus', NULL, 'Fayed', 18),
(7486, 'Gravesia', NULL, 'Naudin', 105),
(7487, 'Gravesiella', NULL, 'A.Fern. & R.Fern.', 105),
(7488, 'Grayia', NULL, 'Hook. & Arn.', 5),
(7489, 'Grazielia', NULL, 'R.M.King & H.Rob.', 18),
(7490, 'Grazielodendron', NULL, 'H.C.Lima', 68),
(7491, 'Greenella', NULL, 'A.Gray', 18),
(7492, 'Greeneocharis', NULL, 'Gurke & Harms', 25),
(7493, 'Greeniopsis', NULL, 'Merr.', 142),
(7494, 'Greenmaniella', NULL, 'W.M.Sharp', 18),
(7495, 'Greenovia', NULL, 'Webb & Berthel.', 48),
(7496, 'Greggia', NULL, 'A.Gray(SUH)', 197),
(7497, 'Grenacheria', NULL, 'Mez', 115),
(7498, 'Grevellina', NULL, 'Baill.', 106),
(7499, 'Grevillea', NULL, 'R.Br. ex Knight', 135),
(7500, 'Grewiopsis', NULL, 'De Wild. & T.Durand', 102),
(7501, 'Greyia', NULL, 'Hook. & Harv.', 182),
(7502, 'Griffithia', NULL, 'Maingay ex King(SUH)', 8),
(7503, 'Griffithianthus', NULL, 'Merr.', 8),
(7504, 'Griffonia', NULL, 'Hook.f.(SUH)', 68),
(7505, 'Grimaldia', NULL, 'Schrank', 68),
(7506, 'Grimmeodendron', NULL, 'Urb.', 66),
(7507, 'Grindelia', NULL, 'Willd.', 18),
(7508, 'Grischowia', NULL, 'H.Karst.', 105),
(7509, 'Grisebachia', NULL, 'Klotzsch', 64),
(7510, 'Grisebachianthus', NULL, 'R.M.King & H.Rob.', 18),
(7511, 'Grisebachiella', NULL, 'Lorentz', 10),
(7512, 'Grisia', NULL, 'Brongn.', 142),
(7513, 'Grislea', NULL, 'L.', 44),
(7514, 'Grisollea', NULL, 'Baill.', 545),
(7515, 'Grisseea', NULL, 'Bakh.f.', 10),
(7516, 'Gronophyllum', NULL, 'Scheff.', 15),
(7517, 'Grossera', NULL, 'Pax', 66),
(7518, 'Grosvenoria', NULL, 'R.M.King & H.Rob.', 18),
(7519, 'Grotefendia', NULL, 'Seem.', 13),
(7520, 'Gruhlmannia', NULL, 'Neck. ex Raf.', 142),
(7521, 'Grumilea', NULL, 'Gaertn.', 142),
(7522, 'Grundlea', NULL, 'Steud.(SUO)', 142),
(7523, 'Grunilea', NULL, 'Poir.(SUO)', 142),
(7524, 'Guagnebina', NULL, 'Vell.', 142),
(7525, 'Guaiacum', NULL, 'L.', 177),
(7526, 'Guaicaia', NULL, 'Maguire', 18),
(7527, 'Guajacum', NULL, 'L.(SUO)', 177),
(7528, 'Guajava', NULL, 'Mill.', 116),
(7529, 'Guamatela', NULL, 'Donn.Sm.', 141),
(7530, 'Guamia', NULL, 'Merr.', 8),
(7531, 'Guanabanus', NULL, 'Mill.', 8),
(7532, 'Guapeba', NULL, 'Gomes', 148),
(7533, 'Guarania', NULL, 'Wedd. ex Baill.', 184),
(7534, 'Guardiola', NULL, 'Cerv. ex Humb. & Bonpl.', 18),
(7535, 'Guatteriella', NULL, 'R.E.Fr.', 8),
(7536, 'Guatteriopsis', NULL, 'R.E.Fr.', 8),
(7537, 'Guayabilla', NULL, 'Sesse & Moc.', 145),
(7538, 'Guayania', NULL, 'R.M.King & H.Rob.', 18),
(7539, 'Guaymasia', NULL, 'Britton & Rose', 68),
(7540, 'Gubleria', NULL, 'Gaudich.', 154),
(7541, 'Gueldenstaedtia', NULL, 'Fisch.', 68),
(7542, 'Guerkea', NULL, 'K.Schum.', 10),
(7543, 'Guerreroia', NULL, 'Merr.', 18),
(7544, 'Guersentia', NULL, 'Raf.', 148),
(7545, 'Guettardella', NULL, 'Benth.', 142),
(7546, 'Guevaria', NULL, 'R.M.King & H.Rob.', 18),
(7547, 'Guibourtia', NULL, 'Benn.', 68),
(7548, 'Guichenotia', NULL, 'J.Gay', 102),
(7549, 'Guidonia', NULL, 'P.Browne(SUH)', 145),
(7550, 'Guiera', NULL, 'Adans. ex Juss.', 44),
(7551, 'Guihaia', NULL, 'J.Dransf., S.K.Lee & F.N.Wei', 15),
(7552, 'Guilandina', NULL, 'L.', 68),
(7553, 'Guilielma', NULL, 'Mart.', 15),
(7554, 'Guilleminea', NULL, 'Kunth', 5),
(7555, 'Guillenia', NULL, 'Greene', 197),
(7556, 'Guillonea', NULL, 'Coss.', 9),
(7557, 'Guindilia', NULL, 'Gillies ex Hook. & Arn.', 147),
(7558, 'Guiraoa', NULL, 'Coss.', 197),
(7559, 'Guizotia', NULL, 'Cass.', 18),
(7560, 'Gulubia', NULL, 'Becc.', 15),
(7561, 'Gulubiopsis', NULL, 'Becc.', 15),
(7562, 'Gumillea', NULL, 'Ruiz & Pav.', 50),
(7563, 'Gundelia', NULL, 'L.', 18),
(7564, 'Gundlachia', NULL, 'A.Gray', 18),
(7565, 'Gunillaea', NULL, 'Thulin', 30),
(7566, 'Gunnessia', NULL, 'P.I.Forst.', 10),
(7567, 'Gurania', NULL, '(Schltdl.) Cogn.', 49),
(7568, 'Guraniopsis', NULL, 'Cogn.', 49),
(7569, 'Guru', NULL, 'Buch.-Ham. ex Wight', 10),
(7570, 'Gussonia', NULL, 'Spreng.', 66),
(7571, 'Gutenbergia', NULL, 'Walp.(SUO)', 18),
(7572, 'Guthnickia', NULL, 'Regel', 76),
(7573, 'Gutierrezia', NULL, 'Lag.', 18),
(7574, 'Guttenbergia', NULL, 'Zoll. & Moritzi', 142),
(7575, 'Gutzlaffia', NULL, 'Hance', 1),
(7576, 'Guya', NULL, 'Frapp.', 66),
(7577, 'Guyonia', NULL, 'Naudin', 105),
(7578, 'Gymapsis', NULL, 'Bremek.', 1),
(7579, 'Gymelaea', NULL, '(Endl.) Spach', 120),
(7580, 'Gyminda', NULL, 'Sarg.', 38),
(7581, 'Gymnacanthus', NULL, 'Oerst.', 1),
(7582, 'Gymnagathis', NULL, 'Stapf(SUH)', 105),
(7583, 'Gymnalypha', NULL, 'Griseb.', 66),
(7584, 'Gymnanthemum', NULL, 'Cass.', 18),
(7585, 'Gymnanthera', NULL, 'R.Br.', 10),
(7586, 'Gymnanthes', NULL, 'Sw.', 66),
(7587, 'Gymnarrhena', NULL, 'Desf.', 18),
(7588, 'Gymnartocarpus', NULL, 'Boerl.', 109),
(7589, 'Gymnema', NULL, 'R.Br.', 10),
(7590, 'Gymnemopsis', NULL, 'Costantin', 10),
(7591, 'Gymnobothrys', NULL, 'Wall. ex Baill.', 66),
(7592, 'Gymnocladus', NULL, 'Lam.', 68),
(7593, 'Gymnocondylus', NULL, 'R.M.King & H.Rob.', 18),
(7594, 'Gymnocoronis', NULL, 'DC.', 18),
(7595, 'Gymnodiscus', NULL, 'Less.', 18),
(7596, 'Gymnogonum', NULL, 'Parry', 134),
(7597, 'Gymnolaema', NULL, 'Benth.(SUH)', 10),
(7598, 'Gymnolaena', NULL, '(DC.) Rydb.', 18),
(7599, 'Gymnoleima', NULL, 'Decne.', 25),
(7600, 'Gymnolomia', NULL, 'Kunth', 18),
(7601, 'Gymnoluma', NULL, 'Baill.', 148),
(7602, 'Gymnomesium', NULL, 'Schott', 12),
(7603, 'Gymnopentzia', NULL, 'Benth.', 18),
(7604, 'Gymnopetalum', NULL, 'Arn.', 49),
(7605, 'Gymnophyton', NULL, 'Clos', 9),
(7606, 'Gymnopodium', NULL, 'Rolfe', 134),
(7607, 'Gymnopremnon', NULL, 'Lindig', 52),
(7608, 'Gymnorinorea', NULL, 'Keay', 174),
(7609, 'Gymnoschoenus', NULL, 'Nees', 55),
(7610, 'Gymnosciadium', NULL, 'Hochst.', 9),
(7611, 'Gymnosperma', NULL, 'Less.', 18),
(7612, 'Gymnosphaera', NULL, 'Blume', 52),
(7613, 'Gymnostachys', NULL, 'R.Br.', 12),
(7614, 'Gymnostachyum', NULL, 'Nees', 1),
(7615, 'Gymnostemon', NULL, 'Aubrev. & Pellegr.', 151),
(7616, 'Gymnostephium', NULL, 'Less.', 18),
(7617, 'Gymnostillingia', NULL, 'Mull.Arg.', 66),
(7618, 'Gymnostoma', NULL, 'L.A.S.Johnson', 36),
(7619, 'Gymnostyles', NULL, 'Juss.', 18),
(7620, 'Gynaecopachys', NULL, 'Hassk.(SUO)', 142),
(7621, 'Gynamblosis', NULL, 'Torr.', 66),
(7622, 'Gynandropsis', NULL, 'DC.', 32),
(7623, 'Gynatrix', NULL, 'Alef.', 102),
(7624, 'Gynestum', NULL, 'Poit.', 15),
(7625, 'Gynocardia', NULL, 'R.Br.', 198),
(7626, 'Gynochthodes', NULL, 'Blume', 142),
(7627, 'Gynocraterium', NULL, 'Bremek.', 1),
(7628, 'Gynoon', NULL, 'Juss.', 184),
(7629, 'Gynopachis', NULL, 'Blume', 142),
(7630, 'Gynophoraria', NULL, 'Rydb.', 68),
(7631, 'Gynophorea', NULL, 'Gilli', 197),
(7632, 'Gynophyge', NULL, 'Gilli', 9),
(7633, 'Gynostemma', NULL, 'Blume', 49),
(7634, 'Gynoxys', NULL, 'Cass.', 18),
(7635, 'Gynura', NULL, 'Cass.', 18),
(7636, 'Gypothamnium', NULL, 'Phil.', 18),
(7637, 'Gypsacanthus', NULL, 'Lott, V.Jaram. & Rzed.', 1),
(7638, 'Gyptidium', NULL, 'R.M.King & H.Rob.', 18),
(7639, 'Gyptis', NULL, '(Cass.) Cass.', 18),
(7640, 'Gyrandra', NULL, 'Wall.(SUI)', 195),
(7641, 'Gyrinopsis', NULL, 'Decne.', 164),
(7642, 'Gyrocarpus', NULL, 'Jacq.', 79),
(7643, 'Gyrocaryum', NULL, 'Valdes', 25),
(7644, 'Gyrodoma', NULL, 'Wild', 18),
(7645, 'Gyroptera', NULL, 'Botsch.', 5),
(7646, 'Gyrostelma', NULL, 'E.Fourn.', 10),
(7647, 'Gyrostipula', NULL, 'J.-F.Leroy', 142),
(7648, 'Gyrotaenia', NULL, 'Griseb.', 171),
(7649, 'Haarera', NULL, 'Hutch. & E.A.Bruce', 18),
(7650, 'Haastia', NULL, 'Hook.f.', 18),
(7651, 'Haberlea', NULL, 'Friv.', 76),
(7652, 'Hablitzia', NULL, 'M.Bieb.', 5),
(7653, 'Habracanthus', NULL, 'Nees', 1),
(7654, 'Habroneuron', NULL, 'Standl.', 142),
(7655, 'Habrothamnus', NULL, 'Endl.', 154),
(7656, 'Habsia', NULL, 'Steud.', 142),
(7657, 'Habzelia', NULL, 'A.DC.', 8),
(7658, 'Hackelia', NULL, 'Opiz', 25),
(7659, 'Hacquetia', NULL, 'Neck. ex DC.', 9),
(7660, 'Haeckeria', NULL, 'F.Muell.', 18),
(7661, 'Haegiela', NULL, 'P.S.Short', 18),
(7662, 'Haemacanthus', NULL, 'S.Moore', 1),
(7663, 'Haematocarpus', NULL, 'Miers', 107),
(7664, 'Haematodendron', NULL, 'Capuron', 114),
(7665, 'Haematospermum', NULL, 'Wall.', 66),
(7666, 'Haematostaphis', NULL, 'Hook.f.', 6),
(7667, 'Haematostemon', NULL, '(Mull.Arg.) Pax & K.Hoffm.', 66),
(7668, 'Haematoxylum', NULL, 'L.', 68),
(7669, 'Haemax', NULL, 'E.Mey.', 10),
(7670, 'Haemocharis', NULL, 'Salisb. ex Mart. & Zucc.', 162),
(7671, 'Haenianthus', NULL, 'Griseb.', 120),
(7672, 'Hagenia', NULL, 'J.F.Gmel.', 141),
(7673, 'Hainania', NULL, 'Merr.', 102),
(7674, 'Haitia', NULL, 'Urb.', 99),
(7675, 'Haitiella', NULL, 'L.H.Bailey', 15),
(7676, 'Haitimimosa', NULL, 'Britton', 68),
(7677, 'Hakea', NULL, 'Schrad.', 135),
(7678, 'Halacsya', NULL, 'Dorfl.', 25),
(7679, 'Halacsyella', NULL, 'Janch.', 30),
(7680, 'Halanthium', NULL, 'K.Koch', 5),
(7681, 'Halarchon', NULL, 'Bunge', 5),
(7682, 'Halconia', NULL, 'Merr.', 102),
(7683, 'Haldina', NULL, 'Ridsdale', 142),
(7684, 'Halecus', NULL, 'Raf.', 66),
(7685, 'Halenia', NULL, 'Borkh.', 75),
(7686, 'Halesia', NULL, 'Ellis ex L.', 158),
(7687, 'Halfordia', NULL, 'F.Muell.', 143),
(7688, 'Halgania', NULL, 'Gaudich.', 25),
(7689, 'Halimione', NULL, 'Aellen', 5),
(7690, 'Halimocnemis', NULL, 'C.A.Mey.', 5),
(7691, 'Halimodendron', NULL, 'Fisch. ex DC.', 68),
(7692, 'Halimolobos', NULL, 'Tausch', 197),
(7693, 'Halimolobus', NULL, 'Tausch(SUO)', 197),
(7694, 'Halimus', NULL, 'Wallr.', 5),
(7695, 'Halleria', NULL, 'L.', 471),
(7696, 'Hallia', NULL, 'Thunb.', 68),
(7697, 'Hallieracantha', NULL, 'Stapf', 1),
(7698, 'Halliophytum', NULL, 'I.M.Johnst.', 66),
(7699, 'Halmoorea', NULL, 'J.Dransf. & N.W.Uhl', 15),
(7700, 'Halocarpus', NULL, 'Quinn', 132),
(7701, 'Halocharis', NULL, 'Moq.', 5),
(7702, 'Halocnemum', NULL, 'M.Bieb.', 5),
(7703, 'Halogeton', NULL, 'C.A.Mey.', 5),
(7704, 'Halopegia', NULL, 'K.Schum.', 103),
(7705, 'Halopeplis', NULL, 'Bunge ex Ung.-Sternb.', 5),
(7706, 'Halophlebia', NULL, '(Mart.) Lindl.', 52),
(7707, 'Halosarcia', NULL, 'Paul G.Wilson', 5),
(7708, 'Halosciastrum', NULL, 'Koidz.', 9),
(7709, 'Halosicyos', NULL, 'Mart.Crov.', 49),
(7710, 'Halostachys', NULL, 'C.A.Mey. ex Schrenk', 5),
(7711, 'Halothamnus', NULL, 'F.Muell.(SUH)', 5),
(7712, 'Halotis', NULL, 'Bunge', 5),
(7713, 'Haloxanthium', NULL, 'Ulbr.', 5),
(7714, 'Haloxylon', NULL, 'Bunge', 5),
(7715, 'Halphophyllum', NULL, 'Mansf.', 76),
(7716, 'Hambergera', NULL, 'Scop.', 44),
(7717, 'Hamilcoa', NULL, 'Prain', 66),
(7718, 'Hamiltonia', NULL, 'Roxb.', 142),
(7719, 'Hammada', NULL, 'Iljin', 5),
(7720, 'Hammatolobium', NULL, 'Fenzl', 68),
(7721, 'Hamosa', NULL, 'Medik.', 68),
(7722, 'Hanabusaya', NULL, 'Nakai', 30),
(7723, 'Hanburia', NULL, 'Seem.', 49),
(7724, 'Hanburyophyton', NULL, 'Bureau', 22),
(7725, 'Hancea', NULL, 'Seem.(SUH)', 66),
(7726, 'Hanceola', NULL, 'Kudo', 90),
(7727, 'Hancornia', NULL, 'Gomes', 10),
(7728, 'Handelia', NULL, 'Heimerl', 18),
(7729, 'Handeliodendron', NULL, 'Rehder', 148),
(7730, 'Handroanthus', NULL, 'Mattos', 22),
(7731, 'Hanghomia', NULL, 'Gagnep. & Thenint', 10),
(7732, 'Hannafordia', NULL, 'F.Muell.', 102),
(7733, 'Hansemannia', NULL, 'K.Schum.', 68),
(7734, 'Hanslia', NULL, 'Schindl.', 68),
(7735, 'Hansteinia', NULL, 'Oerst.', 1),
(7736, 'Hapaline', NULL, 'Schott', 12),
(7737, 'Hapaloceras', NULL, 'Hassk.', 148),
(7738, 'Haplanthera', NULL, 'Hochst.', 1),
(7739, 'Haplanthodes', NULL, 'Kuntze', 1),
(7740, 'Haplanthoides', NULL, 'H.W.Li(SUH)', 1),
(7741, 'Haplanthus', NULL, 'Nees', 1),
(7742, 'Haplocalymma', NULL, 'S.F.Blake', 18),
(7743, 'Haplocarpha', NULL, 'Less.', 18),
(7744, 'Haploclathra', NULL, 'Benth.', 42),
(7745, 'Haplocoelum', NULL, 'Radlk.', 147),
(7746, 'Haplodesmium', NULL, 'Naudin', 105),
(7747, 'Haplodypsis', NULL, 'Baill.', 15),
(7748, 'Haploesthes', NULL, 'A.Gray', 18),
(7749, 'Haplolobus', NULL, 'H.J.Lam', 27),
(7750, 'Haplolophium', NULL, 'Cham.', 22),
(7751, 'Haplopappus', NULL, 'Cass.', 18),
(7752, 'Haplopetalon', NULL, 'A.Gray', 140),
(7753, 'Haplopetalum', NULL, 'Miq.(SUO)', 140),
(7754, 'Haplophandra', NULL, 'Pichon', 10),
(7755, 'Haplophloga', NULL, 'Baill.', 15),
(7756, 'Haplophragma', NULL, 'Dop', 22),
(7757, 'Haplophyllophorus', NULL, '(Brenan) A.Fern. & R.Fern.', 105),
(7758, 'Haplophyllum', NULL, 'A.Juss.', 143),
(7759, 'Haplophyton', NULL, 'A.DC.', 10),
(7760, 'Haplorhus', NULL, 'Engl.', 6),
(7761, 'Haplormosia', NULL, 'Harms', 68),
(7762, 'Haplosciadium', NULL, 'Hochst.', 9),
(7763, 'Haploseseli', NULL, 'H.Wolff & Hand.-Mazz.', 9),
(7764, 'Haplosphaera', NULL, 'Hand.-Mazz.', 9),
(7765, 'Haplostachys', NULL, '(A.Gray) W.F.Hillebr.', 90),
(7766, 'Haplostephium', NULL, 'Mart. ex DC.', 18),
(7767, 'Haptocarpum', NULL, 'Ule', 509),
(7768, 'Haradjania', NULL, 'Rech.f.', 18),
(7769, 'Harbouria', NULL, 'J.M.Coult. & Rose', 9),
(7770, 'Hardenbergia', NULL, 'Benth.', 68),
(7771, 'Hardwickia', NULL, 'Roxb.', 68),
(7772, 'Harfordia', NULL, 'Greene & Parry', 134),
(7773, 'Harina', NULL, 'Buch.-Ham.', 15),
(7774, 'Harlandia', NULL, 'Hance', 49),
(7775, 'Harlanlewisia', NULL, 'Epling', 90),
(7776, 'Harleya', NULL, 'S.F.Blake', 18),
(7777, 'Harleyodendron', NULL, 'R.S.Cowan', 68),
(7778, 'Harmandiella', NULL, 'Costantin', 10),
(7779, 'Harmogia', NULL, 'Schauer', 116),
(7780, 'Harmsia', NULL, 'K.Schum.', 102),
(7781, 'Harmsiella', NULL, 'Briq.', 90),
(7782, 'Harmsiodoxa', NULL, 'O.E.Schulz', 197),
(7783, 'Harmsiopanax', NULL, 'Warb.', 13),
(7784, 'Harnackia', NULL, 'Urb.', 18),
(7785, 'Harnieria', NULL, 'Solms', 1),
(7786, 'Haronga', NULL, 'Thouars', 42),
(7787, 'Harpagocarpus', NULL, 'Hutch. & Dandy', 134),
(7788, 'Harpagonella', NULL, 'A.Gray', 25),
(7789, 'Harpalyce', NULL, 'Moc. & Sesse ex DC.', 68),
(7790, 'Harpanema', NULL, 'Decne.', 10),
(7791, 'Harpephyllum', NULL, 'Bernh. ex Krauss', 6),
(7792, 'Harperella', NULL, 'Rose', 9),
(7793, 'Harpochilus', NULL, 'Nees', 1),
(7794, 'Harrachia', NULL, 'Jacq.', 1),
(7795, 'Harrimanella', NULL, 'Coville', 64),
(7796, 'Harrisonia', NULL, 'R.Br. ex A.Juss.', 143),
(7797, 'Harrysmithia', NULL, 'H.Wolff', 9),
(7798, 'Harthamnus', NULL, 'H.Rob.', 18),
(7799, 'Hartia', NULL, 'Dunn', 162),
(7800, 'Hartigshea', NULL, 'A.Juss.', 106),
(7801, 'Hartleya', NULL, 'Sleumer', 545),
(7802, 'Hartmannia', NULL, 'Spach', 121),
(7803, 'Hartogia', NULL, 'Thunb. ex L.f.', 38),
(7804, 'Hartogiella', NULL, 'Codd', 38),
(7805, 'Hartogiopsis', NULL, 'H.Perrier', 38),
(7806, 'Hartwegiella', NULL, 'O.E.Schulz', 197),
(7807, 'Hartwrightia', NULL, 'A.Gray ex S.Watson', 18),
(7808, 'Harungana', NULL, 'Lam.', 42),
(7809, 'Harveya', NULL, 'Hook.', 400),
(7810, 'Haselhoffia', NULL, 'Lindau', 1),
(7811, 'Hasseanthus', NULL, 'Rose', 48),
(7812, 'Hasseltiopsis', NULL, 'Sleumer', 145),
(7813, 'Hasskarlia', NULL, 'Baill.(SUH)', 66),
(7814, 'Hassleropsis', NULL, 'Chodat', 150),
(7815, 'Hasteola', NULL, 'Raf.', 18),
(7816, 'Hatschbachia', NULL, 'L.B.Sm.', 76),
(7817, 'Hatschbachiella', NULL, 'R.M.King & H.Rob.', 18),
(7818, 'Haumania', NULL, 'J.Leonard', 103),
(7819, 'Haumaniastrum', NULL, 'P.A.Duvign. & Plancke', 90),
(7820, 'Haussknechtia', NULL, 'Boiss.', 9),
(7821, 'Haussmannia', NULL, 'F.Muell.', 22),
(7822, 'Haussmannianthes', NULL, 'Steenis', 22),
(7823, 'Hauya', NULL, 'Moc. & Sesse ex DC.', 121),
(7824, 'Havardia', NULL, 'Small', 68),
(7825, 'Havetia', NULL, 'Kunth', 42),
(7826, 'Havetiopsis', NULL, 'Planch. & Triana', 42),
(7827, 'Havilandia', NULL, 'Stapf', 25),
(7828, 'Hawkesiophyton', NULL, 'Hunz.', 154),
(7829, 'Hayataella', NULL, 'Masam.', 142),
(7830, 'Haydonia', NULL, 'R.Wilczek', 68),
(7831, 'Haynaldia', NULL, 'Kanitz', 30),
(7832, 'Haynea', NULL, 'Schumach. & Thonn.', 171),
(7833, 'Hazardia', NULL, 'Greene', 18),
(7834, 'Hazomalamia', NULL, 'Capuron', 79),
(7835, 'Hazunta', NULL, 'Pichon', 10),
(7836, 'Hearnia', NULL, 'F.Muell.', 106),
(7837, 'Hebantha', NULL, 'Mart.', 5),
(7838, 'Hebe', NULL, 'Comm. ex Juss.', 150),
(7839, 'Hebecladus', NULL, 'Miers', 154),
(7840, 'Hebeclinium', NULL, 'DC.', 18),
(7841, 'Hebecocca', NULL, 'Beurl.', 66),
(7842, 'Hebecoccus', NULL, 'Radlk.', 147),
(7843, 'Hebenstreitia', NULL, 'L.(SUO)', 150),
(7844, 'Hebenstretia', NULL, 'L.', 150),
(7845, 'Hebepetalum', NULL, 'Benth.', 95),
(7846, 'Heberdenia', NULL, 'Banks ex DC.', 115),
(7847, 'Hebestigma', NULL, 'Urb.', 68),
(7848, 'Hebonga', NULL, 'Radlk.', 151),
(7849, 'Hecastocleis', NULL, 'A.Gray', 18),
(7850, 'Hecatea', NULL, 'Thouars', 66),
(7851, 'Hecatostemon', NULL, 'S.F.Blake', 145),
(7852, 'Hecistocarpus', NULL, 'Post & Kuntze(SUO)', 142),
(7853, 'Hedaroma', NULL, 'Lindl.', 116),
(7854, 'Hedbergia', NULL, 'Molau', 400),
(7855, 'Hedeoma', NULL, 'Pers.', 90),
(7856, 'Hedeomoides', NULL, 'Briq.', 90),
(7857, 'Hedera', NULL, 'L.', 13),
(7858, 'Hederella', NULL, 'Stapf', 105),
(7859, 'Hederopsis', NULL, 'C.B.Clarke', 13),
(7860, 'Hedinia', NULL, 'Ostenf.', 197),
(7861, 'Hediniopsis', NULL, 'Botsch. & V.V.Petrovsky', 197),
(7862, 'Hedraeanthus', NULL, 'Griseb.(SUO)', 30),
(7863, 'Hedraianthera', NULL, 'F.Muell.', 38),
(7864, 'Hedraiostylus', NULL, 'Hassk.', 66),
(7865, 'Hedranthera', NULL, '(Stapf) Pichon', 10),
(7866, 'Hedstromia', NULL, 'A.C.Sm.', 142),
(7867, 'Hedusa', NULL, 'Raf.', 105),
(7868, 'Hedwigia', NULL, 'Sw.', 27),
(7869, 'Hedyachras', NULL, 'Radlk.', 147),
(7870, 'Hedycarpus', NULL, 'Jack', 184),
(7871, 'Hedycarya', NULL, 'J.R.Forst. & G.Forst.', 108),
(7872, 'Hedycaryopsis', NULL, 'Danguy', 108),
(7873, 'Hedycrea', NULL, 'Schreb.', 40),
(7874, 'Hedyosmos', NULL, 'Mitch.', 90),
(7875, 'Hedyphylla', NULL, 'Steven', 68),
(7876, 'Hedypnois', NULL, 'Mill.', 18),
(7877, 'Hedysarum', NULL, 'L.', 68),
(7878, 'Hedyscepe', NULL, 'H.Wendl. & Drude', 15),
(7879, 'Hedythyrsus', NULL, 'Bremek.', 142),
(7880, 'Heeria', NULL, 'Schltdl.(SUH)', 6),
(7881, 'Hegnera', NULL, 'Schindl.', 68),
(7882, 'Heimerlia', NULL, 'Skottsb.', 117),
(7883, 'Heimerliodendron', NULL, 'Skottsb.', 117),
(7884, 'Heimia', NULL, 'Link', 99),
(7885, 'Heimodendron', NULL, 'Sillans', 106),
(7886, 'Heinekenia', NULL, 'Webb ex H.Christ', 68),
(7887, 'Heinsenia', NULL, 'K.Schum.', 142),
(7888, 'Heintzia', NULL, 'H.Karst.', 76),
(7889, 'Heinzelia', NULL, 'Nees', 1),
(7890, 'Hekistocarpa', NULL, 'Hook.f.', 142),
(7891, 'Heladena', NULL, 'A.Juss.', 101),
(7892, 'Heldreichia', NULL, 'Boiss.', 197),
(7893, 'Helenium', NULL, 'L.', 18),
(7894, 'Heleocharis', NULL, 'T.Lestib.', 55),
(7895, 'Helia', NULL, 'Mart.', 75),
(7896, 'Helianthella', NULL, 'Torr. & A.Gray', 18),
(7897, 'Helianthopsis', NULL, 'H.Rob.', 18),
(7898, 'Helianthostylis', NULL, 'Baill.', 109),
(7899, 'Helianthus', NULL, 'L.', 18),
(7900, 'Helicanthera', NULL, 'Roem. & Schult.(SUO)', 98),
(7901, 'Helicanthes', NULL, 'Danser', 98),
(7902, 'Helichrysopsis', NULL, 'Kirp.', 18),
(7903, 'Helichrysum', NULL, 'Mill.', 18),
(7904, 'Helicilla', NULL, 'Moq.', 5),
(7905, 'Helicodiceros', NULL, 'Schott ex K.Koch', 12),
(7906, 'Heliconia', NULL, 'L.', 78),
(7907, 'Helicophyllum', NULL, 'Schott', 12),
(7908, 'Helicteropsis', NULL, 'Hochr.', 102),
(7909, 'Helictonema', NULL, 'Pierre', 38),
(7910, 'Helietta', NULL, 'Tul.', 143),
(7911, 'Helinus', NULL, 'E.Mey. ex Endl.', 139),
(7912, 'Heliocarya', NULL, 'Bunge', 25),
(7913, 'Heliocauta', NULL, 'Humphries', 18),
(7914, 'Heliomeris', NULL, 'Nutt.', 18),
(7915, 'Heliophila', NULL, 'Burm.f. ex L.', 197),
(7916, 'Heliopsis', NULL, 'Pers.', 18),
(7917, 'Heliospora', NULL, 'Hook.f.(SUO)', 142),
(7918, 'Heliostemma', NULL, 'Woodson', 10),
(7919, 'Heliotropium', NULL, 'L.', 25),
(7920, 'Helipterum', NULL, 'DC. ex Lindl.(SUH)', 18),
(7921, 'Helixanthera', NULL, 'Lour.', 98),
(7922, 'Helladia', NULL, 'M.Kral', 48),
(7923, 'Hellenocarum', NULL, 'H.Wolff', 9),
(7924, 'Hellmuthia', NULL, 'Steud.', 55),
(7925, 'Helminthia', NULL, 'Juss.', 18),
(7926, 'Helminthocarpon', NULL, 'A.Rich.', 68),
(7927, 'Helminthospermum', NULL, 'Thwaites', 170),
(7928, 'Helmiopsiella', NULL, 'Arenes', 102),
(7929, 'Helmiopsis', NULL, 'H.Perrier', 102),
(7930, 'Helmontia', NULL, 'Cogn.', 49),
(7931, 'Helogyne', NULL, 'Nutt.', 18),
(7932, 'Helonema', NULL, 'Suess.', 55),
(7933, 'Helosciadium', NULL, 'W.D.J.Koch', 9),
(7934, 'Helospora', NULL, 'Jack', 142),
(7935, 'Helxine', NULL, 'Bubani', 171),
(7936, 'Hemandradenia', NULL, 'Stapf', 45),
(7937, 'Hemiadelphis', NULL, 'Nees', 1),
(7938, 'Hemiandra', NULL, 'R.Br.', 90),
(7939, 'Hemiandrina', NULL, 'Hook.f.', 45),
(7940, 'Hemiangium', NULL, 'A.C.Sm.', 38),
(7941, 'Hemianthus', NULL, 'Nutt.', 150),
(7942, 'Hemiarrhena', NULL, 'Benth.', 150),
(7943, 'Hemiarthron', NULL, 'Tiegh.', 98),
(7944, 'Hemiboea', NULL, 'C.B.Clarke', 76),
(7945, 'Hemicarex', NULL, 'Benth.', 55),
(7946, 'Hemicarpha', NULL, 'Nees', 55),
(7947, 'Hemichaena', NULL, 'Benth.', 417),
(7948, 'Hemichlaena', NULL, 'Schrad.', 55),
(7949, 'Hemichoriste', NULL, 'Nees', 1),
(7950, 'Hemichroa', NULL, 'R.Br.', 5),
(7951, 'Hemicicca', NULL, 'Baill.', 184),
(7952, 'Hemicrambe', NULL, 'Webb', 197),
(7953, 'Hemicrepidospermum', NULL, 'Swart', 27),
(7954, 'Hemicyclia', NULL, 'Wight & Arn.', 66),
(7955, 'Hemidesma', NULL, 'Raf.', 68),
(7956, 'Hemidesmus', NULL, 'R.Br.', 10),
(7957, 'Hemidiodia', NULL, 'K.Schum.', 142),
(7958, 'Hemieva', NULL, 'Raf.', 149),
(7959, 'Hemigenia', NULL, 'R.Br.', 90),
(7960, 'Hemiglochidion', NULL, '(Mull.Arg.) K.Schum.', 184),
(7961, 'Hemigraphis', NULL, 'Nees', 1),
(7962, 'Hemiheisteria', NULL, 'Tiegh.', 119),
(7963, 'Hemilobium', NULL, 'Welw.', 85),
(7964, 'Hemilophia', NULL, 'Franch.', 197),
(7965, 'Hemimeris', NULL, 'L.f.', 150),
(7966, 'Hemiphora', NULL, '(F.Muell.) F.Muell.', 90),
(7967, 'Hemiphragma', NULL, 'Wall.', 423),
(7968, 'Hemipogon', NULL, 'Decne.', 10),
(7969, 'Hemiptelea', NULL, 'Planch.', 170),
(7970, 'Hemisandra', NULL, 'Scheidw.', 1),
(7971, 'Hemisantiria', NULL, 'H.J.Lam', 27),
(7972, 'Hemiscolopia', NULL, 'Slooten', 145),
(7973, 'Hemisiphonia', NULL, 'Urb.', 150),
(7974, 'Hemistegia', NULL, 'C.Presl', 52),
(7975, 'Hemisteptia', NULL, 'Fisch. & C.A.Mey.', 18),
(7976, 'Hemistylus', NULL, 'Benth.', 171),
(7977, 'Hemitelia', NULL, 'R.Br.', 52),
(7978, 'Hemithrinax', NULL, 'Hook.f.', 15),
(7979, 'Hemitomes', NULL, 'A.Gray', 64),
(7980, 'Hemitria', NULL, 'Raf.', 98),
(7981, 'Hemizonia', NULL, 'DC.', 18),
(7982, 'Hemizygia', NULL, '(Benth.) Briq.', 90),
(7983, 'Hemprichia', NULL, 'Ehrenb.', 27),
(7984, 'Hemsleia', NULL, 'Kudo', 90),
(7985, 'Hemsleya', NULL, 'Cogn. ex F.B.Forbes & Hemsl.', 49),
(7986, 'Hemsleyna', NULL, 'Kuntze', 101),
(7987, 'Henckelia', NULL, 'Spreng.', 76),
(7988, 'Hendecandras', NULL, 'Eschsch.', 66),
(7989, 'Henicosanthum', NULL, 'Dalla Torre & Harms(SUO)', 8),
(7990, 'Henisia', NULL, 'Walp.(SUO)', 142),
(7991, 'Henlea', NULL, 'Griseb.', 101),
(7992, 'Henleophytum', NULL, 'H.Karst.', 101),
(7993, 'Hennecartia', NULL, 'Poiss.', 108),
(7994, 'Henonia', NULL, 'Moq.', 5),
(7995, 'Henoonia', NULL, 'Griseb.', 154),
(7996, 'Henophyton', NULL, 'Coss. & Durieu', 197),
(7997, 'Henribaillonia', NULL, 'Kuntze', 184),
(7998, 'Henricksonia', NULL, 'B.L.Turner', 18),
(7999, 'Henrietia', NULL, 'Rchb.', 105),
(8000, 'Henrietta', NULL, 'Macfad.', 105),
(8001, 'Henriquezia', NULL, 'Spruce ex Benth.', 142),
(8002, 'Henrya', NULL, 'Hemsl.(SUH)', 1),
(8003, 'Henryettana', NULL, 'Brand', 25),
(8004, 'Henschelia', NULL, 'C.Presl', 79),
(8005, 'Henslowia', NULL, 'Lowe ex DC.(SUI)', 120),
(8006, 'Hephestionia', NULL, 'Naudin', 105),
(8007, 'Heppiella', NULL, 'Regel', 76),
(8008, 'Heptacodium', NULL, 'Rehder', 33),
(8009, 'Heptallon', NULL, 'Raf.', 66),
(8010, 'Heptanthus', NULL, 'Griseb.', 18),
(8011, 'Heptapleurum', NULL, 'Gaertn.', 13),
(8012, 'Heptaptera', NULL, 'Margot & Reut.', 9),
(8013, 'Heracleum', NULL, 'L.', 9),
(8014, 'Herbstia', NULL, 'Sohmer', 5),
(8015, 'Herderia', NULL, 'Cass.', 18),
(8016, 'Herissantia', NULL, 'Medik.', 102),
(8017, 'Hermannia', NULL, 'L.', 102),
(8018, 'Hermas', NULL, 'L.', 9),
(8019, 'Hermbstaedtia', NULL, 'Rchb.', 5),
(8020, 'Hermesia', NULL, 'Humb. & Bonpl.', 66),
(8021, 'Hermidium', NULL, 'S.Watson', 117),
(8022, 'Herminiera', NULL, 'Guill. & Perr.', 68),
(8023, 'Hernandiopsis', NULL, 'Meisn.', 79),
(8024, 'Herodotia', NULL, 'Urb. & Ekman', 18),
(8025, 'Herpestis', NULL, 'Gaertn.', 423),
(8026, 'Herpetacanthus', NULL, 'Nees', 1),
(8027, 'Herpetica', NULL, '(DC.) Raf.', 68),
(8028, 'Herpetospermum', NULL, 'Wall. ex Hook.f.', 49),
(8029, 'Herpyza', NULL, 'Sauvalle', 68),
(8030, 'Herrera', NULL, 'Adans.', 142),
(8031, 'Herreria', NULL, 'Ruiz & Pav.', 3),
(8032, 'Herreriopsis', NULL, 'H.Perrier', 3),
(8033, 'Herrickia', NULL, 'Wooton & Standl.', 18),
(8034, 'Herschelia', NULL, 'T.E.Bowdich', 154),
(8035, 'Hertelia', NULL, 'Neck.(SUI)', 79),
(8036, 'Hertia', NULL, 'Less.', 18),
(8037, 'Herya', NULL, 'Cordem.', 38),
(8038, 'Hesioda', NULL, 'Vell.', 119),
(8039, 'Hesperaloe', NULL, 'Engelm.', 3),
(8040, 'Hesperastragalus', NULL, 'A.Heller', 68),
(8041, 'Hesperelaea', NULL, 'A.Gray', 120),
(8042, 'Hesperethusa', NULL, 'M.Roem.', 143),
(8043, 'Hesperidanthus', NULL, '(B.L.Rob.) Rydb.', 197),
(8044, 'Hesperis', NULL, 'L.', 197),
(8045, 'Hesperochiron', NULL, 'S.Watson', 25),
(8046, 'Hesperocnide', NULL, 'Torr.', 171),
(8047, 'Hesperogenia', NULL, 'J.M.Coult. & Rose', 9),
(8048, 'Hesperolaburnum', NULL, 'Maire', 68),
(8049, 'Hesperolinon', NULL, '(A.Gray) Small', 95),
(8050, 'Hesperomannia', NULL, 'A.Gray', 18),
(8051, 'Hesperomecon', NULL, 'Greene', 126),
(8052, 'Hesperomeles', NULL, 'Lindl.', 141),
(8053, 'Hesperonia', NULL, 'Standl.', 117),
(8054, 'Hesperonix', NULL, 'Rydb.', 68),
(8055, 'Hesperopeuce', NULL, '(Engelm.) Lemmon', 129),
(8056, 'Hesperoseris', NULL, 'Skottsb.', 18),
(8057, 'Hesperothamnus', NULL, 'Brandegee', 68),
(8058, 'Hesperoxalis', NULL, 'Small', 124),
(8059, 'Hesperoyucca', NULL, 'Baker', 3),
(8060, 'Hesperozygis', NULL, 'Epling', 90),
(8061, 'Heteracia', NULL, 'Fisch. & C.A.Mey.', 18),
(8062, 'Heteradelphia', NULL, 'Lindau', 1),
(8063, 'Heteranthemis', NULL, 'Schott', 18),
(8064, 'Heteranthia', NULL, 'Nees & Mart.', 150),
(8065, 'Heteraspidia', NULL, 'Rizzini', 1),
(8066, 'Heterixia', NULL, 'Tiegh.', 146),
(8067, 'Heteroaridarum', NULL, 'M.Hotta', 12),
(8068, 'Heteroarisaema', NULL, 'Nakai', 12),
(8069, 'Heterocalycium', NULL, 'Rauschert', 22),
(8070, 'Heterocalymnantha', NULL, 'Domin', 184),
(8071, 'Heterocalyx', NULL, 'Gagnep.', 66),
(8072, 'Heterocarpus', NULL, 'Phil.(SUH)', 197),
(8073, 'Heterocaryum', NULL, 'A.DC.', 25),
(8074, 'Heterocentron', NULL, 'Hook. & Arn.', 105),
(8075, 'Heterochaenia', NULL, 'A.DC.', 30),
(8076, 'Heterochlamys', NULL, 'Turcz.', 66),
(8077, 'Heterocodon', NULL, 'Nutt.', 30),
(8078, 'Heterocoma', NULL, 'DC.', 18),
(8079, 'Heterocondylus', NULL, 'R.M.King & H.Rob.', 18),
(8080, 'Heterocroton', NULL, 'S.Moore', 66),
(8081, 'Heterocypsela', NULL, 'H.Rob.', 18),
(8082, 'Heterodendrum', NULL, 'Desf.', 147),
(8083, 'Heteroderis', NULL, '(Bunge) Boiss.', 18),
(8084, 'Heterodraba', NULL, 'Greene', 197),
(8085, 'Heterogaura', NULL, 'Rothr.', 121),
(8086, 'Heterolamium', NULL, 'C.Y.Wu', 90),
(8087, 'Heterolepis', NULL, 'Cass.', 18),
(8088, 'Heterolobium', NULL, 'Peter', 12),
(8089, 'Heteromeles', NULL, 'M.Roem.', 141),
(8090, 'Heteromera', NULL, 'Pomel', 18),
(8091, 'Heteromma', NULL, 'Benth.', 18),
(8092, 'Heteromorpha', NULL, 'Cham. & Schltdl.', 9),
(8093, 'Heteromyrtus', NULL, 'Blume(SUI)', 116),
(8094, 'Heteroneuron', NULL, 'Hook.f.', 105),
(8095, 'Heteronoma', NULL, 'DC.', 105),
(8096, 'Heteropanax', NULL, 'Seem.', 13),
(8097, 'Heteropappus', NULL, 'Less.', 18),
(8098, 'Heteropetalum', NULL, 'Benth.', 8),
(8099, 'Heterophragma', NULL, 'DC.', 22),
(8100, 'Heterophyllaea', NULL, 'Hook.f.', 142),
(8101, 'Heteroplexis', NULL, 'C.C.Chang', 18),
(8102, 'Heteropsis', NULL, 'Kunth', 12),
(8103, 'Heteropterys', NULL, 'Kunth', 101),
(8104, 'Heteroptilis', NULL, 'E.Mey. ex Meisn.', 9),
(8105, 'Heteropyxis', NULL, 'Harv.', 116),
(8106, 'Heterorhachis', NULL, 'Sch.Bip. ex Walp.', 18),
(8107, 'Heterosicyos', NULL, 'Welw. ex Hook.f.', 49),
(8108, 'Heterosicyus', NULL, 'Post & Kuntze(SUO)', 49),
(8109, 'Heterosmilax', NULL, 'Kunth', 153),
(8110, 'Heterospathe', NULL, 'Scheff.', 15),
(8111, 'Heterosperma', NULL, 'Cav.', 18),
(8112, 'Heterostachys', NULL, 'Ung.-Sternb.', 5),
(8113, 'Heterostemma', NULL, 'Wight & Arn.', 10),
(8114, 'Heterostemon', NULL, 'Desf.', 68),
(8115, 'Heterothalamus', NULL, 'Less.', 18),
(8116, 'Heterotheca', NULL, 'Cass.', 18),
(8117, 'Heterothrix', NULL, '(B.L.Rob.) Rydb.', 197),
(8118, 'Heterotis', NULL, 'Benth.', 105),
(8119, 'Heterotoma', NULL, 'Zucc.', 30),
(8120, 'Heterotrichum', NULL, 'DC.', 105),
(8121, 'Heterotropa', NULL, 'C.Morren & Decne.', 16),
(8122, 'Heuchera', NULL, 'L.', 149),
(8123, 'Hewittia', NULL, 'Wight & Arn.', 46),
(8124, 'Hexachlamys', NULL, 'O.Berg', 116),
(8125, 'Hexactina', NULL, 'Willd. ex Schltdl.', 142),
(8126, 'Hexadena', NULL, 'Raf.', 184),
(8127, 'Hexadenia', NULL, 'Klotzsch & Garcke', 66),
(8128, 'Hexakestra', NULL, 'Hook.f.(SUO)', 184),
(8129, 'Hexakistra', NULL, 'Hook.f.', 184),
(8130, 'Hexalobus', NULL, 'A.DC.', 8),
(8131, 'Hexameria', NULL, 'Torr. & A.Gray', 49),
(8132, 'Hexaneurocarpon', NULL, 'Dop', 22),
(8133, 'Hexapora', NULL, 'Hook.f.', 91),
(8134, 'Hexaptera', NULL, 'Hook.', 197),
(8135, 'Hexasepalum', NULL, 'Bartl. ex DC.', 142),
(8136, 'Hexaspermum', NULL, 'Domin', 66),
(8137, 'Hexaspora', NULL, 'C.T.White', 38),
(8138, 'Hexastemon', NULL, 'Klotzsch', 64),
(8139, 'Hexastylis', NULL, 'Raf.', 16),
(8140, 'Hexatheca', NULL, 'C.B.Clarke', 76),
(8141, 'Hexepta', NULL, 'Raf.', 142),
(8142, 'Hexodontocarpus', NULL, 'Dulac', 142),
(8143, 'Hexopetion', NULL, 'Burret', 15),
(8144, 'Heyderia', NULL, 'K.Koch(SUH)', 51),
(8145, 'Heylandia', NULL, 'DC.', 68),
(8146, 'Heymassoli', NULL, 'Aubl.', 119),
(8147, 'Heymia', NULL, 'Dennst.', 142),
(8148, 'Heynella', NULL, 'Backer', 10),
(8149, 'Heywoodia', NULL, 'Sim', 184),
(8150, 'Heywoodiella', NULL, 'Svent. & Bramwell', 18),
(8151, 'Hibbertia', NULL, 'Andrews', 58),
(8152, 'Hibiscadelphus', NULL, 'Rock', 102),
(8153, 'Hickenia', NULL, 'Lillo', 10),
(8154, 'Hicksbeachia', NULL, 'F.Muell.', 135),
(8155, 'Hicorius', NULL, 'Raf.', 87),
(8156, 'Hidalgoa', NULL, 'La Llave', 18),
(8157, 'Hieracium', NULL, 'L.', 18),
(8158, 'Hieranthes', NULL, 'Raf.', 22),
(8159, 'Hieris', NULL, 'Steenis', 22),
(8160, 'Hiernia', NULL, 'S.Moore', 150),
(8161, 'Hierobotana', NULL, 'Briq.', 173),
(8162, 'Hieronima', NULL, 'Allemao', 66),
(8163, 'Hieronymusia', NULL, 'Engl.', 149),
(8164, 'Higginsia', NULL, 'Pers.', 142),
(8165, 'Hilairella', NULL, 'Tiegh.', 118),
(8166, 'Hilariophyton', NULL, 'Pichon(SUS)', 22),
(8167, 'Hildebrandtia', NULL, 'Vatke', 46),
(8168, 'Hildegardia', NULL, 'Schott & Endl.', 102),
(8169, 'Hillebrandia', NULL, 'Oliv.', 20),
(8170, 'Hilleria', NULL, 'Vell.', 128),
(8171, 'Hilliardia', NULL, 'B.Nord.', 18),
(8172, 'Hilliella', NULL, '(O.E.Schulz) Y.H.Zhang & H.W.Li', 197),
(8173, 'Himalrandia', NULL, 'T.Yamaz.', 142),
(8174, 'Himantochilus', NULL, 'T.Anderson ex Benth.', 1),
(8175, 'Himantostemma', NULL, 'A.Gray', 10),
(8176, 'Hindsia', NULL, 'Benth. ex Lindl.', 142),
(8177, 'Hinterhubera', NULL, 'Sch.Bip. ex Wedd.', 18),
(8178, 'Hintonia', NULL, 'Bullock', 142),
(8179, 'Hionanthera', NULL, 'A.Fern. & Diniz', 99),
(8180, 'Hippia', NULL, 'L.', 18),
(8181, 'Hippobroma', NULL, 'G.Don', 30),
(8182, 'Hippobromus', NULL, 'Eckl. & Zeyh.', 147),
(8183, 'Hippocratea', NULL, 'L.', 38),
(8184, 'Hippocrepandra', NULL, 'Mull.Arg.', 66),
(8185, 'Hippocrepis', NULL, 'L.', 68),
(8186, 'Hippodamia', NULL, 'Decne.', 76),
(8187, 'Hippolytia', NULL, 'Poljakov', 18),
(8188, 'Hippotis', NULL, 'Ruiz & Pav.', 142),
(8189, 'Hippoxylon', NULL, 'Raf.', 22),
(8190, 'Hiraea', NULL, 'Jacq.', 101),
(8191, 'Hirpicium', NULL, 'Cass.', 18),
(8192, 'Hirschfeldia', NULL, 'Moench', 197),
(8193, 'Hirschia', NULL, 'Baker', 18),
(8194, 'Hispidella', NULL, 'Barnadez ex Lam.', 18),
(8195, 'Hitoa', NULL, 'Nadeaud', 142),
(8196, 'Hjaltalinia', NULL, 'A.Love & D.Love', 48),
(8197, 'Hladnikia', NULL, 'Rchb.', 9),
(8198, 'Hochreutinera', NULL, 'Krapov.', 102),
(8199, 'Hochstetteria', NULL, 'DC.', 18),
(8200, 'Hockinia', NULL, 'Gardner', 75),
(8201, 'Hodgkinsonia', NULL, 'F.Muell.', 142),
(8202, 'Hodgsonia', NULL, 'Hook.f. & Thomson', 49),
(8203, 'Hoehnea', NULL, 'Epling', 90),
(8204, 'Hoehnelia', NULL, 'Schweinf.', 18),
(8205, 'Hoehnephytum', NULL, 'Cabrera', 18),
(8206, 'Hoepfneria', NULL, 'Vatke', 68),
(8207, 'Hoferia', NULL, 'Scop.', 162),
(8208, 'Hoffmanniella', NULL, 'Schltr. ex Lawalree', 18),
(8209, 'Hoffmannseggia', NULL, 'Cav.', 68),
(8210, 'Hofmeisteria', NULL, 'Walp.', 18),
(8211, 'Hohenackeria', NULL, 'Fisch. & C.A.Mey.', 9),
(8212, 'Hoheria', NULL, 'A.Cunn.', 102),
(8213, 'Hoita', NULL, 'Rydb.', 68),
(8214, 'Holacantha', NULL, 'A.Gray', 151),
(8215, 'Holalafia', NULL, 'Stapf', 10),
(8216, 'Holarrhena', NULL, 'R.Br.', 10),
(8217, 'Holcophacos', NULL, 'Rydb.', 68),
(8218, 'Holigarna', NULL, 'Buch.-Ham. ex Roxb.', 6),
(8219, 'Hollandaea', NULL, 'F.Muell.', 135),
(8220, 'Hollermayera', NULL, 'O.E.Schulz', 197),
(8221, 'Hollisteria', NULL, 'S.Watson', 134),
(8222, 'Hollrungia', NULL, 'K.Schum.', 127),
(8223, 'Holmbergia', NULL, 'Hicken', 5),
(8224, 'Holmgrenanthe', NULL, 'Elisens', 423),
(8225, 'Holmskioldia', NULL, 'Retz.', 90),
(8226, 'Holocalyx', NULL, 'Micheli', 68),
(8227, 'Holocarpa', NULL, 'Baker', 142),
(8228, 'Holocarpha', NULL, 'Greene', 18),
(8229, 'Holocarya', NULL, 'T.Durand(SUO)', 142),
(8230, 'Holocheila', NULL, '(Kudo) S.Chow', 90),
(8231, 'Holocheilus', NULL, 'Cass.', 18),
(8232, 'Holochlamys', NULL, 'Engl.', 12),
(8233, 'Holodiscus', NULL, '(K.Koch) Maxim.', 141),
(8234, 'Holographis', NULL, 'Nees', 1),
(8235, 'Hololachna', NULL, 'Ehrenb.', 160),
(8236, 'Hololeion', NULL, 'Kitam.', 18),
(8237, 'Hololepis', NULL, 'DC.', 18),
(8238, 'Holopyxidium', NULL, 'Ducke', 92),
(8239, 'Holoschoenus', NULL, 'Link(SUH)', 55),
(8240, 'Holostemma', NULL, 'R.Br.', 10),
(8241, 'Holostigma', NULL, 'Spach', 121),
(8242, 'Holostyla', NULL, 'Endl.(SUO)', 142),
(8243, 'Holostylis', NULL, 'Duch.', 16),
(8244, 'Holostylon', NULL, 'Robyns & Lebrun', 90),
(8245, 'Holozonia', NULL, 'Greene', 18),
(8246, 'Holstia', NULL, 'Pax(SUH)', 66),
(8247, 'Holstianthus', NULL, 'Steyerm.', 142),
(8248, 'Holtonia', NULL, 'Standl.', 142),
(8249, 'Holtzea', NULL, 'Schindl.', 68),
(8250, 'Holubogentia', NULL, 'A.Love & D.Love', 75),
(8251, 'Holzneria', NULL, 'Speta', 423),
(8252, 'Homalobus', NULL, 'Nutt.', 68),
(8253, 'Homalocalyx', NULL, 'F.Muell.', 116),
(8254, 'Homalocarpus', NULL, 'Hook. & Arn.', 9),
(8255, 'Homalocheilos', NULL, 'J.K.Morton', 90),
(8256, 'Homalocladium', NULL, '(F.Muell.) L.H.Bailey', 134),
(8257, 'Homaloclados', NULL, 'Hook.f.', 142),
(8258, 'Homalomena', NULL, 'Schott', 12),
(8259, 'Homalosciadium', NULL, 'Domin', 9),
(8260, 'Homalospermum', NULL, 'Schauer', 116),
(8261, 'Homocentria', NULL, 'Naudin', 105),
(8262, 'Homocodon', NULL, 'D.Y.Hong', 30),
(8263, 'Homognaphalium', NULL, 'Kirp.(SUS)', 18),
(8264, 'Homogyne', NULL, 'Cass.', 18),
(8265, 'Homollea', NULL, 'Arenes', 142),
(8266, 'Homolliella', NULL, 'Arenes', 142),
(8267, 'Homonoia', NULL, 'Lour.', 66),
(8268, 'Homonoma', NULL, 'Bello', 105),
(8269, 'Homoranthus', NULL, 'A.Cunn. ex Schauer', 116),
(8270, 'Honckenya', NULL, 'Willd.(SUO)', 257),
(8271, 'Hoodia', NULL, 'Sweet ex Decne.', 10),
(8272, 'Hookerella', NULL, 'Tiegh.', 98),
(8273, 'Hoplophyllum', NULL, 'DC.', 18),
(8274, 'Hoppea', NULL, 'Willd.', 75),
(8275, 'Hoppia', NULL, 'Nees', 55),
(8276, 'Horaninovia', NULL, 'Fisch. & C.A.Mey.', 5),
(8277, 'Horkelia', NULL, 'Cham. & Schltdl.', 141),
(8278, 'Horkeliella', NULL, '(Rydb.) Rydb.', 141),
(8279, 'Hormathophylla', NULL, 'Cullen & T.R.Dudley', 197),
(8280, 'Horminum', NULL, 'L.', 90),
(8281, 'Hormocalyx', NULL, 'Gleason', 105),
(8282, 'Hormogyne', NULL, 'A.DC.', 148),
(8283, 'Hormuzakia', NULL, 'Gusul.', 25),
(8284, 'Hornea', NULL, 'Baker', 147),
(8285, 'Hornemannia', NULL, 'Vahl', 64),
(8286, 'Hornschuchia', NULL, 'Nees', 8),
(8287, 'Hornungia', NULL, 'Rchb.', 197),
(8288, 'Horsfordia', NULL, 'A.Gray', 102),
(8289, 'Horstrissea', NULL, 'Greuter, Gerstb. & Egli', 9),
(8290, 'Horta', NULL, 'Vell.', 163),
(8291, 'Hortonia', NULL, 'Wight', 108),
(8292, 'Horwoodia', NULL, 'Turrill', 197),
(8293, 'Hosackia', NULL, 'Benth. ex Lindl.', 68),
(8294, 'Hosea', NULL, 'Ridl.', 90),
(8295, 'Hoseanthus', NULL, 'Merr.(SUS)', 90),
(8296, 'Hoshiarpuria', NULL, 'Hajra, P.Daniel & Philcox', 99),
(8297, 'Hosiea', NULL, 'Hemsl. & E.H.Wilson', 85),
(8298, 'Hoslundia', NULL, 'Vahl', 90),
(8299, 'Hosta', NULL, 'Tratt.', 3),
(8300, 'Hostmannia', NULL, 'Planch.', 118),
(8301, 'Hoteia', NULL, 'C.Morren & Decne.', 149),
(8302, 'Hotnima', NULL, 'Chev.', 66),
(8303, 'Hottarum', NULL, 'Bogner & Nicolson', 12),
(8304, 'Hottea', NULL, 'Urb.', 116),
(8305, 'Hounea', NULL, 'Baill.', 127),
(8306, 'Houssayanthus', NULL, 'Hunz.', 147),
(8307, 'Houstonia', NULL, 'L.', 142),
(8308, 'Houttea', NULL, 'Heynh.', 76),
(8309, 'Hovea', NULL, 'R.Br. ex W.T.Aiton', 68),
(8310, 'Hovenia', NULL, 'Thunb.', 139),
(8311, 'Hoverdenia', NULL, 'Nees', 1),
(8312, 'Howardia', NULL, 'Wedd.', 142),
(8313, 'Howea', NULL, 'Becc.', 15),
(8314, 'Howellia', NULL, 'A.Gray', 30),
(8315, 'Howelliella', NULL, 'Rothm.', 423),
(8316, 'Howethoa', NULL, 'Rauschert', 147),
(8317, 'Howittia', NULL, 'F.Muell.', 102),
(8318, 'Hoya', NULL, 'R.Br.', 10),
(8319, 'Hoyella', NULL, 'Ridl.', 10),
(8320, 'Hua', NULL, 'Pierre ex De Wild.', 179),
(8321, 'Hualania', NULL, 'Phil.', 133),
(8322, 'Huanaca', NULL, 'Raf.(SUH)', 9),
(8323, 'Huarpea', NULL, 'Cabrera', 18),
(8324, 'Huberia', NULL, 'DC.', 105),
(8325, 'Huberodaphne', NULL, 'Ducke', 91),
(8326, 'Huberodendron', NULL, 'Ducke', 102),
(8327, 'Hubertia', NULL, 'Bory', 18),
(8328, 'Hueblia', NULL, 'Speta', 150),
(8329, 'Huernia', NULL, 'R.Br.', 10),
(8330, 'Huerniopsis', NULL, 'N.E.Br.', 10),
(8331, 'Hufelandia', NULL, 'Nees', 91),
(8332, 'Hughesia', NULL, 'R.M.King & H.Rob.', 18),
(8333, 'Hugonia', NULL, 'L.', 95),
(8334, 'Hugueninia', NULL, 'Rchb.', 197),
(8335, 'Huilaea', NULL, 'Wurdack', 105),
(8336, 'Hulemacanthus', NULL, 'S.Moore', 1),
(8337, 'Hullettia', NULL, 'King ex Hook.f.', 109),
(8338, 'Hulsea', NULL, 'Torr. & A.Gray', 18),
(8339, 'Hulteniella', NULL, 'Tzvelev', 18),
(8340, 'Hulthemia', NULL, 'Dumort.', 141),
(8341, 'Hulthemosa', NULL, 'Juz.', 141),
(8342, 'Humbertia', NULL, 'Comm. ex Lam.', 46),
(8343, 'Humbertianthus', NULL, 'Hochr.', 102),
(8344, 'Humbertiella', NULL, 'Hochr.', 102),
(8345, 'Humbertina', NULL, 'Buchet', 12);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(8346, 'Humbertiodendron', NULL, 'Leandri', 168),
(8347, 'Humbertioturraea', NULL, 'J.-F.Leroy', 106),
(8348, 'Humbertodendron', NULL, 'Leandri(SUO)', 168),
(8349, 'Humblotia', NULL, 'Baill.', 66),
(8350, 'Humblotiodendron', NULL, 'Engl.', 143),
(8351, 'Humboldtiella', NULL, 'Harms', 68),
(8352, 'Humeocline', NULL, 'Anderb.', 18),
(8353, 'Humiria', NULL, 'Aubl.', 83),
(8354, 'Humirianthera', NULL, 'Huber', 85),
(8355, 'Humularia', NULL, 'P.A.Duvign.', 68),
(8356, 'Hunaniopanax', NULL, 'C.J.Qi & T.R.Cao', 13),
(8357, 'Hunga', NULL, 'Pancher ex Prance', 40),
(8358, 'Hunnemannia', NULL, 'Sweet', 126),
(8359, 'Hunzikeria', NULL, 'D''Arcy', 154),
(8360, 'Huodendron', NULL, 'Rehder', 158),
(8361, 'Huperzia', NULL, 'Bernh.', 150),
(8362, 'Husnotia', NULL, 'E.Fourn.', 10),
(8363, 'Hussonia', NULL, 'Boiss.', 197),
(8364, 'Hutchinsia', NULL, 'R.Br.(SUS)', 197),
(8365, 'Hutchinsiella', NULL, 'O.E.Schulz', 197),
(8366, 'Hutchinsonia', NULL, 'Robyns', 142),
(8367, 'Hutera', NULL, 'Porta', 197),
(8368, 'Huttonella', NULL, 'Kirk', 68),
(8369, 'Huxleya', NULL, 'Ewart', 90),
(8370, 'Huynhia', NULL, 'Greuter', 25),
(8371, 'Hyaenanche', NULL, 'Lamb.', 534),
(8372, 'Hyalis', NULL, 'D.Don ex Hook. & Arn.', 18),
(8373, 'Hyalocalyx', NULL, 'Rolfe', 169),
(8374, 'Hyalochaete', NULL, 'Dittrich & Rech.f.', 18),
(8375, 'Hyalochlamys', NULL, 'A.Gray', 18),
(8376, 'Hyalocystis', NULL, 'Hallier f.', 46),
(8377, 'Hyalolaena', NULL, 'Bunge', 9),
(8378, 'Hyalosepalum', NULL, 'Troupin', 107),
(8379, 'Hyaloseris', NULL, 'Griseb.', 18),
(8380, 'Hyalosperma', NULL, 'Steetz', 18),
(8381, 'Hyalostemma', NULL, 'Wall. ex Meisn.', 8),
(8382, 'Hybophrynium', NULL, 'K.Schum.(SUS)', 103),
(8383, 'Hybosema', NULL, 'Harms', 68),
(8384, 'Hybosperma', NULL, 'Urb.', 139),
(8385, 'Hybridella', NULL, 'Cass.', 18),
(8386, 'Hydnophytum', NULL, 'Jack', 142),
(8387, 'Hydranthelium', NULL, 'Kunth', 150),
(8388, 'Hydriastele', NULL, 'H.Wendl. & Drude', 15),
(8389, 'Hydrocotyle', NULL, 'L.', 9),
(8390, 'Hydrodyssodia', NULL, 'B.L.Turner', 18),
(8391, 'Hydrogaster', NULL, 'Kuhlm.', 102),
(8392, 'Hydroidea', NULL, 'P.O.Karis', 18),
(8393, 'Hydrolea', NULL, 'L.', 517),
(8394, 'Hydrolythrum', NULL, 'Hook.f.', 99),
(8395, 'Hydromestus', NULL, 'Scheidw.', 1),
(8396, 'Hydropectis', NULL, 'Rydb.', 18),
(8397, 'Hydrophylax', NULL, 'L.f.', 142),
(8398, 'Hydrophyllum', NULL, 'L.', 25),
(8399, 'Hydrosme', NULL, 'Schott', 12),
(8400, 'Hydrotriche', NULL, 'Zucc.', 423),
(8401, 'Hygea', NULL, 'Hanst.', 76),
(8402, 'Hygrocharis', NULL, 'Hochst.', 46),
(8403, 'Hygrophila', NULL, 'R.Br.', 1),
(8404, 'Hylaeanthe', NULL, 'A.M.E.Jonker & Jonker', 103),
(8405, 'Hylandia', NULL, 'Airy Shaw', 66),
(8406, 'Hylandra', NULL, 'A.Love', 197),
(8407, 'Hylenaea', NULL, 'Miers', 38),
(8408, 'Hylocarpa', NULL, 'Cuatrec.', 83),
(8409, 'Hylocharis', NULL, 'Miq.', 105),
(8410, 'Hylomecon', NULL, 'Maxim.', 126),
(8411, 'Hylotelephium', NULL, 'H.Ohba', 48),
(8412, 'Hymenandra', NULL, '(DC.) Spach', 115),
(8413, 'Hymenanthera', NULL, 'R.Br.', 174),
(8414, 'Hymenatherum', NULL, 'Cass.', 18),
(8415, 'Hymendocarpum', NULL, 'Pierre ex Pit.', 142),
(8416, 'Hymenocarpos', NULL, 'Savi', 68),
(8417, 'Hymenocephalus', NULL, 'Jaub. & Spach', 18),
(8418, 'Hymenochaeta', NULL, 'P.Beauv.(SUH)', 55),
(8419, 'Hymenocharis', NULL, 'Salisb.', 103),
(8420, 'Hymenochlaena', NULL, 'Bremek.', 1),
(8421, 'Hymenoclea', NULL, 'Torr. & A.Gray', 18),
(8422, 'Hymenocnemis', NULL, 'Hook.f.', 142),
(8423, 'Hymenocoleus', NULL, 'Robbr.', 142),
(8424, 'Hymenocrater', NULL, 'Fisch. & C.A.Mey.', 90),
(8425, 'Hymenolaena', NULL, 'DC.', 9),
(8426, 'Hymenolobus', NULL, 'Nutt.', 197),
(8427, 'Hymenolyma', NULL, 'Korovin', 9),
(8428, 'Hymenonema', NULL, 'Cass.', 18),
(8429, 'Hymenopappus', NULL, 'L''Her.', 18),
(8430, 'Hymenophysa', NULL, 'C.A.Mey.', 197),
(8431, 'Hymenopogon', NULL, 'Wall.(SUH)', 142),
(8432, 'Hymenopyramis', NULL, 'Wall. ex Griff.', 90),
(8433, 'Hymenosicyos', NULL, 'Chiov.', 49),
(8434, 'Hymenostemma', NULL, 'Kunze ex Willk.', 18),
(8435, 'Hymenostephium', NULL, 'Benth.', 18),
(8436, 'Hymenothrix', NULL, 'A.Gray', 18),
(8437, 'Hymenoxys', NULL, 'Cass.', 18),
(8438, 'Hyobanche', NULL, 'L.', 400),
(8439, 'Hyophorbe', NULL, 'Gaertn.', 15),
(8440, 'Hyoscyamus', NULL, 'L.', 154),
(8441, 'Hyoseris', NULL, 'L.', 18),
(8442, 'Hypacanthium', NULL, 'Juz.', 18),
(8443, 'Hypagophytum', NULL, 'A.Berger', 48),
(8444, 'Hypanthera', NULL, 'Silva Manso', 49),
(8445, 'Hypecoum', NULL, 'L.', 126),
(8446, 'Hypelate', NULL, 'P.Browne', 147),
(8447, 'Hypelichrysum', NULL, 'Kirp.', 18),
(8448, 'Hypenanthe', NULL, '(Blume) Blume', 105),
(8449, 'Hypenia', NULL, '(Mart. ex Benth.) Harley', 90),
(8450, 'Hyperacanthus', NULL, 'E.Mey. ex Bridson', 142),
(8451, 'Hyperaspis', NULL, 'Briq.', 90),
(8452, 'Hypericophyllum', NULL, 'Steetz', 18),
(8453, 'Hyphaene', NULL, 'Gaertn.', 15),
(8454, 'Hypocalymma', NULL, '(Endl.) Endl.', 116),
(8455, 'Hypocalyptus', NULL, 'Thunb.', 68),
(8456, 'Hypochaeris', NULL, 'L.', 18),
(8457, 'Hypochoeris', NULL, 'L.(SUO)', 18),
(8458, 'Hypocoton', NULL, 'Urb.', 66),
(8459, 'Hypocylix', NULL, 'Wol.', 5),
(8460, 'Hypocyrta', NULL, 'Mart.', 76),
(8461, 'Hypoestes', NULL, 'Sol. ex R.Br.', 1),
(8462, 'Hypogomphia', NULL, 'Bunge', 90),
(8463, 'Hypogon', NULL, 'Raf.', 90),
(8464, 'Hypolobus', NULL, 'E.Fourn.', 10),
(8465, 'Hypolytrum', NULL, 'Rich. ex Pers.', 55),
(8466, 'Hypophyllanthus', NULL, 'Regel', 102),
(8467, 'Hypopitys', NULL, 'Hill(SUS)', 64),
(8468, 'Hypothronia', NULL, 'Schrank', 90),
(8469, 'Hypsela', NULL, 'C.Presl', 30),
(8470, 'Hypselandra', NULL, 'Pax & K.Hoffm.(SUI)', 32),
(8471, 'Hypselodelphys', NULL, '(K.Schum.) Milne-Redh.', 103),
(8472, 'Hypseloderma', NULL, 'Radlk.', 147),
(8473, 'Hypseocharis', NULL, 'J.Remy', 314),
(8474, 'Hypserpa', NULL, 'Miers', 107),
(8475, 'Hypsophila', NULL, 'F.Muell.', 38),
(8476, 'Hyptiandra', NULL, 'Hook.f.(SUH)', 151),
(8477, 'Hyptidendron', NULL, 'Harley', 90),
(8478, 'Hyptiodaphne', NULL, 'Urb.', 164),
(8479, 'Hyptis', NULL, 'Jacq.', 90),
(8480, 'Hyrtanandra', NULL, 'Miq.', 171),
(8481, 'Hyssaria', NULL, 'Kolak.', 30),
(8482, 'Hyssopus', NULL, 'L.', 90),
(8483, 'Hysterionica', NULL, 'Willd.', 18),
(8484, 'Hystrichophora', NULL, 'Mattf.', 18),
(8485, 'Hytophrynium', NULL, 'K.Schum.', 103),
(8486, 'Iacranda', NULL, 'Pers.', 22),
(8487, 'Ibadja', NULL, 'A.Chev.', 68),
(8488, 'Ibarraea', NULL, 'Lundell', 115),
(8489, 'Ibatia', NULL, 'Decne.', 10),
(8490, 'Iberidella', NULL, 'Boiss.', 197),
(8491, 'Iberis', NULL, 'L.', 197),
(8492, 'Ibervillea', NULL, 'Greene', 49),
(8493, 'Ibetralia', NULL, 'Bremek.', 142),
(8494, 'Ibina', NULL, 'Noronha', 184),
(8495, 'Iboza', NULL, 'N.E.Br.', 90),
(8496, 'Icacina', NULL, 'A.Juss.', 85),
(8497, 'Icacinopsis', NULL, 'Roberty', 57),
(8498, 'Icacorea', NULL, 'Aubl.', 115),
(8499, 'Icaria', NULL, 'J.F.Macbr.', 105),
(8500, 'Ichnocarpus', NULL, 'R.Br.', 10),
(8501, 'Ichthyophora', NULL, 'Baehni', 148),
(8502, 'Ichthyothere', NULL, 'Mart.', 18),
(8503, 'Ichtyomethia', NULL, 'Kuntze', 68),
(8504, 'Icianthus', NULL, 'Greene', 197),
(8505, 'Icica', NULL, 'Aubl.', 27),
(8506, 'Icicaster', NULL, 'Ridl.', 27),
(8507, 'Icomum', NULL, 'Hua', 90),
(8508, 'Icosandra', NULL, 'Phil.', 91),
(8509, 'Idahoa', NULL, 'A.Nelson & J.F.Macbr.', 197),
(8510, 'Ideleria', NULL, 'Kunth', 55),
(8511, 'Idertia', NULL, 'Farron', 118),
(8512, 'Idesia', NULL, 'Scop.(SUH)', 145),
(8513, 'Idiothamnus', NULL, 'R.M.King & H.Rob.', 18),
(8514, 'Ifloga', NULL, 'Cass.', 18),
(8515, 'Ighermia', NULL, 'Wiklund', 18),
(8516, 'Ildefonsia', NULL, 'Gardner', 150),
(8517, 'Ileostylus', NULL, 'Tiegh.', 98),
(8518, 'Iliamna', NULL, 'Greene', 102),
(8519, 'Iljinia', NULL, 'Korovin', 5),
(8520, 'Illigera', NULL, 'Blume', 79),
(8521, 'Illipe', NULL, 'J.Konig ex Gras', 148),
(8522, 'Ilocania', NULL, 'Merr.', 49),
(8523, 'Iltisia', NULL, 'S.F.Blake', 18),
(8524, 'Ilysanthes', NULL, 'Raf.', 150),
(8525, 'Imantina', NULL, 'Hook.f.', 142),
(8526, 'Imbralyx', NULL, 'R.Geesink', 68),
(8527, 'Imbricaria', NULL, 'Sm.(SUH)', 116),
(8528, 'Imeria', NULL, 'R.M.King & H.Rob.', 18),
(8529, 'Imperatoria', NULL, 'L.', 9),
(8530, 'Incarvillea', NULL, 'Juss.', 22),
(8531, 'Indigastrum', NULL, 'Jaub. & Spach', 68),
(8532, 'Indobanalia', NULL, 'A.N.Henry & B.Roy', 5),
(8533, 'Indocourtoisia', NULL, 'Bennet & Raizada(SUS)', 55),
(8534, 'Indofevillea', NULL, 'Chatterjee', 49),
(8535, 'Indokingia', NULL, 'Hemsl.', 13),
(8536, 'Indoneesiella', NULL, 'Sreem.', 1),
(8537, 'Indopiptadenia', NULL, 'Brenan', 68),
(8538, 'Indopolysolenia', NULL, 'Bennet', 142),
(8539, 'Indorouchera', NULL, 'Hallier f.', 95),
(8540, 'Indosinia', NULL, 'J.E.Vidal', 118),
(8541, 'Indovethia', NULL, 'Boerl.', 118),
(8542, 'Inezia', NULL, 'E.Phillips', 18),
(8543, 'Inhambanella', NULL, '(Engl.) Dubard', 148),
(8544, 'Inocarpus', NULL, 'J.R.Forst. & G.Forst.', 68),
(8545, 'Inodes', NULL, 'O.F.Cook', 15),
(8546, 'Inophloeum', NULL, 'Pittier', 109),
(8547, 'Inula', NULL, 'L.', 18),
(8548, 'Inulanthera', NULL, 'Kallersjo', 18),
(8549, 'Involucraria', NULL, 'Ser.', 49),
(8550, 'Inyonia', NULL, 'M.E.Jones', 18),
(8551, 'Iocenes', NULL, 'B.Nord.', 18),
(8552, 'Iochroma', NULL, 'Benth.', 154),
(8553, 'Iodanthus', NULL, '(Torr. & A.Gray) Steud.', 197),
(8554, 'Iodes', NULL, 'Blume', 85),
(8555, 'Iodina', NULL, 'Hook. & Arn. ex Meisn.', 146),
(8556, 'Iodocephalus', NULL, 'Thorel ex Gagnep.', 18),
(8557, 'Iogeton', NULL, 'Strother', 18),
(8558, 'Ionacanthus', NULL, 'Benoist', 1),
(8559, 'Iondra', NULL, 'Raf.', 197),
(8560, 'Iondraba', NULL, 'Rchb.', 197),
(8561, 'Ionidium', NULL, 'Vent.', 174),
(8562, 'Ionopsidium', NULL, 'Rchb.', 197),
(8563, 'Ionoxalis', NULL, 'Small', 124),
(8564, 'Iostephane', NULL, 'Benth.', 18),
(8565, 'Ioxylon', NULL, 'Raf.', 109),
(8566, 'Ipecacuahna', NULL, 'Arruda', 142),
(8567, 'Iphiona', NULL, 'Cass.', 18),
(8568, 'Iphionopsis', NULL, 'Anderb.', 18),
(8569, 'Ipomoea', NULL, 'L.', 46),
(8570, 'Iranecio', NULL, 'B.Nord.', 18),
(8571, 'Irenella', NULL, 'Suess.', 5),
(8572, 'Irenepharsus', NULL, 'Hewson', 197),
(8573, 'Iresine', NULL, 'P.Browne', 5),
(8574, 'Iriartella', NULL, 'H.Wendl.', 15),
(8575, 'Irlbachia', NULL, 'Mart.', 75),
(8576, 'Irmischia', NULL, 'Schltdl.', 10),
(8577, 'Irvingbaileya', NULL, 'R.A.Howard', 545),
(8578, 'Irwinia', NULL, 'Barroso', 18),
(8579, 'Isacanthus', NULL, 'Nees', 1),
(8580, 'Isaloa', NULL, 'Humbert', 1),
(8581, 'Isandra', NULL, 'F.Muell.(SUH)', 154),
(8582, 'Isandraea', NULL, 'Rauschert(SUS)', 154),
(8583, 'Isanthera', NULL, 'Nees', 76),
(8584, 'Isanthus', NULL, 'Michx.', 90),
(8585, 'Isartia', NULL, 'Dumort.(SUO)', 142),
(8586, 'Isatis', NULL, 'L.', 197),
(8587, 'Ischnanthus', NULL, '(Engl.) Tiegh.(SUH)', 98),
(8588, 'Ischnea', NULL, 'F.Muell.', 18),
(8589, 'Ischnocarpus', NULL, 'O.E.Schulz', 197),
(8590, 'Ischnolepis', NULL, 'Jum. & H.Perrier', 10),
(8591, 'Ischnosiphon', NULL, 'Korn.', 103),
(8592, 'Ischnostemma', NULL, 'King & Gamble', 10),
(8593, 'Iseia', NULL, 'O''Donell', 46),
(8594, 'Isidorea', NULL, 'A.Rich. ex DC.', 142),
(8595, 'Isinia', NULL, 'Rech.f.', 90),
(8596, 'Iskandera', NULL, 'N.Busch', 197),
(8597, 'Isnardia', NULL, 'L.', 121),
(8598, 'Isoberlinia', NULL, 'Craib & Stapf ex Holland', 68),
(8599, 'Isocarpha', NULL, 'R.Br.', 18),
(8600, 'Isocaulon', NULL, 'Tiegh.', 98),
(8601, 'Isochoriste', NULL, 'Miq.', 1),
(8602, 'Isocoma', NULL, 'Nutt.', 18),
(8603, 'Isodendrion', NULL, 'A.Gray', 174),
(8604, 'Isodesmia', NULL, 'Gardner', 68),
(8605, 'Isodictyophorus', NULL, 'Briq.', 90),
(8606, 'Isodon', NULL, '(Schrad. ex Benth.) Spach', 90),
(8607, 'Isoetopsis', NULL, 'Turcz.', 18),
(8608, 'Isoglossa', NULL, 'Oerst.', 1),
(8609, 'Isolepis', NULL, 'R.Br.', 55),
(8610, 'Isoleucas', NULL, 'O.Schwartz', 90),
(8611, 'Isolobus', NULL, 'A.DC.', 30),
(8612, 'Isomacrolobium', NULL, 'Aubrev. & Pellegr.', 68),
(8613, 'Isomeris', NULL, 'Nutt.', 509),
(8614, 'Isomerocarpa', NULL, 'A.C.Sm.', 108),
(8615, 'Isometrum', NULL, 'Craib', 76),
(8616, 'Isonema', NULL, 'R.Br.', 10),
(8617, 'Isopappus', NULL, 'Torr. & A.Gray', 18),
(8618, 'Isoplexis', NULL, '(Lindl.) Loudon', 423),
(8619, 'Isopogon', NULL, 'R.Br. ex Knight', 135),
(8620, 'Isoptera', NULL, 'Scheff. ex Burck', 60),
(8621, 'Isorium', NULL, 'Raf.', 25),
(8622, 'Isostigma', NULL, 'Less.', 18),
(8623, 'Isotheca', NULL, 'Turrill', 1),
(8624, 'Isotoma', NULL, '(R.Br.) Lindl.', 30),
(8625, 'Isotrema', NULL, 'Raf.', 16),
(8626, 'Isotropis', NULL, 'Benth.', 68),
(8627, 'Itacania', NULL, 'Raf.', 98),
(8628, 'Itaobimia', NULL, 'Rizzini', 68),
(8629, 'Itasina', NULL, 'Raf.', 9),
(8630, 'Itatiaia', NULL, 'Ule', 105),
(8631, 'Itaya', NULL, 'H.E.Moore', 15),
(8632, 'Iteadaphne', NULL, 'Blume', 91),
(8633, 'Iteiluma', NULL, 'Baill.', 148),
(8634, 'Iti', NULL, 'Garn.-Jones & P.N.Johnson', 197),
(8635, 'Itoa', NULL, 'Hemsl.', 145),
(8636, 'Ituridendron', NULL, 'De Wild.', 148),
(8637, 'Itzaea', NULL, 'Standl. & Steyerm.', 46),
(8638, 'Iva', NULL, 'L.', 18),
(8639, 'Ivania', NULL, 'O.E.Schulz', 197),
(8640, 'Ivanjohnstonia', NULL, 'Kazmi', 25),
(8641, 'Ivesia', NULL, 'Torr. & A.Gray', 141),
(8642, 'Ivodea', NULL, 'Capuron', 143),
(8643, 'Ixanthus', NULL, 'Griseb.', 75),
(8644, 'Ixeridium', NULL, '(A.Gray) Tzvelev', 18),
(8645, 'Ixeris', NULL, '(Cass.) Cass.', 18),
(8646, 'Ixianthes', NULL, 'Benth.', 150),
(8647, 'Ixidium', NULL, 'Eichler', 63),
(8648, 'Ixiochlamys', NULL, 'F.Muell. & Sond.', 18),
(8649, 'Ixiolaena', NULL, 'Benth.', 18),
(8650, 'Ixocactus', NULL, 'Rizzini', 98),
(8651, 'Ixodia', NULL, 'R.Br.', 18),
(8652, 'Ixodonerium', NULL, 'Pit.', 10),
(8653, 'Ixtlania', NULL, 'M.E.Jones', 1),
(8654, 'Izabalaea', NULL, 'Lundell', 117),
(8655, 'Jablonskia', NULL, 'G.L.Webster', 184),
(8656, 'Jaborosa', NULL, 'Juss.', 154),
(8657, 'Jacaima', NULL, 'Rendle', 10),
(8658, 'Jackia', NULL, 'Wall.', 142),
(8659, 'Jacksonia', NULL, 'R.Br. ex Sm.', 68),
(8660, 'Jacmaia', NULL, 'B.Nord.', 18),
(8661, 'Jacobinia', NULL, 'Nees ex Moric.', 1),
(8662, 'Jacquemontia', NULL, 'Choisy', 46),
(8663, 'Jacqueshuberia', NULL, 'Ducke', 68),
(8664, 'Jadunia', NULL, 'Lindau', 1),
(8665, 'Jaegeria', NULL, 'Kunth', 18),
(8666, 'Jaeggia', NULL, 'Schinz', 127),
(8667, 'Jaeschkea', NULL, 'Kurz', 75),
(8668, 'Jagera', NULL, 'Blume', 147),
(8669, 'Jahnia', NULL, 'Pittier & S.F.Blake', 155),
(8670, 'Jaimenostia', NULL, 'Guinea & Gomez Mor.', 12),
(8671, 'Jainia', NULL, 'N.P.Balakr.', 142),
(8672, 'Jalcophila', NULL, 'Dillon & Sagast.', 18),
(8673, 'Jaliscoa', NULL, 'S.Watson', 18),
(8674, 'Jaltomata', NULL, 'Schltdl.', 154),
(8675, 'Jambos', NULL, 'Adans.', 116),
(8676, 'Jambosa', NULL, 'Adans.', 116),
(8677, 'Jamesbrittenia', NULL, 'Kuntze', 150),
(8678, 'Jamesianthus', NULL, 'S.F.Blake & Sherff', 18),
(8679, 'Janakia', NULL, 'J.Joseph & Chandras.', 10),
(8680, 'Jancaea', NULL, 'Boiss.', 76),
(8681, 'Jangaraca', NULL, 'Raf.', 142),
(8682, 'Janipha', NULL, 'Kunth', 66),
(8683, 'Jankaea', NULL, 'Boiss.(SUO)', 76),
(8684, 'Janotia', NULL, 'J.-F.Leroy', 142),
(8685, 'Jansonia', NULL, 'Kippist', 68),
(8686, 'Janusia', NULL, 'A.Juss.', 101),
(8687, 'Japarandiba', NULL, 'Adans.', 92),
(8688, 'Jaramilloa', NULL, 'R.M.King & H.Rob.', 18),
(8689, 'Jarandersonia', NULL, 'Kosterm.', 102),
(8690, 'Jarilla', NULL, 'I.M.Johnst.(SUH)', 34),
(8691, 'Jasarum', NULL, 'Bunting', 12),
(8692, 'Jasione', NULL, 'L.', 30),
(8693, 'Jasionella', NULL, 'Stoj. & Stef.', 30),
(8694, 'Jasminium', NULL, 'Dumort.(SUO)', 120),
(8695, 'Jasminochyla', NULL, '(Stapf) Pichon', 10),
(8696, 'Jasminoides', NULL, 'Duhamel', 154),
(8697, 'Jasminum', NULL, 'L.', 120),
(8698, 'Jasonia', NULL, '(Cass.) Cass.', 18),
(8699, 'Jateorhiza', NULL, 'Miers', 107),
(8700, 'Jatropa', NULL, 'Scop.(SUO)', 66),
(8701, 'Jaubertia', NULL, 'Guill.', 142),
(8702, 'Jaumea', NULL, 'Pers.', 18),
(8703, 'Jaundea', NULL, 'Gilg', 45),
(8704, 'Javorkaea', NULL, 'Borhidi & Komlodi', 142),
(8705, 'Jedda', NULL, 'J.R.Clarkson', 164),
(8706, 'Jefea', NULL, 'Strother', 18),
(8707, 'Jeffreya', NULL, 'Wild', 18),
(8708, 'Jehlia', NULL, 'Rose', 121),
(8709, 'Jepsonia', NULL, 'Small', 149),
(8710, 'Jerdonia', NULL, 'Wight', 150),
(8711, 'Jessenia', NULL, 'H.Karst.', 15),
(8712, 'Joannesia', NULL, 'Vell.', 66),
(8713, 'Jobinia', NULL, 'E.Fourn.', 10),
(8714, 'Jocayena', NULL, 'Raf.(SUO)', 142),
(8715, 'Johannesteijsmannia', NULL, 'H.E.Moore', 15),
(8716, 'Johnia', NULL, 'Roxb.', 38),
(8717, 'Johnstonella', NULL, 'Brand', 25),
(8718, 'Johowia', NULL, 'Epling & Looser', 90),
(8719, 'Johrenia', NULL, 'DC.', 9),
(8720, 'Johreniopsis', NULL, 'Pimenov', 9),
(8721, 'Joliffia', NULL, 'Bojer ex Delile', 49),
(8722, 'Jollya', NULL, 'Pierre', 148),
(8723, 'Jondraba', NULL, 'Medik.', 197),
(8724, 'Jonesia', NULL, 'Roxb.', 68),
(8725, 'Jonesiella', NULL, 'Rydb.', 68),
(8726, 'Jontanea', NULL, 'Raf.', 142),
(8727, 'Joseanthus', NULL, 'H.Rob.', 18),
(8728, 'Jossinia', NULL, 'Comm. ex DC.', 116),
(8729, 'Jovellana', NULL, 'Ruiz & Pav.', 507),
(8730, 'Jovetia', NULL, 'Guedes', 142),
(8731, 'Jovibarba', NULL, '(DC.) Opiz', 48),
(8732, 'Juania', NULL, 'Drude', 15),
(8733, 'Juanulloa', NULL, 'Ruiz & Pav.', 154),
(8734, 'Jubaea', NULL, 'Kunth', 15),
(8735, 'Jubaeopsis', NULL, 'Becc.', 15),
(8736, 'Jubelina', NULL, 'A.Juss.', 101),
(8737, 'Jubistylis', NULL, 'Rusby', 101),
(8738, 'Juchia', NULL, 'M.Roem.', 49),
(8739, 'Jugastrum', NULL, 'Miers', 92),
(8740, 'Juglans', NULL, 'L.', 87),
(8741, 'Juliania', NULL, 'Schltdl.(SUH)', 6),
(8742, 'Julibaria', NULL, 'Mez', 115),
(8743, 'Julocroton', NULL, 'Mart.', 66),
(8744, 'Julostylis', NULL, 'Thwaites', 102),
(8745, 'Jumelleanthus', NULL, 'Hochr.', 102),
(8746, 'Juncellus', NULL, 'C.B.Clarke', 55),
(8747, 'Junellia', NULL, 'Moldenke', 173),
(8748, 'Junghuhnia', NULL, 'Miq.(SUH)', 66),
(8749, 'Jungia', NULL, 'Gaertn.(SUH)', 18),
(8750, 'Juniperus', NULL, 'L.', 51),
(8751, 'Juppia', NULL, 'Merr.', 49),
(8752, 'Jupunba', NULL, 'Britton & Rose', 68),
(8753, 'Jurgensia', NULL, 'Raf.', 142),
(8754, 'Jurinea', NULL, 'Cass.', 18),
(8755, 'Jurinella', NULL, 'Jaub. & Spach', 18),
(8756, 'Juruasia', NULL, 'Lindau', 1),
(8757, 'Jussiaea', NULL, 'L.', 121),
(8758, 'Jussieuia', NULL, 'Houst.', 66),
(8759, 'Justago', NULL, 'Kuntze', 32),
(8760, 'Justenia', NULL, 'Hiern', 142),
(8761, 'Kadali', NULL, 'Adans.', 105),
(8762, 'Kadalia', NULL, 'Raf.', 105),
(8763, 'Kadenia', NULL, 'Lavrova & V.N.Tikhom.', 9),
(8764, 'Kadua', NULL, 'Cham. & Schltdl.', 142),
(8765, 'Kafirnigania', NULL, 'Kamelin & Kinzik.', 9),
(8766, 'Kageneckia', NULL, 'Ruiz & Pav.', 141),
(8767, 'Kaieteuria', NULL, 'Dwyer', 118),
(8768, 'Kailarsenia', NULL, 'Tirveng.', 142),
(8769, 'Kairoa', NULL, 'Philipson', 108),
(8770, 'Kairothamnus', NULL, 'Airy Shaw', 534),
(8771, 'Kajewskia', NULL, 'Guillaumin', 15),
(8772, 'Kajewskiella', NULL, 'Merr. & Perry', 142),
(8773, 'Kakosmanthus', NULL, 'Hassk.', 148),
(8774, 'Kalaharia', NULL, 'Baill.', 90),
(8775, 'Kalakia', NULL, 'Alava', 9),
(8776, 'Kalanchoe', NULL, 'Adans.', 48),
(8777, 'Kalappia', NULL, 'Kosterm.', 68),
(8778, 'Kalbreyera', NULL, 'Burret', 15),
(8779, 'Kalbreyeracanthus', NULL, 'Wassh.', 1),
(8780, 'Kalbreyeriella', NULL, 'Lindau', 1),
(8781, 'Kalidiopsis', NULL, 'Aellen', 5),
(8782, 'Kalidium', NULL, 'Moq.', 5),
(8783, 'Kalimeris', NULL, '(Cass.) Cass.', 18),
(8784, 'Kallstroemia', NULL, 'Scop.', 177),
(8785, 'Kalmia', NULL, 'L.', 64),
(8786, 'Kalmiella', NULL, 'Small', 64),
(8787, 'Kalmiopsis', NULL, 'Rehder', 64),
(8788, 'Kalopanax', NULL, 'Miq.', 13),
(8789, 'Kaluhaburunghos', NULL, 'Kuntze', 184),
(8790, 'Kamettia', NULL, 'Kostel.', 10),
(8791, 'Kamiella', NULL, 'Vassilcz.', 68),
(8792, 'Kamptzia', NULL, 'Nees', 116),
(8793, 'Kanahia', NULL, 'R.Br.', 10),
(8794, 'Kandaharia', NULL, 'Alava', 9),
(8795, 'Kandelia', NULL, '(DC.) Wight & Arn.', 140),
(8796, 'Kania', NULL, 'Schltr.', 116),
(8797, 'Kanilia', NULL, 'Blume', 140),
(8798, 'Kanimia', NULL, 'Gardner', 18),
(8799, 'Kanjarum', NULL, 'Ramam.', 1),
(8800, 'Kanopikon', NULL, 'Raf.', 66),
(8801, 'Kantou', NULL, 'Aubrev. & Pellegr.', 148),
(8802, 'Kaoue', NULL, 'Pellegr.', 68),
(8803, 'Karamyschewia', NULL, 'Fisch. & C.A.Mey.', 142),
(8804, 'Karatavia', NULL, 'Pimenov & Lavrova', 9),
(8805, 'Kardanoglyphos', NULL, 'Schltdl.', 197),
(8806, 'Karekandel', NULL, 'Wolf', 140),
(8807, 'Karelinia', NULL, 'Less.', 18),
(8808, 'Karimbolea', NULL, 'Desc.', 10),
(8809, 'Karina', NULL, 'Boutique', 75),
(8810, 'Karivia', NULL, 'Arn.', 49),
(8811, 'Karlea', NULL, 'Pierre', 139),
(8812, 'Karnataka', NULL, 'P.K.Mukh. & Constance', 9),
(8813, 'Karomia', NULL, 'Dop', 90),
(8814, 'Karvandarina', NULL, 'Rech.f.', 18),
(8815, 'Karwinskia', NULL, 'Zucc.', 139),
(8816, 'Kaschgaria', NULL, 'Poljakov', 18),
(8817, 'Kashmiria', NULL, 'D.Y.Hong', 423),
(8818, 'Katafa', NULL, 'Costantin & J.Poiss.', 38),
(8819, 'Katoutheka', NULL, 'Adans.', 142),
(8820, 'Kaukenia', NULL, 'Kuntze', 148),
(8821, 'Kaunia', NULL, 'R.M.King & H.Rob.', 18),
(8822, 'Kearnemalvastrum', NULL, 'D.M.Bates', 102),
(8823, 'Keckia', NULL, 'Straw(SUH)', 150),
(8824, 'Keckiella', NULL, 'Straw', 423),
(8825, 'Kedarnatha', NULL, 'P.K.Mukh. & Constance', 9),
(8826, 'Kedrostis', NULL, 'Medik.', 49),
(8827, 'Keenania', NULL, 'Hook.f.', 142),
(8828, 'Keetia', NULL, 'E.Phillips', 142),
(8829, 'Keiskea', NULL, 'Miq.', 90),
(8830, 'Keithia', NULL, 'Benth.', 90),
(8831, 'Kelleria', NULL, 'Endl.', 164),
(8832, 'Kelleronia', NULL, 'Schinz', 177),
(8833, 'Kelloggia', NULL, 'Torr. ex Benth.', 142),
(8834, 'Kelseya', NULL, 'Rydb.', 141),
(8835, 'Kendrickia', NULL, 'Hook.f.', 105),
(8836, 'Kennedia', NULL, 'Vent.', 68),
(8837, 'Kenopleurum', NULL, 'Candargy', 9),
(8838, 'Kentia', NULL, 'Blume(SUH)', 8),
(8839, 'Kentiopsis', NULL, 'Brongn.', 15),
(8840, 'Kentrochrosia', NULL, 'K.Schum. & Lauterb.', 10),
(8841, 'Kentrophyta', NULL, 'Nutt.', 68),
(8842, 'Kentrosphaera', NULL, 'Volkens', 5),
(8843, 'Kentrothamnus', NULL, 'Suess. & Overkott', 139),
(8844, 'Keppleria', NULL, 'Mart. ex Endl.', 15),
(8845, 'Keracia', NULL, '(Coss.) Calest.', 9),
(8846, 'Keramanthus', NULL, 'Hook.f.', 127),
(8847, 'Keramocarpus', NULL, 'Fenzl', 9),
(8848, 'Keratephorus', NULL, 'Hassk.', 148),
(8849, 'Keratolepis', NULL, 'Rose ex Frod.', 48),
(8850, 'Keraudrenia', NULL, 'J.Gay', 102),
(8851, 'Keraymonia', NULL, 'Farille', 9),
(8852, 'Kerbera', NULL, 'E.Fourn.', 10),
(8853, 'Kerianthera', NULL, 'J.H.Kirkbr.', 142),
(8854, 'Kermadecia', NULL, 'Brongn. & Gris', 135),
(8855, 'Kernera', NULL, 'Medik.', 197),
(8856, 'Kerrdora', NULL, 'Gagnep.', 164),
(8857, 'Kerria', NULL, 'DC.', 141),
(8858, 'Kerriodoxa', NULL, 'J.Dransf.', 15),
(8859, 'Kerriothyrsus', NULL, 'C.Hansen', 105),
(8860, 'Kerstania', NULL, 'Rech.f.', 68),
(8861, 'Kerstingia', NULL, 'K.Schum.', 142),
(8862, 'Kerstingiella', NULL, 'Harms', 68),
(8863, 'Keteleeria', NULL, 'Carriere', 129),
(8864, 'Keyserlingia', NULL, 'Bunge ex Boiss.', 68),
(8865, 'Keysseria', NULL, 'Lauterb.', 18),
(8866, 'Khasiaclunea', NULL, 'Ridsdale', 142),
(8867, 'Kiapasia', NULL, 'Woronow ex Grossh.', 68),
(8868, 'Kibaropsis', NULL, 'Vieill. ex Jeremie', 108),
(8869, 'Kibbesia', NULL, 'Walp.(SUO)', 105),
(8870, 'Kibessia', NULL, 'DC.', 105),
(8871, 'Kickxia', NULL, 'Dumort.', 423),
(8872, 'Kielmeyera', NULL, 'Mart.', 42),
(8873, 'Kierschlegeria', NULL, 'Spach', 121),
(8874, 'Kigelianthe', NULL, 'Baill.', 22),
(8875, 'Kigelkeia', NULL, 'Raf.', 22),
(8876, 'Kiggelaria', NULL, 'L.', 198),
(8877, 'Killipia', NULL, 'Gleason', 105),
(8878, 'Killipiella', NULL, 'A.C.Sm.', 64),
(8879, 'Killipiodendron', NULL, 'Kobuski', 409),
(8880, 'Kinepetalum', NULL, 'Schltr.', 10),
(8881, 'Kinetostigma', NULL, 'Dammer', 15),
(8882, 'Kingdon-Wardia', NULL, 'C.Marquand', 75),
(8883, 'Kingella', NULL, 'Tiegh.', 98),
(8884, 'Kinghamia', NULL, 'C.Jeffrey', 18),
(8885, 'Kingianthus', NULL, 'H.Rob.', 18),
(8886, 'Kinginda', NULL, 'Kuntze', 8),
(8887, 'Kingiodendron', NULL, 'Harms', 68),
(8888, 'Kinkina', NULL, 'Adans.', 142),
(8889, 'Kinostemon', NULL, 'Kudo', 90),
(8890, 'Kippistia', NULL, 'F.Muell.', 18),
(8891, 'Kirganelia', NULL, 'Juss.', 184),
(8892, 'Kirilowia', NULL, 'Bunge', 5),
(8893, 'Kirkbridea', NULL, 'Wurdack', 105),
(8894, 'Kirkia', NULL, 'Oliv.', 518),
(8895, 'Kirkianella', NULL, 'Allan', 18),
(8896, 'Kirkophytum', NULL, '(Harms) Allan', 13),
(8897, 'Kirpicznikovia', NULL, 'A.Love & D.Love', 48),
(8898, 'Kirschlegera', NULL, 'Rchb.(SUO)', 121),
(8899, 'Kissodendron', NULL, 'Seem.', 13),
(8900, 'Kita', NULL, 'A.Chev.', 1),
(8901, 'Kitagawia', NULL, 'Pimenov', 9),
(8902, 'Kitaibela', NULL, 'Willd.', 102),
(8903, 'Kitamuraea', NULL, 'Rauschert(SUS)', 18),
(8904, 'Kitamuraster', NULL, 'Sojak(SUS)', 18),
(8905, 'Kitchingia', NULL, 'Baker', 48),
(8906, 'Kittelia', NULL, 'Rchb.', 30),
(8907, 'Kjellbergia', NULL, 'Bremek.', 1),
(8908, 'Kjellbergiodendron', NULL, 'Burret', 116),
(8909, 'Klaineastrum', NULL, 'Pierre ex A.Chev.', 105),
(8910, 'Klanderia', NULL, 'F.Muell.', 90),
(8911, 'Kleinhovia', NULL, 'L.', 102),
(8912, 'Kleinia', NULL, 'Crantz(SUH)', 18),
(8913, 'Kleinodendron', NULL, 'L.B.Sm. & Downs', 66),
(8914, 'Klopstockia', NULL, 'H.Karst.', 15),
(8915, 'Klossia', NULL, 'Ridl.', 142),
(8916, 'Klotzschia', NULL, 'Cham.', 9),
(8917, 'Klotzschiphytum', NULL, 'Baill.', 66),
(8918, 'Klugia', NULL, 'Schltdl.', 76),
(8919, 'Klugiodendron', NULL, 'Britton & Killip', 68),
(8920, 'Kmeria', NULL, '(Pierre) Dandy', 100),
(8921, 'Kneiffia', NULL, 'Spach', 121),
(8922, 'Knightia', NULL, 'R.Br.', 135),
(8923, 'Kniphofia', NULL, 'Scop.(SUH)', 225),
(8924, 'Knorringia', NULL, '(Czukav.) Tzvelev', 134),
(8925, 'Knoxia', NULL, 'L.', 142),
(8926, 'Koanophyllum', NULL, 'Arruda(SUO)', 18),
(8927, 'Kobiosis', NULL, 'Raf.', 66),
(8928, 'Kobresia', NULL, 'Willd.', 55),
(8929, 'Kochia', NULL, 'Roth', 5),
(8930, 'Kochummenia', NULL, 'K.M.Wong', 142),
(8931, 'Kodalyodendron', NULL, 'Borhidi & Acuna', 143),
(8932, 'Koeberlinia', NULL, 'Zucc.', 519),
(8933, 'Koechlea', NULL, 'Endl.', 18),
(8934, 'Koehneago', NULL, 'Kuntze', 142),
(8935, 'Koehneola', NULL, 'Urb.', 18),
(8936, 'Koehneria', NULL, 'S.A.Graham, Tobe & Baas', 99),
(8937, 'Koeiea', NULL, 'Rech.f.', 197),
(8938, 'Koellia', NULL, 'Moench', 90),
(8939, 'Koellikeria', NULL, 'Regel', 76),
(8940, 'Koelpinia', NULL, 'Pall.', 18),
(8941, 'Koelreuteria', NULL, 'Laxm.', 147),
(8942, 'Koelzella', NULL, 'Hiroe', 9),
(8943, 'Koelzia', NULL, 'Rech.f.', 197),
(8944, 'Koenigia', NULL, 'L.', 134),
(8945, 'Koernickanthe', NULL, 'L.Andersson', 103),
(8946, 'Kohautia', NULL, 'Cham. & Schltdl.', 142),
(8947, 'Kohleria', NULL, 'Regel', 76),
(8948, 'Kohlerianthus', NULL, 'Fritsch', 76),
(8949, 'Kokabus', NULL, 'Raf.', 154),
(8950, 'Kokia', NULL, 'Lewton', 102),
(8951, 'Kokoschkinia', NULL, 'Turcz.', 22),
(8952, 'Kolbia', NULL, 'P.Beauv.', 127),
(8953, 'Kolkwitzia', NULL, 'Graebn.', 521),
(8954, 'Kolobochilus', NULL, 'Lindau', 1),
(8955, 'Kolobopetalum', NULL, 'Engl.', 107),
(8956, 'Komarovia', NULL, 'Korovin', 9),
(8957, 'Kompitsia', NULL, 'Costantin & Gallaud', 10),
(8958, 'Konig', NULL, 'Adans.', 197),
(8959, 'Konxikas', NULL, 'Raf.', 68),
(8960, 'Koordersiodendron', NULL, 'Engl.', 6),
(8961, 'Kopsiopsis', NULL, '(Beck) Beck', 400),
(8962, 'Kordelestris', NULL, 'Arruda', 22),
(8963, 'Korolkowia', NULL, 'Regel', 94),
(8964, 'Korovinia', NULL, 'Nevski & Vved.', 9),
(8965, 'Korshinskia', NULL, 'Lipsky', 9),
(8966, 'Korthalsella', NULL, 'Tiegh.', 146),
(8967, 'Korthalsia', NULL, 'Blume', 15),
(8968, 'Kosaria', NULL, 'Forssk.', 109),
(8969, 'Kosmosiphon', NULL, 'Lindau', 1),
(8970, 'Kosopoljanskia', NULL, 'Korovin', 9),
(8971, 'Kosteletzkya', NULL, 'C.Presl', 102),
(8972, 'Kostermansia', NULL, 'Soegeng', 102),
(8973, 'Kostyczewa', NULL, 'Korsh.', 68),
(8974, 'Kotschya', NULL, 'Endl.', 68),
(8975, 'Kotschyella', NULL, 'F.K.Mey.', 197),
(8976, 'Koyamaea', NULL, 'W.W.Thomas & Davidse', 55),
(8977, 'Kozlovia', NULL, 'Lipsky', 9),
(8978, 'Krameria', NULL, 'L. ex Loefl.', 88),
(8979, 'Krapovickasia', NULL, 'Fryxell', 102),
(8980, 'Krascheninnikovia', NULL, 'Gueldenst.', 5),
(8981, 'Krasnovia', NULL, 'Popov ex Schischk.', 9),
(8982, 'Krassera', NULL, 'O.Schwartz', 105),
(8983, 'Kraunhia', NULL, 'Raf.', 68),
(8984, 'Krausella', NULL, 'H.J.Lam', 148),
(8985, 'Kraussia', NULL, 'Harv.', 142),
(8986, 'Krebsia', NULL, 'Harv.', 10),
(8987, 'Kremeria', NULL, 'Durieu', 18),
(8988, 'Kremeriella', NULL, 'Maire', 197),
(8989, 'Krigia', NULL, 'Schreb.', 18),
(8990, 'Krokia', NULL, 'Urb.', 116),
(8991, 'Krubera', NULL, 'Hoffm.', 9),
(8992, 'Krugella', NULL, 'Pierre', 148),
(8993, 'Krugia', NULL, 'Urb.', 116),
(8994, 'Krugiodendron', NULL, 'Urb.', 139),
(8995, 'Krukoviella', NULL, 'A.C.Sm.', 118),
(8996, 'Kubitzkia', NULL, 'van der Werff', 91),
(8997, 'Kudoacanthus', NULL, 'Hosok.', 1),
(8998, 'Kudrjaschevia', NULL, 'Pojark.', 90),
(8999, 'Kuepferella', NULL, 'M.Lainz', 75),
(9000, 'Kuestera', NULL, 'Regel', 1),
(9001, 'Kuhlia', NULL, 'Kunth', 145),
(9002, 'Kuhlmannia', NULL, 'J.C.Gomes', 22),
(9003, 'Kuhlmanniella', NULL, 'Barroso', 46),
(9004, 'Kuhnia', NULL, 'L.(SUH)', 18),
(9005, 'Kuhnistera', NULL, 'Lam.', 68),
(9006, 'Kukolis', NULL, 'Raf.', 154),
(9007, 'Kumbaya', NULL, 'Endl. ex Steud.', 142),
(9008, 'Kummeria', NULL, 'Mart.', 85),
(9009, 'Kummerowia', NULL, 'Schindl.', 68),
(9010, 'Kundmannia', NULL, 'Scop.', 9),
(9011, 'Kunkeliella', NULL, 'Stearn', 146),
(9012, 'Kunstleria', NULL, 'Prain', 68),
(9013, 'Kunstlerodendron', NULL, 'Ridl.', 66),
(9014, 'Kunthea', NULL, 'Humb. & Bonpl.', 15),
(9015, 'Kunzea', NULL, 'Rchb.', 116),
(9016, 'Kurkas', NULL, 'Raf.', 66),
(9017, 'Kurria', NULL, 'Hochst. ex Steud.', 142),
(9018, 'Kurrimia', NULL, 'Wall. ex Thwaites', 38),
(9019, 'Kurzamra', NULL, 'Kuntze', 90),
(9020, 'Kurziodendron', NULL, 'N.P.Balakr.', 66),
(9021, 'Kuschakewiczia', NULL, 'Regel & Smirn.', 25),
(9022, 'Kutchubaea', NULL, 'Fisch. ex DC.', 142),
(9023, 'Kyllinga', NULL, 'Rottb.', 55),
(9024, 'Kyllingiella', NULL, 'R.W.Haines & Lye', 55),
(9025, 'Kyphocarpa', NULL, '(Fenzl ex Endl.) Lopr.', 5),
(9026, 'Kyrsteniopsis', NULL, 'R.M.King & H.Rob.', 18),
(9027, 'Kyrtanthus', NULL, 'J.F.Gmel.', 142),
(9028, 'Labatia', NULL, 'Sw.', 148),
(9029, 'Labichea', NULL, 'Gaudich. ex DC.', 68),
(9030, 'Labidostelma', NULL, 'Schltr.', 10),
(9031, 'Labisia', NULL, 'Lindl.', 115),
(9032, 'Lablab', NULL, 'Adans.', 68),
(9033, 'Labordia', NULL, 'Gaudich.', 97),
(9034, 'Labourdonnaisia', NULL, 'Bojer', 148),
(9035, 'Labramia', NULL, 'A.DC.', 148),
(9036, 'Laburnum', NULL, 'Fabr.', 68),
(9037, 'Lacaitaea', NULL, 'Brand', 25),
(9038, 'Lacanthis', NULL, 'Raf.', 66),
(9039, 'Laccospadix', NULL, 'Drude & H.Wendl.', 15),
(9040, 'Laccosperma', NULL, '(G.Mann & H.Wendl.) Drude', 15),
(9041, 'Lacerdaea', NULL, 'O.Berg', 116),
(9042, 'Lachanodes', NULL, 'DC.', 18),
(9043, 'Lachemilla', NULL, '(Focke) Rydb.', 141),
(9044, 'Lachnaea', NULL, 'L.', 164),
(9045, 'Lachnastoma', NULL, 'Korth.(SUH)', 142),
(9046, 'Lachnocapsa', NULL, 'Balf.f.', 197),
(9047, 'Lachnoloma', NULL, 'Bunge', 197),
(9048, 'Lachnophyllum', NULL, 'Bunge', 18),
(9049, 'Lachnopodium', NULL, 'Blume', 105),
(9050, 'Lachnorhiza', NULL, 'A.Rich.', 18),
(9051, 'Lachnosiphonium', NULL, 'Hochst.', 142),
(9052, 'Lachnospermum', NULL, 'Willd.', 18),
(9053, 'Lachnostachys', NULL, 'Hook.', 90),
(9054, 'Lachnostoma', NULL, 'Hassk.(SUO)', 10),
(9055, 'Lachnostylis', NULL, 'Turcz.', 184),
(9056, 'Laciala', NULL, 'Kuntze', 18),
(9057, 'Lactuca', NULL, 'L.', 18),
(9058, 'Lactucosonchus', NULL, '(Sch.Bip.) Svent.', 18),
(9059, 'Ladyginia', NULL, 'Lipsky', 9),
(9060, 'Laennecia', NULL, 'Cass.', 18),
(9061, 'Laestadia', NULL, 'Kunth ex Less.', 18),
(9062, 'Lafuentea', NULL, 'Lag.', 423),
(9063, 'Lafuentia', NULL, 'Lag.(SUO)', 150),
(9064, 'Lagarinthus', NULL, 'E.Mey.', 10),
(9065, 'Lagarostrobos', NULL, 'Quinn', 132),
(9066, 'Lagascea', NULL, 'Cav.', 18),
(9067, 'Lagedium', NULL, 'Sojak', 18),
(9068, 'Lagenandra', NULL, 'Dalzell', 12),
(9069, 'Lagenantha', NULL, 'Chiov.', 5),
(9070, 'Lagenanthus', NULL, 'Gilg', 75),
(9071, 'Lagenaria', NULL, 'Ser.', 49),
(9072, 'Lagenia', NULL, 'E.Fourn.', 10),
(9073, 'Lagenias', NULL, 'E.Mey.', 75),
(9074, 'Lagenifera', NULL, 'Cass.(SUO)', 18),
(9075, 'Lagenocarpus', NULL, 'Klotzsch(SUH)', 55),
(9076, 'Lagenophora', NULL, 'Cass.', 18),
(9077, 'Lageropyxis', NULL, 'Miq.', 22),
(9078, 'Lagetta', NULL, 'Juss.', 164),
(9079, 'Laggera', NULL, 'Sch.Bip. ex Benth.', 18),
(9080, 'Lagoa', NULL, 'T.Durand', 10),
(9081, 'Lagochilium', NULL, 'Nees', 1),
(9082, 'Lagochilopsis', NULL, 'Knorring', 90),
(9083, 'Lagochilus', NULL, 'Bunge', 90),
(9084, 'Lagoecia', NULL, 'L.', 9),
(9085, 'Lagonychium', NULL, 'M.Bieb.', 68),
(9086, 'Lagophylla', NULL, 'Nutt.', 18),
(9087, 'Lagopsis', NULL, 'Bunge', 90),
(9088, 'Lagoseris', NULL, 'M.Bieb.', 18),
(9089, 'Lagotis', NULL, 'Gaertn.', 423),
(9090, 'Lagrezia', NULL, 'Moq.', 5),
(9091, 'Lagunaria', NULL, '(DC.) Rchb.', 102),
(9092, 'Lagynias', NULL, 'E.Mey. ex Robyns', 142),
(9093, 'Lahia', NULL, 'Hassk.', 102),
(9094, 'Lalldhwojia', NULL, 'Farille', 9),
(9095, 'Lallemantia', NULL, 'Fisch. & C.A.Mey.', 90),
(9096, 'Lamanonia', NULL, 'Vell.', 50),
(9097, 'Lamarchea', NULL, 'Gaudich.', 116),
(9098, 'Lamarkea', NULL, 'Rchb.(SUO)', 116),
(9099, 'Lambertia', NULL, 'Sm.', 135),
(9100, 'Lambertya', NULL, 'F.Muell.', 66),
(9101, 'Lamechites', NULL, 'Markgr.', 10),
(9102, 'Lamellisepalum', NULL, 'Engl.', 139),
(9103, 'Lamiacanthus', NULL, 'Kuntze', 1),
(9104, 'Lamiastrum', NULL, 'Heist. ex Fabr.', 90),
(9105, 'Lamiodendron', NULL, 'Steenis', 22),
(9106, 'Lamiofrutex', NULL, 'Lauterb.', 106),
(9107, 'Lamiophlomis', NULL, 'Kudo', 90),
(9108, 'Lamium', NULL, 'L.', 90),
(9109, 'Lamourouxia', NULL, 'Kunth', 400),
(9110, 'Lampas', NULL, 'Danser', 98),
(9111, 'Lampayo', NULL, 'Phil.', 173),
(9112, 'Lampocarya', NULL, 'R.Br.', 55),
(9113, 'Lamprachaenium', NULL, 'Benth.', 18),
(9114, 'Lamprocephalus', NULL, 'B.Nord.', 18),
(9115, 'Lamprolobium', NULL, 'Benth.', 68),
(9116, 'Lamprophragma', NULL, 'O.E.Schulz', 197),
(9117, 'Lamprothamnus', NULL, 'Hiern', 142),
(9118, 'Lamyropappus', NULL, 'Knorring & Tamamsch.', 18),
(9119, 'Lamyropsis', NULL, '(Kharadze) Dittrich', 18),
(9120, 'Lancea', NULL, 'Hook.f. & Thomson', 417),
(9121, 'Landersia', NULL, 'Macfad.', 49),
(9122, 'Landia', NULL, 'Comm. ex Juss.', 142),
(9123, 'Landolphia', NULL, 'P.Beauv.', 10),
(9124, 'Landtia', NULL, 'Less.', 18),
(9125, 'Landukia', NULL, 'Planch.', 181),
(9126, 'Laneasagum', NULL, 'Bedd.', 66),
(9127, 'Lanessania', NULL, 'Baill.', 109),
(9128, 'Langebergia', NULL, 'Anderb.', 18),
(9129, 'Langlassea', NULL, 'H.Wolff', 9),
(9130, 'Langsdorfia', NULL, 'Raf.', 154),
(9131, 'Lankesteria', NULL, 'Lindl.', 1),
(9132, 'Lanneoma', NULL, 'Delile', 6),
(9133, 'Lantanopsis', NULL, 'C.Wright', 18),
(9134, 'Lanthorus', NULL, 'C.Presl', 98),
(9135, 'Lanugia', NULL, 'N.E.Br.', 10),
(9136, 'Laphamia', NULL, 'A.Gray', 18),
(9137, 'Lapithea', NULL, 'Griseb.', 75),
(9138, 'Laplacea', NULL, 'Kunth', 162),
(9139, 'Laportea', NULL, 'Gaudich.', 171),
(9140, 'Lappula', NULL, 'Moench', 25),
(9141, 'Lapsana', NULL, 'L.', 18),
(9142, 'Laretia', NULL, 'Gillies & Hook.', 9),
(9143, 'Larix', NULL, 'Mill.', 129),
(9144, 'Larrea', NULL, 'Cav.', 177),
(9145, 'Larsenia', NULL, 'Bremek.', 1),
(9146, 'Lasallea', NULL, 'Greene', 18),
(9147, 'Laseguea', NULL, 'A.DC.', 10),
(9148, 'Laser', NULL, 'P.Gaertn., B.Mey. & Scherb.', 9),
(9149, 'Laserpitium', NULL, 'L.', 9),
(9150, 'Lasia', NULL, 'Lour.', 12),
(9151, 'Lasiadenia', NULL, 'Benth.', 164),
(9152, 'Lasiandra', NULL, 'DC.', 105),
(9153, 'Lasianthaea', NULL, 'DC.', 18),
(9154, 'Lasiarrhenum', NULL, 'I.M.Johnst.', 25),
(9155, 'Lasimorpha', NULL, 'Schott', 12),
(9156, 'Lasiobema', NULL, '(Korth.) Miq.', 68),
(9157, 'Lasiocarpus', NULL, 'Liebm.', 101),
(9158, 'Lasiocaryum', NULL, 'I.M.Johnst.', 25),
(9159, 'Lasiocephalus', NULL, 'Schltdl.', 18),
(9160, 'Lasiochlamys', NULL, 'Pax & K.Hoffm.', 145),
(9161, 'Lasiocladus', NULL, 'Bojer ex Nees', 1),
(9162, 'Lasiococca', NULL, 'Hook.f.', 66),
(9163, 'Lasiocoma', NULL, 'Bolus', 18),
(9164, 'Lasiocorys', NULL, 'Benth.', 90),
(9165, 'Lasiocroton', NULL, 'Griseb.', 66),
(9166, 'Lasiogyne', NULL, 'Klotzsch', 66),
(9167, 'Lasiolaena', NULL, 'R.M.King & H.Rob.', 18),
(9168, 'Lasionema', NULL, 'D.Don', 142),
(9169, 'Lasiopetalum', NULL, 'Sm.', 102),
(9170, 'Lasiopogon', NULL, 'Cass.', 18),
(9171, 'Lasiosiphon', NULL, 'Fresen.', 164),
(9172, 'Lasiospermum', NULL, 'Lag.', 18),
(9173, 'Lasiostelma', NULL, 'Benth.', 10),
(9174, 'Lasiostoma', NULL, 'Benth.', 142),
(9175, 'Lasiostyles', NULL, 'C.Presl', 66),
(9176, 'Lasipana', NULL, 'Raf.', 66),
(9177, 'Lassia', NULL, 'Baill.', 66),
(9178, 'Lastarriaea', NULL, 'J.Remy', 134),
(9179, 'Lasthenia', NULL, 'Cass.', 18),
(9180, 'Latania', NULL, 'Comm. ex Juss.', 15),
(9181, 'Lateropora', NULL, 'A.C.Sm.', 64),
(9182, 'Lathraea', NULL, 'L.', 400),
(9183, 'Lathraeocarpa', NULL, 'Bremek.', 142),
(9184, 'Lathriogyne', NULL, 'Eckl. & Zeyh.', 68),
(9185, 'Lathyris', NULL, 'Trew', 66),
(9186, 'Lathyrus', NULL, 'L.', 68),
(9187, 'Latnax', NULL, 'Miers', 154),
(9188, 'Latouchea', NULL, 'Franch.', 75),
(9189, 'Latrobea', NULL, 'Meisn.', 68),
(9190, 'Latua', NULL, 'Phil.', 154),
(9191, 'Laubertia', NULL, 'A.DC.', 10),
(9192, 'Laugeria', NULL, 'L.(SUO)', 142),
(9193, 'Laumoniera', NULL, 'Noot.', 151),
(9194, 'Launaea', NULL, 'Cass.', 18),
(9195, 'Laurea', NULL, 'Gaudich.', 109),
(9196, 'Laurelia', NULL, 'Juss.', 505),
(9197, 'Laureliopsis', NULL, 'Schodde', 108),
(9198, 'Laurentia', NULL, 'Adans.', 30),
(9199, 'Laureria', NULL, 'Schltdl.', 154),
(9200, 'Lauridia', NULL, 'Eckl. & Zeyh.', 38),
(9201, 'Lauro-Cerasus', NULL, 'Duhamel', 141),
(9202, 'Lauromerrillia', NULL, 'C.K.Allen', 91),
(9203, 'Laurophyllus', NULL, 'Thunb.', 6),
(9204, 'Laurus', NULL, 'L.', 91),
(9205, 'Lautembergia', NULL, 'Baill.', 66),
(9206, 'Lauterbachia', NULL, 'Perkins', 108),
(9207, 'Lavallea', NULL, 'Baill.', 119),
(9208, 'Lavalleopsis', NULL, 'Tiegh.', 119),
(9209, 'Lavana', NULL, 'Raf.', 154),
(9210, 'Lavandula', NULL, 'L.', 90),
(9211, 'Lavatera', NULL, 'L.', 102),
(9212, 'Lavauxia', NULL, 'Spach', 121),
(9213, 'Lavigeria', NULL, 'Pierre', 85),
(9214, 'Lavoisiera', NULL, 'DC.', 105),
(9215, 'Lavoisieria', NULL, 'Spreng.(SUO)', 105),
(9216, 'Lavoixia', NULL, 'H.E.Moore', 15),
(9217, 'Lavradia', NULL, 'Vell. ex Vand.', 118),
(9218, 'Lavrania', NULL, 'Plowes', 10),
(9219, 'Lawrencella', NULL, 'Lindl.', 18),
(9220, 'Lawrencia', NULL, 'Hook.', 102),
(9221, 'Lawsonia', NULL, 'L.', 99),
(9222, 'Layia', NULL, 'Hook. & Arn. ex DC.', 18),
(9223, 'Le-Monniera', NULL, 'Lecomte(SUH)', 148),
(9224, 'Leandriella', NULL, 'Benoist', 1),
(9225, 'Leavenworthia', NULL, 'Torr.', 197),
(9226, 'Lebeckia', NULL, 'Thunb.', 68),
(9227, 'Lebetanthus', NULL, 'Endl.', 64),
(9228, 'Lebetina', NULL, 'Cass.', 18),
(9229, 'Lebidiera', NULL, 'Baill.', 184),
(9230, 'Lebidieropsis', NULL, 'Mull.Arg.', 184),
(9231, 'Lebronnecia', NULL, 'Fosberg', 102),
(9232, 'Lebrunia', NULL, 'Staner', 42),
(9233, 'Lebruniodendron', NULL, 'J.Leonard', 68),
(9234, 'Lecananthus', NULL, 'Jack', 142),
(9235, 'Lecanocarpus', NULL, 'Nees', 5),
(9236, 'Lecanosperma', NULL, 'Rusby', 142),
(9237, 'Lecanthus', NULL, 'Wedd.', 171),
(9238, 'Lecardia', NULL, 'Poiss. ex Guillaumin', 38),
(9239, 'Lecariocalyx', NULL, 'Bremek.', 142),
(9240, 'Lecocarpus', NULL, 'Decne.', 18),
(9241, 'Lecokia', NULL, 'DC.', 9),
(9242, 'Lecontea', NULL, 'A.Rich.', 142),
(9243, 'Lecythopsis', NULL, 'Schrank', 92),
(9244, 'Leda', NULL, 'C.B.Clarke', 1),
(9245, 'Ledebouriella', NULL, 'H.Wolff', 9),
(9246, 'Ledenbergia', NULL, 'Klotzsch ex Moq.', 128),
(9247, 'Ledermannia', NULL, 'Mildbr. & Burret', 102),
(9248, 'Ledothamnus', NULL, 'Meisn.', 64),
(9249, 'Ledum', NULL, 'L.', 64),
(9250, 'Leeuwenbergia', NULL, 'Letouzey & N.Halle', 66),
(9251, 'Lefebvrea', NULL, 'A.Rich.', 9),
(9252, 'Legendrea', NULL, 'Webb & Berthel.', 46),
(9253, 'Legenere', NULL, 'McVaugh', 30),
(9254, 'Legnea', NULL, 'O.F.Cook(SUI)', 15),
(9255, 'Legnephora', NULL, 'Miers', 107),
(9256, 'Legnotis', NULL, 'Sw.', 140),
(9257, 'Legousia', NULL, 'Durande', 30),
(9258, 'Legrandia', NULL, 'Kausel', 116),
(9259, 'Lehmannia', NULL, 'Spreng.', 154),
(9260, 'Lehmanniella', NULL, 'Gilg', 75),
(9261, 'Leianthus', NULL, 'Griseb.', 75),
(9262, 'Leibergia', NULL, 'J.M.Coult. & Rose', 9),
(9263, 'Leibnitzia', NULL, 'Cass.', 18),
(9264, 'Leiboldia', NULL, 'Schltdl. ex Gleason', 18),
(9265, 'Leichardtia', NULL, 'R.Br.', 10),
(9266, 'Leichhardtia', NULL, 'F.Muell.', 184),
(9267, 'Leidesia', NULL, 'Mull.Arg.', 66),
(9268, 'Leiocarpus', NULL, 'Blume', 184),
(9269, 'Leiochilus', NULL, 'Hook.f.', 142),
(9270, 'Leiogyne', NULL, 'K.Schum.', 22),
(9271, 'Leioluma', NULL, 'Baill.', 148),
(9272, 'Leiophaca', NULL, 'Lindau', 1),
(9273, 'Leiophyllum', NULL, '(Pers.) R.Hedw.', 64),
(9274, 'Leioptyx', NULL, 'Pierre ex De Wild.', 106),
(9275, 'Leiopyxis', NULL, 'Miq.', 184),
(9276, 'Leiospermum', NULL, 'D.Don', 50),
(9277, 'Leiospora', NULL, '(C.A.Mey.) A.N.Vassiljeva', 197),
(9278, 'Leiostemon', NULL, 'Raf.', 150),
(9279, 'Leiphaimos', NULL, 'Cham. & Schltdl.', 75),
(9280, 'Leitgebia', NULL, 'Eichler', 118),
(9281, 'Leitneria', NULL, 'Chapm.', 151),
(9282, 'Leloutrea', NULL, 'Gaudich.', 154),
(9283, 'Lelya', NULL, 'Bremek.', 142),
(9284, 'Lembertia', NULL, 'Greene', 18),
(9285, 'Lembocarpus', NULL, 'Leeuwenb.', 76),
(9286, 'Lembotropis', NULL, 'Griseb.', 68),
(9287, 'Lemmonia', NULL, 'A.Gray', 25),
(9288, 'Lemna', NULL, 'L.', 12),
(9289, 'Lemooria', NULL, 'P.S.Short', 18),
(9290, 'Lemphoria', NULL, 'O.E.Schulz', 197),
(9291, 'Lemurodendron', NULL, 'Villiers & Guinet', 68),
(9292, 'Lemurophoenix', NULL, 'J.Dransf.', 15),
(9293, 'Lemuropisum', NULL, 'H.Perrier', 68),
(9294, 'Lemurosicyos', NULL, 'Keraudren', 49),
(9295, 'Lemyrea', NULL, '(A.Chev.) A.Chev. & Beille', 142),
(9296, 'Lenbrassia', NULL, 'G.W.Gillett', 76),
(9297, 'Lendneria', NULL, 'Minod', 150),
(9298, 'Lennoa', NULL, 'Lex.', 25),
(9299, 'Lenophyllum', NULL, 'Rose', 48),
(9300, 'Lens', NULL, 'Mill.', 68),
(9301, 'Leobordea', NULL, 'Delile', 68),
(9302, 'Leocus', NULL, 'A.Chev.', 90),
(9303, 'Leonardendron', NULL, 'Aubrev.', 68),
(9304, 'Leonardoxa', NULL, 'Aubrev.', 68),
(9305, 'Leonocassia', NULL, 'Britton', 68),
(9306, 'Leonohebe', NULL, 'Heads', 150),
(9307, 'Leonotis', NULL, '(Pers.) R.Br.', 90),
(9308, 'Leontia', NULL, 'Rchb.', 66),
(9309, 'Leontodon', NULL, 'L.', 18),
(9310, 'Leontonyx', NULL, 'Cass.', 18),
(9311, 'Leontopodium', NULL, '(Pers.) R.Br. ex Cass.', 18),
(9312, 'Leonuroides', NULL, 'Rauschert(SUS)', 90),
(9313, 'Leonurus', NULL, 'L.', 90),
(9314, 'Leopoldinia', NULL, 'Mart.', 15),
(9315, 'Lepadanthus', NULL, 'Ridl.', 76),
(9316, 'Lepadena', NULL, 'Raf.', 66),
(9317, 'Lepechinia', NULL, 'Willd.', 90),
(9318, 'Lepechiniella', NULL, 'Popov', 25),
(9319, 'Lepeostegeres', NULL, 'Blume', 98),
(9320, 'Lepiaglaia', NULL, 'Pierre', 106),
(9321, 'Lepianthes', NULL, 'Raf.', 130),
(9322, 'Lepicochlea', NULL, 'Rojas Acosta', 197),
(9323, 'Lepidacanthus', NULL, 'C.Presl', 1),
(9324, 'Lepidagathis', NULL, 'Willd.', 1),
(9325, 'Lepidanthemum', NULL, 'Klotzsch', 105),
(9326, 'Lepidaploa', NULL, '(Cass.) Cass.', 18),
(9327, 'Lepidaria', NULL, 'Tiegh.', 98),
(9328, 'Lepidella', NULL, 'Tiegh.', 98),
(9329, 'Lepiderema', NULL, 'Radlk.', 147),
(9330, 'Lepidesmia', NULL, 'Klatt', 18),
(9331, 'Lepidium', NULL, 'L.', 197),
(9332, 'Lepidocarpa', NULL, 'Korth.', 40),
(9333, 'Lepidocaryum', NULL, 'Mart.', 15),
(9334, 'Lepidoceras', NULL, 'Hook.f.', 63),
(9335, 'Lepidococcus', NULL, 'H.Wendl. & Drude', 15),
(9336, 'Lepidococea', NULL, 'Turcz.', 66),
(9337, 'Lepidocordia', NULL, 'Ducke', 25),
(9338, 'Lepidolopha', NULL, 'C.Winkl.', 18),
(9339, 'Lepidolopsis', NULL, 'Poljakov', 18),
(9340, 'Lepidonia', NULL, 'S.F.Blake', 18),
(9341, 'Lepidopelma', NULL, 'Klotzsch', 28),
(9342, 'Lepidopetalum', NULL, 'Blume', 147),
(9343, 'Lepidophorum', NULL, 'Neck. ex DC.', 18),
(9344, 'Lepidophyllum', NULL, 'Cass.', 18),
(9345, 'Lepidorrhachis', NULL, '(H.Wendl. & Drude) O.F.Cook', 15),
(9346, 'Lepidospartum', NULL, '(A.Gray) A.Gray', 18),
(9347, 'Lepidosperma', NULL, 'Labill.', 55),
(9348, 'Lepidostachys', NULL, 'Wall.', 184),
(9349, 'Lepidostemon', NULL, 'Hook.f. & Thomson', 197),
(9350, 'Lepidostephium', NULL, 'Oliv.', 18),
(9351, 'Lepidostoma', NULL, 'Bremek.', 142),
(9352, 'Lepidothamnus', NULL, 'Phil.', 132),
(9353, 'Lepidotrichilia', NULL, '(Harms) J.-F.Leroy', 106),
(9354, 'Lepidotrichum', NULL, 'Velen. & Bornm.', 197),
(9355, 'Lepidoturus', NULL, 'Baill.', 66),
(9356, 'Lepinia', NULL, 'Decne.', 10),
(9357, 'Lepiniopsis', NULL, 'Valeton', 10),
(9358, 'Lepionurus', NULL, 'Blume', 122),
(9359, 'Lepipogon', NULL, 'G.Bertol.', 142),
(9360, 'Lepironia', NULL, 'Rich.', 55),
(9361, 'Lepistemon', NULL, 'Blume', 46),
(9362, 'Lepistemonopsis', NULL, 'Dammer', 46),
(9363, 'Lepistoma', NULL, 'Blume', 10),
(9364, 'Leplaea', NULL, 'Vermoesen', 106),
(9365, 'Leposma', NULL, 'Blume', 10),
(9366, 'Leptacanthus', NULL, 'Nees', 1),
(9367, 'Leptactina', NULL, 'Hook.f.', 142),
(9368, 'Leptadenia', NULL, 'R.Br.', 10),
(9369, 'Leptaleum', NULL, 'DC.', 197),
(9370, 'Leptalix', NULL, 'Raf.', 120),
(9371, 'Leptandra', NULL, 'Nutt.', 150),
(9372, 'Leptanthe', NULL, 'Klotzsch', 25),
(9373, 'Leptarrhena', NULL, 'R.Br.', 149),
(9374, 'Leptaxis', NULL, 'Raf.', 149),
(9375, 'Lepteiris', NULL, 'Raf.', 150),
(9376, 'Leptemon', NULL, 'Raf.', 66),
(9377, 'Lepterica', NULL, 'N.E.Br.', 64),
(9378, 'Leptinella', NULL, 'Cass.', 18),
(9379, 'Leptoboea', NULL, 'Benth.', 76),
(9380, 'Leptobotrys', NULL, 'Baill.', 66),
(9381, 'Leptocarpha', NULL, 'DC.', 18),
(9382, 'Leptocaulis', NULL, 'Nutt. ex DC.', 9),
(9383, 'Leptocladus', NULL, 'Oliv.', 97),
(9384, 'Leptoclinium', NULL, '(Nutt.) Benth.', 18),
(9385, 'Leptocodon', NULL, '(Hook.f.) Lem.', 30),
(9386, 'Leptodermis', NULL, 'Wall.', 142),
(9387, 'Leptoderris', NULL, 'Dunn', 68),
(9388, 'Leptodesmia', NULL, '(Benth.) Benth.', 68),
(9389, 'Leptofeddea', NULL, 'Diels', 154),
(9390, 'Leptoglossis', NULL, 'Benth.', 154),
(9391, 'Leptoglottis', NULL, 'DC.', 68),
(9392, 'Leptogonum', NULL, 'Benth.', 134),
(9393, 'Leptomeria', NULL, 'R.Br.', 146),
(9394, 'Leptomischus', NULL, 'Drake', 142),
(9395, 'Leptomyrtus', NULL, 'Miq. ex O.Berg', 116),
(9396, 'Leptonema', NULL, 'A.Juss.', 184),
(9397, 'Leptonium', NULL, 'Griff.', 122),
(9398, 'Leptonychiopsis', NULL, 'Ridl.', 102),
(9399, 'Leptopaetia', NULL, 'Harv.', 10),
(9400, 'Leptopetalum', NULL, 'Hook. & Arn.', 142),
(9401, 'Leptopharyngia', NULL, '(Stapf) Boiteau', 10),
(9402, 'Leptopharynx', NULL, 'Rydb.', 18),
(9403, 'Leptophoenix', NULL, 'Becc.', 15),
(9404, 'Leptophragma', NULL, 'Benth. ex Dunal', 154),
(9405, 'Leptoplax', NULL, 'O.E.Schulz', 197),
(9406, 'Leptopus', NULL, 'Klotzsch & Garcke(SUH)', 184),
(9407, 'Leptorhabdos', NULL, 'Schrenk', 400),
(9408, 'Leptorhachis', NULL, 'Klotzsch', 66),
(9409, 'Leptorhynchos', NULL, 'Less.', 18),
(9410, 'Leptoscela', NULL, 'Hook.f.', 142),
(9411, 'Leptosema', NULL, 'Benth.', 68),
(9412, 'Leptosiphonium', NULL, 'F.Muell.', 1),
(9413, 'Leptospermopsis', NULL, 'S.Moore', 116),
(9414, 'Leptospermum', NULL, 'J.R.Forst. & G.Forst.', 116),
(9415, 'Leptostachya', NULL, 'Nees', 1),
(9416, 'Leptostigma', NULL, 'Arn.', 142),
(9417, 'Leptostylis', NULL, 'Benth.', 148),
(9418, 'Leptotaenia', NULL, 'Nutt.', 9),
(9419, 'Leptoterantha', NULL, 'Louis ex Troupin', 107),
(9420, 'Leptothyrsa', NULL, 'Hook.f.', 143),
(9421, 'Leptotriche', NULL, 'Turcz.', 18),
(9422, 'Leptunis', NULL, 'Steven', 142),
(9423, 'Lepurandra', NULL, 'Graham', 109),
(9424, 'Lerchea', NULL, 'L.', 142),
(9425, 'Lerchia', NULL, 'Zinn', 5),
(9426, 'Lereschia', NULL, 'Boiss.', 9),
(9427, 'Leretia', NULL, 'Vell.', 85),
(9428, 'Leroya', NULL, 'Cavaco', 142),
(9429, 'Leroyia', NULL, 'Cavaco(SUO)', 142),
(9430, 'Lescaillea', NULL, 'Griseb.', 18),
(9431, 'Lespedeza', NULL, 'Michx.', 68),
(9432, 'Lesquerella', NULL, 'S.Watson', 197),
(9433, 'Lesquereuxia', NULL, 'Boiss. & Reut.', 150),
(9434, 'Lessertia', NULL, 'DC.', 68),
(9435, 'Lessingia', NULL, 'Cham.', 18),
(9436, 'Lessingianthus', NULL, 'H.Rob.', 18),
(9437, 'Letestua', NULL, 'Lecomte', 148),
(9438, 'Letestudoxa', NULL, 'Pellegr.', 8),
(9439, 'Lethedon', NULL, 'Spreng.', 164),
(9440, 'Leto', NULL, 'Phil.', 18),
(9441, 'Lettowianthus', NULL, 'Diels', 8),
(9442, 'Lettsomia', NULL, 'Roxb.', 46),
(9443, 'Leucactinia', NULL, 'Rydb.', 18),
(9444, 'Leucadendron', NULL, 'R.Br.', 135),
(9445, 'Leucadenia', NULL, 'Klotzsch ex Baill.', 66),
(9446, 'Leucaena', NULL, 'Benth.', 68),
(9447, 'Leucampyx', NULL, 'A.Gray ex Benth.', 18),
(9448, 'Leucandra', NULL, 'Klotzsch', 66),
(9449, 'Leucanthea', NULL, 'Scheele', 154),
(9450, 'Leucanthemella', NULL, 'Tzvelev', 18),
(9451, 'Leucanthemopsis', NULL, '(Giroux) Heywood', 18),
(9452, 'Leucanthemum', NULL, 'Mill.', 18),
(9453, 'Leucas', NULL, 'R.Br.', 90),
(9454, 'Leucaster', NULL, 'Choisy', 117),
(9455, 'Leucelene', NULL, 'Greene', 18),
(9456, 'Leuceres', NULL, 'Calest.', 9),
(9457, 'Leucheria', NULL, 'Lag.', 18),
(9458, 'Leuciva', NULL, 'Rydb.', 18),
(9459, 'Leucobarleria', NULL, 'Lindau', 1),
(9460, 'Leucoblepharis', NULL, 'Arn.', 18),
(9461, 'Leucobotrys', NULL, 'Tiegh.', 98),
(9462, 'Leucocalantha', NULL, 'Barb.Rodr.', 22),
(9463, 'Leucocarpus', NULL, 'D.Don', 417),
(9464, 'Leucocasia', NULL, 'Schott', 12),
(9465, 'Leucocodon', NULL, 'Gardner', 142),
(9466, 'Leucocrinum', NULL, 'Nutt. ex A.Gray', 3),
(9467, 'Leucocroton', NULL, 'Griseb.', 66),
(9468, 'Leucocyclus', NULL, 'Boiss.', 18),
(9469, 'Leucogenes', NULL, 'Beauverd', 18),
(9470, 'Leucolophus', NULL, 'Bremek.', 142),
(9471, 'Leucomeris', NULL, 'D.Don', 18),
(9472, 'Leucomphalos', NULL, 'Benth. ex Planch.', 68),
(9473, 'Leuconotis', NULL, 'Jack', 10),
(9474, 'Leucophae', NULL, 'Webb & Berthel.', 90),
(9475, 'Leucopholis', NULL, 'Gardner', 18),
(9476, 'Leucophyllum', NULL, 'Bonpl.', 150),
(9477, 'Leucophysalis', NULL, 'Rydb.', 154),
(9478, 'Leucopogon', NULL, 'R.Br.', 64),
(9479, 'Leucopsis', NULL, '(DC.) Baker', 18),
(9480, 'Leucoptera', NULL, 'B.Nord.', 18),
(9481, 'Leucoraphis', NULL, 'Nees', 1),
(9482, 'Leucosalpa', NULL, 'Scott-Elliot', 150),
(9483, 'Leucosceptrum', NULL, 'Sm.', 90),
(9484, 'Leucosedum', NULL, 'Fourr.', 48),
(9485, 'Leucosidea', NULL, 'Eckl. & Zeyh.', 141),
(9486, 'Leucosmis', NULL, 'Benth.', 164),
(9487, 'Leucospermum', NULL, 'R.Br.', 135),
(9488, 'Leucosphaera', NULL, 'Gilg', 5),
(9489, 'Leucospora', NULL, 'Nutt.', 150),
(9490, 'Leucostegane', NULL, 'Prain', 68),
(9491, 'Leucosyris', NULL, 'Greene', 18),
(9492, 'Leucothoe', NULL, 'D.Don', 64),
(9493, 'Leucoxylon', NULL, 'Raf.', 22),
(9494, 'Leunisia', NULL, 'Phil.', 18),
(9495, 'Leuranthus', NULL, 'Knobl.', 120),
(9496, 'Leurocline', NULL, 'S.Moore', 25),
(9497, 'Leutea', NULL, 'Pimenov', 9),
(9498, 'Leuzea', NULL, 'DC.', 18),
(9499, 'Leveillea', NULL, 'Vaniot', 18),
(9500, 'Levieria', NULL, 'Becc.', 108),
(9501, 'Levisticum', NULL, 'Hill', 9),
(9502, 'Levya', NULL, 'Bureau ex Baill.', 22),
(9503, 'Leycephyllum', NULL, 'Piper', 68),
(9504, 'Leycesteria', NULL, 'Wall.', 33),
(9505, 'Leysera', NULL, 'L.', 18),
(9506, 'Lhotskya', NULL, 'Schauer', 116),
(9507, 'Lhotzkyella', NULL, 'Rauschert', 10),
(9508, 'Liabellum', NULL, 'Rydb.', 18),
(9509, 'Liabum', NULL, 'Adans.', 18),
(9510, 'Liatris', NULL, 'Gaertn. ex Schreb.', 18),
(9511, 'Libanothamnus', NULL, 'Ernst', 18),
(9512, 'Libanotis', NULL, 'Haller ex Zinn', 9),
(9513, 'Liberatia', NULL, 'Rizzini', 1),
(9514, 'Liberbaileya', NULL, 'Furtado', 15),
(9515, 'Libocedrus', NULL, 'Endl.', 51),
(9516, 'Libonia', NULL, 'K.Koch', 1),
(9517, 'Librevillea', NULL, 'Hoyle', 68),
(9518, 'Lichtensteinia', NULL, 'Cham. & Schltdl.', 9),
(9519, 'Licuala', NULL, 'Thunb.', 15),
(9520, 'Lidbeckia', NULL, 'Bergius', 18),
(9521, 'Liebrechtsia', NULL, 'De Wild.', 68),
(9522, 'Lietzia', NULL, 'Regel', 76),
(9523, 'Lifago', NULL, 'Schweinf. & Muschl.', 18),
(9524, 'Ligaria', NULL, 'Tiegh.', 98),
(9525, 'Ligeria', NULL, 'Decne.', 76),
(9526, 'Lightfootia', NULL, 'L''Her.', 30),
(9527, 'Lightia', NULL, 'R.H.Schomb.(SUH)', 67),
(9528, 'Lightiodendron', NULL, 'Rauschert', 67),
(9529, 'Lignariella', NULL, 'Baehni', 197),
(9530, 'Lignieria', NULL, 'A.Chev.', 105),
(9531, 'Lignocarpa', NULL, 'J.W.Dawson', 9),
(9532, 'Ligularia', NULL, 'Cass.', 18),
(9533, 'Ligusticella', NULL, 'J.M.Coult. & Rose', 9),
(9534, 'Ligusticopsis', NULL, 'Leute', 9),
(9535, 'Ligusticum', NULL, 'L.', 9),
(9536, 'Ligustridium', NULL, 'Spach', 120),
(9537, 'Ligustrina', NULL, 'Rupr.', 120),
(9538, 'Ligustrum', NULL, 'L.', 120),
(9539, 'Lilac', NULL, 'Mill.', 120),
(9540, 'Lilaca', NULL, 'Raf.(SUS)', 120),
(9541, 'Lilaeopsis', NULL, 'Greene', 9),
(9542, 'Liliacum', NULL, 'Renault(SUI)', 120),
(9543, 'Lilium', NULL, 'L.', 94),
(9544, 'Lilloa', NULL, 'Speg.', 12);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(9545, 'Limacia', NULL, 'Lour.', 107),
(9546, 'Limaciopsis', NULL, 'Engl.', 107),
(9547, 'Limbarda', NULL, 'Adans.', 18),
(9548, 'Limniboza', NULL, 'R.E.Fr.', 90),
(9549, 'Limnocitrus', NULL, 'Swingle', 143),
(9550, 'Limnophila', NULL, 'R.Br.', 423),
(9551, 'Limnosciadium', NULL, 'Mathias & Constance', 9),
(9552, 'Limnosipanea', NULL, 'Hook.f.', 142),
(9553, 'Limonia', NULL, 'L.', 143),
(9554, 'Limosella', NULL, 'L.', 423),
(9555, 'Linaria', NULL, 'Mill.', 423),
(9556, 'Linariantha', NULL, 'B.L.Burtt & R.M.Sm.', 1),
(9557, 'Lindauea', NULL, 'Rendle', 1),
(9558, 'Lindelofia', NULL, 'Lehm.', 25),
(9559, 'Lindenbergia', NULL, 'Lehm.', 400),
(9560, 'Lindenia', NULL, 'Benth.', 142),
(9561, 'Lindeniopiper', NULL, 'Trel.', 130),
(9562, 'Lindernia', NULL, 'All.', 520),
(9563, 'Lindheimera', NULL, 'A.Gray & Engelm.', 18),
(9564, 'Lindleya', NULL, 'Nees(SUH)', 141),
(9565, 'Lindleyella', NULL, 'Rydb.', 141),
(9566, 'Lindsayomyrtus', NULL, 'B.Hyland & Steenis', 116),
(9567, 'Lingelsheimia', NULL, 'Pax', 538),
(9568, 'Linnaea', NULL, 'L.', 521),
(9569, 'Linnaeobreynia', NULL, 'Hutch.', 32),
(9570, 'Linnaeopsis', NULL, 'Engl.', 76),
(9571, 'Linocalyx', NULL, 'Lindau', 1),
(9572, 'Linodendron', NULL, 'Griseb.', 164),
(9573, 'Linoma', NULL, 'O.F.Cook', 15),
(9574, 'Linospadix', NULL, 'Becc. ex Hook.f.(SUH)', 15),
(9575, 'Linostachys', NULL, 'Klotzsch ex Schltdl.', 66),
(9576, 'Linostoma', NULL, 'Wall. ex Endl.', 164),
(9577, 'Linum', NULL, 'L.', 95),
(9578, 'Liodendron', NULL, 'H.Keng', 66),
(9579, 'Liparena', NULL, 'Poit. ex Leman', 66),
(9580, 'Liparene', NULL, 'Baill.', 66),
(9581, 'Liparia', NULL, 'L.', 68),
(9582, 'Lipocarpha', NULL, 'R.Br.', 55),
(9583, 'Lipochaeta', NULL, 'DC.', 18),
(9584, 'Lipophragma', NULL, 'Schott & Kotschy ex Boiss.', 197),
(9585, 'Lipostoma', NULL, 'D.Don', 142),
(9586, 'Lippaya', NULL, 'Endl.', 142),
(9587, 'Lippia', NULL, 'L.', 173),
(9588, 'Lipskya', NULL, '(Koso-Pol.) Nevski', 9),
(9589, 'Lipskyella', NULL, 'Juz.', 18),
(9590, 'Lirayea', NULL, 'Pierre', 1),
(9591, 'Liriodendron', NULL, 'L.', 100),
(9592, 'Liriosma', NULL, 'Poepp. & Endl.', 119),
(9593, 'Lisaea', NULL, 'Boiss.', 9),
(9594, 'Lisianthius', NULL, 'P.Browne', 75),
(9595, 'Lisianthus', NULL, 'P.Browne(SUO)', 75),
(9596, 'Lissanthe', NULL, 'R.Br.', 64),
(9597, 'Lissocarpa', NULL, 'Benth.', 61),
(9598, 'Lissospermum', NULL, 'Bremek.', 1),
(9599, 'Listeria', NULL, 'Neck. ex Raf.', 142),
(9600, 'Listia', NULL, 'E.Mey.', 68),
(9601, 'Listrobanthes', NULL, 'Bremek.', 1),
(9602, 'Lithobium', NULL, 'Bong.', 105),
(9603, 'Lithocardium', NULL, 'Kuntze', 25),
(9604, 'Lithocarpos', NULL, 'Ant.Targ.Tozz.', 15),
(9605, 'Lithocaulon', NULL, 'Bally', 10),
(9606, 'Lithococca', NULL, 'Small ex Rydb.', 25),
(9607, 'Lithodora', NULL, 'Griseb.', 25),
(9608, 'Lithodraba', NULL, 'Boelcke', 197),
(9609, 'Lithophila', NULL, 'Sw.', 5),
(9610, 'Lithophragma', NULL, '(Nutt.) Torr. & A.Gray', 149),
(9611, 'Lithophytum', NULL, 'Brandegee', 97),
(9612, 'Lithospermum', NULL, 'L.', 25),
(9613, 'Lithoxylon', NULL, 'Endl.', 184),
(9614, 'Lithraea', NULL, 'Miers ex Hook. & Arn.', 6),
(9615, 'Litosanthes', NULL, 'Blume', 142),
(9616, 'Litosiphon', NULL, 'Pierre ex Harms', 106),
(9617, 'Litothamnus', NULL, 'R.M.King & H.Rob.', 18),
(9618, 'Litrisa', NULL, 'Small', 18),
(9619, 'Litwinowia', NULL, 'Woronow', 197),
(9620, 'Livistona', NULL, 'R.Br.', 15),
(9621, 'Llagunoa', NULL, 'Ruiz & Pav.', 147),
(9622, 'Llanosia', NULL, 'Blanco', 162),
(9623, 'Llavea', NULL, 'Liebm.(SUH)', 202),
(9624, 'Llerasia', NULL, 'Triana', 18),
(9625, 'Llewelynia', NULL, 'Pittier', 105),
(9626, 'Lloydia', NULL, 'Salisb. ex Rchb.', 94),
(9627, 'Lobanilia', NULL, 'Radcl.-Sm.', 66),
(9628, 'Lobbia', NULL, 'Planch.', 16),
(9629, 'Lobelia', NULL, 'L.', 30),
(9630, 'Lobia', NULL, 'O.F.Cook(SUI)', 15),
(9631, 'Lobocarpus', NULL, 'Wight & Arn.', 184),
(9632, 'Lobostema', NULL, 'Spreng.', 25),
(9633, 'Lobostemon', NULL, 'Lehm.', 25),
(9634, 'Lobostephanus', NULL, 'N.E.Br.', 10),
(9635, 'Lobularia', NULL, 'Desv.', 197),
(9636, 'Locella', NULL, 'Tiegh.', 98),
(9637, 'Locheria', NULL, 'Regel', 76),
(9638, 'Lochmocydia', NULL, 'Mart. ex DC.', 22),
(9639, 'Lochnera', NULL, 'Endl.', 10),
(9640, 'Loddigesia', NULL, 'Sims', 68),
(9641, 'Lodoicea', NULL, 'Comm. ex DC.', 15),
(9642, 'Loerzingia', NULL, 'Airy Shaw', 66),
(9643, 'Loesenera', NULL, 'Harms', 68),
(9644, 'Loevigia', NULL, 'H.Karst. & Triana', 105),
(9645, 'Loewia', NULL, 'Urb.', 169),
(9646, 'Logania', NULL, 'R.Br.', 97),
(9647, 'Logfia', NULL, 'Cass.', 18),
(9648, 'Loheria', NULL, 'Merr.', 115),
(9649, 'Loiseleuria', NULL, 'Desv.', 64),
(9650, 'Lomanodia', NULL, 'Raf.', 105),
(9651, 'Lomanthes', NULL, 'Raf.', 184),
(9652, 'Lomastelma', NULL, 'Raf.', 116),
(9653, 'Lomatia', NULL, 'R.Br.', 135),
(9654, 'Lomatium', NULL, 'Raf.', 9),
(9655, 'Lomatocarpa', NULL, 'Pimenov', 9),
(9656, 'Lomatogoniopsis', NULL, 'T.N.Ho & S.W.Liu', 75),
(9657, 'Lomatogonium', NULL, 'A.Braun', 75),
(9658, 'Lomatopodium', NULL, 'Fisch. & C.A.Mey.', 9),
(9659, 'Lomatozona', NULL, 'Baker', 18),
(9660, 'Lomoplis', NULL, 'Raf.', 68),
(9661, 'Lonas', NULL, 'Adans.', 18),
(9662, 'Lonchestigma', NULL, 'Dunal', 154),
(9663, 'Lonchomera', NULL, 'Hook.f. & Thomson', 8),
(9664, 'Lonchophaca', NULL, 'Rydb.', 68),
(9665, 'Lonchophora', NULL, 'Durieu', 197),
(9666, 'Londesia', NULL, 'Fisch. & C.A.Mey.', 5),
(9667, 'Longetia', NULL, 'Baill.', 66),
(9668, 'Lonicera', NULL, 'Gaertn.(SUH)', 33),
(9669, 'Loniceroides', NULL, 'Bullock', 10),
(9670, 'Lontarus', NULL, 'Adans.', 15),
(9671, 'Lopezia', NULL, 'Cav.', 121),
(9672, 'Lophalix', NULL, 'Raf.', 76),
(9673, 'Lophanthera', NULL, 'A.Juss.', 101),
(9674, 'Lophanthus', NULL, 'Adans.', 90),
(9675, 'Lophia', NULL, 'Desv.(SUS)', 76),
(9676, 'Lophiocarpus', NULL, 'Turcz.', 128),
(9677, 'Lophobios', NULL, 'Raf.', 66),
(9678, 'Lophocarpinia', NULL, 'Burkart', 68),
(9679, 'Lophocarpus', NULL, 'Boeck.', 55),
(9680, 'Lopholaena', NULL, 'DC.', 18),
(9681, 'Lophomyrtus', NULL, 'Burret', 116),
(9682, 'Lophopappus', NULL, 'Rusby', 18),
(9683, 'Lophopterys', NULL, 'A.Juss.', 101),
(9684, 'Lophoschoenus', NULL, 'Stapf', 55),
(9685, 'Lophosciadium', NULL, 'DC.', 9),
(9686, 'Lophospatha', NULL, 'Burret', 15),
(9687, 'Lophospermum', NULL, 'D.Don', 423),
(9688, 'Lophostachys', NULL, 'Pohl', 1),
(9689, 'Lophostemon', NULL, 'Schott', 116),
(9690, 'Lophostigma', NULL, 'Radlk.', 147),
(9691, 'Lophostoma', NULL, '(Meisn.) Meisn.', 164),
(9692, 'Lophothecium', NULL, 'Rizzini', 1),
(9693, 'Lophothele', NULL, 'O.F.Cook(SUI)', 15),
(9694, 'Lopriorea', NULL, 'Schinz', 5),
(9695, 'Loranthus', NULL, 'Jacq.', 98),
(9696, 'Lordhowea', NULL, 'B.Nord.', 18),
(9697, 'Lorentzianthus', NULL, 'R.M.King & H.Rob.', 18),
(9698, 'Loretoa', NULL, 'Standl.', 142),
(9699, 'Loricalepis', NULL, 'Brade', 105),
(9700, 'Loricaria', NULL, 'Wedd.', 18),
(9701, 'Loroma', NULL, 'O.F.Cook', 15),
(9702, 'Lorostelma', NULL, 'E.Fourn.', 10),
(9703, 'Lorostemon', NULL, 'Ducke', 42),
(9704, 'Lortia', NULL, 'Rendle', 66),
(9705, 'Lotononis', NULL, '(DC.) Eckl. & Zeyh.', 68),
(9706, 'Lotoxalis', NULL, 'Small', 124),
(9707, 'Lotus', NULL, 'L.', 68),
(9708, 'Lourea', NULL, 'Desv.', 68),
(9709, 'Loureira', NULL, 'Cav.', 66),
(9710, 'Lourteigia', NULL, 'R.M.King & H.Rob.', 18),
(9711, 'Lourtella', NULL, 'S.A.Graham, Baas & Tobe', 99),
(9712, 'Louteridium', NULL, 'S.Watson', 1),
(9713, 'Louvelia', NULL, 'Jum. & H.Perrier', 15),
(9714, 'Lovanafia', NULL, 'M.Peltier', 68),
(9715, 'Loxania', NULL, 'Tiegh.', 98),
(9716, 'Loxanthera', NULL, '(Blume) Blume', 98),
(9717, 'Loxidium', NULL, 'Vent.', 68),
(9718, 'Loxocalyx', NULL, 'Hemsl.', 90),
(9719, 'Loxocarpus', NULL, 'R.Br.', 76),
(9720, 'Loxococcus', NULL, 'H.Wendl. & Drude', 15),
(9721, 'Loxodiscus', NULL, 'Hook.f.', 147),
(9722, 'Loxonia', NULL, 'Jack', 76),
(9723, 'Loxophyllum', NULL, 'Blume', 76),
(9724, 'Loxoptera', NULL, 'O.E.Schulz', 197),
(9725, 'Loxopterygium', NULL, 'Hook.f.', 6),
(9726, 'Loxostemon', NULL, 'Hook.f. & Thomson', 197),
(9727, 'Loxostigma', NULL, 'C.B.Clarke', 76),
(9728, 'Loxostylis', NULL, 'A.Spreng. ex Rchb.', 6),
(9729, 'Loxothysanus', NULL, 'B.L.Rob.', 18),
(9730, 'Loxotis', NULL, '(R.Br.) Benth.', 76),
(9731, 'Lozanella', NULL, 'Greenm.', 170),
(9732, 'Lubaria', NULL, 'Pittier', 143),
(9733, 'Lucilia', NULL, 'Cass.', 18),
(9734, 'Luciliocline', NULL, 'Anderb. & Freire', 18),
(9735, 'Luciliopsis', NULL, 'Wedd.', 18),
(9736, 'Lucinaea', NULL, 'DC.', 142),
(9737, 'Luckhoffia', NULL, 'A.C.White & B.Sloane', 10),
(9738, 'Luculia', NULL, 'Sweet', 142),
(9739, 'Lucuma', NULL, 'Molina', 148),
(9740, 'Lucya', NULL, 'DC.', 142),
(9741, 'Ludekia', NULL, 'Ridsdale', 142),
(9742, 'Ludia', NULL, 'Comm. ex Juss.', 145),
(9743, 'Ludovia', NULL, 'Brongn.', 54),
(9744, 'Ludwigia', NULL, 'L.', 121),
(9745, 'Ludwigiantha', NULL, '(Torr. & A.Gray) Small', 121),
(9746, 'Lueheopsis', NULL, 'Burret', 102),
(9747, 'Luerssenidendron', NULL, 'Domin', 143),
(9748, 'Luetkea', NULL, 'Bong.', 141),
(9749, 'Luetzelburgia', NULL, 'Harms', 68),
(9750, 'Luffa', NULL, 'Mill.', 49),
(9751, 'Lugoa', NULL, 'DC.', 18),
(9752, 'Lugonia', NULL, 'Wedd.', 10),
(9753, 'Luina', NULL, 'Benth.', 18),
(9754, 'Lulia', NULL, 'Zardini', 18),
(9755, 'Luma', NULL, 'A.Gray', 116),
(9756, 'Lumanaja', NULL, 'Blanco', 66),
(9757, 'Lumnitzera', NULL, 'Willd.', 44),
(9758, 'Lunaria', NULL, 'L.', 197),
(9759, 'Lunasia', NULL, 'Blanco', 143),
(9760, 'Lundellia', NULL, 'Leonard', 1),
(9761, 'Lundellianthus', NULL, 'H.Rob.', 18),
(9762, 'Lundia', NULL, 'DC.', 22),
(9763, 'Lunellia', NULL, 'Nieuwl.', 150),
(9764, 'Luntia', NULL, 'Neck. ex Raf.', 66),
(9765, 'Lupinophyllum', NULL, 'Hutch.', 68),
(9766, 'Lupinus', NULL, 'L.', 68),
(9767, 'Lupulina', NULL, 'Noulet', 68),
(9768, 'Lustrinia', NULL, 'Raf.', 1),
(9769, 'Lutzia', NULL, 'Gand.', 197),
(9770, 'Luvunga', NULL, 'Buch.-Ham. ex Wight & Arn.', 143),
(9771, 'Luxemburgia', NULL, 'A.St.-Hil.', 118),
(9772, 'Luzonia', NULL, 'Elmer', 68),
(9773, 'Lyauteya', NULL, 'Maire', 68),
(9774, 'Lycapsus', NULL, 'Phil.', 18),
(9775, 'Lychniothyrsus', NULL, 'Lindau', 1),
(9776, 'Lychnophora', NULL, 'Mart.', 18),
(9777, 'Lychnophoriopsis', NULL, 'Sch.Bip.', 18),
(9778, 'Lyciodes', NULL, 'Kuntze', 148),
(9779, 'Lyciopsis', NULL, '(Boiss.) Schweinf.(SUH)', 66),
(9780, 'Lycioserissa', NULL, 'Roem. & Schult.', 142),
(9781, 'Lycium', NULL, 'L.', 154),
(9782, 'Lycocarpus', NULL, 'O.E.Schulz', 197),
(9783, 'Lycomela', NULL, 'Fabr.', 154),
(9784, 'Lycopersicon', NULL, 'Mill.', 154),
(9785, 'Lycopsis', NULL, 'L.', 25),
(9786, 'Lycopus', NULL, 'L.', 90),
(9787, 'Lycoseris', NULL, 'Cass.', 18),
(9788, 'Lydenburgia', NULL, 'N.Robson', 38),
(9789, 'Lygia', NULL, 'Fasano', 164),
(9790, 'Lygisma', NULL, 'Hook.f.', 10),
(9791, 'Lygistrum', NULL, 'P.Browne', 142),
(9792, 'Lygodesmia', NULL, 'D.Don', 18),
(9793, 'Lygodisodea', NULL, 'Ruiz & Pav.', 142),
(9794, 'Lygos', NULL, 'Adans.', 68),
(9795, 'Lyncea', NULL, 'Cham. & Schltdl.', 150),
(9796, 'Lyonia', NULL, 'Nutt.', 64),
(9797, 'Lyonothamnus', NULL, 'A.Gray', 141),
(9798, 'Lyonsia', NULL, 'R.Br.', 10),
(9799, 'Lyperia', NULL, 'Benth.', 150),
(9800, 'Lyrocarpa', NULL, 'Hook. & Harv.', 197),
(9801, 'Lysiana', NULL, 'Tiegh.', 98),
(9802, 'Lysicarpus', NULL, 'F.Muell.', 116),
(9803, 'Lysichiton', NULL, 'Schott', 12),
(9804, 'Lysiclesia', NULL, 'A.C.Sm.', 64),
(9805, 'Lysidice', NULL, 'Hance', 68),
(9806, 'Lysiloma', NULL, 'Benth.', 68),
(9807, 'Lysimachia', NULL, 'L.', 115),
(9808, 'Lysinema', NULL, 'R.Br.', 64),
(9809, 'Lysionotus', NULL, 'D.Don', 76),
(9810, 'Lysiosepalum', NULL, 'F.Muell.', 102),
(9811, 'Lysiostyles', NULL, 'Benth.', 46),
(9812, 'Lysiphyllum', NULL, '(Benth.) de Wit', 68),
(9813, 'Lysipomia', NULL, 'Kunth', 30),
(9814, 'Lythrum', NULL, 'L.', 99),
(9815, 'Lytocaryum', NULL, 'Toledo', 15),
(9816, 'Maackia', NULL, 'Rupr.', 68),
(9817, 'Maba', NULL, 'J.R.Forst. & G.Forst.', 61),
(9818, 'Mabola', NULL, 'Raf.', 61),
(9819, 'Maborea', NULL, 'Aubl.', 184),
(9820, 'Mabrya', NULL, 'Elisens', 423),
(9821, 'Macadamia', NULL, 'F.Muell.', 135),
(9822, 'Macairea', NULL, 'DC.', 105),
(9823, 'Macania', NULL, 'Blanco', 8),
(9824, 'Macarisia', NULL, 'Thouars', 140),
(9825, 'Macbridea', NULL, 'Elliott ex Nutt.', 90),
(9826, 'Macbrideina', NULL, 'Standl.', 142),
(9827, 'Maccoya', NULL, 'F.Muell.', 25),
(9828, 'Macdougalia', NULL, 'A.Heller', 18),
(9829, 'Macfadyena', NULL, 'A.DC.', 22),
(9830, 'Macgregoria', NULL, 'F.Muell.', 38),
(9831, 'Macgregorianthus', NULL, 'Merr.', 164),
(9832, 'Machadoa', NULL, 'Welw. ex Hook.f.', 127),
(9833, 'Machaeranthera', NULL, 'Nees', 18),
(9834, 'Machaerina', NULL, 'Vahl', 55),
(9835, 'Machaerophorus', NULL, 'Schltdl.', 197),
(9836, 'Machaonia', NULL, 'Bonpl.', 142),
(9837, 'Mackaya', NULL, 'Harv.', 1),
(9838, 'Mackeea', NULL, 'H.E.Moore', 15),
(9839, 'Mackenziea', NULL, 'Nees', 1),
(9840, 'Mackinlaya', NULL, 'F.Muell.', 9),
(9841, 'Macklottia', NULL, 'Korth.', 116),
(9842, 'Macleania', NULL, 'Hook.', 64),
(9843, 'Macleaya', NULL, 'R.Br.', 126),
(9844, 'Macowania', NULL, 'Oliv.', 18),
(9845, 'Macphersonia', NULL, 'Blume', 147),
(9846, 'Macrachaenium', NULL, 'Hook.f.', 18),
(9847, 'Macraea', NULL, 'Hook.f.', 18),
(9848, 'Macrandria', NULL, 'Meisn.', 142),
(9849, 'Macranthera', NULL, 'Nutt. ex Benth.', 400),
(9850, 'Macranthisiphon', NULL, 'Bureau ex K.Schum.', 22),
(9851, 'Macroberlinia', NULL, '(Harms) Hauman', 68),
(9852, 'Macrobia', NULL, '(Webb & Berthel.) G.Kunkel', 48),
(9853, 'Macrocalyx', NULL, 'Tiegh.', 98),
(9854, 'Macrocarpium', NULL, '(Spach) Nakai', 47),
(9855, 'Macrocatalpa', NULL, '(Griseb.) Britton', 22),
(9856, 'Macrocentrum', NULL, 'Hook.f.', 105),
(9857, 'Macrochaetium', NULL, 'Steud.', 55),
(9858, 'Macrochiton', NULL, 'M.Roem.', 106),
(9859, 'Macrochlaena', NULL, 'Hand.-Mazz.', 9),
(9860, 'Macrochlamys', NULL, 'Decne.', 76),
(9861, 'Macrocladus', NULL, 'Griff.', 15),
(9862, 'Macroclinidium', NULL, 'Maxim.', 18),
(9863, 'Macrococculus', NULL, 'Becc.', 107),
(9864, 'Macrocroton', NULL, 'Klotzsch', 66),
(9865, 'Macrodiscus', NULL, 'Bureau', 22),
(9866, 'Macroditassa', NULL, 'Malme', 10),
(9867, 'Macrohasseltia', NULL, 'L.O.Williams', 145),
(9868, 'Macrolenes', NULL, 'Naudin', 105),
(9869, 'Macromeria', NULL, 'D.Don', 25),
(9870, 'Macromyrtus', NULL, 'Miq.', 116),
(9871, 'Macronema', NULL, 'Nutt.', 18),
(9872, 'Macropanax', NULL, 'Miq.', 13),
(9873, 'Macropeplus', NULL, 'Perkins', 108),
(9874, 'Macropetalum', NULL, 'Burch. ex Decne.', 10),
(9875, 'Macropharynx', NULL, 'Rusby', 10),
(9876, 'Macrophloga', NULL, 'Becc.', 15),
(9877, 'Macrophthalmia', NULL, 'Gasp.', 109),
(9878, 'Macropiper', NULL, 'Miq.', 130),
(9879, 'Macroplacis', NULL, 'Blume', 105),
(9880, 'Macropodandra', NULL, 'Gilg', 28),
(9881, 'Macropodina', NULL, 'R.M.King & H.Rob.', 18),
(9882, 'Macropodium', NULL, 'R.Br.', 197),
(9883, 'Macropsidium', NULL, 'Blume', 116),
(9884, 'Macropsychanthus', NULL, 'Harms ex K.Schum. & Lauterb.', 68),
(9885, 'Macropteranthes', NULL, 'F.Muell.', 44),
(9886, 'Macroptilium', NULL, '(Benth.) Urb.', 68),
(9887, 'Macrorhamnus', NULL, 'Baill.', 139),
(9888, 'Macrorungia', NULL, 'C.B.Clarke', 1),
(9889, 'Macrosamanea', NULL, 'Britton & Rose', 68),
(9890, 'Macroscepis', NULL, 'Kunth', 10),
(9891, 'Macrosepalum', NULL, 'Regel & Schmalh.', 48),
(9892, 'Macrosiphon', NULL, 'Miq.', 142),
(9893, 'Macrosiphonia', NULL, 'Mull.Arg.', 10),
(9894, 'Macrosolen', NULL, '(Blume) Rchb.', 98),
(9895, 'Macrosphyra', NULL, 'Hook.f.', 142),
(9896, 'Macrostegia', NULL, 'Nees', 90),
(9897, 'Macrostelia', NULL, 'Hochr.', 102),
(9898, 'Macrostemon', NULL, 'Boriss.', 150),
(9899, 'Macrostigmatella', NULL, 'Rauschert(SUS)', 197),
(9900, 'Macrostylis', NULL, 'Bartl. & H.L.Wendl.', 143),
(9901, 'Macrotomia', NULL, 'DC.', 25),
(9902, 'Macrotorus', NULL, 'Perkins', 108),
(9903, 'Macrotropis', NULL, 'DC.', 68),
(9904, 'Macrotyloma', NULL, '(Wight & Arn.) Verdc.', 68),
(9905, 'Macroule', NULL, 'Pierce', 68),
(9906, 'Macrozanonia', NULL, '(Cogn.) Cogn.', 49),
(9907, 'Macuillamia', NULL, 'Raf.', 150),
(9908, 'Macvaughiella', NULL, 'R.M.King & H.Rob.', 18),
(9909, 'Madarosperma', NULL, 'Benth.', 10),
(9910, 'Maddenia', NULL, 'Hook.f. & Thomson', 141),
(9911, 'Madia', NULL, 'Molina', 18),
(9912, 'Madronella', NULL, 'Mill.', 90),
(9913, 'Maerua', NULL, 'Forssk.', 32),
(9914, 'Maesoluma', NULL, 'Baill.', 148),
(9915, 'Maeviella', NULL, 'Rossow', 150),
(9916, 'Mafekingia', NULL, 'Baill.', 10),
(9917, 'Mafureira', NULL, 'Bertol.', 106),
(9918, 'Maga', NULL, 'Urb.', 102),
(9919, 'Magadania', NULL, 'Pimenov & Lavrova', 9),
(9920, 'Magdalenaea', NULL, 'Brade', 150),
(9921, 'Magodendron', NULL, 'Vink', 148),
(9922, 'Magonia', NULL, 'A.St.-Hil.', 147),
(9923, 'Maguirea', NULL, 'A.D.Hawkes', 12),
(9924, 'Maguireanthus', NULL, 'Wurdack', 105),
(9925, 'Maguireocharis', NULL, 'Steyerm.', 142),
(9926, 'Maguireothamnus', NULL, 'Steyerm.', 142),
(9927, 'Magydaris', NULL, 'W.D.J.Koch ex DC.', 9),
(9928, 'Mahafalia', NULL, 'Jum. & H.Perrier', 10),
(9929, 'Mahagoni', NULL, 'Adans.', 106),
(9930, 'Maharanga', NULL, 'A.DC.', 25),
(9931, 'Mahea', NULL, 'Pierre', 148),
(9932, 'Mahernia', NULL, 'L.', 102),
(9933, 'Mahurea', NULL, 'Aubl.', 42),
(9934, 'Mahya', NULL, 'Cordem.', 90),
(9935, 'Maieta', NULL, 'Aubl.', 105),
(9936, 'Maillardia', NULL, 'Frapp. & Duch.', 109),
(9937, 'Maireana', NULL, 'Moq.', 5),
(9938, 'Mairetis', NULL, 'I.M.Johnst.', 25),
(9939, 'Mairia', NULL, 'Nees', 18),
(9940, 'Majepea', NULL, 'Post & Kuntze(SUS)', 120),
(9941, 'Majorana', NULL, 'Mill.', 90),
(9942, 'Malabaila', NULL, 'Hoffm.', 9),
(9943, 'Malabathris', NULL, 'Raf.', 105),
(9944, 'Malacantha', NULL, 'Pierre', 148),
(9945, 'Malache', NULL, 'Vogel', 102),
(9946, 'Malachra', NULL, 'L.', 102),
(9947, 'Malacmaea', NULL, 'Griseb.', 101),
(9948, 'Malacocarpus', NULL, 'Fisch. & C.A.Mey.', 501),
(9949, 'Malacocera', NULL, 'R.H.Anderson', 5),
(9950, 'Malacomeles', NULL, '(Decne.) Engl.', 141),
(9951, 'Malacothamnus', NULL, 'Greene', 102),
(9952, 'Malacothrix', NULL, 'DC.', 18),
(9953, 'Malagasia', NULL, 'L.A.S.Johnson & B.G.Briggs', 135),
(9954, 'Malaisia', NULL, 'Blanco', 109),
(9955, 'Malanea', NULL, 'Aubl.', 142),
(9956, 'Malania', NULL, 'Chun & S.K.Lee', 119),
(9957, 'Malanthos', NULL, 'Stapf', 105),
(9958, 'Malcolmia', NULL, 'R.Br.', 197),
(9959, 'Malea', NULL, 'Lundell', 64),
(9960, 'Malidra', NULL, 'Raf.', 116),
(9961, 'Malinvaudia', NULL, 'E.Fourn.', 10),
(9962, 'Mallea', NULL, 'A.Juss.', 106),
(9963, 'Malleastrum', NULL, '(Baill.) J.-F.Leroy', 106),
(9964, 'Malleostemon', NULL, 'J.W.Green', 116),
(9965, 'Mallophora', NULL, 'Endl.', 90),
(9966, 'Mallophyton', NULL, 'Wurdack', 105),
(9967, 'Mallostoma', NULL, 'H.Karst.', 142),
(9968, 'Mallotonia', NULL, '(Griseb.) Britton', 25),
(9969, 'Mallotopus', NULL, 'Franch. & Sav.', 18),
(9970, 'Malmeanthus', NULL, 'R.M.King & H.Rob.', 18),
(9971, 'Malope', NULL, 'L.', 102),
(9972, 'Malortiea', NULL, 'H.Wendl.', 15),
(9973, 'Malosma', NULL, '(Nutt.) Raf.', 6),
(9974, 'Malouetiella', NULL, 'Pichon', 10),
(9975, 'Maloutchia', NULL, 'Warb.', 114),
(9976, 'Malperia', NULL, 'S.Watson', 18),
(9977, 'Malpighiodes', NULL, 'Nied.', 101),
(9978, 'Malus', NULL, 'Mill.', 141),
(9979, 'Malva', NULL, 'L.', 102),
(9980, 'Malvastrum', NULL, 'A.Gray', 102),
(9981, 'Malvaviscus', NULL, 'Fabr.', 102),
(9982, 'Malvella', NULL, 'Jaub. & Spach', 102),
(9983, 'Malveopsis', NULL, 'C.Presl', 102),
(9984, 'Mamboga', NULL, 'Blanco', 142),
(9985, 'Mananthes', NULL, 'Bremek.', 1),
(9986, 'Manaosella', NULL, 'J.C.Gomes', 22),
(9987, 'Mancanilla', NULL, 'Mill.', 66),
(9988, 'Mancinella', NULL, 'Tussac', 66),
(9989, 'Mancoa', NULL, 'Wedd.', 197),
(9990, 'Mandenovia', NULL, 'Alava', 9),
(9991, 'Mandevilla', NULL, 'Lindl.', 10),
(9992, 'Mandioca', NULL, 'Link', 66),
(9993, 'Mandirola', NULL, 'Decne.', 76),
(9994, 'Mandragora', NULL, 'L.', 154),
(9995, 'Manekia', NULL, 'Trel.', 130),
(9996, 'Manettia', NULL, 'Boehm.(SUH)', 142),
(9997, 'Manfreda', NULL, 'Salisb.', 3),
(9998, 'Manganaroa', NULL, 'Speg.', 68),
(9999, 'Unidentified', NULL, 'NULL', 185),
(10000, 'Mangium', NULL, 'Rumph. ex Scop.', 140),
(10001, 'Manglesia', NULL, 'Lindl.', 116),
(10002, 'Manglietia', NULL, 'Blume', 100),
(10003, 'Manglietiastrum', NULL, 'Y.W.Law', 100),
(10004, 'Mangonia', NULL, 'Schott', 12),
(10005, 'Manicaria', NULL, 'Gaertn.', 15),
(10006, 'Manihotoides', NULL, 'D.J.Rogers & Appan', 66),
(10007, 'Manilkariopsis', NULL, '(Gilly) Lundell', 148),
(10008, 'Maniltoa', NULL, 'Scheff.', 68),
(10009, 'Mannagettaea', NULL, 'Harry Sm.', 400),
(10010, 'Mannaphorus', NULL, 'Raf.(SUS)', 120),
(10011, 'Mannia', NULL, 'Hook.f.', 151),
(10012, 'Manniophyton', NULL, 'Mull.Arg.', 66),
(10013, 'Manochlamys', NULL, 'Aellen', 5),
(10014, 'Manoelia', NULL, 'Bowdich', 154),
(10015, 'Manongarivea', NULL, 'Choux', 147),
(10016, 'Manostachya', NULL, 'Bremek.', 142),
(10017, 'Manotes', NULL, 'Sol. ex Planch.', 45),
(10018, 'Mansoa', NULL, 'DC.', 22),
(10019, 'Mansonia', NULL, 'J.R.Drumm. ex Prain', 102),
(10020, 'Mantalania', NULL, 'Capuron ex J.-F.Leroy', 142),
(10021, 'Mantisalca', NULL, 'Cass.', 18),
(10022, 'Manulea', NULL, 'L.', 150),
(10023, 'Manuleopsis', NULL, 'Thell. ex Schinz', 150),
(10024, 'Manungala', NULL, 'Blanco', 151),
(10025, 'Maoutia', NULL, 'Wedd.', 171),
(10026, 'Mapania', NULL, 'Aubl.', 55),
(10027, 'Mapaniopsis', NULL, 'C.B.Clarke', 55),
(10028, 'Mapouria', NULL, 'Aubl.', 142),
(10029, 'Mappa', NULL, 'A.Juss.', 66),
(10030, 'Mappia', NULL, 'Jacq.', 85),
(10031, 'Mappianthus', NULL, 'Hand.-Mazz.', 85),
(10032, 'Maracanthus', NULL, 'Kuijt', 98),
(10033, 'Marah', NULL, 'Kellogg', 49),
(10034, 'Maralia', NULL, 'Thouars', 13),
(10035, 'Maranta', NULL, 'L.', 103),
(10036, 'Marantochloa', NULL, 'Brongn. ex Gris', 103),
(10037, 'Marara', NULL, 'H.Karst.', 15),
(10038, 'Marasmodes', NULL, 'DC.', 18),
(10039, 'Marcania', NULL, 'J.B.Imlay', 1),
(10040, 'Marcellia', NULL, 'Baill.', 5),
(10041, 'Marcelliopsis', NULL, 'Schinz', 5),
(10042, 'Marcetella', NULL, 'Svent.', 141),
(10043, 'Marcetia', NULL, 'DC.', 105),
(10044, 'Marcgravia', NULL, 'L.', 104),
(10045, 'Marcuccia', NULL, 'Becc.', 8),
(10046, 'Marenteria', NULL, 'Thouars', 8),
(10047, 'Maresia', NULL, 'Pomel', 197),
(10048, 'Margaranthus', NULL, 'Schltdl.', 154),
(10049, 'Margaretta', NULL, 'Oliv.', 10),
(10050, 'Margaris', NULL, 'Griseb.(SUI)', 142),
(10051, 'Margaritolobium', NULL, 'Harms', 68),
(10052, 'Margaritopsis', NULL, 'Sauvalle', 142),
(10053, 'Margotia', NULL, 'Boiss.', 9),
(10054, 'Margyricarpus', NULL, 'Ruiz & Pav.', 141),
(10055, 'Marina', NULL, 'Liebm.', 68),
(10056, 'Maripa', NULL, 'Aubl.', 46),
(10057, 'Mariscopsis', NULL, 'Cherm.', 55),
(10058, 'Marisculus', NULL, 'Goetgh.', 55),
(10059, 'Mariscus', NULL, 'Vahl', 55),
(10060, 'Marlierea', NULL, 'Cambess.', 116),
(10061, 'Marlieriopsis', NULL, 'Kiaersk.', 116),
(10062, 'Marlothia', NULL, 'Engl.', 139),
(10063, 'Marlothiella', NULL, 'H.Wolff', 9),
(10064, 'Marmoritis', NULL, 'Benth.', 90),
(10065, 'Marojejya', NULL, 'Humbert', 15),
(10066, 'Marquesia', NULL, 'Gilg', 60),
(10067, 'Marquisia', NULL, 'A.Rich.', 142),
(10068, 'Marrubium', NULL, 'L.', 90),
(10069, 'Marsdenia', NULL, 'R.Br.', 10),
(10070, 'Marshallfieldia', NULL, 'J.F.Macbr.', 105),
(10071, 'Marshallia', NULL, 'Schreb.', 18),
(10072, 'Marshalljohnstonia', NULL, 'Henr.', 18),
(10073, 'Marssonia', NULL, 'H.Karst.', 76),
(10074, 'Marsypianthes', NULL, 'Mart. ex Benth.', 90),
(10075, 'Martha', NULL, 'F.Muell.', 142),
(10076, 'Marticorenia', NULL, 'Crisci', 18),
(10077, 'Martiella', NULL, 'Tiegh.', 98),
(10078, 'Martinella', NULL, 'Baill.', 22),
(10079, 'Martinezia', NULL, 'Ruiz & Pav.', 15),
(10080, 'Martiodendron', NULL, 'Gleason', 68),
(10081, 'Martiusella', NULL, 'Pierre', 148),
(10082, 'Martiusia', NULL, 'Benth.', 68),
(10083, 'Martretia', NULL, 'Beille', 66),
(10084, 'Marumia', NULL, 'Blume', 105),
(10085, 'Mascagnia', NULL, '(Bertero ex DC.) Colla', 101),
(10086, 'Mascarena', NULL, 'L.H.Bailey', 15),
(10087, 'Mascarenhasia', NULL, 'A.DC.', 10),
(10088, 'Maschalanthe', NULL, 'Blume', 142),
(10089, 'Maschalanthus', NULL, 'Nutt.', 184),
(10090, 'Maschalocorymbus', NULL, 'Bremek.', 142),
(10091, 'Maschalodesme', NULL, 'K.Schum. & Lauterb.', 142),
(10092, 'Masmenia', NULL, 'F.K.Mey.', 197),
(10093, 'Masoala', NULL, 'Jum.', 15),
(10094, 'Massartina', NULL, 'Maire', 25),
(10095, 'Massoia', NULL, 'Becc.', 91),
(10096, 'Mastersia', NULL, 'Benth.', 68),
(10097, 'Mastichodendron', NULL, '(Engl.) H.J.Lam', 148),
(10098, 'Mastigosciadium', NULL, 'Rech.f. & Kuber', 9),
(10099, 'Mastixiodendron', NULL, 'Melch.', 142),
(10100, 'Mastosuke', NULL, 'Raf.', 109),
(10101, 'Matelea', NULL, 'Aubl.', 10),
(10102, 'Mathaea', NULL, 'Vell.', 154),
(10103, 'Mathewsia', NULL, 'Hook. & Arn.', 197),
(10104, 'Mathiasella', NULL, 'Constance & C.L.Hitchc.', 9),
(10105, 'Mathiola', NULL, 'R.Br.', 197),
(10106, 'Mathiolaria', NULL, 'Chevall.', 197),
(10107, 'Mathurina', NULL, 'Balf.f.', 169),
(10108, 'Matricaria', NULL, 'L.', 18),
(10109, 'Matsumurella', NULL, 'Makino', 90),
(10110, 'Matsumuria', NULL, 'Hemsl.', 76),
(10111, 'Mattfeldanthus', NULL, 'H.Rob. & R.M.King', 18),
(10112, 'Mattfeldia', NULL, 'Urb.', 18),
(10113, 'Matthiola', NULL, 'L.(SUH)', 197),
(10114, 'Matthissonia', NULL, 'Raddi', 154),
(10115, 'Mattia', NULL, 'Schult.', 25),
(10116, 'Mattiastrum', NULL, '(Boiss.) Brand', 25),
(10117, 'Mattuschkaea', NULL, 'Schreb.', 142),
(10118, 'Mattuschkea', NULL, 'Batsch(SUO)', 142),
(10119, 'Matudina', NULL, 'R.M.King & H.Rob.', 18),
(10120, 'Maurandella', NULL, '(A.Gray) Rothm.', 423),
(10121, 'Maurandya', NULL, 'Ortega', 423),
(10122, 'Mauranthe', NULL, 'O.F.Cook', 15),
(10123, 'Mauria', NULL, 'Kunth', 6),
(10124, 'Mauritia', NULL, 'L.f.', 15),
(10125, 'Mauritiella', NULL, 'Burret', 15),
(10126, 'Maurocenia', NULL, 'Mill.', 38),
(10127, 'Mausolea', NULL, 'Poljakov', 18),
(10128, 'Maxburretia', NULL, 'Furtado', 15),
(10129, 'Maximiliana', NULL, 'Mart.', 15),
(10130, 'Maximoviczia', NULL, 'A.P.Khokhr.(SUH)', 55),
(10131, 'Maximovicziella', NULL, 'A.P.Khokhr.', 55),
(10132, 'Maximowiczia', NULL, 'Cogn.(SUS)', 49),
(10133, 'Maxwellia', NULL, 'Baill.', 102),
(10134, 'Mayanaea', NULL, 'Lundell', 174),
(10135, 'Mayepea', NULL, 'Aubl.', 120),
(10136, 'Mayodendron', NULL, 'Kurz', 22),
(10137, 'Mazaea', NULL, 'Krug & Urb.', 142),
(10138, 'Mazus', NULL, 'Lour.', 417),
(10139, 'Mcvaughia', NULL, 'W.R.Anderson', 101),
(10140, 'Mearnsia', NULL, 'Merr.', 116),
(10141, 'Mecardonia', NULL, 'Ruiz & Pav.', 423),
(10142, 'Mechowia', NULL, 'Schinz', 5),
(10143, 'Meckelia', NULL, '(Mart. ex A.Juss.) Griseb.', 101),
(10144, 'Mecomischus', NULL, 'Coss. ex Benth.', 18),
(10145, 'Meconella', NULL, 'Nutt.', 126),
(10146, 'Meconopsis', NULL, 'R.Vig.', 126),
(10147, 'Mecopus', NULL, 'Benn.', 68),
(10148, 'Mecostylis', NULL, 'Kurz ex Teijsm. & Binn.', 66),
(10149, 'Mecranium', NULL, 'Hook.f.', 105),
(10150, 'Medea', NULL, 'Klotzsch', 66),
(10151, 'Medemia', NULL, 'Wurttemb. ex H.Wendl.', 15),
(10152, 'Mediasia', NULL, 'Pimenov', 9),
(10153, 'Medica', NULL, 'Cothen.', 22),
(10154, 'Medicago', NULL, 'L.', 68),
(10155, 'Medicosma', NULL, 'Hook.f.', 143),
(10156, 'Medinilla', NULL, 'Gaudich.', 105),
(10157, 'Medinillopsis', NULL, 'Cogn.', 105),
(10158, 'Medusandra', NULL, 'Brenan', 193),
(10159, 'Medusea', NULL, 'Haw.', 66),
(10160, 'Meeboldia', NULL, 'H.Wolff', 9),
(10161, 'Meehania', NULL, 'Britton', 90),
(10162, 'Meehaniopsis', NULL, 'Kudo', 90),
(10163, 'Megabaria', NULL, 'Pierre ex Hutch.', 184),
(10164, 'Megacarpaea', NULL, 'DC.', 197),
(10165, 'Megacarpha', NULL, 'Hochst.', 142),
(10166, 'Megacaryon', NULL, 'Boiss.', 25),
(10167, 'Megacodon', NULL, '(Hemsl.) Harry Sm.', 75),
(10168, 'Megadenia', NULL, 'Maxim.', 197),
(10169, 'Megalochlamys', NULL, 'Lindau', 1),
(10170, 'Megalodonta', NULL, 'Greene', 18),
(10171, 'Megalonium', NULL, '(Berger) Kunkel', 48),
(10172, 'Megalopanax', NULL, 'Ekman', 13),
(10173, 'Megalopus', NULL, 'K.Schum.', 142),
(10174, 'Megalostoma', NULL, 'Leonard', 1),
(10175, 'Megalostylis', NULL, 'S.Moore', 66),
(10176, 'Megaphrynium', NULL, 'Milne-Redh.', 103),
(10177, 'Megaphyllaea', NULL, 'Hemsl.', 106),
(10178, 'Megaphyllum', NULL, 'Spruce ex Baill.', 142),
(10179, 'Megapleilis', NULL, 'Raf.', 76),
(10180, 'Megapterium', NULL, 'Spach', 121),
(10181, 'Megarrhena', NULL, 'Schrad. ex Nees', 55),
(10182, 'Megarrhiza', NULL, 'Torr. & A.Gray', 49),
(10183, 'Megasea', NULL, 'Haw.', 149),
(10184, 'Megaskepasma', NULL, 'Lindau', 1),
(10185, 'Megastigma', NULL, 'Hook.f.', 143),
(10186, 'Megastoma', NULL, 'Coss. & Durieu(SUH)', 25),
(10187, 'Megatritheca', NULL, 'Cristobal', 102),
(10188, 'Megistostegium', NULL, 'Hochr.', 102),
(10189, 'Megistostigma', NULL, 'Hook.f.', 66),
(10190, 'Mehraea', NULL, 'A.Love & D.Love', 75),
(10191, 'Meialisa', NULL, 'Raf.', 66),
(10192, 'Meiandra', NULL, 'Markgr.', 105),
(10193, 'Meiena', NULL, 'Raf.', 98),
(10194, 'Meineckia', NULL, 'Baill.', 184),
(10195, 'Meiocarpidium', NULL, 'Engl. & Diels', 8),
(10196, 'Meioluma', NULL, 'Baill.', 148),
(10197, 'Meiomeria', NULL, 'Standl.', 5),
(10198, 'Meionandra', NULL, 'Gauba', 142),
(10199, 'Meiostemon', NULL, 'Exell & Stace', 44),
(10200, 'Meiota', NULL, 'O.F.Cook(SUI)', 15),
(10201, 'Meisneria', NULL, 'DC.', 105),
(10202, 'Melachone', NULL, 'Gilli', 142),
(10203, 'Meladendron', NULL, 'St.-Lag.', 116),
(10204, 'Meladerma', NULL, 'Kerr', 10),
(10205, 'Melaleuca', NULL, 'L.', 116),
(10206, 'Melaleucon', NULL, 'St.-Lag.', 116),
(10207, 'Melampodium', NULL, 'L.', 18),
(10208, 'Melampyrum', NULL, 'L.', 400),
(10209, 'Melananthus', NULL, 'Walp.', 154),
(10210, 'Melancium', NULL, 'Naudin', 49),
(10211, 'Melanea', NULL, 'Pers.(SUO)', 142),
(10212, 'Melanidion', NULL, 'Greene', 197),
(10213, 'Melanium', NULL, 'P.Browne', 99),
(10214, 'Melanocarpum', NULL, 'Hook.f.', 5),
(10215, 'Melanococca', NULL, 'Blume', 6),
(10216, 'Melanocommia', NULL, 'Ridl.', 6),
(10217, 'Melanodendron', NULL, 'DC.', 18),
(10218, 'Melanodiscus', NULL, 'Radlk.', 147),
(10219, 'Melanoleuca', NULL, 'St.-Lag.', 116),
(10220, 'Melanopsidium', NULL, 'Poit. ex DC.(SUH)', 142),
(10221, 'Melanorrhoea', NULL, 'Wall.', 6),
(10222, 'Melanosciadium', NULL, 'Boissieu', 9),
(10223, 'Melanoselinum', NULL, 'Hoffm.', 9),
(10224, 'Melanospermum', NULL, 'Hilliard', 150),
(10225, 'Melanosticta', NULL, 'DC.', 68),
(10226, 'Melanoxylon', NULL, 'Schott', 68),
(10227, 'Melanthera', NULL, 'Rohr', 18),
(10228, 'Melanthes', NULL, 'Blume', 184),
(10229, 'Melanthesa', NULL, 'Blume(SUO)', 184),
(10230, 'Melanthesopsis', NULL, 'Mull.Arg.', 184),
(10231, 'Melasma', NULL, 'Bergius', 400),
(10232, 'Melastomastrum', NULL, 'Naudin', 105),
(10233, 'Melchiora', NULL, 'Kobuski', 162),
(10234, 'Melhania', NULL, 'Forssk.', 102),
(10235, 'Meliandra', NULL, 'Ducke', 105),
(10236, 'Melianthus', NULL, 'L.', 182),
(10237, 'Melichrus', NULL, 'R.Br.', 64),
(10238, 'Melicytus', NULL, 'J.R.Forst. & G.Forst.', 174),
(10239, 'Melilotus', NULL, 'Mill.', 68),
(10240, 'Melinia', NULL, 'Decne.', 10),
(10241, 'Melio-Schinzia', NULL, 'K.Schum.', 106),
(10242, 'Meliopsis', NULL, 'Rchb.', 120),
(10243, 'Melissa', NULL, 'L.', 90),
(10244, 'Melissitus', NULL, 'Medik.', 68),
(10245, 'Melittacanthus', NULL, 'S.Moore', 1),
(10246, 'Melittis', NULL, 'L.', 90),
(10247, 'Mellera', NULL, 'S.Moore', 1),
(10248, 'Mellichampia', NULL, 'A.Gray ex S.Watson', 10),
(10249, 'Melliniella', NULL, 'Harms', 68),
(10250, 'Melliodendron', NULL, 'Hand.-Mazz.', 158),
(10251, 'Mellissia', NULL, 'Hook.f.', 154),
(10252, 'Melloa', NULL, 'Bureau', 22),
(10253, 'Mellouia', NULL, 'Gasp.', 49),
(10254, 'Melo', NULL, 'Mill.', 49),
(10255, 'Melochia', NULL, 'L.', 102),
(10256, 'Melodinus', NULL, 'J.R.Forst. & G.Forst.', 10),
(10257, 'Melodorum', NULL, '(Dunal) Hook.f. & Thomson(SUH)', 8),
(10258, 'Melolobium', NULL, 'Eckl. & Zeyh.', 68),
(10259, 'Melongena', NULL, 'Mill.', 154),
(10260, 'Melopepo', NULL, 'Mill.', 49),
(10261, 'Melosperma', NULL, 'Benth.', 423),
(10262, 'Melothria', NULL, 'L.', 49),
(10263, 'Melothrianthus', NULL, 'Mart.Crov.', 49),
(10264, 'Melvilla', NULL, 'A.Anderson', 99),
(10265, 'Memorialis', NULL, 'Buch.-Ham. ex Wedd.', 171),
(10266, 'Menabea', NULL, 'Baill.', 10),
(10267, 'Menarda', NULL, 'Comm. ex Juss.', 184),
(10268, 'Mendoncia', NULL, 'Vell. ex Vand.', 1),
(10269, 'Mendoravia', NULL, 'Capuron', 68),
(10270, 'Menendezia', NULL, 'Britton', 105),
(10271, 'Menepetalum', NULL, 'Loes.', 38),
(10272, 'Meniocus', NULL, 'Desv.', 197),
(10273, 'Meniscogyne', NULL, 'Gagnep.', 171),
(10274, 'Menispermum', NULL, 'L.', 107),
(10275, 'Menkea', NULL, 'Lehm.', 197),
(10276, 'Menodora', NULL, 'Bonpl.', 120),
(10277, 'Menodoropsis', NULL, '(A.Gray) Small', 120),
(10278, 'Menonvillea', NULL, 'R.Br. ex DC.', 197),
(10279, 'Mentha', NULL, 'L.', 90),
(10280, 'Mentodendron', NULL, 'Lundell', 116),
(10281, 'Menziesia', NULL, 'Sm.', 64),
(10282, 'Mephitidia', NULL, 'Reinw. ex Blume', 142),
(10283, 'Meranthera', NULL, 'Tiegh.', 98),
(10284, 'Mercadoa', NULL, 'Naves', 66),
(10285, 'Merciera', NULL, 'A.DC.', 30),
(10286, 'Mercurialis', NULL, 'L.', 66),
(10287, 'Mercuriastrum', NULL, 'Fabr.', 66),
(10288, 'Meresaldia', NULL, 'Bullock', 10),
(10289, 'Meriana', NULL, 'Vent.(SUO)', 105),
(10290, 'Meriandra', NULL, 'Benth.', 90),
(10291, 'Merianthera', NULL, 'Kuhlm.', 105),
(10292, 'Mericarpaea', NULL, 'Boiss.', 142),
(10293, 'Mericocalyx', NULL, 'Bamps', 142),
(10294, 'Merinogyne', NULL, 'H.Wolff', 9),
(10295, 'Merinthopodium', NULL, 'Donn.Sm.', 154),
(10296, 'Meriolix', NULL, 'Raf. ex Endl.', 121),
(10297, 'Merismia', NULL, 'Tiegh.(SUH)', 98),
(10298, 'Merismostigma', NULL, 'S.Moore', 142),
(10299, 'Meristotropis', NULL, 'Fisch. & C.A.Mey.', 68),
(10300, 'Merleta', NULL, 'Raf.', 66),
(10301, 'Merope', NULL, 'M.Roem.', 143),
(10302, 'Merostela', NULL, 'Pierre', 106),
(10303, 'Merremia', NULL, 'Dennst. ex Endl.', 46),
(10304, 'Merrillanthus', NULL, 'Chun & Tsiang', 10),
(10305, 'Merrillia', NULL, 'Swingle', 143),
(10306, 'Merrilliodendron', NULL, 'Kaneh.', 85),
(10307, 'Merrilliopanax', NULL, 'H.L.Li', 13),
(10308, 'Merrittia', NULL, 'Merr.', 18),
(10309, 'Mertensia', NULL, 'Roth', 25),
(10310, 'Merumea', NULL, 'Steyerm.', 142),
(10311, 'Merwia', NULL, 'B.Fedtsch.', 9),
(10312, 'Meryta', NULL, 'J.R.Forst. & G.Forst.', 13),
(10313, 'Mesandrinia', NULL, 'Raf.', 66),
(10314, 'Mesaulosperma', NULL, 'Slooten', 145),
(10315, 'Mesechites', NULL, 'Mull.Arg.', 10),
(10316, 'Mesogyne', NULL, 'Engl.', 109),
(10317, 'Mesomelaena', NULL, 'Nees', 55),
(10318, 'Mesona', NULL, 'Blume', 90),
(10319, 'Mesopanax', NULL, 'R.Vig.', 13),
(10320, 'Mesoptera', NULL, 'Hook.f.', 142),
(10321, 'Mesoreanthus', NULL, 'Greene', 197),
(10322, 'Mesosphaerum', NULL, 'P.Browne', 90),
(10323, 'Mespilodaphne', NULL, 'Nees', 91),
(10324, 'Mespilus', NULL, 'L.', 141),
(10325, 'Messerschmidia', NULL, 'Hebenstr.(SUO)', 25),
(10326, 'Messersmidia', NULL, 'L.(SUS)', 25),
(10327, 'Metabolos', NULL, 'Blume', 142),
(10328, 'Metabriggsia', NULL, 'W.T.Wang', 76),
(10329, 'Metaeritrichium', NULL, 'W.T.Wang', 25),
(10330, 'Metalasia', NULL, 'R.Br.', 18),
(10331, 'Metalepis', NULL, 'Griseb.', 10),
(10332, 'Metalonicera', NULL, 'M.Wang & A.G.Gu', 33),
(10333, 'Metaplexis', NULL, 'R.Br.', 10),
(10334, 'Metaporana', NULL, 'N.E.Br.', 46),
(10335, 'Metarungia', NULL, 'Baden', 1),
(10336, 'Metasequoia', NULL, 'Miki ex Hu & W.C.Cheng', 51),
(10337, 'Metasocratea', NULL, 'Dugand', 15),
(10338, 'Metastachydium', NULL, 'Airy Shaw ex C.Y.Wu & H.W.Li', 90),
(10339, 'Metastachys', NULL, 'Knorring(SUH)', 90),
(10340, 'Metastelma', NULL, 'R.Br.', 10),
(10341, 'Metastevia', NULL, 'Grashoff', 18),
(10342, 'Meteoromyrtus', NULL, 'Gamble', 116),
(10343, 'Meterana', NULL, 'Raf.', 66),
(10344, 'Meterostachys', NULL, 'Nakai', 48),
(10345, 'Metharme', NULL, 'Phil. ex Engl.', 177),
(10346, 'Methysticodendron', NULL, 'R.E.Schult.', 154),
(10347, 'Metopium', NULL, 'P.Browne', 6),
(10348, 'Metrodorea', NULL, 'A.St.-Hil.', 143),
(10349, 'Metrosideros', NULL, 'Banks ex Gaertn.', 116),
(10350, 'Metroxylon', NULL, 'Rottb.', 15),
(10351, 'Mettenia', NULL, 'Griseb.', 66),
(10352, 'Metteniusa', NULL, 'H.Karst.', 523),
(10353, 'Metternichia', NULL, 'J.C.Mikan', 154),
(10354, 'Metula', NULL, 'Tiegh.', 98),
(10355, 'Meum', NULL, 'Mill.', 9),
(10356, 'Mexacanthus', NULL, 'T.F.Daniel', 1),
(10357, 'Mexerion', NULL, 'G.L.Nesom', 18),
(10358, 'Mexianthus', NULL, 'B.L.Rob.', 18),
(10359, 'Meximalva', NULL, 'Fryxell', 102),
(10360, 'Meyenia', NULL, 'Nees', 1),
(10361, 'Meynia', NULL, 'Schult.(SUO)', 142),
(10362, 'Mezia', NULL, 'Schwacke ex Nied.', 101),
(10363, 'Mezleria', NULL, 'C.Presl', 30),
(10364, 'Mezoneuron', NULL, 'Desf.', 68),
(10365, 'Mezzettiopsis', NULL, 'Ridl.', 8),
(10366, 'Michauxia', NULL, 'L''Her.', 30),
(10367, 'Micheliella', NULL, 'Briq.', 90),
(10368, 'Michelsonia', NULL, 'Hauman', 68),
(10369, 'Micholitzia', NULL, 'N.E.Br.', 10),
(10370, 'Micractis', NULL, 'DC.', 18),
(10371, 'Micraeschynanthus', NULL, 'Ridl.', 76),
(10372, 'Micrampelis', NULL, 'Raf.', 49),
(10373, 'Micrandra', NULL, 'Benn. & R.Br.(SUH)', 66),
(10374, 'Micrandropsis', NULL, 'W.A.Rodrigues', 66),
(10375, 'Micrantha', NULL, 'Dvorak', 197),
(10376, 'Micranthella', NULL, 'Naudin', 105),
(10377, 'Micranthemum', NULL, 'Michx.', 423),
(10378, 'Micrantheum', NULL, 'Desf.', 534),
(10379, 'Micrargeria', NULL, 'Benth.', 400),
(10380, 'Micrargeriella', NULL, 'R.E.Fr.', 150),
(10381, 'Micrasepalum', NULL, 'Urb.', 142),
(10382, 'Micrechites', NULL, 'Miq.', 10),
(10383, 'Microbahia', NULL, 'Cockerell', 18),
(10384, 'Microberlinia', NULL, 'A.Chev.', 68),
(10385, 'Microbignonia', NULL, 'Kraenzl.', 22),
(10386, 'Microbiota', NULL, 'Kom.', 51),
(10387, 'Microblepharis', NULL, '(Wight & Arn.) M.Roem.', 127),
(10388, 'Microcachrys', NULL, 'Hook.f.', 132),
(10389, 'Microcala', NULL, 'Hoffmanns. & Link', 75),
(10390, 'Microcardamum', NULL, 'O.E.Schulz', 197),
(10391, 'Microcarpaea', NULL, 'R.Br.', 423),
(10392, 'Microcaryum', NULL, 'I.M.Johnst.', 25),
(10393, 'Microcasia', NULL, 'Becc.', 12),
(10394, 'Microcephala', NULL, 'Pobed.', 18),
(10395, 'Microcharis', NULL, 'Benth.', 68),
(10396, 'Microchonea', NULL, 'Pierre', 10),
(10397, 'Microcitrus', NULL, 'Swingle', 143),
(10398, 'Microcnemum', NULL, 'Ung.-Sternb.', 5),
(10399, 'Micrococca', NULL, 'Benth.', 66),
(10400, 'Micrococos', NULL, 'Phil.', 15),
(10401, 'Microcodon', NULL, 'A.DC.', 30),
(10402, 'Microcoelum', NULL, 'Burret & Potztal', 15),
(10403, 'Microconomorpha', NULL, '(Mez) Lundell', 115),
(10404, 'Microcorys', NULL, 'R.Br.', 90),
(10405, 'Microculcas', NULL, 'Peter', 12),
(10406, 'Microcybe', NULL, 'Turcz.', 143),
(10407, 'Microdactylon', NULL, 'Brandegee', 10),
(10408, 'Microderis', NULL, 'A.DC.', 18),
(10409, 'Microdon', NULL, 'Choisy', 150),
(10410, 'Microdracoides', NULL, 'Hua', 55),
(10411, 'Microelus', NULL, 'Wight & Arn.', 184),
(10412, 'Microglossa', NULL, 'DC.', 18),
(10413, 'Microgynella', NULL, 'Grau', 18),
(10414, 'Microgynoecium', NULL, 'Hook.f.', 5),
(10415, 'Microjambosa', NULL, 'Blume', 116),
(10416, 'Microkentia', NULL, 'H.Wendl. ex Hook.f.', 15),
(10417, 'Microlecane', NULL, 'Sch.Bip. ex Benth.', 18),
(10418, 'Microlepidium', NULL, 'F.Muell.', 197),
(10419, 'Microlepis', NULL, '(DC.) Miq.', 105),
(10420, 'Microliabum', NULL, 'Cabrera', 18),
(10421, 'Microlicia', NULL, 'D.Don', 105),
(10422, 'Microlobium', NULL, 'Liebm.', 68),
(10423, 'Microloma', NULL, 'R.Br.', 10),
(10424, 'Microlonchoides', NULL, 'Candargy', 18),
(10425, 'Microluma', NULL, 'Baill.', 148),
(10426, 'Micromeles', NULL, 'Decne.', 141),
(10427, 'Micromeria', NULL, 'Benth.', 90),
(10428, 'Micromonolepis', NULL, 'Ulbr.', 5),
(10429, 'Micromyrtus', NULL, 'Benth.', 116),
(10430, 'Micromystria', NULL, 'O.E.Schulz', 197),
(10431, 'Micronychia', NULL, 'Oliv.', 6),
(10432, 'Micropaegma', NULL, 'Pichon', 22),
(10433, 'Micropapyrus', NULL, 'Suess.', 55),
(10434, 'Microparacaryum', NULL, '(Popov ex Riedl) Hilger', 25),
(10435, 'Micropeplis', NULL, 'Bunge', 5),
(10436, 'Micropetalum', NULL, 'Poit. ex Baill.', 184),
(10437, 'Microphacos', NULL, 'Rydb.', 68),
(10438, 'Microphysa', NULL, 'Schrenk', 142),
(10439, 'Microphysca', NULL, 'Naudin', 105),
(10440, 'Micropleura', NULL, 'Lag.', 9),
(10441, 'Microplumeria', NULL, 'Baill.', 10),
(10442, 'Micropsis', NULL, 'DC.', 18),
(10443, 'Micropteryx', NULL, 'Walp.', 68),
(10444, 'Micropus', NULL, 'L.', 18),
(10445, 'Microrhamnus', NULL, 'A.Gray', 139),
(10446, 'Microrphium', NULL, 'C.B.Clarke', 75),
(10447, 'Microschwenkia', NULL, 'Benth. ex Hemsl.', 154),
(10448, 'Microsciadium', NULL, 'Boiss.', 9),
(10449, 'Microsechium', NULL, 'Naudin', 49),
(10450, 'Microsemia', NULL, 'Greene', 197),
(10451, 'Microsemma', NULL, 'Labill.', 164),
(10452, 'Microsepala', NULL, 'Miq.', 184),
(10453, 'Microseris', NULL, 'D.Don', 18),
(10454, 'Microsideros', NULL, 'Baum.-Bod.(SUI)', 116),
(10455, 'Microsisymbrium', NULL, 'O.E.Schulz', 197),
(10456, 'Microspermum', NULL, 'Lag.', 18),
(10457, 'Microsplenium', NULL, 'Hook.f.(SUI)', 142),
(10458, 'Microstachys', NULL, 'A.Juss.', 66),
(10459, 'Microstegnus', NULL, 'C.Presl', 52),
(10460, 'Microsteira', NULL, 'Baker', 101),
(10461, 'Microstelma', NULL, 'Baill.', 10),
(10462, 'Microstemma', NULL, 'R.Br.', 10),
(10463, 'Microstemon', NULL, 'Engl.', 6),
(10464, 'Microstephanus', NULL, 'N.E.Br.', 10),
(10465, 'Microstephium', NULL, 'Less.', 18),
(10466, 'Microstigma', NULL, 'Trautv.', 197),
(10467, 'Microstrobilus', NULL, 'Bremek.', 1),
(10468, 'Microstrobos', NULL, 'J.Garden & L.A.S.Johnson', 132),
(10469, 'Microtea', NULL, 'Sw.', 128),
(10470, 'Microthlaspi', NULL, 'F.K.Mey.', 197),
(10471, 'Microtoena', NULL, 'Prain', 90),
(10472, 'Microtrichia', NULL, 'DC.', 18),
(10473, 'Microula', NULL, 'Benth.', 25),
(10474, 'Mida', NULL, 'A.Cunn. ex Endl.', 146),
(10475, 'Miersiophyton', NULL, 'Engl.', 107),
(10476, 'Migandra', NULL, 'O.F.Cook', 15),
(10477, 'Mikania', NULL, 'Willd.', 18),
(10478, 'Mikaniopsis', NULL, 'Milne-Redh.', 18),
(10479, 'Mildbraedia', NULL, 'Pax', 66),
(10480, 'Mildbraediodendron', NULL, 'Harms', 68),
(10481, 'Milleria', NULL, 'L.', 18),
(10482, 'Millingtonia', NULL, 'L.f.', 22),
(10483, 'Millotia', NULL, 'Cass.', 18),
(10484, 'Millspaughia', NULL, 'B.L.Rob.', 134),
(10485, 'Milnea', NULL, 'Roxb.', 106),
(10486, 'Miltianthus', NULL, 'Bunge', 177),
(10487, 'Miltitzia', NULL, 'A.DC.', 25),
(10488, 'Mimela', NULL, 'Phil.', 18),
(10489, 'Mimetanthe', NULL, 'Greene', 150),
(10490, 'Mimetes', NULL, 'Salisb.', 135),
(10491, 'Mimophytum', NULL, 'Greenm.', 25),
(10492, 'Mimosopsis', NULL, 'Britton & Rose', 68),
(10493, 'Mimozyganthus', NULL, 'Burkart', 68),
(10494, 'Mimulicalyx', NULL, 'P.C.Tsoong', 150),
(10495, 'Mimulopsis', NULL, 'Schweinf.', 1),
(10496, 'Mimulus', NULL, 'L.', 417),
(10497, 'Mina', NULL, 'Cerv.', 46),
(10498, 'Minkelersia', NULL, 'M.Martens & Galeotti', 68),
(10499, 'Minthostachys', NULL, '(Benth.) Spach', 90),
(10500, 'Minuria', NULL, 'DC.', 18),
(10501, 'Minutalia', NULL, 'Fenzl', 184),
(10502, 'Minutia', NULL, 'Vell.', 120),
(10503, 'Mionandra', NULL, 'Griseb.', 101),
(10504, 'Miquelia', NULL, 'Meisn.', 85),
(10505, 'Mirabellia', NULL, 'Baill.', 66),
(10506, 'Mirabilis', NULL, 'L.', 117),
(10507, 'Miraglossum', NULL, 'Kupicha', 10),
(10508, 'Mirandaceltis', NULL, 'Sharp', 170),
(10509, 'Mirandea', NULL, 'Rzed.', 1),
(10510, 'Mirbelia', NULL, 'Sm.', 68),
(10511, 'Miricacalia', NULL, 'Kitam.', 18),
(10512, 'Mirmecodia', NULL, 'Gaudich.(SUO)', 142),
(10513, 'Mirobalanus', NULL, 'Rumph.', 184),
(10514, 'Misanteca', NULL, 'Schltdl. & Cham.', 91),
(10515, 'Mischocodon', NULL, 'Radlk.', 147),
(10516, 'Mischodon', NULL, 'Thwaites', 534),
(10517, 'Mischogyne', NULL, 'Exell', 8),
(10518, 'Mischophloeus', NULL, 'Scheff.', 15),
(10519, 'Mischopleura', NULL, 'Wernham ex Ridl.', 64),
(10520, 'Misiessya', NULL, 'Wedd.', 171),
(10521, 'Misopates', NULL, 'Raf.', 423),
(10522, 'Mitchella', NULL, 'L.', 142),
(10523, 'Mitella', NULL, 'L.', 149),
(10524, 'Mitellastra', NULL, 'Howell', 149),
(10525, 'Mitellopsis', NULL, 'Meisn.', 149),
(10526, 'Mitolepis', NULL, 'Balf.f.', 10),
(10527, 'Mitophyllum', NULL, 'Greene', 197),
(10528, 'Mitostemma', NULL, 'Mast.', 127),
(10529, 'Mitostigma', NULL, 'Decne.', 10),
(10530, 'Mitozus', NULL, 'Miers', 10),
(10531, 'Mitracarpus', NULL, 'Zucc.', 142),
(10532, 'Mitranthes', NULL, 'O.Berg', 116),
(10533, 'Mitrantia', NULL, 'Peter G.Wilson & B.Hyland', 116),
(10534, 'Mitraria', NULL, 'Cav.', 76),
(10535, 'Mitrasacme', NULL, 'Labill.', 97),
(10536, 'Mitrasacmopsis', NULL, 'Jovet', 142),
(10537, 'Mitrastigma', NULL, 'Harv.', 142),
(10538, 'Mitrastylus', NULL, 'Alm & T.C.E.Fr.', 64),
(10539, 'Mitratheca', NULL, 'K.Schum.', 142),
(10540, 'Mitrella', NULL, 'Miq.', 8),
(10541, 'Mitreola', NULL, 'Boehm.(SUH)', 97),
(10542, 'Mitriostigma', NULL, 'Hochst.', 142),
(10543, 'Mitropsidium', NULL, 'Burret', 116),
(10544, 'Mitrosicyos', NULL, 'Maxim.', 49),
(10545, 'Mixandra', NULL, 'Pierre', 148),
(10546, 'Miyamayomena', NULL, 'Kitam.', 18),
(10547, 'Mkilua', NULL, 'Verdc.', 8),
(10548, 'Mniodes', NULL, '(A.Gray) Benth.', 18),
(10549, 'Moacroton', NULL, 'Croizat', 66),
(10550, 'Mocquerysia', NULL, 'Hua', 145),
(10551, 'Modecca', NULL, 'Lam.', 127),
(10552, 'Modestia', NULL, 'Kharadze & Tamamsch.', 18),
(10553, 'Modiola', NULL, 'Moench', 102),
(10554, 'Modiolastrum', NULL, 'K.Schum.', 102),
(10555, 'Moeroris', NULL, 'Raf.', 184),
(10556, 'Moghania', NULL, 'J.St.-Hil.', 68),
(10557, 'Mogiphanes', NULL, 'Mart.', 5),
(10558, 'Mogoltavia', NULL, 'Korovin', 9),
(10559, 'Mogorium', NULL, 'Juss.', 120),
(10560, 'Mohavea', NULL, 'A.Gray', 423),
(10561, 'Mohlana', NULL, 'Mart.', 128),
(10562, 'Moldavica', NULL, 'Fabr.', 90),
(10563, 'Moldenhauera', NULL, 'Spreng.', 85),
(10564, 'Moldenhawera', NULL, 'Schrad.', 68),
(10565, 'Molina', NULL, 'Gay', 66),
(10566, 'Molinaea', NULL, 'Comm. ex Juss.', 147),
(10567, 'Mollera', NULL, 'O.Hoffm.', 18),
(10568, 'Molongum', NULL, 'Pichon', 10),
(10569, 'Molopanthera', NULL, 'Turcz.', 142),
(10570, 'Molopospermum', NULL, 'W.D.J.Koch', 9),
(10571, 'Moltkia', NULL, 'Lehm.', 25),
(10572, 'Moltkiopsis', NULL, 'I.M.Johnst.', 25),
(10573, 'Moluccella', NULL, 'L.', 90),
(10574, 'Mommsenia', NULL, 'Urb. & Ekman', 105),
(10575, 'Momordica', NULL, 'L.', 49),
(10576, 'Monachochlamys', NULL, 'Baker', 1),
(10577, 'Monactineirma', NULL, 'Bory', 127),
(10578, 'Monactis', NULL, 'Kunth', 18),
(10579, 'Monadelphanthus', NULL, 'H.Karst.', 142),
(10580, 'Monadenium', NULL, 'Pax', 66),
(10581, 'Monanthella', NULL, 'A.Berger', 48),
(10582, 'Monanthes', NULL, 'Haw.', 48),
(10583, 'Monanthocitrus', NULL, 'Tanaka', 143),
(10584, 'Monanthotaxis', NULL, 'Baill.', 8),
(10585, 'Monarda', NULL, 'L.', 90),
(10586, 'Monardella', NULL, 'Benth.', 90),
(10587, 'Monarrhenus', NULL, 'Cass.', 18),
(10588, 'Monarthrocarpus', NULL, 'Merr.', 68),
(10589, 'Mondia', NULL, 'Skeels', 10),
(10590, 'Monechma', NULL, 'Hochst.', 1),
(10591, 'Monenteles', NULL, 'Labill.', 18),
(10592, 'Moneses', NULL, 'Salisb. ex Gray', 64),
(10593, 'Monguia', NULL, 'Chapel. ex Baill.', 66),
(10594, 'Moniera', NULL, 'Loefl.(SUO)', 143),
(10595, 'Monimia', NULL, 'Thouars', 108),
(10596, 'Monimiastrum', NULL, 'J.Gueho & A.J.Scott', 116),
(10597, 'Monimopetalum', NULL, 'Rehder', 38),
(10598, 'Monizia', NULL, 'Lowe', 9),
(10599, 'Monnieria', NULL, 'Loefl.', 143),
(10600, 'Monnina', NULL, 'Ruiz & Pav.', 133),
(10601, 'Monocardia', NULL, 'Pennell', 423),
(10602, 'Monocelastrus', NULL, 'F.T.Wang & T.Tang', 38),
(10603, 'Monocephalium', NULL, 'S.Moore', 85),
(10604, 'Monocera', NULL, 'Jack', 62),
(10605, 'Monochaetum', NULL, '(DC.) Naudin', 105),
(10606, 'Monochasma', NULL, 'Maxim. ex Franch. & Sav.', 400),
(10607, 'Monochilus', NULL, 'Fisch. & C.A.Mey.', 90),
(10608, 'Monococcus', NULL, 'F.Muell.', 128),
(10609, 'Monocyclanthus', NULL, 'Keay', 8),
(10610, 'Monogereion', NULL, 'G.M.Barroso & R.M.King', 18),
(10611, 'Monolena', NULL, 'Triana', 105),
(10612, 'Monolepis', NULL, 'Schrad.', 5),
(10613, 'Monolopia', NULL, 'DC.', 18),
(10614, 'Monomesia', NULL, 'Raf.(SUS)', 25),
(10615, 'Monoon', NULL, 'Miq.', 8),
(10616, 'Monopanax', NULL, 'Regel', 13),
(10617, 'Monopera', NULL, 'Barringer', 423),
(10618, 'Monopetalanthus', NULL, 'Harms', 68),
(10619, 'Monopholis', NULL, 'S.F.Blake', 18),
(10620, 'Monophrynium', NULL, 'K.Schum.', 103),
(10621, 'Monophyllaea', NULL, 'R.Br.', 76),
(10622, 'Monophyllanthe', NULL, 'K.Schum.', 103),
(10623, 'Monoplegma', NULL, 'Piper', 68),
(10624, 'Monoporandra', NULL, 'Thwaites', 60),
(10625, 'Monoporus', NULL, 'A.DC.', 115),
(10626, 'Monopsis', NULL, 'Salisb.', 30),
(10627, 'Monopteryx', NULL, 'Spruce ex Benth.', 68),
(10628, 'Monoptilon', NULL, 'Torr. & A.Gray', 18),
(10629, 'Monopyle', NULL, 'Moritz ex Benth.', 76),
(10630, 'Monopyrena', NULL, 'Speg.', 173),
(10631, 'Monosalpinx', NULL, 'N.Halle', 142),
(10632, 'Monoschisma', NULL, 'Brenan', 68),
(10633, 'Monosemion', NULL, 'Raf.', 68),
(10634, 'Monosoma', NULL, 'Griff.', 106),
(10635, 'Monotagma', NULL, 'K.Schum.', 103),
(10636, 'Monotaxis', NULL, 'Brongn.', 66),
(10637, 'Monotes', NULL, 'A.DC.', 60),
(10638, 'Monotheca', NULL, 'A.DC.', 148),
(10639, 'Monothecium', NULL, 'Hochst.', 1),
(10640, 'Monotoca', NULL, 'R.Br.', 64),
(10641, 'Monotropa', NULL, 'L.', 64),
(10642, 'Monotropanthum', NULL, 'Andres', 64),
(10643, 'Monotropastrum', NULL, 'Andres', 64),
(10644, 'Monotropsis', NULL, 'Schwein. ex Elliott', 64),
(10645, 'Monoxora', NULL, 'Wight', 116),
(10646, 'Monrosia', NULL, 'Grondona', 133),
(10647, 'Monstera', NULL, 'Adans.', 12),
(10648, 'Montagueia', NULL, 'Baker f.', 13),
(10649, 'Montamans', NULL, 'Dwyer', 142),
(10650, 'Montanoa', NULL, 'Cerv.', 18),
(10651, 'Monteiroa', NULL, 'Krapov.', 102),
(10652, 'Montejacquia', NULL, 'Roberty', 46),
(10653, 'Montelia', NULL, 'A.Gray', 5),
(10654, 'Montezuma', NULL, 'DC.', 102),
(10655, 'Montrichardia', NULL, 'Crueg.', 12),
(10656, 'Montrouziera', NULL, 'Planch. & Triana', 42),
(10657, 'Monttea', NULL, 'Gay', 423),
(10658, 'Moonia', NULL, 'Arn.', 18),
(10659, 'Moorcroftia', NULL, 'Choisy', 46),
(10660, 'Mooria', NULL, 'Montrouz.', 116),
(10661, 'Mopania', NULL, 'Lundell', 148),
(10662, 'Moparia', NULL, 'Britton & Rose', 68),
(10663, 'Moquilea', NULL, 'Aubl.', 40),
(10664, 'Moquinia', NULL, 'DC.', 18),
(10665, 'Moquiniella', NULL, 'Balle', 98),
(10666, 'Mora', NULL, 'Benth.', 68),
(10667, 'Moratia', NULL, 'H.E.Moore', 15),
(10668, 'Morelotia', NULL, 'Gaudich.', 55),
(10669, 'Morenia', NULL, 'Ruiz & Pav.', 15),
(10670, 'Morettia', NULL, 'DC.', 197),
(10671, 'Morgania', NULL, 'R.Br.', 150),
(10672, 'Moricandia', NULL, 'DC.', 197),
(10673, 'Moriera', NULL, 'Boiss.', 197),
(10674, 'Morierina', NULL, 'Vieill.', 142),
(10675, 'Morindopsis', NULL, 'Hook.f.', 142),
(10676, 'Moringa', NULL, 'Adans.', 110),
(10677, 'Morisia', NULL, 'J.Gay', 197),
(10678, 'Morithamnus', NULL, 'R.M.King, H.Rob. & G.M.Barroso', 18),
(10679, 'Moritzia', NULL, 'DC. ex Meisn.', 25),
(10680, 'Morkillia', NULL, 'Rose & Painter', 177),
(10681, 'Morleya', NULL, 'Woodson', 10),
(10682, 'Morocarpus', NULL, 'Siebold & Zucc.(SUS)', 171),
(10683, 'Morolobium', NULL, 'Kosterm.', 68),
(10684, 'Morongia', NULL, 'Britton', 68),
(10685, 'Morrenia', NULL, 'Lindl.', 10),
(10686, 'Morrisiella', NULL, 'Aellen', 5),
(10687, 'Morsacanthus', NULL, 'Rizzini', 1),
(10688, 'Mortonia', NULL, 'A.Gray', 38),
(10689, 'Mortoniella', NULL, 'Woodson', 10),
(10690, 'Moscharia', NULL, 'Ruiz & Pav.', 18),
(10691, 'Moschosma', NULL, 'Rchb.', 90),
(10692, 'Moschoxylum', NULL, 'A.Juss.', 106),
(10693, 'Moseleya', NULL, 'Hemsl.', 150),
(10694, 'Mosenodendron', NULL, 'R.E.Fr.', 8),
(10695, 'Mosheovia', NULL, 'Eig', 150),
(10696, 'Mosiera', NULL, 'Small', 116),
(10697, 'Mosla', NULL, '(Benth.) Buch.-Ham. ex Maxim.', 90),
(10698, 'Mostacillastrum', NULL, 'O.E.Schulz', 197),
(10699, 'Motandra', NULL, 'A.DC.', 10),
(10700, 'Motherwellia', NULL, 'F.Muell.', 13),
(10701, 'Motleyia', NULL, 'J.T.Johanss.', 142),
(10702, 'Moullava', NULL, 'Adans.', 68),
(10703, 'Moultonia', NULL, 'Balf.f. & W.W.Sm.', 76),
(10704, 'Mouretia', NULL, 'Pit.', 142),
(10705, 'Mouriria', NULL, 'Juss.(SUO)', 105),
(10706, 'Mouroucoa', NULL, 'Aubl.', 46),
(10707, 'Moussonia', NULL, 'Regel', 76),
(10708, 'Moutabea', NULL, 'Aubl.', 133),
(10709, 'Moya', NULL, 'Griseb.', 38),
(10710, 'Mozartia', NULL, 'Urb.', 116),
(10711, 'Mozinna', NULL, 'Ortega', 66),
(10712, 'Msuata', NULL, 'O.Hoffm.', 18),
(10713, 'Muantum', NULL, 'Pichon', 10),
(10714, 'Mucizonia', NULL, '(DC.) A.Berger', 48),
(10715, 'Mucoa', NULL, 'Zarucchi', 10),
(10716, 'Mucronea', NULL, 'Benth.', 134),
(10717, 'Mucuna', NULL, 'Adans.', 71),
(10718, 'Muehlbergella', NULL, 'Feer', 30),
(10719, 'Muehlenbeckia', NULL, 'Meisn.', 134);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(10720, 'Muellera', NULL, 'L.f.', 68),
(10721, 'Muelleranthus', NULL, 'Hutch.', 68),
(10722, 'Muellerargia', NULL, 'Cogn.', 49),
(10723, 'Muellerina', NULL, 'Tiegh.', 98),
(10724, 'Muenteria', NULL, 'Seem.', 22),
(10725, 'Muiriantha', NULL, 'C.A.Gardner', 143),
(10726, 'Mukdenia', NULL, 'Koidz.', 149),
(10727, 'Mukia', NULL, 'Arn.', 49),
(10728, 'Mulgedium', NULL, 'Cass.', 18),
(10729, 'Mulinum', NULL, 'Pers.', 9),
(10730, 'Multidentia', NULL, 'Gilli', 142),
(10731, 'Munbya', NULL, 'Boiss.', 25),
(10732, 'Mundia', NULL, 'Kunth(SUS)', 133),
(10733, 'Mundulea', NULL, '(DC.) Benth.', 68),
(10734, 'Mungos', NULL, 'Adans.', 142),
(10735, 'Munnozia', NULL, 'Ruiz & Pav.', 18),
(10736, 'Munroidendron', NULL, 'Sherff', 13),
(10737, 'Munronia', NULL, 'Wight', 106),
(10738, 'Muntafara', NULL, 'Pichon', 10),
(10739, 'Munzothamnus', NULL, 'Raven', 18),
(10740, 'Muraltia', NULL, 'DC.', 133),
(10741, 'Muratina', NULL, 'Maire', 5),
(10742, 'Murbeckiella', NULL, 'Rothm.', 197),
(10743, 'Muretia', NULL, 'Boiss.', 9),
(10744, 'Muricaria', NULL, 'Desv.', 197),
(10745, 'Muricia', NULL, 'Lour.', 49),
(10746, 'Muricococcum', NULL, 'Chun & F.C.How', 66),
(10747, 'Muriea', NULL, 'Hartog', 148),
(10748, 'Murieanthe', NULL, '(Baill.) Aubrev.', 148),
(10749, 'Murrinea', NULL, 'Raf.', 116),
(10750, 'Murtekias', NULL, 'Raf.', 66),
(10751, 'Murtonia', NULL, 'Craib', 68),
(10752, 'Murucuja', NULL, 'Medik.', 127),
(10753, 'Musa', NULL, 'L.', 111),
(10754, 'Muschleria', NULL, 'S.Moore', 18),
(10755, 'Musella', NULL, '(Franch.) C.Y.Wu', 111),
(10756, 'Museniopsis', NULL, '(A.Gray) J.M.Coult. & Rose', 9),
(10757, 'Musgravea', NULL, 'F.Muell.', 135),
(10758, 'Musilia', NULL, 'Velen.', 18),
(10759, 'Musineon', NULL, 'Raf.', 9),
(10760, 'Mussatia', NULL, 'Bureau ex Baill.', 22),
(10761, 'Musschia', NULL, 'Dumort.', 30),
(10762, 'Mutisia', NULL, 'L.f.', 18),
(10763, 'Myagropsis', NULL, 'Hort. ex O.E.Schulz', 197),
(10764, 'Myagrum', NULL, 'L.', 197),
(10765, 'Mycelis', NULL, 'Cass.', 18),
(10766, 'Mycerinus', NULL, 'A.C.Sm.', 64),
(10767, 'Mycetia', NULL, 'Reinw.', 142),
(10768, 'Myconia', NULL, 'Lapeyr.', 76),
(10769, 'Myginda', NULL, 'Jacq.', 38),
(10770, 'Myladenia', NULL, 'Airy Shaw', 66),
(10771, 'Myllanthus', NULL, 'R.S.Cowan', 143),
(10772, 'Myodocarpus', NULL, 'Brongn. & Gris', 525),
(10773, 'Myonima', NULL, 'Comm. ex Juss.', 142),
(10774, 'Myopordon', NULL, 'Boiss.', 18),
(10775, 'Myoporum', NULL, 'Banks & Sol. ex G.Forst.', 150),
(10776, 'Myopsia', NULL, 'C.Presl', 30),
(10777, 'Myoschilos', NULL, 'Ruiz & Pav.', 146),
(10778, 'Myosotidium', NULL, 'Hook.', 25),
(10779, 'Myosotis', NULL, 'L.', 25),
(10780, 'Myospyrum', NULL, 'Lindl.(SUO)', 120),
(10781, 'Myracrodruon', NULL, 'Allemao', 6),
(10782, 'Myrceugenella', NULL, 'Kausel', 116),
(10783, 'Myrceugenia', NULL, 'O.Berg', 116),
(10784, 'Myrcialeucus', NULL, 'Rojas Acosta', 116),
(10785, 'Myrciariopsis', NULL, 'Kausel', 116),
(10786, 'Myriactis', NULL, 'Less.', 18),
(10787, 'Myrialepis', NULL, 'Becc.', 15),
(10788, 'Myrianthemum', NULL, 'Gilg', 105),
(10789, 'Myriaspora', NULL, 'DC.', 105),
(10790, 'Myricanthe', NULL, 'Airy Shaw', 66),
(10791, 'Myricaria', NULL, 'Desv.', 160),
(10792, 'Myrinia', NULL, 'Lilja', 121),
(10793, 'Myriocephalus', NULL, 'Benth.', 18),
(10794, 'Myriogomphus', NULL, 'Didr.', 66),
(10795, 'Myrioneuron', NULL, 'R.Br. ex Hook.', 142),
(10796, 'Myriopteron', NULL, 'Griff.', 10),
(10797, 'Myripnois', NULL, 'Bunge', 18),
(10798, 'Myrmecodendron', NULL, 'Britton & Rose', 68),
(10799, 'Myrmecodia', NULL, 'Jack', 142),
(10800, 'Myrmecoides', NULL, 'Elmer(SUO)', 142),
(10801, 'Myrmeconauclea', NULL, 'Merr.', 142),
(10802, 'Myrmecosicyos', NULL, 'C.Jeffrey', 49),
(10803, 'Myrmedoma', NULL, 'Becc.', 142),
(10804, 'Myrmephytum', NULL, 'Becc.', 142),
(10805, 'Myrmidone', NULL, 'Mart.', 105),
(10806, 'Myrobalanifera', NULL, 'Houtt.', 44),
(10807, 'Myrobalanus', NULL, 'Gaertn.', 44),
(10808, 'Myrocarpus', NULL, 'Allemao', 68),
(10809, 'Myrosma', NULL, 'L.f.', 103),
(10810, 'Myrrhidendron', NULL, 'J.M.Coult. & Rose', 9),
(10811, 'Myrrhinium', NULL, 'Schott', 116),
(10812, 'Myrrhis', NULL, 'Mill.', 9),
(10813, 'Myrrhoides', NULL, 'Heist. ex Fabr.', 9),
(10814, 'Myrsiniluma', NULL, 'Baill.', 148),
(10815, 'Myrstiphylla', NULL, 'Raf.', 142),
(10816, 'Myrstiphyllum', NULL, 'P.Browne', 142),
(10817, 'Myrtama', NULL, 'Ovcz. & Kinzik.', 160),
(10818, 'Myrtastrum', NULL, 'Burret', 116),
(10819, 'Myrtekmania', NULL, 'Urb.', 116),
(10820, 'Myrtella', NULL, 'F.Muell.', 116),
(10821, 'Myrteola', NULL, 'O.Berg', 116),
(10822, 'Myrthoides', NULL, 'Wolf', 116),
(10823, 'Myrthus', NULL, 'Scop.', 116),
(10824, 'Myrtiluma', NULL, 'Baill.', 148),
(10825, 'Myrtobium', NULL, 'Miq.', 63),
(10826, 'Myrtopsis', NULL, 'Engl.', 143),
(10827, 'Myrtus', NULL, 'L.', 116),
(10828, 'Mystirophora', NULL, 'Nevski', 68),
(10829, 'Mystroxylon', NULL, 'Eckl. & Zeyh.', 38),
(10830, 'Myxopappus', NULL, 'Kallersjo', 18),
(10831, 'Myxopyrum', NULL, 'Blume', 120),
(10832, 'Mzymtella', NULL, 'Kolak.', 30),
(10833, 'Nabalus', NULL, 'Cass.', 18),
(10834, 'Nablonium', NULL, 'Cass.', 18),
(10835, 'Nacibaea', NULL, 'Poir.(SUO)', 142),
(10836, 'Nacibea', NULL, 'Aubl.', 142),
(10837, 'Naegelia', NULL, 'Regel', 76),
(10838, 'Nageia', NULL, 'Gaertn.', 132),
(10839, 'Nagelia', NULL, 'Lindl.', 141),
(10840, 'Nagelocarpus', NULL, 'Bullock', 64),
(10841, 'Nahusia', NULL, 'Schneev.', 121),
(10842, 'Naletonia', NULL, 'Bremek.', 142),
(10843, 'Nama', NULL, 'L.', 25),
(10844, 'Namacodon', NULL, 'Thulin', 30),
(10845, 'Namation', NULL, 'Brand', 150),
(10846, 'Nananthea', NULL, 'DC.', 18),
(10847, 'Nanarepenta', NULL, 'Matuda', 59),
(10848, 'Nandiroba', NULL, 'Adans.(SUO)', 49),
(10849, 'Nani', NULL, 'Adans.', 116),
(10850, 'Nannoglottis', NULL, 'Maxim.', 18),
(10851, 'Nannorrhops', NULL, 'H.Wendl.', 15),
(10852, 'Nanocnide', NULL, 'Blume', 171),
(10853, 'Nanodea', NULL, 'Banks ex C.F.Gaertn.', 146),
(10854, 'Nanopetalum', NULL, 'Hassk.', 184),
(10855, 'Nanophyton', NULL, 'Less.', 5),
(10856, 'Nanorrhinum', NULL, 'Betsche', 150),
(10857, 'Nanostelma', NULL, 'Baill.', 10),
(10858, 'Nanothamnus', NULL, 'Thomson', 18),
(10859, 'Nanuza', NULL, 'L.B.Sm. & Ayensu', 172),
(10860, 'Napaea', NULL, 'L.', 102),
(10861, 'Napeanthus', NULL, 'Gardner', 76),
(10862, 'Napeodendron', NULL, 'Ridl.', 106),
(10863, 'Napoleona', NULL, 'P.Beauv.', 92),
(10864, 'Nardophyllum', NULL, '(Hook. & Arn.) Hook. & Arn.', 18),
(10865, 'Narega', NULL, 'Raf.', 142),
(10866, 'Naregamia', NULL, 'Wight & Arn.', 106),
(10867, 'Naringi', NULL, 'Adans.', 143),
(10868, 'Narthex', NULL, 'Falc.', 9),
(10869, 'Narum', NULL, 'Adans.', 8),
(10870, 'Naruma', NULL, 'Raf.', 8),
(10871, 'Narvalina', NULL, 'Cass.', 18),
(10872, 'Nashia', NULL, 'Millsp.', 173),
(10873, 'Nassauvia', NULL, 'Comm. ex Juss.', 18),
(10874, 'Nasturtiastrum', NULL, '(Gren. & Godr.) Gillet & Magne', 197),
(10875, 'Nasturtiicarpa', NULL, 'Gilli', 197),
(10876, 'Nasturtiopsis', NULL, 'Boiss.', 197),
(10877, 'Nasturtium', NULL, 'R.Br.', 197),
(10878, 'Natalanthe', NULL, 'Sond.', 142),
(10879, 'Nathaliella', NULL, 'B.Fedtsch.', 150),
(10880, 'Nathusia', NULL, 'Hochst.', 120),
(10881, 'Natsiatopsis', NULL, 'Kurz', 85),
(10882, 'Natsiatum', NULL, 'Buch.-Ham. ex Arn.', 85),
(10883, 'Naudinia', NULL, 'Planch. & Linden', 143),
(10884, 'Naudiniella', NULL, 'Krasser', 105),
(10885, 'Naufraga', NULL, 'Constance & Cannon', 9),
(10886, 'Naumburgia', NULL, 'Moench', 115),
(10887, 'Nauplius', NULL, '(Cass.) Cass.', 18),
(10888, 'Nautilocalyx', NULL, 'Linden ex Hanst.', 76),
(10889, 'Nautochilus', NULL, 'Bremek.', 90),
(10890, 'Nautonia', NULL, 'Decne.', 10),
(10891, 'Nautophylla', NULL, 'Guillaumin', 97),
(10892, 'Naxiandra', NULL, '(Baill.) Krasser', 186),
(10893, 'Nealchornea', NULL, 'Huber', 66),
(10894, 'Neamyza', NULL, 'Tiegh.', 98),
(10895, 'Neanotis', NULL, 'W.H.Lewis', 142),
(10896, 'Neanthe', NULL, 'O.F.Cook(SUI)', 15),
(10897, 'Neatostema', NULL, 'I.M.Johnst.', 25),
(10898, 'Neblinaea', NULL, 'Maguire & Wurdack', 18),
(10899, 'Neblinantha', NULL, 'Maguire', 75),
(10900, 'Neblinanthera', NULL, 'Wurdack', 105),
(10901, 'Neblinathamnus', NULL, 'Steyerm.', 142),
(10902, 'Necalistis', NULL, 'Raf.', 109),
(10903, 'Necepsia', NULL, 'Prain', 66),
(10904, 'Neckia', NULL, 'Korth.', 118),
(10905, 'Necramium', NULL, 'Britton', 105),
(10906, 'Necranthus', NULL, 'Gilli', 400),
(10907, 'Nectaropetalum', NULL, 'Engl.', 65),
(10908, 'Nectouxia', NULL, 'Kunth', 154),
(10909, 'Needhamia', NULL, 'R.Br.', 64),
(10910, 'Needhamiella', NULL, 'L.Watson', 64),
(10911, 'Neeopsis', NULL, 'Lundell', 117),
(10912, 'Neesenbeckia', NULL, 'Levyns', 55),
(10913, 'Negria', NULL, 'F.Muell.', 76),
(10914, 'Neillia', NULL, 'D.Don', 141),
(10915, 'Neisosperma', NULL, 'Raf.', 10),
(10916, 'Nelanaregam', NULL, 'Adans.', 106),
(10917, 'Neleixa', NULL, 'Raf.', 142),
(10918, 'Nelitris', NULL, 'Spreng.', 116),
(10919, 'Nellica', NULL, 'Raf.', 184),
(10920, 'Nelmesia', NULL, 'Van der Veken', 55),
(10921, 'Nelsia', NULL, 'Schinz', 5),
(10922, 'Nelsonia', NULL, 'R.Br.', 1),
(10923, 'Nelsonianthus', NULL, 'H.Rob. & Brettell', 18),
(10924, 'Nemacaulis', NULL, 'Nutt.', 134),
(10925, 'Nemacladus', NULL, 'Nutt.', 30),
(10926, 'Nemaluma', NULL, 'Baill.', 148),
(10927, 'Nematanthus', NULL, 'Schrad.', 76),
(10928, 'Nematolepis', NULL, 'Turcz.', 143),
(10929, 'Nematopogon', NULL, 'Bureau & K.Schum.', 22),
(10930, 'Nematosciadium', NULL, 'H.Wolff', 9),
(10931, 'Nematostigma', NULL, 'Planch.', 170),
(10932, 'Nematostylis', NULL, 'Hook.f.', 142),
(10933, 'Nematuris', NULL, 'Turcz.', 10),
(10934, 'Nemcia', NULL, 'Domin', 68),
(10935, 'Nemedra', NULL, 'A.Juss.', 106),
(10936, 'Nemesia', NULL, 'Vent.', 150),
(10937, 'Nemodon', NULL, 'Griff.', 46),
(10938, 'Nemopanthus', NULL, 'Raf.', 11),
(10939, 'Nemophila', NULL, 'Nutt.', 84),
(10940, 'Nemosenecio', NULL, '(Kitam.) B.Nord.', 18),
(10941, 'Nemoseris', NULL, 'Greene', 18),
(10942, 'Nemostylis', NULL, 'Steven', 142),
(10943, 'Nemotopyxis', NULL, 'Miq.', 121),
(10944, 'Nemuaron', NULL, 'Baill.', 505),
(10945, 'Nemum', NULL, 'Desv.', 55),
(10946, 'Nenax', NULL, 'Gaertn.', 142),
(10947, 'Nenga', NULL, 'H.Wendl. & Drude', 15),
(10948, 'Nengella', NULL, 'Becc.', 15),
(10949, 'Neo-Senea', NULL, 'K.Schum. ex H.Pfeiff.', 55),
(10950, 'Neo-Uvaria', NULL, 'Airy Shaw', 8),
(10951, 'Neoacanthophora', NULL, 'Bennet', 13),
(10952, 'Neoalsomitra', NULL, 'Hutch.', 49),
(10953, 'Neoancistrophyllum', NULL, 'Rauschert(SUS)', 15),
(10954, 'Neoapaloxylon', NULL, 'Rauschert', 68),
(10955, 'Neobaclea', NULL, 'Hochr.', 102),
(10956, 'Neobaronia', NULL, 'Baker', 68),
(10957, 'Neobassia', NULL, 'A.J.Scott', 5),
(10958, 'Neobaumannia', NULL, 'Hutch. & Dalziel', 142),
(10959, 'Neobeckia', NULL, 'Greene', 197),
(10960, 'Neobeguea', NULL, 'J.-F.Leroy', 106),
(10961, 'Neobertiera', NULL, 'Wernham', 142),
(10962, 'Neoblakea', NULL, 'Standl.', 142),
(10963, 'Neoboivinella', NULL, 'Aubrev. & Pellegr.', 148),
(10964, 'Neobotrydium', NULL, 'Moldenke', 5),
(10965, 'Neobracea', NULL, 'Britton', 10),
(10966, 'Neobreonia', NULL, 'Ridsdale', 142),
(10967, 'Neobrittonia', NULL, 'Hochr.', 102),
(10968, 'Neobuchia', NULL, 'Urb.', 102),
(10969, 'Neobyrnesia', NULL, 'J.A.Armstr.', 143),
(10970, 'Neocabreria', NULL, 'R.M.King & H.Rob.', 18),
(10971, 'Neocallitropsis', NULL, 'Florin', 51),
(10972, 'Neocalyptrocalyx', NULL, 'Hutch.', 32),
(10973, 'Neocarya', NULL, '(DC.) Prance ex F.White', 40),
(10974, 'Neocastela', NULL, 'Small', 151),
(10975, 'Neocentema', NULL, 'Schinz', 5),
(10976, 'Neochamaelea', NULL, '(Engl.) Erdtman', 143),
(10977, 'Neochevaliera', NULL, 'A.Chev. & Beille', 66),
(10978, 'Neochevalierodendron', NULL, 'J.Leonard', 68),
(10979, 'Neocodon', NULL, 'Kolak. & Serdyuk.', 30),
(10980, 'Neocollettia', NULL, 'Hemsl.', 68),
(10981, 'Neoconopodium', NULL, '(Koso-Pol.) Pimenov & Kljuykov', 9),
(10982, 'Neocouma', NULL, 'Pierre', 10),
(10983, 'Neocracca', NULL, 'Kuntze', 68),
(10984, 'Neocryptodiscus', NULL, 'Hedge & Lamond', 9),
(10985, 'Neocuatrecasia', NULL, 'R.M.King & H.Rob.', 18),
(10986, 'Neocussonia', NULL, 'Hutch.', 13),
(10987, 'Neodielsia', NULL, 'Harms', 68),
(10988, 'Neodissochaeta', NULL, 'Bakh.f.', 105),
(10989, 'Neodistemon', NULL, 'Babu & A.N.Henry', 171),
(10990, 'Neodriessenia', NULL, 'M.P.Nayar', 105),
(10991, 'Neodunnia', NULL, 'R.Vig.', 68),
(10992, 'Neodypsis', NULL, 'Baill.', 15),
(10993, 'Neoeplingia', NULL, 'Ramam., Hiriart & Medrano', 90),
(10994, 'Neofabricia', NULL, 'Joy Thomps.', 116),
(10995, 'Neoferetia', NULL, 'Baehni', 85),
(10996, 'Neofranciella', NULL, 'Guillaumin', 142),
(10997, 'Neogaerrhinum', NULL, 'Rothm.', 423),
(10998, 'Neogaillonia', NULL, 'Lincz.', 142),
(10999, 'Neogoetzia', NULL, 'Pax', 184),
(11000, 'Neogoezia', NULL, 'Hemsl.', 9),
(11001, 'Neoguillauminia', NULL, 'Croizat', 66),
(11002, 'Neohallia', NULL, 'Hemsl.', 1),
(11003, 'Neoharmsia', NULL, 'R.Vig.', 68),
(11004, 'Neohemsleya', NULL, 'T.D.Penn.', 148),
(11005, 'Neohenrya', NULL, 'Hemsl.', 10),
(11006, 'Neohintonia', NULL, 'R.M.King & H.Rob.', 18),
(11007, 'Neoholstia', NULL, 'Rauschert', 66),
(11008, 'Neohuberia', NULL, 'Ledoux', 92),
(11009, 'Neohumbertiella', NULL, 'Hochr.', 102),
(11010, 'Neohymenopogon', NULL, 'Bennet', 142),
(11011, 'Neohyptis', NULL, 'J.K.Morton', 90),
(11012, 'Neojatropha', NULL, 'Pax', 66),
(11013, 'Neojeffreya', NULL, 'Cabrera', 18),
(11014, 'Neojobertia', NULL, 'Baill.', 22),
(11015, 'Neojunghuhnia', NULL, 'Koord.', 64),
(11016, 'Neokeithia', NULL, 'Steenis', 10),
(11017, 'Neolabatia', NULL, 'Aubrev.', 148),
(11018, 'Neolaugeria', NULL, 'Nicolson', 142),
(11019, 'Neolemonniera', NULL, 'Heine', 148),
(11020, 'Neolepia', NULL, 'W.A.Weber', 197),
(11021, 'Neoleroya', NULL, 'Cavaco', 142),
(11022, 'Neolindenia', NULL, 'Baill.', 1),
(11023, 'Neolindleyella', NULL, 'Fedde', 141),
(11024, 'Neolophocarpus', NULL, 'E.G.Camus', 55),
(11025, 'Neoluederitzia', NULL, 'Schinz', 177),
(11026, 'Neoluffa', NULL, 'Chakrav.', 49),
(11027, 'Neomacfadya', NULL, 'Baill.', 22),
(11028, 'Neomangenotia', NULL, 'J.-F.Leroy', 27),
(11029, 'Neomanniophyton', NULL, 'Pax & K.Hoffm.', 66),
(11030, 'Neomartinella', NULL, 'Pilg.', 197),
(11031, 'Neomazaea', NULL, 'Urb.', 142),
(11032, 'Neomezia', NULL, 'Votsch', 163),
(11033, 'Neomillspaughia', NULL, 'S.F.Blake', 134),
(11034, 'Neomimosa', NULL, 'Britton & Rose', 68),
(11035, 'Neomirandea', NULL, 'R.M.King & H.Rob.', 18),
(11036, 'Neomitranthes', NULL, 'Legrand', 116),
(11037, 'Neomortonia', NULL, 'Wiehler', 76),
(11038, 'Neomphalea', NULL, 'Pax & K.Hoffm.', 66),
(11039, 'Neomuellera', NULL, 'Briq.', 90),
(11040, 'Neomyrtus', NULL, 'Burret', 116),
(11041, 'Neonelsonia', NULL, 'J.M.Coult. & Rose', 9),
(11042, 'Neonicholsonia', NULL, 'Dammer', 15),
(11043, 'Neonotonia', NULL, 'Lackey', 68),
(11044, 'Neopalissya', NULL, 'Pax', 66),
(11045, 'Neopallasia', NULL, 'Poljakov', 18),
(11046, 'Neopanax', NULL, 'Allan', 13),
(11047, 'Neoparrya', NULL, 'Mathias', 9),
(11048, 'Neopaulia', NULL, 'Pimenov & Kljuykov(SUS)', 9),
(11049, 'Neopeltandra', NULL, 'Gamble(SUS)', 184),
(11050, 'Neopentanisia', NULL, 'Verdc.', 142),
(11051, 'Neopetalonema', NULL, 'Brenan', 105),
(11052, 'Neophloga', NULL, 'Baill.', 15),
(11053, 'Neophylum', NULL, 'Tiegh.', 98),
(11054, 'Neopicrorhiza', NULL, 'D.Y.Hong', 423),
(11055, 'Neopieris', NULL, 'Britton', 64),
(11056, 'Neopilea', NULL, 'Leandri', 171),
(11057, 'Neoplatytaenia', NULL, 'Geld.', 9),
(11058, 'Neopometia', NULL, 'Aubrev.', 148),
(11059, 'Neopreissia', NULL, 'Ulbr.', 5),
(11060, 'Neopringlea', NULL, 'S.Watson', 145),
(11061, 'Neoptychocarpus', NULL, 'Buchheim', 145),
(11062, 'Neopycnocoma', NULL, 'Pax', 66),
(11063, 'Neorapinia', NULL, 'Moldenke', 90),
(11064, 'Neoraputia', NULL, 'Emmerich', 143),
(11065, 'Neorautanenia', NULL, 'Schinz', 68),
(11066, 'Neoregnellia', NULL, 'Urb.', 102),
(11067, 'Neorites', NULL, 'L.S.Sm.', 135),
(11068, 'Neoroepera', NULL, 'Mull.Arg. & F.Muell.', 534),
(11069, 'Neorosea', NULL, 'N.Halle', 142),
(11070, 'Neorudolphia', NULL, 'Britton', 68),
(11071, 'Neosabicea', NULL, 'Wernham', 142),
(11072, 'Neoschimpera', NULL, 'Hemsl.', 142),
(11073, 'Neoschroetera', NULL, 'Briq.', 177),
(11074, 'Neoschumannia', NULL, 'Schltr.', 10),
(11075, 'Neosciadium', NULL, 'Domin', 9),
(11076, 'Neosepicaea', NULL, 'Diels', 22),
(11077, 'Neosieversia', NULL, 'Bolle', 141),
(11078, 'Neosloetiopsis', NULL, 'Engl.', 109),
(11079, 'Neosparton', NULL, 'Griseb.', 173),
(11080, 'Neostachyanthus', NULL, 'Exell & Mendonca', 85),
(11081, 'Neostyphonia', NULL, 'Shafer', 6),
(11082, 'Neotatea', NULL, 'Maguire', 42),
(11083, 'Neotchihatchewia', NULL, 'Rauschert', 197),
(11084, 'Neotessmannia', NULL, 'Burret', 524),
(11085, 'Neothorelia', NULL, 'Gagnep.', 549),
(11086, 'Neothymopsis', NULL, 'Britton & Millsp.', 18),
(11087, 'Neotina', NULL, 'Capuron', 147),
(11088, 'Neotorularia', NULL, 'Hedge & J.Leonard', 197),
(11089, 'Neotrigonostemon', NULL, 'Pax & K.Hoffm.', 66),
(11090, 'Neotuerckheimia', NULL, 'Donn.Sm.', 22),
(11091, 'Neotysonia', NULL, 'Dalla Torre & Harms', 18),
(11092, 'Neoveitchia', NULL, 'Becc.', 15),
(11093, 'Neowashingtonia', NULL, 'Sudw.', 15),
(11094, 'Neowawraea', NULL, 'Rock', 184),
(11095, 'Neowimmeria', NULL, 'O.Deg. & I.Deg.', 30),
(11096, 'Neowollastonia', NULL, 'Wernham ex Ridl.', 10),
(11097, 'Neowormia', NULL, 'Hutch. & Summerh.', 58),
(11098, 'Neoxythece', NULL, 'Aubrev. & Pellegr.', 148),
(11099, 'Neozenkerina', NULL, 'Mildbr.', 1),
(11100, 'Nepa', NULL, 'Webb', 68),
(11101, 'Nepenthandra', NULL, 'S.Moore', 66),
(11102, 'Nepeta', NULL, 'L.', 90),
(11103, 'Nephradenia', NULL, 'Decne.', 10),
(11104, 'Nephrocarpus', NULL, 'Dammer', 15),
(11105, 'Nephrocarya', NULL, 'Candargy', 25),
(11106, 'Nephrodesmus', NULL, 'Schindl.', 68),
(11107, 'Nephromeria', NULL, '(Benth.) Schindl.', 68),
(11108, 'Nephropetalum', NULL, 'B.L.Rob. & Greenm.', 102),
(11109, 'Nephrophyllum', NULL, 'A.Rich.', 46),
(11110, 'Nephrosperma', NULL, 'Balf.f.', 15),
(11111, 'Nephrostylus', NULL, 'Gagnep.', 66),
(11112, 'Nephthytis', NULL, 'Schott', 12),
(11113, 'Nepsera', NULL, 'Naudin', 105),
(11114, 'Neptunia', NULL, 'Lour.', 68),
(11115, 'Neraudia', NULL, 'Gaudich.', 171),
(11116, 'Neriacanthus', NULL, 'Benth.', 1),
(11117, 'Nerisyrenia', NULL, 'Greene', 197),
(11118, 'Nerium', NULL, 'L.', 10),
(11119, 'Nernstia', NULL, 'Urb.', 142),
(11120, 'Nerophila', NULL, 'Naudin', 105),
(11121, 'Nertera', NULL, 'Banks & Sol. ex Gaertn.', 142),
(11122, 'Nesaea', NULL, 'Kunth', 99),
(11123, 'Nescidia', NULL, 'A.Rich.', 142),
(11124, 'Nesiota', NULL, 'Hook.f.', 139),
(11125, 'Neslia', NULL, 'Desv.', 197),
(11126, 'Nesobium', NULL, 'Phil. ex Fuentes', 171),
(11127, 'Nesocaryum', NULL, 'I.M.Johnst.', 25),
(11128, 'Nesocodon', NULL, 'Thulin', 30),
(11129, 'Nesodaphne', NULL, 'Hook.f.', 91),
(11130, 'Nesodoxa', NULL, 'Calest.', 13),
(11131, 'Nesodraba', NULL, 'Greene', 197),
(11132, 'Nesohedyotis', NULL, '(Hook.f.) Bremek.', 142),
(11133, 'Nesoluma', NULL, 'Baill.', 148),
(11134, 'Nesopanax', NULL, 'Seem.', 13),
(11135, 'Nesothamnus', NULL, 'Rydb.', 18),
(11136, 'Nesphostylis', NULL, 'Verdc.', 68),
(11137, 'Nestegis', NULL, 'Raf.', 120),
(11138, 'Nestoria', NULL, 'Urb.', 22),
(11139, 'Nestronia', NULL, 'Raf.', 146),
(11140, 'Nettlera', NULL, 'Raf.', 142),
(11141, 'Nettoa', NULL, 'Baill.', 102),
(11142, 'Neuburgia', NULL, 'Blume', 97),
(11143, 'Neudorfia', NULL, 'Adans.', 154),
(11144, 'Neuhofia', NULL, 'Stokes', 116),
(11145, 'Neumannia', NULL, 'A.Rich.', 73),
(11146, 'Neuontobotrys', NULL, 'O.E.Schulz', 197),
(11147, 'Neuracanthus', NULL, 'Nees', 1),
(11148, 'Neuractis', NULL, 'Cass.', 18),
(11149, 'Neurocalyx', NULL, 'Hook.', 142),
(11150, 'Neurocarpaea', NULL, 'R.Br.(SUI)', 142),
(11151, 'Neurolaena', NULL, 'R.Br.', 18),
(11152, 'Neurolakis', NULL, 'Mattf.', 18),
(11153, 'Neurolobium', NULL, 'Baill.', 10),
(11154, 'Neuropeltis', NULL, 'Wall.', 46),
(11155, 'Neuropeltopsis', NULL, 'Ooststr.', 46),
(11156, 'Neurosperma', NULL, 'Raf.', 49),
(11157, 'Neurospermum', NULL, 'Bartl.(SUO)', 49),
(11158, 'Neurotecoma', NULL, 'K.Schum.', 22),
(11159, 'Neurotheca', NULL, 'Salisb. ex Benth.', 75),
(11160, 'Neustanthus', NULL, 'Benth.', 68),
(11161, 'Neustruevia', NULL, 'Juz.', 90),
(11162, 'Neves-Armondia', NULL, 'K.Schum.', 22),
(11163, 'Neviusia', NULL, 'A.Gray', 141),
(11164, 'Nevrilis', NULL, 'Raf.', 22),
(11165, 'Nevrosperma', NULL, 'Raf.(SUO)', 49),
(11166, 'Newberrya', NULL, 'Torr.', 64),
(11167, 'Newbouldia', NULL, 'Seem. ex Bureau', 22),
(11168, 'Newcastelia', NULL, 'F.Muell.', 90),
(11169, 'Nhandiroba', NULL, 'Adans.', 49),
(11170, 'Nicandra', NULL, 'Adans.', 154),
(11171, 'Nicarago', NULL, 'Britton & Rose', 68),
(11172, 'Nicodemia', NULL, 'Ten.', 150),
(11173, 'Nicolasia', NULL, 'S.Moore', 18),
(11174, 'Nicolletia', NULL, 'A.Gray', 18),
(11175, 'Nicoteba', NULL, 'Lindau', 1),
(11176, 'Nicotiana', NULL, 'L.', 154),
(11177, 'Nidorella', NULL, 'Cass.', 18),
(11178, 'Niebuhria', NULL, 'DC.', 32),
(11179, 'Niedenzua', NULL, 'Pax', 66),
(11180, 'Niedzwedzkia', NULL, 'B.Fedtsch.', 22),
(11181, 'Nierembergia', NULL, 'Ruiz & Pav.', 154),
(11182, 'Nietoa', NULL, 'Seem. ex W.Schaffn.', 49),
(11183, 'Nigrina', NULL, 'L.', 150),
(11184, 'Nikitinia', NULL, 'Iljin', 18),
(11185, 'Nilgirianthus', NULL, 'Bremek.', 1),
(11186, 'Nimiria', NULL, 'Prain ex Craib', 68),
(11187, 'Nimmoia', NULL, 'Wight(SUH)', 106),
(11188, 'Niopa', NULL, '(Benth.) Britton & Rose', 68),
(11189, 'Nipa', NULL, 'Thunb.', 15),
(11190, 'Niphaea', NULL, 'Lindl.', 76),
(11191, 'Niphogeton', NULL, 'Schltdl.', 9),
(11192, 'Nipponanthemum', NULL, '(Kitam.) Kitam.', 18),
(11193, 'Nirarathamnos', NULL, 'Balf.f.', 9),
(11194, 'Niruri', NULL, 'Adans.', 184),
(11195, 'Nisa', NULL, 'Noronha ex Thouars', 145),
(11196, 'Nisomenes', NULL, 'Raf.', 66),
(11197, 'Nispero', NULL, 'Aubrev.', 148),
(11198, 'Nissolia', NULL, 'Jacq.', 68),
(11199, 'Nitraria', NULL, 'L.', 526),
(11200, 'Nitrophila', NULL, 'S.Watson', 5),
(11201, 'Noaea', NULL, 'Moq.', 5),
(11202, 'Nobeliodendron', NULL, 'O.C.Schmidt', 91),
(11203, 'Nobula', NULL, 'Adans.', 142),
(11204, 'Noccaea', NULL, 'Moench', 197),
(11205, 'Noccidium', NULL, 'F.K.Mey.', 197),
(11206, 'Nodocarpaea', NULL, 'A.Gray', 142),
(11207, 'Nodonema', NULL, 'B.L.Burtt', 76),
(11208, 'Nogalia', NULL, 'Verdc.', 25),
(11209, 'Nogo', NULL, 'Baehni', 148),
(11210, 'Nogra', NULL, 'Merr.', 68),
(11211, 'Noisettia', NULL, 'Kunth', 174),
(11212, 'Nolana', NULL, 'L.f.', 154),
(11213, 'Noldeanthus', NULL, 'Knobl.', 120),
(11214, 'Nolletia', NULL, 'Cass.', 18),
(11215, 'Noltea', NULL, 'Rchb.', 139),
(11216, 'Noltia', NULL, 'Schumach. & Thonn.', 61),
(11217, 'Nomaphila', NULL, 'Blume', 1),
(11218, 'Nomismia', NULL, 'Wight & Arn.', 68),
(11219, 'Nomocharis', NULL, 'Franch.', 94),
(11220, 'Nomosa', NULL, 'I.M.Johnst.', 25),
(11221, 'Nonatelia', NULL, 'Aubl.', 142),
(11222, 'Nonea', NULL, 'Medik.', 25),
(11223, 'Norantea', NULL, 'Aubl.', 104),
(11224, 'Normanbya', NULL, 'F.Muell. ex Becc.', 15),
(11225, 'Normandia', NULL, 'Hook.f.', 142),
(11226, 'Normania', NULL, 'Lowe', 154),
(11227, 'Noronhaea', NULL, 'Post & Kuntze(SUO)', 120),
(11228, 'Noronhia', NULL, 'Stadman ex Thouars', 120),
(11229, 'Northea', NULL, 'Hook.f.(SUO)', 148),
(11230, 'Northia', NULL, 'Hook.f.', 148),
(11231, 'Northiopsis', NULL, 'Kaneh.', 148),
(11232, 'Nosema', NULL, 'Prain', 90),
(11233, 'Nostolachma', NULL, 'T.Durand', 142),
(11234, 'Notanthera', NULL, '(DC.) G.Don', 98),
(11235, 'Notechidnopsis', NULL, 'Lavranos & Bleck', 10),
(11236, 'Notelaea', NULL, 'Vent.', 120),
(11237, 'Notelea', NULL, 'Raf.(SUO)', 120),
(11238, 'Noterophila', NULL, 'Mart.', 105),
(11239, 'Nothoalsomitra', NULL, 'Telford', 49),
(11240, 'Nothobaccharis', NULL, 'R.M.King & H.Rob.', 18),
(11241, 'Nothocalais', NULL, 'Greene', 18),
(11242, 'Nothocarpus', NULL, 'Post & Kuntze', 142),
(11243, 'Nothocestrum', NULL, 'A.Gray', 154),
(11244, 'Nothochelone', NULL, '(A.Gray) Straw', 423),
(11245, 'Nothochilus', NULL, 'Radlk.', 400),
(11246, 'Nothocissus', NULL, '(Miq.) Latiff', 181),
(11247, 'Nothocnestis', NULL, 'Miq.', 38),
(11248, 'Nothocnide', NULL, 'Blume ex Chew', 171),
(11249, 'Nothofagus', NULL, 'Blume', 527),
(11250, 'Notholirion', NULL, 'Wall. ex Boiss.', 94),
(11251, 'Nothomyrcia', NULL, 'Kausel', 116),
(11252, 'Nothopanax', NULL, 'Miq.', 13),
(11253, 'Nothopegiopsis', NULL, 'Lauterb.', 6),
(11254, 'Nothophlebia', NULL, 'Standl.', 142),
(11255, 'Nothoprotium', NULL, 'Miq.', 6),
(11256, 'Nothoruellia', NULL, 'Bremek.', 1),
(11257, 'Nothosaerva', NULL, 'Wight', 5),
(11258, 'Nothosmyrnium', NULL, 'Miq.', 9),
(11259, 'Nothospondias', NULL, 'Engl.', 151),
(11260, 'Nothotsuga', NULL, 'Hu ex C.N.Page', 129),
(11261, 'Noticastrum', NULL, 'DC.', 18),
(11262, 'Notiosciadium', NULL, 'Speg.', 9),
(11263, 'Notobasis', NULL, '(Cass.) Cass.', 18),
(11264, 'Notobuxus', NULL, 'Oliv.', 28),
(11265, 'Notocentrum', NULL, 'Naudin', 105),
(11266, 'Notoceras', NULL, 'R.Br.', 197),
(11267, 'Notochaete', NULL, 'Benth.', 90),
(11268, 'Notodon', NULL, 'Urb.', 68),
(11269, 'Notodontia', NULL, 'Pierre ex Pit.', 142),
(11270, 'Notonia', NULL, 'DC.', 18),
(11271, 'Notoniopsis', NULL, 'B.Nord.', 18),
(11272, 'Notophaena', NULL, 'Miers', 139),
(11273, 'Notopleura', NULL, '(Hook.f.) Bremek.', 142),
(11274, 'Notopora', NULL, 'Hook.f.', 64),
(11275, 'Notoptera', NULL, 'Urb.', 18),
(11276, 'Notopterygium', NULL, 'Boissieu', 9),
(11277, 'Notoseris', NULL, 'C.Shih', 18),
(11278, 'Notospartium', NULL, 'Hook.f.', 68),
(11279, 'Notothixos', NULL, 'Oliv.', 146),
(11280, 'Notothlaspi', NULL, 'Hook.f.', 197),
(11281, 'Nototriche', NULL, 'Turcz.', 102),
(11282, 'Nototrichium', NULL, '(A.Gray) W.F.Hillebr.', 5),
(11283, 'Notoxylinon', NULL, 'Lewton', 102),
(11284, 'Nouelia', NULL, 'Franch.', 18),
(11285, 'Nouettea', NULL, 'Pierre', 10),
(11286, 'Nouletia', NULL, 'Endl.', 22),
(11287, 'Novatilia', NULL, 'Wight(SUO)', 142),
(11288, 'Novenia', NULL, 'Freire', 18),
(11289, 'Novosieversia', NULL, 'F.Bolle', 141),
(11290, 'Nowickea', NULL, 'J.Martinez & J.A.McDonald', 128),
(11291, 'Noyera', NULL, 'Trecul', 109),
(11292, 'Nucularia', NULL, 'Batt.', 5),
(11293, 'Nudilus', NULL, 'Raf.', 120),
(11294, 'Nuihonia', NULL, 'Dop', 64),
(11295, 'Numaeacampa', NULL, 'Gagnep.', 30),
(11296, 'Nunnezharia', NULL, 'Ruiz & Pav.', 15),
(11297, 'Nunnezia', NULL, 'Willd.', 15),
(11298, 'Nurmonia', NULL, 'Harms', 106),
(11299, 'Nuttallanthus', NULL, 'D.A.Sutton', 150),
(11300, 'Nuttallia', NULL, 'Torr. & A.Gray', 141),
(11301, 'Nuytsia', NULL, 'R.Br. ex G.Don', 98),
(11302, 'Nyctaginia', NULL, 'Choisy', 117),
(11303, 'Nyctanthes', NULL, 'L.', 120),
(11304, 'Nycterinia', NULL, 'D.Don', 150),
(11305, 'Nycteristion', NULL, 'Ruiz & Pav.', 148),
(11306, 'Nycterium', NULL, 'Vent.', 154),
(11307, 'Nycticalanthus', NULL, 'Ducke', 143),
(11308, 'Nyctocalos', NULL, 'Teijsm. & Binn.', 22),
(11309, 'Nylandtia', NULL, 'Dumort.', 133),
(11310, 'Nymania', NULL, 'K.Schum.(SUH)', 106),
(11311, 'Nymphanthus', NULL, 'Lour.', 184),
(11312, 'Nypa', NULL, 'Steck', 15),
(11313, 'Nyssa', NULL, 'Gronov. ex L.', 528),
(11314, 'Nyssanthes', NULL, 'R.Br.', 5),
(11315, 'Nzidora', NULL, 'A.Chev.(SUI)', 148),
(11316, 'Oaxacania', NULL, 'B.L.Rob. & Greenm.', 18),
(11317, 'Obbea', NULL, 'Hook.f.', 142),
(11318, 'Obesia', NULL, 'Haw.', 10),
(11319, 'Obetia', NULL, 'Gaudich.', 171),
(11320, 'Obione', NULL, 'Gaertn.', 5),
(11321, 'Oblivia', NULL, 'Strother', 18),
(11322, 'Obolaria', NULL, 'L.', 75),
(11323, 'Obolinga', NULL, 'Barneby', 68),
(11324, 'Ocalia', NULL, 'Klotzsch', 66),
(11325, 'Oceanopapaver', NULL, 'Guillaumin', 102),
(11326, 'Ochetophila', NULL, 'Poepp. ex Reissek', 139),
(11327, 'Ochocoa', NULL, 'Pierre', 114),
(11328, 'Ochoterenaea', NULL, 'F.A.Barkley', 6),
(11329, 'Ochreinauclea', NULL, 'Ridsdale & Bakh.f.', 142),
(11330, 'Ochrocarpos', NULL, 'Thouars', 42),
(11331, 'Ochrocephala', NULL, 'Dittrich', 18),
(11332, 'Ochroluma', NULL, 'Baill.', 148),
(11333, 'Ochronerium', NULL, 'Baill.', 10),
(11334, 'Ochrosia', NULL, 'Juss.', 10),
(11335, 'Ochrosperma', NULL, 'Trudgen', 116),
(11336, 'Ochrothallus', NULL, 'Pierre ex Baill.', 148),
(11337, 'Ochthephilus', NULL, 'Wurdack', 105),
(11338, 'Ochthocosmus', NULL, 'Benth.', 86),
(11339, 'Ochthodium', NULL, 'DC.', 197),
(11340, 'Ocimastrum', NULL, 'Rupr.', 121),
(11341, 'Ocimum', NULL, 'L.', 90),
(11342, 'Oclemena', NULL, 'Greene', 18),
(11343, 'Octamyrtus', NULL, 'Diels', 116),
(11344, 'Octavia', NULL, 'DC.', 142),
(11345, 'Octoceras', NULL, 'Bunge', 197),
(11346, 'Octodon', NULL, 'Thonn.', 142),
(11347, 'Octolepis', NULL, 'Oliv.', 164),
(11348, 'Octolobus', NULL, 'Welw.', 102),
(11349, 'Octomeria', NULL, 'Pfeiff.(SUO)', 123),
(11350, 'Octomeron', NULL, 'Robyns', 90),
(11351, 'Octonum', NULL, 'Raf.', 105),
(11352, 'Octopleura', NULL, 'Griseb.', 105),
(11353, 'Octosomatium', NULL, 'Gagnep.', 25),
(11354, 'Octospermum', NULL, 'Airy Shaw', 66),
(11355, 'Octotheca', NULL, 'R.Vig.', 13),
(11356, 'Octotropis', NULL, 'Bedd.', 142),
(11357, 'Ocyroe', NULL, 'Phil.', 18),
(11358, 'Oddoniodendron', NULL, 'De Wild.', 68),
(11359, 'Odicardis', NULL, 'Raf.', 423),
(11360, 'Odina', NULL, 'Roxb.', 6),
(11361, 'Odixia', NULL, 'Orchard', 18),
(11362, 'Odonellia', NULL, 'K.R.Robertson', 46),
(11363, 'Odonostephana', NULL, 'Alexander', 10),
(11364, 'Odontadenia', NULL, 'Benth.', 10),
(11365, 'Odontandra', NULL, 'Willd. ex Roem. & Schult.', 106),
(11366, 'Odontanthera', NULL, 'Wight', 10),
(11367, 'Odonteilema', NULL, 'Turcz.', 66),
(11368, 'Odontella', NULL, 'Tiegh.(SUH)', 98),
(11369, 'Odontites', NULL, 'Ludw.', 400),
(11370, 'Odontocarya', NULL, 'Miers', 107),
(11371, 'Odontocline', NULL, 'B.Nord.', 18),
(11372, 'Odontocyclus', NULL, 'Turcz.', 197),
(11373, 'Odontonema', NULL, 'Nees', 1),
(11374, 'Odontonemella', NULL, 'Lindau', 1),
(11375, 'Odontophyllum', NULL, 'Sreem.(SUH)', 1),
(11376, 'Odontosiphon', NULL, 'M.Roem.', 106),
(11377, 'Odontostelma', NULL, 'Rendle', 10),
(11378, 'Odontostigma', NULL, 'Zoll. & Moritzi', 1),
(11379, 'Odontotecoma', NULL, 'Bureau & K.Schum.', 22),
(11380, 'Odontotrichum', NULL, 'Zucc.', 18),
(11381, 'Odosicyos', NULL, 'Keraudren', 49),
(11382, 'Odotalon', NULL, 'Raf.', 66),
(11383, 'Odyendea', NULL, 'Pierre ex Engl.', 151),
(11384, 'Oecopetalum', NULL, 'Greenm. & C.H.Thomps.', 85),
(11385, 'Oedematopus', NULL, 'Planch. & Triana', 42),
(11386, 'Oedera', NULL, 'L.', 18),
(11387, 'Oedibasis', NULL, 'Koso-Pol.', 9),
(11388, 'Oedicephalus', NULL, 'Nevski', 68),
(11389, 'Oedina', NULL, 'Tiegh.', 98),
(11390, 'Oemleria', NULL, 'Rchb.', 141),
(11391, 'Oenanthe', NULL, 'L.', 9),
(11392, 'Oenosciadium', NULL, 'Pomel', 9),
(11393, 'Oenothera', NULL, 'L.', 121),
(11394, 'Oenotheridium', NULL, 'Reiche', 121),
(11395, 'Oerstedianthus', NULL, 'Lundell', 115),
(11396, 'Oerstedina', NULL, 'Wiehler', 76),
(11397, 'Ofaiston', NULL, 'Raf.', 5),
(11398, 'Oftia', NULL, 'Adans.', 150),
(11399, 'Ogastemma', NULL, 'Brummitt', 25),
(11400, 'Ogcodeia', NULL, 'Bureau', 109),
(11401, 'Ohigginsis', NULL, 'Ruiz & Pav.', 142),
(11402, 'Oianthus', NULL, 'Benth.', 10),
(11403, 'Oiospermum', NULL, 'Less.', 18),
(11404, 'Oistanthera', NULL, 'Markgr.', 10),
(11405, 'Oistonema', NULL, 'Schltr.', 10),
(11406, 'Okenia', NULL, 'Schltdl. & Cham.', 117),
(11407, 'Okoubaka', NULL, 'Pellegr. & Normand', 146),
(11408, 'Oldenburgia', NULL, 'Less.', 18),
(11409, 'Oldenlandia', NULL, 'L.', 142),
(11410, 'Oldenlandiopsis', NULL, 'Terrell & W.H.Lewis', 142),
(11411, 'Oldfieldia', NULL, 'Benth. & Hook.', 534),
(11412, 'Olearia', NULL, 'Moench', 18),
(11413, 'Oleiocarpon', NULL, 'Dwyer', 68),
(11414, 'Olgaea', NULL, 'Iljin', 18),
(11415, 'Oligactis', NULL, '(Kunth) Cass.', 18),
(11416, 'Oligandra', NULL, 'Less.', 18),
(11417, 'Oliganthes', NULL, 'Cass.', 18),
(11418, 'Oligarrhena', NULL, 'R.Br.', 64),
(11419, 'Oligocarpus', NULL, 'Less.', 18),
(11420, 'Oligoceras', NULL, 'Gagnep.', 66),
(11421, 'Oligochaeta', NULL, '(DC.) K.Koch', 18),
(11422, 'Oligocladus', NULL, 'Chodat & Wilczek', 9),
(11423, 'Oligocodon', NULL, 'Keay', 142),
(11424, 'Oligogynium', NULL, 'Engl.', 12),
(11425, 'Oligoscias', NULL, 'Seem.', 13),
(11426, 'Oligospermum', NULL, 'D.Y.Hong', 150),
(11427, 'Oligostemon', NULL, 'Benth.', 68),
(11428, 'Oligothrix', NULL, 'DC.', 18),
(11429, 'Olisbaea', NULL, 'Hook.f.(SUO)', 105),
(11430, 'Olisbea', NULL, 'DC.', 105),
(11431, 'Olivaea', NULL, 'Sch.Bip. ex Benth.', 18),
(11432, 'Oliveranthus', NULL, 'Rose', 48),
(11433, 'Oliverella', NULL, 'Tiegh.', 98),
(11434, 'Oliveria', NULL, 'Vent.', 9),
(11435, 'Olmediella', NULL, 'Baill.', 145),
(11436, 'Olmedioperebea', NULL, 'Ducke', 109),
(11437, 'Olmediophaena', NULL, 'H.Karst.', 109),
(11438, 'Olmediopsis', NULL, 'H.Karst.', 109),
(11439, 'Olneya', NULL, 'A.Gray', 68),
(11440, 'Olostyla', NULL, 'DC.', 142),
(11441, 'Oluntos', NULL, 'Raf.', 109),
(11442, 'Olymposciadium', NULL, 'H.Wolff', 9),
(11443, 'Omalanthus', NULL, 'A.Juss.(SUO)', 66),
(11444, 'Omalocaldos', NULL, 'Hook.f.(SUO)', 142),
(11445, 'Omalocarpus', NULL, 'Choux', 147),
(11446, 'Omalotheca', NULL, 'Cass.', 18),
(11447, 'Omania', NULL, 'S.Moore', 150),
(11448, 'Ombrocharis', NULL, 'Hand.-Mazz.', 90),
(11449, 'Omiltemia', NULL, 'Standl.', 142),
(11450, 'Omphacomeria', NULL, '(Endl.) A.DC.', 146),
(11451, 'Omphalandria', NULL, 'P.Browne', 66),
(11452, 'Omphalobium', NULL, 'Gaertn.', 45),
(11453, 'Omphalodes', NULL, 'Mill.', 25),
(11454, 'Omphalogonus', NULL, 'Baill.', 10),
(11455, 'Omphalolappula', NULL, 'Brand', 25),
(11456, 'Omphalopappus', NULL, 'O.Hoffm.', 18),
(11457, 'Omphalophthalmum', NULL, 'H.Karst.', 10),
(11458, 'Omphalopus', NULL, 'Naudin', 105),
(11459, 'Omphalotrigonotis', NULL, 'W.T.Wang', 25),
(11460, 'Omphalotrix', NULL, 'Maxim.', 400),
(11461, 'Onagra', NULL, 'Mill.(SUS)', 121),
(11462, 'Oncella', NULL, 'Tiegh.', 98),
(11463, 'Oncinema', NULL, 'Arn.', 10),
(11464, 'Oncinocalyx', NULL, 'F.Muell.', 90),
(11465, 'Oncinotis', NULL, 'Benth.', 10),
(11466, 'Oncocalamus', NULL, '(G.Mann & H.Wendl.) Hook.f.', 15),
(11467, 'Oncocalyx', NULL, 'Tiegh.', 98),
(11468, 'Oncocarpus', NULL, 'A.Gray', 6),
(11469, 'Oncosiphon', NULL, 'Kallersjo', 18),
(11470, 'Oncostemma', NULL, 'K.Schum.', 10),
(11471, 'Oncostemum', NULL, 'A.Juss.', 115),
(11472, 'Oncostylus', NULL, '(Schltdl.) Bolle', 141),
(11473, 'Ondetia', NULL, 'Benth.', 18),
(11474, 'Ongokea', NULL, 'Pierre', 119),
(11475, 'Onix', NULL, 'Medik.', 68),
(11476, 'Onobrychis', NULL, 'Mill.', 68),
(11477, 'Onochiles', NULL, 'Bubani', 25),
(11478, 'Onohualcoa', NULL, 'Lundell', 22),
(11479, 'Ononis', NULL, 'L.', 68),
(11480, 'Onopordum', NULL, 'L.', 18),
(11481, 'Onoseris', NULL, 'Willd.', 18),
(11482, 'Onosma', NULL, 'L.', 25),
(11483, 'Onosmodium', NULL, 'Michx.', 25),
(11484, 'Onosuris', NULL, 'Raf.', 121),
(11485, 'Onosurus', NULL, 'G.Don(SUO)', 121),
(11486, 'Onuris', NULL, 'Phil.', 197),
(11487, 'Onus', NULL, 'Gilli', 1),
(11488, 'Onychacanthus', NULL, 'Nees', 1),
(11489, 'Onychopetalum', NULL, 'R.E.Fr.', 8),
(11490, 'Oocarpon', NULL, 'Micheli', 121),
(11491, 'Oonopsis', NULL, '(Nutt.) Greene', 18),
(11492, 'Oosterdickia', NULL, 'Boehm.', 50),
(11493, 'Oothrinax', NULL, 'O.F.Cook', 15),
(11494, 'Opa', NULL, 'Lour.', 116),
(11495, 'Opanea', NULL, 'Raf.', 116),
(11496, 'Oparanthus', NULL, 'Sherff', 18),
(11497, 'Opercularia', NULL, 'Gaertn.', 142),
(11498, 'Operculicarya', NULL, 'H.Perrier', 6),
(11499, 'Operculina', NULL, 'Silva Manso', 46),
(11500, 'Ophellantha', NULL, 'Standl.', 66),
(11501, 'Ophiocarpus', NULL, '(Bunge) Ikonn.', 68),
(11502, 'Ophiocaulon', NULL, 'Hook.f.', 127),
(11503, 'Ophiocephalus', NULL, 'Wiggins', 400),
(11504, 'Ophiocolea', NULL, 'H.Perrier', 22),
(11505, 'Ophione', NULL, 'Schott', 12),
(11506, 'Ophionella', NULL, 'Bruyns', 10),
(11507, 'Ophiorrhiza', NULL, 'L.', 142),
(11508, 'Ophiorrhiziphyllon', NULL, 'Kurz', 1),
(11509, 'Ophiria', NULL, 'Becc.', 15),
(11510, 'Ophrestia', NULL, 'H.M.L.Forbes', 68),
(11511, 'Ophryococcus', NULL, 'Oerst.', 142),
(11512, 'Ophryosporus', NULL, 'Meyen', 18),
(11513, 'Ophrypetalum', NULL, 'Diels', 8),
(11514, 'Ophthalmoblapton', NULL, 'Allemao', 66),
(11515, 'Opisthiolepis', NULL, 'L.S.Sm.', 135),
(11516, 'Opisthocentra', NULL, 'Hook.f.', 105),
(11517, 'Opisthopappus', NULL, 'C.Shih', 18),
(11518, 'Opithandra', NULL, 'B.L.Burtt', 76),
(11519, 'Oplexion', NULL, 'Raf.', 25),
(11520, 'Oplonia', NULL, 'Raf.', 1),
(11521, 'Oplopanax', NULL, '(Torr. & A.Gray) Miq.', 13),
(11522, 'Oplukion', NULL, 'Raf.', 154),
(11523, 'Opocunonia', NULL, 'Schltr.', 50),
(11524, 'Opoidea', NULL, 'Lindl.', 9),
(11525, 'Opopanax', NULL, 'W.D.J.Koch', 9),
(11526, 'Opsago', NULL, 'Raf.', 154),
(11527, 'Opsiandra', NULL, 'O.F.Cook', 15),
(11528, 'Opsianthes', NULL, 'Lilja', 121),
(11529, 'Oraniopsis', NULL, 'J.Dransf., A.K.Irvine & N.W.Uhl', 15),
(11530, 'Oraoma', NULL, 'Turcz.', 106),
(11531, 'Orbea', NULL, 'Haw.', 10),
(11532, 'Orbeanthus', NULL, 'L.C.Leach', 10),
(11533, 'Orbeopsis', NULL, 'L.C.Leach', 10),
(11534, 'Orbexilum', NULL, 'Raf.', 68),
(11535, 'Orbicularia', NULL, 'Baill.', 184),
(11536, 'Orbignya', NULL, 'Mart. ex Endl.', 15),
(11537, 'Orchadocarpa', NULL, 'Ridl.', 76),
(11538, 'Orchidocarpum', NULL, 'Michx.', 8),
(11539, 'Orchipeda', NULL, 'Blume', 10),
(11540, 'Oreacanthus', NULL, 'Benth.', 1),
(11541, 'Oreanthes', NULL, 'Benth.', 64),
(11542, 'Oreas', NULL, 'Cham. & Schltdl.', 197),
(11543, 'Oregandra', NULL, 'Standl.', 142),
(11544, 'Oreoblastus', NULL, 'Suslova', 197),
(11545, 'Oreobliton', NULL, 'Durieu', 5),
(11546, 'Oreobolopsis', NULL, 'Koyama & Guagl.', 55),
(11547, 'Oreobolus', NULL, 'R.Br.', 55),
(11548, 'Oreocallis', NULL, 'R.Br.', 135),
(11549, 'Oreocarya', NULL, 'Greene', 25),
(11550, 'Oreocaryon', NULL, 'Kuntze ex K.Schum.', 142),
(11551, 'Oreocharis', NULL, '(Decne.) Lindl.(SUH)', 76),
(11552, 'Oreochrysum', NULL, 'Rydb.', 18),
(11553, 'Oreocome', NULL, 'Edgew.', 9),
(11554, 'Oreocosmus', NULL, 'Naudin', 105),
(11555, 'Oreodaphne', NULL, 'Nees & Mart.', 91),
(11556, 'Oreodendron', NULL, 'C.T.White', 164),
(11557, 'Oreodoxa', NULL, 'Willd.', 15),
(11558, 'Oreogenia', NULL, 'I.M.Johnst.(SUH)', 25),
(11559, 'Oreogeum', NULL, '(Ser.) E.I.Golubk.', 141),
(11560, 'Oreograstis', NULL, 'K.Schum.', 55),
(11561, 'Oreoherzogia', NULL, 'W.Vent', 139),
(11562, 'Oreoleysera', NULL, 'Bremer', 18),
(11563, 'Oreoloma', NULL, 'Botsch.', 197),
(11564, 'Oreomitra', NULL, 'Diels', 8),
(11565, 'Oreomunnea', NULL, 'Oerst.', 87),
(11566, 'Oreomyrrhis', NULL, 'Endl.', 9),
(11567, 'Oreonana', NULL, 'Jeps.', 9),
(11568, 'Oreonesion', NULL, 'J.Raynal', 75),
(11569, 'Oreophylax', NULL, 'Endl.', 75),
(11570, 'Oreophysa', NULL, '(Bunge ex Boiss.) Bornm.', 68),
(11571, 'Oreophyton', NULL, 'O.E.Schulz', 197),
(11572, 'Oreopolus', NULL, 'Schltdl.', 142),
(11573, 'Oreoporanthera', NULL, 'Hutch.', 184),
(11574, 'Oreorhamnus', NULL, 'Ridl.', 139),
(11575, 'Oreoschimperella', NULL, 'Rauschert', 9),
(11576, 'Oreosciadium', NULL, 'Wedd.', 9),
(11577, 'Oreosedum', NULL, 'Grulich', 48),
(11578, 'Oreosolen', NULL, 'Hook.f.', 150),
(11579, 'Oreospacus', NULL, 'Phil.', 90),
(11580, 'Oreosparte', NULL, 'Schltr.', 10),
(11581, 'Oreostemma', NULL, 'Greene', 18),
(11582, 'Oreosyce', NULL, 'Hook.f.', 49),
(11583, 'Oreothyrsus', NULL, 'Lindau', 1),
(11584, 'Oreoxis', NULL, 'Raf.', 9),
(11585, 'Oresitrophe', NULL, 'Bunge', 149),
(11586, 'Orfilea', NULL, 'Baill.', 66),
(11587, 'Orias', NULL, 'Dode', 99),
(11588, 'Oribasia', NULL, 'Schreb.', 142),
(11589, 'Oriciopsis', NULL, 'Engl.', 143),
(11590, 'Origanum', NULL, 'L.', 90),
(11591, 'Orinocoa', NULL, 'Raf.', 154),
(11592, 'Orites', NULL, 'R.Br.', 135),
(11593, 'Orithalia', NULL, 'Blume', 76),
(11594, 'Oritrephes', NULL, 'Ridl.', 105),
(11595, 'Oritrophium', NULL, '(Kunth) Cuatrec.', 18),
(11596, 'Orixa', NULL, 'Thunb.', 143),
(11597, 'Orlaya', NULL, 'Hoffm.', 9),
(11598, 'Ormenis', NULL, 'Cass.', 18),
(11599, 'Ormocarpopsis', NULL, 'R.Vig.', 68),
(11600, 'Ormopterum', NULL, 'Schischk.', 9),
(11601, 'Ormosciadium', NULL, 'Boiss.', 9),
(11602, 'Ormosiopsis', NULL, 'Ducke', 68),
(11603, 'Ormosolenia', NULL, 'Tausch', 9),
(11604, 'Ornanthes', NULL, 'Raf.', 120),
(11605, 'Ornichia', NULL, 'Klack.', 75),
(11606, 'Ornithoboea', NULL, 'Parish ex C.B.Clarke', 76),
(11607, 'Ornithocarpa', NULL, 'Rose', 197),
(11608, 'Ornithopus', NULL, 'L.', 68),
(11609, 'Ornithostaphylos', NULL, 'Small', 64),
(11610, 'Ornithrophus', NULL, 'Bojer ex Engl.(SUI)', 50),
(11611, 'Ornus', NULL, 'Boehm.', 120),
(11612, 'Orobanche', NULL, 'L.', 400),
(11613, 'Orobus', NULL, 'L.', 68),
(11614, 'Orochaenactis', NULL, 'Coville', 18),
(11615, 'Orogenia', NULL, 'S.Watson', 9),
(11616, 'Orontium', NULL, 'L.', 12),
(11617, 'Orophaca', NULL, 'Nutt.', 68),
(11618, 'Orophochilus', NULL, 'Lindau', 1),
(11619, 'Orophoma', NULL, 'Spruce', 15),
(11620, 'Orostachys', NULL, 'Fisch. ex A.Berger', 48),
(11621, 'Orothamnus', NULL, 'Pappe ex Hook.', 135),
(11622, 'Orphanidesia', NULL, 'Boiss. & Balansa', 64),
(11623, 'Orphanodendron', NULL, 'Barneby & J.W.Grimes', 68),
(11624, 'Orphium', NULL, 'E.Mey.', 75),
(11625, 'Orthaea', NULL, 'Klotzsch', 64),
(11626, 'Orthandra', NULL, 'Burret', 102),
(11627, 'Orthantha', NULL, '(Benth.) Wettst.', 150),
(11628, 'Orthanthe', NULL, 'Lem.', 76),
(11629, 'Orthanthella', NULL, 'Rauschert', 150),
(11630, 'Orthanthera', NULL, 'Wight', 10),
(11631, 'Orthechites', NULL, 'Urb.', 10),
(11632, 'Orthilia', NULL, 'Raf.', 64),
(11633, 'Orthion', NULL, 'Standl. & Steyerm.', 174),
(11634, 'Orthocarpus', NULL, 'Nutt.', 400),
(11635, 'Orthodon', NULL, 'Benth. & Oliv.', 90),
(11636, 'Orthogoneuron', NULL, 'Gilg', 105),
(11637, 'Orthogynium', NULL, 'Baill.', 107),
(11638, 'Ortholobium', NULL, 'Gagnep.', 68),
(11639, 'Ortholoma', NULL, 'Hanst.', 76),
(11640, 'Orthomene', NULL, 'Barneby & Krukoff', 107),
(11641, 'Orthopichonia', NULL, 'H.Huber', 10),
(11642, 'Orthopterygium', NULL, 'Hemsl.', 6),
(11643, 'Orthosia', NULL, 'Decne.', 10),
(11644, 'Orthosiphon', NULL, 'Benth.', 90),
(11645, 'Orthosphenia', NULL, 'Standl.', 38),
(11646, 'Orthostemma', NULL, 'Wall. ex Voigt(SUI)', 142),
(11647, 'Orthostemon', NULL, 'O.Berg', 116),
(11648, 'Orthotactus', NULL, 'Nees', 1),
(11649, 'Orthotheca', NULL, 'Pichon(SUH)', 22),
(11650, 'Orthurus', NULL, 'Juz.', 141),
(11651, 'Orumbella', NULL, 'J.M.Coult. & Rose', 9),
(11652, 'Orychophragmus', NULL, 'Bunge', 197),
(11653, 'Oryctanthus', NULL, '(Griseb.) Eichler', 98),
(11654, 'Oryctes', NULL, 'S.Watson', 154),
(11655, 'Oryctina', NULL, 'Tiegh.', 98),
(11656, 'Osa', NULL, 'Aiello', 142),
(11657, 'Osbeckia', NULL, 'L.', 105),
(11658, 'Osbeckiastrum', NULL, 'Naudin', 105),
(11659, 'Osbertia', NULL, 'Greene', 18),
(11660, 'Osbornia', NULL, 'F.Muell.', 116),
(11661, 'Oschatzia', NULL, 'Walp.', 9),
(11662, 'Oshimella', NULL, 'Masam. & Suzuki', 76),
(11663, 'Osmaronia', NULL, 'Greene', 141),
(11664, 'Osmhydrophora', NULL, 'Barb.Rodr.', 22),
(11665, 'Osmiopsis', NULL, 'R.M.King & H.Rob.', 18),
(11666, 'Osmitopsis', NULL, 'Cass.', 18),
(11667, 'Osmorhiza', NULL, 'Raf.', 9),
(11668, 'Ossifraga', NULL, 'Rumph.', 66),
(11669, 'Osteocarpum', NULL, 'F.Muell.', 5),
(11670, 'Osteocarpus', NULL, 'Phil.', 154),
(11671, 'Osteomeles', NULL, 'Lindl.', 141),
(11672, 'Osteospermum', NULL, 'L.', 18),
(11673, 'Ostericum', NULL, 'Hoffm.', 9),
(11674, 'Ostodes', NULL, 'Blume', 66),
(11675, 'Ostrowskia', NULL, 'Regel', 30),
(11676, 'Ostrya', NULL, 'Scop.', 21),
(11677, 'Ostryocarpus', NULL, 'Hook.f.', 68),
(11678, 'Ostryoderris', NULL, 'Dunn', 68),
(11679, 'Ostryopsis', NULL, 'Decne.', 21),
(11680, 'Osyridicarpos', NULL, 'A.DC.', 146),
(11681, 'Osyris', NULL, 'L.', 146),
(11682, 'Otacanthus', NULL, 'Lindl.', 423),
(11683, 'Otanthera', NULL, 'Blume', 105),
(11684, 'Otanthus', NULL, 'Hoffmanns. & Link', 18),
(11685, 'Oteiza', NULL, 'La Llave', 18),
(11686, 'Otherodendron', NULL, 'Makino', 38),
(11687, 'Otholobium', NULL, 'C.H.Stirt.', 68),
(11688, 'Othonna', NULL, 'L.', 18),
(11689, 'Otilix', NULL, 'Raf.', 154),
(11690, 'Otiophora', NULL, 'Zucc.', 142),
(11691, 'Otocalyx', NULL, 'Brandegee', 142),
(11692, 'Otocarpus', NULL, 'Durieu', 197),
(11693, 'Otocephalus', NULL, 'Chiov.', 142),
(11694, 'Otomeria', NULL, 'Benth.', 142),
(11695, 'Otonephelium', NULL, 'Radlk.', 147),
(11696, 'Otopappus', NULL, 'Benth.', 18),
(11697, 'Otophora', NULL, 'Blume', 147),
(11698, 'Otoptera', NULL, 'DC.', 68),
(11699, 'Otospermum', NULL, 'Willk.', 18),
(11700, 'Otostegia', NULL, 'Benth.', 90),
(11701, 'Otostemma', NULL, 'Blume', 10),
(11702, 'Otoxalis', NULL, 'Small', 124),
(11703, 'Ottoa', NULL, 'Kunth', 9),
(11704, 'Ottonia', NULL, 'Spreng.', 130),
(11705, 'Ottoschmidtia', NULL, 'Urb.', 142),
(11706, 'Ottoschulzia', NULL, 'Urb.', 85),
(11707, 'Oudneya', NULL, 'R.Br.', 197),
(11708, 'Ourisia', NULL, 'Comm. ex Juss.', 423),
(11709, 'Ourisianthus', NULL, 'Bonati', 150),
(11710, 'Ourouparia', NULL, 'Aubl.', 142),
(11711, 'Outarda', NULL, 'Dumort.(SUO)', 142),
(11712, 'Outreya', NULL, 'Jaub. & Spach', 18),
(11713, 'Ovaria', NULL, 'Fabr.', 154),
(11714, 'Ovidia', NULL, 'Meisn.', 164),
(11715, 'Ovilla', NULL, 'Adans.', 30),
(11716, 'Owataria', NULL, 'Matsum.', 66),
(11717, 'Owenia', NULL, 'F.Muell.', 106),
(11718, 'Oxalis', NULL, 'L.', 124),
(11719, 'Oxalistylis', NULL, 'Baill.', 184),
(11720, 'Oxanthera', NULL, 'Montrouz.', 143),
(11721, 'Oxera', NULL, 'Labill.', 90),
(11722, 'Oxybaphus', NULL, 'L''Her. ex Willd.', 117),
(11723, 'Oxycarpha', NULL, 'S.F.Blake', 18),
(11724, 'Oxycarpus', NULL, 'Lour.', 42),
(11725, 'Oxycaryum', NULL, 'Nees', 55),
(11726, 'Oxyceros', NULL, 'Lour.', 142),
(11727, 'Oxychlamys', NULL, 'Schltr.', 76),
(11728, 'Oxycoccus', NULL, 'Hill', 64),
(11729, 'Oxydectes', NULL, 'Kuntze', 66),
(11730, 'Oxydendrum', NULL, 'DC.', 64),
(11731, 'Oxyglottis', NULL, '(Bunge) Nevski', 68),
(11732, 'Oxygonum', NULL, 'Burch. ex Campd.', 134),
(11733, 'Oxylaena', NULL, 'Benth. ex Anderb.', 18),
(11734, 'Oxylobium', NULL, 'Andrews', 68),
(11735, 'Oxylobus', NULL, '(Moq. ex DC.) A.Gray', 18),
(11736, 'Oxymeris', NULL, 'DC.', 105),
(11737, 'Oxymitra', NULL, '(Blume) Hook.f. & Thomson(SUH)', 8),
(11738, 'Oxymyrrhine', NULL, 'Schauer', 116),
(11739, 'Oxyosmyles', NULL, 'Speg.', 25),
(11740, 'Oxypappus', NULL, 'Benth.', 18),
(11741, 'Oxypetalum', NULL, 'R.Br.', 10),
(11742, 'Oxyphyllum', NULL, 'Phil.', 18),
(11743, 'Oxypolis', NULL, 'Raf.', 9),
(11744, 'Oxypteryx', NULL, 'Greene', 10),
(11745, 'Oxyrhynchus', NULL, 'Brandegee', 68),
(11746, 'Oxyria', NULL, 'Hill', 134),
(11747, 'Oxys', NULL, 'Mill.', 124),
(11748, 'Oxyspermum', NULL, 'Eckl. & Zeyh.', 142),
(11749, 'Oxyspora', NULL, 'DC.', 105),
(11750, 'Oxystelma', NULL, 'R.Br.', 10),
(11751, 'Oxystemon', NULL, 'Planch. & Triana', 42),
(11752, 'Oxystigma', NULL, 'Harms', 68),
(11753, 'Oxystylis', NULL, 'Torr. & Frem.', 509),
(11754, 'Oxytenia', NULL, 'Nutt.', 18),
(11755, 'Oxytheca', NULL, 'Nutt.', 134),
(11756, 'Oxythece', NULL, 'Miq.', 148),
(11757, 'Oxytropis', NULL, 'DC.', 68),
(11758, 'Oyedaea', NULL, 'DC.', 18),
(11759, 'Ozodycus', NULL, 'Raf.', 49),
(11760, 'Ozomelis', NULL, 'Raf.', 149),
(11761, 'Ozoroa', NULL, 'Delile', 6),
(11762, 'Ozothamnus', NULL, 'R.Br.', 18),
(11763, 'Pachecoa', NULL, 'Standl. & Steyerm.', 68),
(11764, 'Pacheya', NULL, 'Scop.', 142),
(11765, 'Pachyanthus', NULL, 'Rich.', 105),
(11766, 'Pachycarpus', NULL, 'E.Mey.', 10),
(11767, 'Pachycentria', NULL, 'Blume', 105),
(11768, 'Pachychlamys', NULL, 'Dyer ex Ridl.', 60),
(11769, 'Pachycladon', NULL, 'Hook.f.', 197),
(11770, 'Pachycormus', NULL, 'Coville ex Standl.', 6),
(11771, 'Pachycornia', NULL, 'Hook.f.', 5),
(11772, 'Pachyctenium', NULL, 'Maire & Pamp.', 9),
(11773, 'Pachycymbium', NULL, 'L.C.Leach', 10),
(11774, 'Pachyderma', NULL, 'Blume', 120),
(11775, 'Pachydesmia', NULL, 'Gleason', 105),
(11776, 'Pachygone', NULL, 'Miers', 107),
(11777, 'Pachylaena', NULL, 'D.Don ex Hook. & Arn.', 18),
(11778, 'Pachylarnax', NULL, 'Dandy', 100),
(11779, 'Pachylecythis', NULL, 'Ledoux', 92),
(11780, 'Pachylobus', NULL, 'G.Don', 27),
(11781, 'Pachyloma', NULL, 'Bosch(SUH)', 105),
(11782, 'Pachylophus', NULL, 'Spach', 121),
(11783, 'Pachymeria', NULL, 'Benth.', 105),
(11784, 'Pachymitus', NULL, 'O.E.Schulz', 197),
(11785, 'Pachynema', NULL, 'R.Br. ex DC.', 58),
(11786, 'Pachyneurum', NULL, 'Bunge', 197),
(11787, 'Pachynocarpus', NULL, 'Hook.f.', 60),
(11788, 'Pachypharynx', NULL, 'Aellen', 5),
(11789, 'Pachyphragma', NULL, '(DC.) Rchb.', 197),
(11790, 'Pachyphytum', NULL, 'Link, Klotzsch & Otto', 48),
(11791, 'Pachypleurum', NULL, 'Ledeb.', 9),
(11792, 'Pachypodium', NULL, 'Lindl.', 10),
(11793, 'Pachyptera', NULL, 'DC.', 22),
(11794, 'Pachypteris', NULL, 'Kar. & Kir.', 197),
(11795, 'Pachypterygium', NULL, 'Bunge', 197),
(11796, 'Pachyrhizus', NULL, 'Rich. ex DC.', 68),
(11797, 'Pachyrhynchus', NULL, 'DC.', 18),
(11798, 'Pachysandra', NULL, 'Michx.', 28),
(11799, 'Pachysanthus', NULL, 'C.Presl', 142),
(11800, 'Pachysolen', NULL, 'Phil.', 154),
(11801, 'Pachystachys', NULL, 'Nees', 1),
(11802, 'Pachystegia', NULL, 'Cheeseman', 18),
(11803, 'Pachystela', NULL, 'Pierre ex Engl.', 148),
(11804, 'Pachystelma', NULL, 'Brandegee', 10),
(11805, 'Pachystemon', NULL, 'Blume', 66),
(11806, 'Pachystigma', NULL, 'Hochst.', 142),
(11807, 'Pachystima', NULL, 'Raf.', 38),
(11808, 'Pachystrobilus', NULL, 'Bremek.', 1),
(11809, 'Pachystroma', NULL, 'Mull.Arg.', 66),
(11810, 'Pachystylidium', NULL, 'Pax & K.Hoffm.', 66),
(11811, 'Pachystylus', NULL, 'K.Schum.', 142),
(11812, 'Pachythamnus', NULL, '(R.M.King & H.Rob.) R.M.King & H', 18),
(11813, 'Pachytrophe', NULL, 'Bureau', 109),
(11814, 'Packera', NULL, 'A.Love & D.Love', 18),
(11815, 'Pacouria', NULL, 'Aubl.', 10),
(11816, 'Pacourina', NULL, 'Aubl.', 18),
(11817, 'Padbruggea', NULL, 'Miq.', 68),
(11818, 'Padellus', NULL, 'Vassilcz.', 141),
(11819, 'Padus', NULL, 'Mill.', 141),
(11820, 'Paederia', NULL, 'L.', 142),
(11821, 'Paederota', NULL, 'L.', 423),
(11822, 'Paederotella', NULL, '(Wulf) Kem.-Nath.', 150),
(11823, 'Paedicalyx', NULL, 'Pierre ex Pit.', 142),
(11824, 'Pagaea', NULL, 'Griseb.', 75),
(11825, 'Pagamea', NULL, 'Aubl.', 142),
(11826, 'Pagameopsis', NULL, 'Steyerm.', 142),
(11827, 'Pagella', NULL, 'Schonl.', 48),
(11828, 'Pagetia', NULL, 'F.Muell.', 143),
(11829, 'Pagiantha', NULL, 'Markgr.', 10),
(11830, 'Pahudia', NULL, 'Miq.', 68),
(11831, 'Painteria', NULL, 'Britton & Rose', 68),
(11832, 'Paiva', NULL, 'Vell.', 142),
(11833, 'Paivaea', NULL, 'O.Berg', 116),
(11834, 'Paivaeusa', NULL, 'Welw.', 66),
(11835, 'Pajanelia', NULL, 'DC.', 22),
(11836, 'Pakaraimaea', NULL, 'Maguire & P.S.Ashton', 60),
(11837, 'Paladelpha', NULL, 'Pichon', 10),
(11838, 'Palaeocyanus', NULL, 'Dostal', 18),
(11839, 'Palafoxia', NULL, 'Lag.', 18),
(11840, 'Palandra', NULL, 'O.F.Cook', 15),
(11841, 'Palanostigma', NULL, 'Mart. ex Klotzsch', 66),
(11842, 'Palaoea', NULL, 'Kaneh.', 147),
(11843, 'Palaua', NULL, 'Cav.', 102),
(11844, 'Palava', NULL, 'Juss.(SUO)', 102),
(11845, 'Paleaepappus', NULL, 'Cabrera', 18),
(11846, 'Palenga', NULL, 'Thwaites', 66),
(11847, 'Paletuviera', NULL, 'Thouars ex DC.', 140),
(11848, 'Paliavana', NULL, 'Vell. ex Vand.', 76),
(11849, 'Palimbia', NULL, 'Besser ex DC.', 9),
(11850, 'Palissya', NULL, 'Baill.(SUH)', 66),
(11851, 'Paliurus', NULL, 'Mill.', 139),
(11852, 'Pallasia', NULL, 'Klotzsch', 142),
(11853, 'Pallavicinia', NULL, 'De Not.', 154),
(11854, 'Pallenis', NULL, '(Cass.) Cass.(SUS)', 18),
(11855, 'Palma', NULL, 'Mill.', 15),
(11856, 'Palmerella', NULL, 'A.Gray', 30),
(11857, 'Palmeria', NULL, 'F.Muell.', 108),
(11858, 'Palmerocassia', NULL, 'Britton', 68),
(11859, 'Palmervandenbrockia', NULL, 'Gibbs', 13),
(11860, 'Palmjuncus', NULL, 'Kuntze', 15),
(11861, 'Palmolmedia', NULL, 'Ducke', 109),
(11862, 'Palmstruckia', NULL, 'Sond.(SUH)', 197),
(11863, 'Paloue', NULL, 'Aubl.', 68),
(11864, 'Palovea', NULL, 'Juss.(SUO)', 68),
(11865, 'Paloveopsis', NULL, 'R.S.Cowan', 68),
(11866, 'Pamburus', NULL, 'Swingle', 143),
(11867, 'Pamea', NULL, 'Aubl.', 44),
(11868, 'Pamphalea', NULL, 'Lag.', 18),
(11869, 'Pamphilia', NULL, 'Mart. ex A.DC.', 158),
(11870, 'Pamplethantha', NULL, 'Bremek.', 142),
(11871, 'Panamanthus', NULL, 'Kuijt', 98),
(11872, 'Panax', NULL, 'L.', 13),
(11873, 'Pancheria', NULL, 'Brongn. & Gris', 50),
(11874, 'Panchezia', NULL, 'B.D.Jacks.(SUO)', 142),
(11875, 'Pancicia', NULL, 'Vis. & Schltdl.', 9),
(11876, 'Pandaca', NULL, 'Thouars', 10),
(11877, 'Pandacastrum', NULL, 'Pichon', 10),
(11878, 'Panderia', NULL, 'Fisch. & C.A.Mey.', 5),
(11879, 'Pandiaka', NULL, '(Moq.) Hook.f.', 5),
(11880, 'Pandorea', NULL, '(Endl.) Spach', 22),
(11881, 'Panetos', NULL, 'Raf.', 142),
(11882, 'Pangium', NULL, 'Reinw.', 198),
(11883, 'Panke', NULL, 'Willd.', 182);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(11884, 'Panopia', NULL, 'Noronha ex Thouars', 66),
(11885, 'Panphalea', NULL, 'Lag.(SUO)', 18),
(11886, 'Pantacantha', NULL, 'Speg.', 154),
(11887, 'Pantadenia', NULL, 'Gagnep.', 66),
(11888, 'Panterpa', NULL, 'Miers', 22),
(11889, 'Pantorrhynchus', NULL, 'Murb.', 197),
(11890, 'Panurea', NULL, 'Spruce ex Benth.', 68),
(11891, 'Panzeria', NULL, 'Moench(SUH)', 90),
(11892, 'Panzerina', NULL, 'Sojak', 90),
(11893, 'Paolia', NULL, 'Chiov.', 142),
(11894, 'Papaver', NULL, 'L.', 126),
(11895, 'Paphia', NULL, 'Seem.', 64),
(11896, 'Pappea', NULL, 'Eckl. & Zeyh.', 147),
(11897, 'Pappobolus', NULL, 'S.F.Blake', 18),
(11898, 'Pappostyles', NULL, 'Pierre', 142),
(11899, 'Pappostylum', NULL, 'Pierre(SUO)', 142),
(11900, 'Papuacalia', NULL, 'Veldkamp', 18),
(11901, 'Papuacedrus', NULL, 'H.L.Li', 51),
(11902, 'Papualthia', NULL, 'Diels', 8),
(11903, 'Papuanthes', NULL, 'Danser', 98),
(11904, 'Papuastelma', NULL, 'Bullock', 10),
(11905, 'Papuechites', NULL, 'Markgr.', 10),
(11906, 'Papuodendron', NULL, 'C.T.White', 102),
(11907, 'Papuzilla', NULL, 'Ridl.', 197),
(11908, 'Papyrius', NULL, 'Lam.', 109),
(11909, 'Parabaena', NULL, 'Miers', 107),
(11910, 'Parabarium', NULL, 'Pierre', 10),
(11911, 'Parabarleria', NULL, 'Baill.', 1),
(11912, 'Parabeaumontia', NULL, 'Pichon', 10),
(11913, 'Parabenzoin', NULL, 'Nakai', 91),
(11914, 'Paraberlinia', NULL, 'Pellegr.', 68),
(11915, 'Parabesleria', NULL, 'Oerst.', 76),
(11916, 'Parabignonia', NULL, 'Bureau ex K.Schum.', 22),
(11917, 'Paraboea', NULL, '(C.B.Clarke) Ridl.', 76),
(11918, 'Parabotrys', NULL, 'Mull.Hal.(SUO)', 8),
(11919, 'Parabouchetia', NULL, 'Baill.', 154),
(11920, 'Paracalia', NULL, 'Cuatrec.', 18),
(11921, 'Paracalyx', NULL, 'Ali', 68),
(11922, 'Paracarpaea', NULL, '(K.Schum.) Pichon', 22),
(11923, 'Paracaryopsis', NULL, 'R.R.Mill', 25),
(11924, 'Paracaryum', NULL, '(A.DC.) Boiss.', 25),
(11925, 'Paracasearia', NULL, 'Boerl.', 66),
(11926, 'Paracelastrus', NULL, 'Miq.', 38),
(11927, 'Paracelsea', NULL, 'Zoll.(SUH)', 66),
(11928, 'Paracephaelis', NULL, 'Baill.', 142),
(11929, 'Parachampionella', NULL, 'Bremek.', 1),
(11930, 'Parachimarrhis', NULL, 'Ducke', 142),
(11931, 'Paraclarisia', NULL, 'Ducke', 109),
(11932, 'Paracleisthus', NULL, 'Gagnep.', 184),
(11933, 'Paracoffea', NULL, 'J.-F.Leroy(SUI)', 142),
(11934, 'Paracolea', NULL, 'Baill.', 22),
(11935, 'Paracorynanthe', NULL, 'Capuron', 142),
(11936, 'Paracynoglossum', NULL, 'Popov', 25),
(11937, 'Paradaniellia', NULL, 'Rolfe', 68),
(11938, 'Paradenocline', NULL, 'Mull.Arg.', 66),
(11939, 'Paraderris', NULL, '(Miq.) R.Geesink', 68),
(11940, 'Paradina', NULL, 'Pierre ex Pit.', 142),
(11941, 'Paradolichandra', NULL, 'Hassl.', 22),
(11942, 'Paradombeya', NULL, 'Stapf', 102),
(11943, 'Paradrymonia', NULL, 'Hanst.', 76),
(11944, 'Paraeremostachys', NULL, 'Adylov, Kamelin & Machm.', 90),
(11945, 'Paragelonium', NULL, 'Leandri', 66),
(11946, 'Paragenipa', NULL, 'Baill.', 142),
(11947, 'Parageum', NULL, 'Nakai & H.Hara', 141),
(11948, 'Paraglycine', NULL, 'F.J.Herm.', 68),
(11949, 'Paragoldfussia', NULL, 'Bremek.', 1),
(11950, 'Paragonia', NULL, 'Bureau', 22),
(11951, 'Paragophyton', NULL, 'K.Schum.', 142),
(11952, 'Paragrewia', NULL, 'Gagnep. ex R.S.Rao', 102),
(11953, 'Paragulubia', NULL, 'Burret', 15),
(11954, 'Paragutzlaffia', NULL, 'H.P.Tsui', 1),
(11955, 'Paragynoxys', NULL, '(Cuatrec.) Cuatrec.', 18),
(11956, 'Parahancornia', NULL, 'Ducke', 10),
(11957, 'Parahebe', NULL, 'W.R.B.Oliv.', 423),
(11958, 'Paraia', NULL, 'Rohwer, H.G.Richt. & van der Wer', 91),
(11959, 'Paraixeris', NULL, 'Nakai', 18),
(11960, 'Parajaeschkea', NULL, 'Burkill', 75),
(11961, 'Parajubaea', NULL, 'Burret', 15),
(11962, 'Parajusticia', NULL, 'Benoist', 1),
(11963, 'Parakibara', NULL, 'Philipson', 108),
(11964, 'Parakmeria', NULL, 'Hu & W.C.Cheng', 100),
(11965, 'Paraknoxia', NULL, 'Bremek.', 142),
(11966, 'Parakohleria', NULL, 'Wiehler', 76),
(11967, 'Paralabatia', NULL, 'Pierre', 148),
(11968, 'Paralamium', NULL, 'Dunn', 90),
(11969, 'Paralbizzia', NULL, 'Kosterm.', 68),
(11970, 'Paralepistemon', NULL, 'Lejoly & Lisowski', 46),
(11971, 'Paraligusticum', NULL, 'V.N.Tikhom.', 9),
(11972, 'Paralinospadix', NULL, 'Burret', 15),
(11973, 'Paralstonia', NULL, 'Baill.', 10),
(11974, 'Paralychnophora', NULL, 'MacLeish', 18),
(11975, 'Paralyxia', NULL, 'Baill.', 10),
(11976, 'Paramachaerium', NULL, 'Ducke', 68),
(11977, 'Paramacrolobium', NULL, 'J.Leonard', 68),
(11978, 'Paramammea', NULL, 'J.-F.Leroy', 42),
(11979, 'Paramansoa', NULL, 'Baill.', 22),
(11980, 'Paramapania', NULL, 'Uittien', 55),
(11981, 'Paramelhania', NULL, 'Arenes', 102),
(11982, 'Parameria', NULL, 'Benth.', 10),
(11983, 'Parameriopsis', NULL, 'Pichon', 10),
(11984, 'Paramichelia', NULL, 'Hu', 100),
(11985, 'Paramicropholis', NULL, 'Aubrev. & Pellegr.', 148),
(11986, 'Paramignya', NULL, 'Wight', 143),
(11987, 'Paramitranthes', NULL, 'Burret', 116),
(11988, 'Paramoltkia', NULL, 'Greuter', 25),
(11989, 'Paramyrciaria', NULL, 'Kausel', 116),
(11990, 'Paranecepsia', NULL, 'Radcl.-Sm.', 66),
(11991, 'Paranephelius', NULL, 'Poepp.', 18),
(11992, 'Paranneslea', NULL, 'Gagnep.', 409),
(11993, 'Paranomus', NULL, 'Salisb.', 135),
(11994, 'Parantennaria', NULL, 'Beauverd', 18),
(11995, 'Paranthe', NULL, 'O.F.Cook(SUI)', 15),
(11996, 'Parapachygone', NULL, 'Forman', 107),
(11997, 'Parapanax', NULL, 'Miq.', 13),
(11998, 'Parapantadenia', NULL, 'Capuron', 66),
(11999, 'Parapentapanax', NULL, 'Hutch.', 13),
(12000, 'Parapentas', NULL, 'Bremek.', 142),
(12001, 'Paraphlomis', NULL, 'Prain', 90),
(12002, 'Paraphyadanthe', NULL, 'Mildbr.', 73),
(12003, 'Parapiptadenia', NULL, 'Brenan', 68),
(12004, 'Parapiqueria', NULL, 'R.M.King & H.Rob.', 18),
(12005, 'Parapodium', NULL, 'E.Mey.', 10),
(12006, 'Paraprenanthes', NULL, 'C.C.Chang ex C.Shih', 18),
(12007, 'Paraprotium', NULL, 'Cuatrec.', 27),
(12008, 'Parapteropyrum', NULL, 'A.J.Li', 134),
(12009, 'Parapyrenaria', NULL, 'H.T.Chang', 162),
(12010, 'Pararchidendron', NULL, 'I.C.Nielsen', 68),
(12011, 'Parardisia', NULL, 'M.P.Nayar & G.S.Giri', 115),
(12012, 'Pararistolochia', NULL, 'Hutch. & Dalziel', 16),
(12013, 'Parartabotrys', NULL, 'Miq.', 8),
(12014, 'Pararuellia', NULL, 'Bremek.', 1),
(12015, 'Parasamanea', NULL, 'Kosterm.', 68),
(12016, 'Parasassafras', NULL, 'D.G.Long', 91),
(12017, 'Parascheelea', NULL, 'Dugand', 15),
(12018, 'Parascopolia', NULL, 'Baill.', 154),
(12019, 'Paraselinum', NULL, 'H.Wolff', 9),
(12020, 'Parasenecio', NULL, 'W.W.Sm. & Small', 18),
(12021, 'Paraserianthes', NULL, 'I.C.Nielsen', 68),
(12022, 'Parasicyos', NULL, 'Dieterle', 49),
(12023, 'Parasilaus', NULL, 'Leute', 9),
(12024, 'Parasitaxus', NULL, 'de Laub.', 132),
(12025, 'Parasitipomoea', NULL, 'Hayata', 46),
(12026, 'Paraskevia', NULL, 'W.Sauer & G.Sauer', 25),
(12027, 'Parasponia', NULL, 'Miq.', 253),
(12028, 'Parastranthus', NULL, 'G.Don', 30),
(12029, 'Parastrephia', NULL, 'Nutt.', 18),
(12030, 'Parastriga', NULL, 'Mildbr.', 150),
(12031, 'Parastrobilanthes', NULL, 'Bremek.', 1),
(12032, 'Parastyrax', NULL, 'W.W.Sm.', 158),
(12033, 'Parasympagis', NULL, 'Bremek.', 1),
(12034, 'Parasyringa', NULL, 'W.W.Sm.', 120),
(12035, 'Parasystasia', NULL, 'Baill.', 1),
(12036, 'Paratecoma', NULL, 'Kuhlm.', 22),
(12037, 'Paratephrosia', NULL, 'Domin', 68),
(12038, 'Paratriaina', NULL, 'Bremek.', 142),
(12039, 'Paratrophis', NULL, 'Blume', 109),
(12040, 'Paratropia', NULL, '(Blume) DC.', 13),
(12041, 'Paravallaris', NULL, 'Pierre', 10),
(12042, 'Paravinia', NULL, 'Hassk.(SUO)', 142),
(12043, 'Paravitex', NULL, 'H.R.Fletcher', 90),
(12044, 'Pardoglossum', NULL, 'E.Barbier & Mathez', 25),
(12045, 'Parenterolobium', NULL, 'Kosterm.', 68),
(12046, 'Parentucellia', NULL, 'Viv.', 400),
(12047, 'Pareugenia', NULL, 'Turrill', 116),
(12048, 'Parietaria', NULL, 'L.', 171),
(12049, 'Parinarium', NULL, 'Juss.', 40),
(12050, 'Parishella', NULL, 'A.Gray', 30),
(12051, 'Pariti', NULL, 'Adans.', 102),
(12052, 'Parlatoria', NULL, 'Boiss.', 197),
(12053, 'Parochetus', NULL, 'Buch.-Ham. ex D.Don', 68),
(12054, 'Parodianthus', NULL, 'Tronc.', 173),
(12055, 'Parodiodendron', NULL, 'Hunz.', 534),
(12056, 'Parodiodoxa', NULL, 'O.E.Schulz', 197),
(12057, 'Parolinia', NULL, 'Webb', 197),
(12058, 'Paropsiopsis', NULL, 'Engl.', 127),
(12059, 'Parosela', NULL, 'Cav.', 68),
(12060, 'Parquetina', NULL, 'Baill.', 10),
(12061, 'Parqui', NULL, 'Adans.', 154),
(12062, 'Parrasia', NULL, 'Greene', 197),
(12063, 'Parrya', NULL, 'R.Br.', 197),
(12064, 'Parryella', NULL, 'Torr. & A.Gray', 68),
(12065, 'Parryodes', NULL, 'Jafri', 197),
(12066, 'Parryopsis', NULL, 'Botsch.', 197),
(12067, 'Parsana', NULL, 'Parsa & Maleki', 171),
(12068, 'Parsonsia', NULL, 'P.Browne(SUH)', 10),
(12069, 'Parthenice', NULL, 'A.Gray', 18),
(12070, 'Parthenium', NULL, 'L.', 18),
(12071, 'Parthenocissus', NULL, 'Planch.', 181),
(12072, 'Parvisedum', NULL, 'R.T.Clausen', 48),
(12073, 'Paryphantha', NULL, 'Schauer', 116),
(12074, 'Paryphosphaera', NULL, 'H.Karst.', 68),
(12075, 'Pasaccardoa', NULL, 'Kuntze', 18),
(12076, 'Pasaniopsis', NULL, 'Kudo', 72),
(12077, 'Pascalia', NULL, 'Ortega', 18),
(12078, 'Pascalium', NULL, 'Cass.(SUO)', 18),
(12079, 'Paschalococos', NULL, 'J.Dransf.', 15),
(12080, 'Paschanthus', NULL, 'Burch.', 127),
(12081, 'Pasovia', NULL, 'H.Karst.', 98),
(12082, 'Passaea', NULL, 'Baill.(SUH)', 66),
(12083, 'Passaveria', NULL, 'Mart. & Eichler ex Miq.', 148),
(12084, 'Passerina', NULL, 'L.', 164),
(12085, 'Passowia', NULL, 'H.Karst.(SUO)', 98),
(12086, 'Pastinaca', NULL, 'L.', 9),
(12087, 'Pastinacopsis', NULL, 'Golosk.', 9),
(12088, 'Patabea', NULL, 'Aubl.', 142),
(12089, 'Patagonula', NULL, 'L.', 25),
(12090, 'Patascoya', NULL, 'Urb.', 162),
(12091, 'Patellaria', NULL, 'J.T.Williams, A.J.Scott & Ford-L', 5),
(12092, 'Patellifolia', NULL, 'A.J.Scott, Ford-Lloyd & J.T.Will', 5),
(12093, 'Patima', NULL, 'Aubl.', 142),
(12094, 'Patonia', NULL, 'Wight', 8),
(12095, 'Patrisia', NULL, 'Rich.', 145),
(12096, 'Patsjotti', NULL, 'Adans.', 142),
(12097, 'Pattalias', NULL, 'S.Watson', 10),
(12098, 'Paua', NULL, 'Caball.', 18),
(12099, 'Pauella', NULL, 'Ramam. & Sebastine', 12),
(12100, 'Pauia', NULL, 'Deb & R.M.Dutta', 154),
(12101, 'Pauldopia', NULL, 'Steenis', 22),
(12102, 'Paulia', NULL, 'Korovin(SUH)', 9),
(12103, 'Paulita', NULL, 'Sojak', 9),
(12104, 'Paulowilhelmia', NULL, 'Hochst.(SUH)', 1),
(12105, 'Paulownia', NULL, 'Siebold & Zucc.', 529),
(12106, 'Paulseniella', NULL, 'Briq.', 90),
(12107, 'Paurolepis', NULL, 'S.Moore', 18),
(12108, 'Paurotis', NULL, 'O.F.Cook', 15),
(12109, 'Pausia', NULL, 'Raf.(SUS)', 120),
(12110, 'Pavate', NULL, 'Adans.', 142),
(12111, 'Pavieasia', NULL, 'Pierre', 147),
(12112, 'Paxia', NULL, 'Gilg', 45),
(12113, 'Paxiodendron', NULL, 'Engl.', 108),
(12114, 'Paxistima', NULL, 'Raf.', 38),
(12115, 'Paxiuscula', NULL, 'Herter', 66),
(12116, 'Payera', NULL, 'Baill.', 142),
(12117, 'Payeria', NULL, 'Baill.', 106),
(12118, 'Paypayrola', NULL, 'Aubl.', 174),
(12119, 'Pearcea', NULL, 'Regel', 76),
(12120, 'Pearsonia', NULL, 'Dummer', 68),
(12121, 'Peccana', NULL, 'Raf.', 66),
(12122, 'Pecheya', NULL, 'Scop.', 142),
(12123, 'Pechuel-Loeschea', NULL, 'O.Hoffm.', 18),
(12124, 'Peckeya', NULL, 'Raf.(SUO)', 142),
(12125, 'Peckia', NULL, 'Vell.', 115),
(12126, 'Peckoltia', NULL, 'E.Fourn.', 10),
(12127, 'Pectiantia', NULL, 'Raf.', 149),
(12128, 'Pectinaria', NULL, 'Haw.', 10),
(12129, 'Pectis', NULL, 'L.', 18),
(12130, 'Pectocarya', NULL, 'DC. ex Meisn.', 25),
(12131, 'Pederlea', NULL, 'Raf.', 154),
(12132, 'Pedicellaria', NULL, 'Schrank', 32),
(12133, 'Pedicellarum', NULL, 'M.Hotta', 12),
(12134, 'Pediculariopsis', NULL, 'A.Love & D.Love', 150),
(12135, 'Pedicularis', NULL, 'L.', 400),
(12136, 'Pedilanthus', NULL, 'Neck. ex Poit.', 66),
(12137, 'Pedinogyne', NULL, 'Brand', 25),
(12138, 'Pedinopetalum', NULL, 'Urb. & H.Wolff', 9),
(12139, 'Pediomellum', NULL, 'Rydb.', 68),
(12140, 'Pediomelum', NULL, 'Rydb.', 68),
(12141, 'Pedistylis', NULL, 'Wiens', 98),
(12142, 'Peekelia', NULL, 'Harms', 68),
(12143, 'Peekeliodendron', NULL, 'Sleumer', 85),
(12144, 'Peekeliopanax', NULL, 'Harms', 13),
(12145, 'Pegaeophyton', NULL, 'Hayek & Hand.-Mazz.', 197),
(12146, 'Pegamea', NULL, 'Vitman(SUO)', 142),
(12147, 'Peganum', NULL, 'L.', 526),
(12148, 'Pegia', NULL, 'Colebr.', 6),
(12149, 'Peglera', NULL, 'Bolus', 65),
(12150, 'Pegolettia', NULL, 'Cass.', 18),
(12151, 'Pehria', NULL, 'Sprague', 99),
(12152, 'Peixotoa', NULL, 'A.Juss.', 101),
(12153, 'Pelagatia', NULL, 'O.E.Schulz', 197),
(12154, 'Pelagodendron', NULL, 'Seem.', 142),
(12155, 'Pelagodoxa', NULL, 'Becc.', 15),
(12156, 'Pelaphia', NULL, 'Banks & Sol.(SUI)', 142),
(12157, 'Pelea', NULL, 'A.Gray', 143),
(12158, 'Pelecostemon', NULL, 'Leonard', 1),
(12159, 'Peliostomum', NULL, 'Benth.', 150),
(12160, 'Pella', NULL, 'Gaertn.', 109),
(12161, 'Pellegrinia', NULL, 'Sleumer', 64),
(12162, 'Pellegriniodendron', NULL, 'J.Leonard', 68),
(12163, 'Pelletiera', NULL, 'A.St.-Hil.', 115),
(12164, 'Pellionia', NULL, 'Gaudich.', 171),
(12165, 'Pelozia', NULL, 'Rose', 121),
(12166, 'Peltaea', NULL, '(C.Presl) Standl.', 102),
(12167, 'Peltandra', NULL, 'Raf.', 12),
(12168, 'Peltanthera', NULL, 'Benth.', 76),
(12169, 'Peltaria', NULL, 'Jacq.', 197),
(12170, 'Peltariopsis', NULL, '(Boiss.) N.Busch', 197),
(12171, 'Peltastes', NULL, 'Woodson', 10),
(12172, 'Peltiphyllum', NULL, 'Engl.', 149),
(12173, 'Peltoboykinia', NULL, '(Engl.) Hara', 149),
(12174, 'Peltobractea', NULL, 'Rusby', 102),
(12175, 'Peltodon', NULL, 'Pohl', 90),
(12176, 'Peltogyne', NULL, 'Vogel', 68),
(12177, 'Peltophoropsis', NULL, 'Chiov.', 68),
(12178, 'Peltospermum', NULL, 'Benth.', 142),
(12179, 'Peltostegia', NULL, 'Turcz.', 102),
(12180, 'Peltostigma', NULL, 'Walp.', 143),
(12181, 'Pelucha', NULL, 'S.Watson', 18),
(12182, 'Pemphis', NULL, 'J.R.Forst. & G.Forst.', 99),
(12183, 'Penar-Valli', NULL, 'Adans.', 49),
(12184, 'Penarvallia', NULL, 'Post & Kuntze(SUO)', 49),
(12185, 'Penelopeia', NULL, 'Urb.', 49),
(12186, 'Peniculifera', NULL, 'Ridl.', 66),
(12187, 'Peniophyllum', NULL, 'Pennell', 121),
(12188, 'Pennantia', NULL, 'J.R.Forst. & G.Forst.', 531),
(12189, 'Pennellia', NULL, 'Nieuwl.', 197),
(12190, 'Penstemon', NULL, 'Schmidel', 423),
(12191, 'Pentabothra', NULL, 'Hook.f.', 10),
(12192, 'Pentabrachion', NULL, 'Mull.Arg.', 184),
(12193, 'Pentacalia', NULL, 'Cass.', 18),
(12194, 'Pentacarpaea', NULL, 'Hiern', 142),
(12195, 'Pentacarpus', NULL, 'Post & Kuntze(SUO)', 142),
(12196, 'Pentaceras', NULL, 'Hook.f.', 143),
(12197, 'Pentachaeta', NULL, 'Nutt.', 18),
(12198, 'Pentachondra', NULL, 'R.Br.', 64),
(12199, 'Pentaclathra', NULL, 'Endl.', 49),
(12200, 'Pentacme', NULL, 'A.DC.', 60),
(12201, 'Pentacrostigma', NULL, 'K.Afzel.', 46),
(12202, 'Pentactina', NULL, 'Nakai', 141),
(12203, 'Pentacyphus', NULL, 'Schltr.', 10),
(12204, 'Pentadenia', NULL, 'Hanst.', 76),
(12205, 'Pentadiplandra', NULL, 'Baill.', 532),
(12206, 'Pentadynamis', NULL, 'R.Br.', 68),
(12207, 'Pentaglottis', NULL, 'Tausch', 25),
(12208, 'Pentagonanthus', NULL, 'Bullock', 10),
(12209, 'Pentagonaster', NULL, 'Klotzsch', 116),
(12210, 'Pentalinon', NULL, 'Voigt', 10),
(12211, 'Pentaloncha', NULL, 'Hook.f.', 142),
(12212, 'Pentameria', NULL, 'Klotzsch ex Baill.', 184),
(12213, 'Pentamerista', NULL, 'Maguire', 190),
(12214, 'Pentanema', NULL, 'Cass.', 18),
(12215, 'Pentanisia', NULL, 'Harv.', 142),
(12216, 'Pentanopsis', NULL, 'Rendle', 142),
(12217, 'Pentanura', NULL, 'Blume', 10),
(12218, 'Pentapanax', NULL, 'Seem.', 13),
(12219, 'Pentapeltis', NULL, 'Bunge', 9),
(12220, 'Pentapera', NULL, 'Klotzsch', 64),
(12221, 'Pentapetes', NULL, 'L.', 102),
(12222, 'Pentaphalangium', NULL, 'Warb.', 42),
(12223, 'Pentaphitrum', NULL, 'Rchb.', 154),
(12224, 'Pentaphylloides', NULL, 'Duhamel', 141),
(12225, 'Pentapleura', NULL, 'Hand.-Mazz.', 90),
(12226, 'Pentaptera', NULL, 'Roxb.', 44),
(12227, 'Pentapterygium', NULL, 'Klotzsch', 64),
(12228, 'Pentarhaphia', NULL, 'Lindl.', 76),
(12229, 'Pentarhopalopilia', NULL, '(Engl.) Hiepko', 122),
(12230, 'Pentaria', NULL, 'M.Roem.', 127),
(12231, 'Pentarrhinum', NULL, 'E.Mey.', 10),
(12232, 'Pentas', NULL, 'Benth.', 142),
(12233, 'Pentasachme', NULL, 'Wall. ex Wight(SUO)', 10),
(12234, 'Pentasacme', NULL, 'Wall. ex Wight', 10),
(12235, 'Pentascyphus', NULL, 'Radlk.', 147),
(12236, 'Pentaspatella', NULL, 'Gleason', 118),
(12237, 'Pentastelma', NULL, 'Tsiang & P.T.Li', 10),
(12238, 'Pentasticha', NULL, 'Turcz.', 55),
(12239, 'Pentathymelaea', NULL, 'Lecomte', 164),
(12240, 'Pentatrichia', NULL, 'Klatt', 18),
(12241, 'Pentatropis', NULL, 'R.Br. ex Wight & Arn.', 10),
(12242, 'Penteca', NULL, 'Raf.', 66),
(12243, 'Pentelesia', NULL, 'Raf.', 22),
(12244, 'Pentheriella', NULL, 'O.Hoffm. & Muschl.', 18),
(12245, 'Penthysa', NULL, 'Raf.', 25),
(12246, 'Pentodon', NULL, 'Hochst.', 142),
(12247, 'Pentopetia', NULL, 'Decne.', 10),
(12248, 'Pentopetiopsis', NULL, 'Costantin & Gallaud', 10),
(12249, 'Pentossaea', NULL, 'Judd', 105),
(12250, 'Pentstemon', NULL, 'Aiton(SUO)', 150),
(12251, 'Pentzia', NULL, 'Thunb.', 18),
(12252, 'Peperomia', NULL, 'Ruiz & Pav.', 130),
(12253, 'Peplidium', NULL, 'Delile', 417),
(12254, 'Peplis', NULL, 'L.', 99),
(12255, 'Peplonia', NULL, 'Decne.', 10),
(12256, 'Pepo', NULL, 'Mill.', 49),
(12257, 'Peponia', NULL, 'Naudin', 49),
(12258, 'Peponidium', NULL, '(Baill.) Arenes', 142),
(12259, 'Peponiella', NULL, 'Kuntze', 49),
(12260, 'Peponium', NULL, 'Engl.', 49),
(12261, 'Peponopsis', NULL, 'Naudin', 49),
(12262, 'Peracarpa', NULL, 'Hook.f. & Thomson', 30),
(12263, 'Perakanthus', NULL, 'Robyns', 142),
(12264, 'Perama', NULL, 'Aubl.', 142),
(12265, 'Perantha', NULL, 'Craib', 76),
(12266, 'Peraphyllum', NULL, 'Nutt.', 141),
(12267, 'Peratanthe', NULL, 'Urb.', 142),
(12268, 'Peraxilla', NULL, 'Tiegh.', 98),
(12269, 'Perdicesca', NULL, 'Prov.', 142),
(12270, 'Perdicium', NULL, 'L.', 18),
(12271, 'Peregrina', NULL, 'W.R.Anderson', 101),
(12272, 'Perella', NULL, '(Tiegh.) Tiegh.', 98),
(12273, 'Perenideboles', NULL, 'Ram.Goyena', 1),
(12274, 'Perezia', NULL, 'Lag.', 18),
(12275, 'Pergularia', NULL, 'L.', 10),
(12276, 'Periandra', NULL, 'Mart. ex Benth.', 68),
(12277, 'Perianthomega', NULL, 'Bureau ex Baill.', 22),
(12278, 'Perianthopodus', NULL, 'Silva Manso', 49),
(12279, 'Perianthostelma', NULL, 'Baill.', 10),
(12280, 'Periarrabidaea', NULL, 'A.Samp.', 22),
(12281, 'Periblema', NULL, 'DC.', 1),
(12282, 'Periblepharis', NULL, 'Tiegh.', 118),
(12283, 'Pericalia', NULL, 'Cass.', 18),
(12284, 'Pericallis', NULL, 'D.Don', 18),
(12285, 'Pericalymma', NULL, '(Endl.) Endl.', 116),
(12286, 'Pericalymna', NULL, 'Meisn.(SUO)', 116),
(12287, 'Pericalypta', NULL, 'Benoist', 1),
(12288, 'Pericampylus', NULL, 'Miers', 107),
(12289, 'Perichasma', NULL, 'Miers', 107),
(12290, 'Perichlaena', NULL, 'Baill.', 22),
(12291, 'Periclesia', NULL, 'A.C.Sm.', 64),
(12292, 'Pericome', NULL, 'A.Gray', 18),
(12293, 'Pericopsis', NULL, 'Thwaites', 68),
(12294, 'Perictenia', NULL, 'Miers', 10),
(12295, 'Pericycla', NULL, 'Blume', 15),
(12296, 'Perideridia', NULL, 'Rchb.', 9),
(12297, 'Peridium', NULL, 'Schott', 66),
(12298, 'Periestes', NULL, 'Baill.', 1),
(12299, 'Perieteris', NULL, 'Raf.', 154),
(12300, 'Perigaria', NULL, 'Span.', 92),
(12301, 'Periglossum', NULL, 'Decne.', 10),
(12302, 'Perilepta', NULL, 'Bremek.', 1),
(12303, 'Perilimnastes', NULL, 'Ridl.', 105),
(12304, 'Perilla', NULL, 'L.', 90),
(12305, 'Perillula', NULL, 'Maxim.', 90),
(12306, 'Periloba', NULL, 'Raf.', 154),
(12307, 'Perilomia', NULL, 'Kunth', 90),
(12308, 'Peripentadenia', NULL, 'L.S.Sm.', 62),
(12309, 'Peripeplus', NULL, 'Pierre', 142),
(12310, 'Periplexis', NULL, 'Wall.', 66),
(12311, 'Periploca', NULL, 'L.', 10),
(12312, 'Periptera', NULL, 'DC.', 102),
(12313, 'Peripterygia', NULL, '(Baill.) Loes.', 38),
(12314, 'Perispermum', NULL, 'O.Deg.', 46),
(12315, 'Perissocarpa', NULL, 'Steyerm. & Maguire', 118),
(12316, 'Perissocoeleum', NULL, 'Mathias & Constance', 9),
(12317, 'Peristethium', NULL, 'Tiegh.', 98),
(12318, 'Peristrophe', NULL, 'Nees', 1),
(12319, 'Peritassa', NULL, 'Miers', 38),
(12320, 'Perithrix', NULL, 'Pierre', 10),
(12321, 'Perittostemma', NULL, 'I.M.Johnst.', 25),
(12322, 'Perityle', NULL, 'Benth.', 18),
(12323, 'Perizoma', NULL, '(Miers) Lindl.', 154),
(12324, 'Permia', NULL, 'Raf.', 68),
(12325, 'Pernettya', NULL, 'Gaudich.', 64),
(12326, 'Pernettyopsis', NULL, 'King & Gamble', 64),
(12327, 'Peronema', NULL, 'Jack', 90),
(12328, 'Perovskia', NULL, 'Kar.', 90),
(12329, 'Perplexia', NULL, 'Iljin', 18),
(12330, 'Perralderia', NULL, 'Coss.', 18),
(12331, 'Perralderiopsis', NULL, 'Rauschert', 18),
(12332, 'Perriera', NULL, 'Courchet', 151),
(12333, 'Perrieranthus', NULL, 'Hochr.', 102),
(12334, 'Perrierastrum', NULL, 'Guillaumin', 90),
(12335, 'Perrierophytum', NULL, 'Hochr.', 102),
(12336, 'Perrierosedum', NULL, '(A.Berger) H.Ohba', 48),
(12337, 'Persica', NULL, 'Mill.', 141),
(12338, 'Persicaria', NULL, '(L.) Mill.', 134),
(12339, 'Persoonia', NULL, 'Sm.', 135),
(12340, 'Pertya', NULL, 'Sch.Bip.', 18),
(12341, 'Perula', NULL, 'Schreb.', 66),
(12342, 'Pervillaea', NULL, 'Decne.', 10),
(12343, 'Perxo', NULL, 'Raf.', 90),
(12344, 'Perymeniopsis', NULL, 'H.Rob.', 18),
(12345, 'Perymenium', NULL, 'Schrad.', 18),
(12346, 'Peschiera', NULL, 'A.DC.', 10),
(12347, 'Pestalozzia', NULL, 'Zoll. & Moritzi', 49),
(12348, 'Petagnia', NULL, 'Guss.', 9),
(12349, 'Petagomoa', NULL, 'Bremek.', 142),
(12350, 'Petalacte', NULL, 'D.Don', 18),
(12351, 'Petaladenium', NULL, 'Ducke', 68),
(12352, 'Petalandra', NULL, 'F.Muell. ex Boiss.', 66),
(12353, 'Petalanthera', NULL, 'Raf.(SUH)', 1),
(12354, 'Petalidium', NULL, 'Nees', 1),
(12355, 'Petalodactylis', NULL, 'Arenes', 140),
(12356, 'Petalodiscus', NULL, 'Baill.', 184),
(12357, 'Petalogyne', NULL, 'F.Muell.', 68),
(12358, 'Petalolophus', NULL, 'K.Schum.', 8),
(12359, 'Petalonema', NULL, 'Schltr.', 10),
(12360, 'Petalostelma', NULL, 'E.Fourn.', 10),
(12361, 'Petalostemon', NULL, 'Michx.', 68),
(12362, 'Petalostigma', NULL, 'F.Muell.', 534),
(12363, 'Petalostylis', NULL, 'R.Br.', 68),
(12364, 'Petasites', NULL, 'Mill.', 18),
(12365, 'Petastoma', NULL, 'Miers', 22),
(12366, 'Petchia', NULL, 'Livera', 10),
(12367, 'Petelotiella', NULL, 'Gagnep.', 171),
(12368, 'Petelotoma', NULL, 'DC.', 140),
(12369, 'Petenaea', NULL, 'Lundell', 102),
(12370, 'Peteniodendron', NULL, 'Lundell', 148),
(12371, 'Peteravenia', NULL, 'R.M.King & H.Rob.', 18),
(12372, 'Peteria', NULL, 'A.Gray', 68),
(12373, 'Peterodendron', NULL, 'Sleumer', 198),
(12374, 'Petersia', NULL, 'Welw. ex Benth.', 92),
(12375, 'Petesia', NULL, 'P.Browne', 142),
(12376, 'Petilium', NULL, 'Ludw.', 94),
(12377, 'Petiniotia', NULL, 'J.Leonard', 197),
(12378, 'Petitia', NULL, 'Jacq.', 90),
(12379, 'Petitmenginia', NULL, 'Bonati', 150),
(12380, 'Petiveria', NULL, 'L.', 128),
(12381, 'Petlomelia', NULL, 'Nieuwl.', 120),
(12382, 'Petopentia', NULL, 'Bullock', 10),
(12383, 'Petracanthus', NULL, 'Nees', 1),
(12384, 'Petradoria', NULL, 'Greene', 18),
(12385, 'Petraeovitex', NULL, 'Oliv.', 90),
(12386, 'Petrea', NULL, 'L.', 173),
(12387, 'Petrobium', NULL, 'R.Br.', 18),
(12388, 'Petrocallis', NULL, 'R.Br.', 197),
(12389, 'Petrocarya', NULL, 'Schreb.', 40),
(12390, 'Petrocodon', NULL, 'Hance', 76),
(12391, 'Petrocosmea', NULL, 'Oliv.', 76),
(12392, 'Petrodoxa', NULL, 'Anthony', 76),
(12393, 'Petroedmondia', NULL, 'Tamamsch.', 9),
(12394, 'Petrogenia', NULL, 'I.M.Johnst.', 46),
(12395, 'Petromarula', NULL, 'Vent. ex R.Hedw.', 30),
(12396, 'Petromecon', NULL, 'Greene', 126),
(12397, 'Petrophile', NULL, 'R.Br. ex Knight', 135),
(12398, 'Petrophyes', NULL, 'Webb & Berthel.', 48),
(12399, 'Petrophytum', NULL, '(Nutt.) Rydb.', 141),
(12400, 'Petrosciadium', NULL, 'Edgew.', 9),
(12401, 'Petrosedum', NULL, 'Grulich', 48),
(12402, 'Petroselinum', NULL, 'Hill', 9),
(12403, 'Petrosimonia', NULL, 'Bunge', 5),
(12404, 'Petteria', NULL, 'C.Presl', 68),
(12405, 'Petunga', NULL, 'DC.', 142),
(12406, 'Petunia', NULL, 'Juss.', 154),
(12407, 'Peucedanum', NULL, 'L.', 9),
(12408, 'Peuceluma', NULL, 'Baill.', 148),
(12409, 'Peucephyllum', NULL, 'A.Gray', 18),
(12410, 'Peumus', NULL, 'Molina', 108),
(12411, 'Peyrousea', NULL, 'DC.', 18),
(12412, 'Pezisicarpus', NULL, 'Vernet', 10),
(12413, 'Pfaffia', NULL, 'Mart.', 5),
(12414, 'Pfeifferago', NULL, 'Kuntze', 50),
(12415, 'Phaca', NULL, 'L.', 68),
(12416, 'Phacelia', NULL, 'Juss.', 25),
(12417, 'Phacellanthus', NULL, 'Siebold & Zucc.', 400),
(12418, 'Phacellaria', NULL, 'Benth.', 146),
(12419, 'Phacellothrix', NULL, 'F.Muell.', 18),
(12420, 'Phacelophrynium', NULL, 'K.Schum.', 103),
(12421, 'Phacocapnos', NULL, 'Bernh.', 126),
(12422, 'Phacomene', NULL, 'Rydb.', 68),
(12423, 'Phacopsis', NULL, 'Rydb.', 68),
(12424, 'Phaedra', NULL, 'Klotzsch ex Endl.', 66),
(12425, 'Phaedranthus', NULL, 'Miers', 22),
(12426, 'Phaenocoma', NULL, 'D.Don', 18),
(12427, 'Phaenohoffmannia', NULL, 'Kuntze', 68),
(12428, 'Phaeocephalus', NULL, 'S.Moore', 18),
(12429, 'Phaeoneuron', NULL, 'Gilg', 105),
(12430, 'Phaeonychium', NULL, 'O.E.Schulz', 197),
(12431, 'Phaeoptilum', NULL, 'Radlk.', 117),
(12432, 'Phaeostemma', NULL, 'E.Fourn.', 10),
(12433, 'Phaeostigma', NULL, 'Muldashev', 18),
(12434, 'Phaestoma', NULL, 'Spach', 121),
(12435, 'Phagnalon', NULL, 'Cass.', 18),
(12436, 'Phainantha', NULL, 'Gleason', 105),
(12437, 'Phalacrachena', NULL, 'Iljin', 18),
(12438, 'Phalacraea', NULL, 'DC.', 18),
(12439, 'Phalacrocarpum', NULL, '(DC.) Willk.', 18),
(12440, 'Phalacroderis', NULL, 'DC.', 18),
(12441, 'Phalacroseris', NULL, 'A.Gray', 18),
(12442, 'Phaleria', NULL, 'Jack', 164),
(12443, 'Phallaria', NULL, 'Schumach. & Thonn.', 142),
(12444, 'Phanera', NULL, 'Lour.', 68),
(12445, 'Phanerocalyx', NULL, 'S.Moore', 119),
(12446, 'Phanerodiscus', NULL, 'Cavaco', 119),
(12447, 'Phaneroglossa', NULL, 'B.Nord.', 18),
(12448, 'Phanerogonocarpus', NULL, 'Cavaco', 108),
(12449, 'Phanerostylis', NULL, '(A.Gray) R.M.King & H.Rob.', 18),
(12450, 'Phania', NULL, 'DC.', 18),
(12451, 'Phanrangia', NULL, 'Tardieu', 6),
(12452, 'Pharbitis', NULL, 'Choisy', 46),
(12453, 'Pharmaceum', NULL, 'Kuntze', 105),
(12454, 'Pharmacosycea', NULL, 'Miq.', 109),
(12455, 'Phaseolus', NULL, 'L.', 68),
(12456, 'Phaulanthus', NULL, 'Ridl.', 105),
(12457, 'Phaulopsis', NULL, 'Willd.', 1),
(12458, 'Phaylopsis', NULL, 'Willd.(SUO)', 1),
(12459, 'Phebalium', NULL, 'Vent.', 143),
(12460, 'Phedimus', NULL, 'Raf.', 48),
(12461, 'Pheidonocarpa', NULL, 'L.E.Skog', 76),
(12462, 'Pheliandra', NULL, 'Werderm.', 154),
(12463, 'Phelipaea', NULL, 'Desf.(SUO)', 150),
(12464, 'Phellocalyx', NULL, 'Bridson', 142),
(12465, 'Phellodendron', NULL, 'Rupr.', 143),
(12466, 'Phellolophium', NULL, 'Baker', 9),
(12467, 'Phellopterus', NULL, 'Benth.', 9),
(12468, 'Phelypaea', NULL, 'L.', 400),
(12469, 'Phenakospermum', NULL, 'Endl.', 157),
(12470, 'Phenax', NULL, 'Wedd.', 171),
(12471, 'Pherosphaera', NULL, 'Archer', 132),
(12472, 'Pherotrichis', NULL, 'Decne.', 10),
(12473, 'Phialacanthus', NULL, 'Benth.', 1),
(12474, 'Phialanthus', NULL, 'Griseb.', 142),
(12475, 'Phialodiscus', NULL, 'Radlk.', 147),
(12476, 'Phidiasia', NULL, 'Urb.', 1),
(12477, 'Philacra', NULL, 'Dwyer', 118),
(12478, 'Philactis', NULL, 'Schrad.', 18),
(12479, 'Philastrea', NULL, 'Pierre', 106),
(12480, 'Philbornea', NULL, 'Hallier f.', 95),
(12481, 'Philgamia', NULL, 'Baill.', 101),
(12482, 'Philibertella', NULL, 'Vail', 10),
(12483, 'Philibertia', NULL, 'Kunth', 10),
(12484, 'Philippia', NULL, 'Klotzsch', 64),
(12485, 'Phillipsia', NULL, 'Rolfe', 1),
(12486, 'Phillyraea', NULL, 'Moench(SUO)', 120),
(12487, 'Phillyrea', NULL, 'L.', 120),
(12488, 'Philodendron', NULL, 'Schott', 12),
(12489, 'Philoglossa', NULL, 'DC.', 18),
(12490, 'Philonotion', NULL, 'Schott', 12),
(12491, 'Philotheca', NULL, 'Rudge', 143),
(12492, 'Philoxerus', NULL, 'R.Br.', 5),
(12493, 'Philyra', NULL, 'Klotzsch', 66),
(12494, 'Philyrea', NULL, 'Blume(SUO)', 120),
(12495, 'Philyrophyllum', NULL, 'O.Hoffm.', 18),
(12496, 'Phinaea', NULL, 'Benth.', 76),
(12497, 'Phitopis', NULL, 'Hook.f.', 142),
(12498, 'Phlebiophragmus', NULL, 'O.E.Schulz', 197),
(12499, 'Phlebocalymna', NULL, 'Griff. ex Miers', 85),
(12500, 'Phlebochiton', NULL, 'Wall.', 6),
(12501, 'Phlebolobium', NULL, 'O.E.Schulz', 197),
(12502, 'Phlebophyllum', NULL, 'Nees', 1),
(12503, 'Phlebotaenia', NULL, 'Griseb.', 133),
(12504, 'Phlegmatospermum', NULL, 'O.E.Schulz', 197),
(12505, 'Phloga', NULL, 'Noronha ex Hook.f.', 15),
(12506, 'Phlogacanthus', NULL, 'Nees', 1),
(12507, 'Phlogella', NULL, 'Baill.', 15),
(12508, 'Phlojodicarpus', NULL, 'Turcz. ex Ledeb.', 9),
(12509, 'Phlomidoschema', NULL, '(Benth.) Vved.', 90),
(12510, 'Phlomis', NULL, 'L.', 90),
(12511, 'Phlomoides', NULL, 'Moench', 90),
(12512, 'Phlyarodoxa', NULL, 'S.Moore', 120),
(12513, 'Phlyctidocarpa', NULL, 'Cannon & W.L.Theob.', 9),
(12514, 'Phocea', NULL, 'Seem.', 66),
(12515, 'Phoebanthus', NULL, 'S.F.Blake', 18),
(12516, 'Phoenicanthemum', NULL, '(Blume) Blume', 98),
(12517, 'Phoenicanthus', NULL, 'Alston', 8),
(12518, 'Phoenicaulis', NULL, 'Nutt.', 197),
(12519, 'Phoenicocissus', NULL, 'Mart. ex Meisn.', 22),
(12520, 'Phoenicophorium', NULL, 'H.Wendl.', 15),
(12521, 'Phoenicoseris', NULL, '(Skottsb.) Skottsb.', 18),
(12522, 'Phoenix', NULL, 'L.', 15),
(12523, 'Pholacilia', NULL, 'Griseb.', 106),
(12524, 'Pholidia', NULL, 'R.Br.', 150),
(12525, 'Pholidostachys', NULL, 'H.Wendl. ex Hook.f.', 15),
(12526, 'Pholisma', NULL, 'Nutt. ex Hook.', 25),
(12527, 'Pholistoma', NULL, 'Lilja', 25),
(12528, 'Phoradendron', NULL, 'Nutt.', 146),
(12529, 'Phornothamnus', NULL, 'Baker', 105),
(12530, 'Phosanthus', NULL, 'Raf.(SUI)', 142),
(12531, 'Phragmanthera', NULL, 'Tiegh.', 98),
(12532, 'Phragmocarpidium', NULL, 'Krapov.', 102),
(12533, 'Phragmocassia', NULL, 'Britton & Rose', 68),
(12534, 'Phragmotheca', NULL, 'Cuatrec.', 102),
(12535, 'Phrissocarpus', NULL, 'Miers', 10),
(12536, 'Phrodus', NULL, 'Miers', 154),
(12537, 'Phryganocydia', NULL, 'Mart. ex Bureau', 22),
(12538, 'Phrygilanthus', NULL, 'Eichler', 98),
(12539, 'Phrygiobureaua', NULL, 'Kuntze', 22),
(12540, 'Phryne', NULL, 'Bubani', 197),
(12541, 'Phrynium', NULL, 'Willd.', 103),
(12542, 'Phtheirospermum', NULL, 'Bunge ex Fisch. & C.A.Mey.', 400),
(12543, 'Phthirusa', NULL, 'Mart.', 98),
(12544, 'Phuopsis', NULL, '(Griseb.) Hook.f.', 142),
(12545, 'Phygelius', NULL, 'E.Mey. ex Benth.', 150),
(12546, 'Phyla', NULL, 'Lour.', 173),
(12547, 'Phylacium', NULL, 'Benn.', 68),
(12548, 'Phylanthera', NULL, 'Noronha', 142),
(12549, 'Phylica', NULL, 'L.', 139),
(12550, 'Phyllacantha', NULL, 'Hook.f.(SUO)', 142),
(12551, 'Phyllacanthus', NULL, 'Hook.f.', 142),
(12552, 'Phyllagathis', NULL, 'Blume', 105),
(12553, 'Phyllanoa', NULL, 'Croizat', 184),
(12554, 'Phyllanthera', NULL, 'Blume', 10),
(12555, 'Phyllanthodendron', NULL, 'Hemsl.', 184),
(12556, 'Phyllapophysis', NULL, 'Mansf.', 105),
(12557, 'Phyllarthron', NULL, 'DC.', 22),
(12558, 'Phyllaurea', NULL, 'Lour.', 66),
(12559, 'Phyllera', NULL, 'Endl.(SUO)', 66),
(12560, 'Phyllirea', NULL, 'Duhamel(SUO)', 120),
(12561, 'Phyllis', NULL, 'L.', 142),
(12562, 'Phyllobaea', NULL, 'Benth.(SUO)', 76),
(12563, 'Phylloboea', NULL, 'Benth.', 76),
(12564, 'Phyllocalyx', NULL, 'O.Berg', 116),
(12565, 'Phyllocara', NULL, 'Gusul.', 25),
(12566, 'Phyllocarpus', NULL, 'Riedel ex Tul.', 68),
(12567, 'Phyllocephalum', NULL, 'Blume', 18),
(12568, 'Phyllocharis', NULL, 'Diels(SUH)', 30),
(12569, 'Phyllochlamys', NULL, 'Bureau', 109),
(12570, 'Phylloclinium', NULL, 'Baill.', 145),
(12571, 'Phyllocrater', NULL, 'Wernham', 142),
(12572, 'Phylloctenium', NULL, 'Baill.', 22),
(12573, 'Phyllodesmis', NULL, 'Tiegh.', 98),
(12574, 'Phyllodium', NULL, 'Desv.', 68),
(12575, 'Phyllodoce', NULL, 'Salisb.', 64),
(12576, 'Phyllogeiton', NULL, '(Weberb.) Herzog', 139),
(12577, 'Phyllogonum', NULL, 'Coville', 134),
(12578, 'Phyllomelia', NULL, 'Griseb.', 142),
(12579, 'Phyllophyton', NULL, 'Kudo', 90),
(12580, 'Phyllopodium', NULL, 'Benth.', 150),
(12581, 'Phylloscirpus', NULL, 'C.B.Clarke', 55),
(12582, 'Phyllosma', NULL, 'Bolus', 143),
(12583, 'Phyllostegia', NULL, 'Benth.', 90),
(12584, 'Phyllostemonodaphne', NULL, 'Kosterm.', 91),
(12585, 'Phyllostephanus', NULL, 'Tiegh.', 98),
(12586, 'Phyllostylon', NULL, 'Capan. ex Benth.', 170),
(12587, 'Phyllota', NULL, '(DC.) Benth.', 68),
(12588, 'Phyllotrichum', NULL, 'Thorel ex Lecomte', 147),
(12589, 'Phylloxylon', NULL, 'Baill.', 68),
(12590, 'Phylohydrax', NULL, 'Puff', 142),
(12591, 'Phymaspermum', NULL, 'Less.', 18),
(12592, 'Phymatarum', NULL, 'M.Hotta', 12),
(12593, 'Phymatocarpus', NULL, 'F.Muell.', 116),
(12594, 'Phymosia', NULL, 'Desv.', 102),
(12595, 'Physacanthus', NULL, 'Benth.', 1),
(12596, 'Physalastrum', NULL, 'Monteiro', 102),
(12597, 'Physaliastrum', NULL, 'Makino', 154),
(12598, 'Physalidium', NULL, 'Fenzl', 197),
(12599, 'Physalis', NULL, 'L.', 154),
(12600, 'Physalodes', NULL, 'Boehm.', 154),
(12601, 'Physaloides', NULL, 'Moench', 154),
(12602, 'Physandra', NULL, 'Botsch.', 5),
(12603, 'Physanthillis', NULL, 'Boiss.', 68),
(12604, 'Physaria', NULL, '(Nutt.) A.Gray', 197),
(12605, 'Physedra', NULL, 'Hook.f.', 49),
(12606, 'Physetobasis', NULL, 'Hassk.', 10),
(12607, 'Physocalymma', NULL, 'Pohl', 99),
(12608, 'Physocalymna', NULL, 'DC.(SUO)', 99),
(12609, 'Physocalyx', NULL, 'Pohl', 400),
(12610, 'Physocardamum', NULL, 'Hedge', 197),
(12611, 'Physocarpus', NULL, '(Cambess.) Maxim.', 141),
(12612, 'Physocaulis', NULL, '(DC.) Tausch', 9),
(12613, 'Physochlaina', NULL, 'G.Don', 154),
(12614, 'Physodeira', NULL, 'Hanst.', 76),
(12615, 'Physodium', NULL, 'C.Presl', 102),
(12616, 'Physokentia', NULL, 'Becc.', 15),
(12617, 'Physoleucas', NULL, 'Jaub. & Spach', 90),
(12618, 'Physolophium', NULL, 'Turcz.', 9),
(12619, 'Physoplexis', NULL, '(Endl.) Schur', 30),
(12620, 'Physopodium', NULL, 'Desv.', 44),
(12621, 'Physopsis', NULL, 'Turcz.', 90),
(12622, 'Physoptychis', NULL, 'Boiss.', 197),
(12623, 'Physopyrum', NULL, 'Popov', 134),
(12624, 'Physorhynchus', NULL, 'Hook.', 197),
(12625, 'Physospermopsis', NULL, 'H.Wolff', 9),
(12626, 'Physospermum', NULL, 'Cusson ex Juss.', 9),
(12627, 'Physostegia', NULL, 'Benth.', 90),
(12628, 'Physostelma', NULL, 'Wight', 10),
(12629, 'Physostemon', NULL, 'Mart.', 32),
(12630, 'Physostigma', NULL, 'Balf.', 68),
(12631, 'Physotrichia', NULL, 'Hiern', 9),
(12632, 'Phyteuma', NULL, 'L.', 30),
(12633, 'Phyteumoides', NULL, 'Smeathman ex DC.', 142),
(12634, 'Phytocrene', NULL, 'Wall.', 85),
(12635, 'Phytolacca', NULL, 'L.', 128),
(12636, 'Piaggiaea', NULL, 'Chiov.', 10),
(12637, 'Piaranthus', NULL, 'R.Br.', 10),
(12638, 'Picardaea', NULL, 'Urb.', 142),
(12639, 'Picconia', NULL, 'DC.', 120),
(12640, 'Picea', NULL, 'A.Dietr.', 129),
(12641, 'Pichisermollia', NULL, 'H.C.Monteiro', 15),
(12642, 'Pichleria', NULL, 'Stapf & Wettst.', 9),
(12643, 'Pichonia', NULL, 'Pierre', 148),
(12644, 'Pickeringia', NULL, 'Nutt.', 68),
(12645, 'Picnomon', NULL, 'Adans.', 18),
(12646, 'Picradeniopsis', NULL, 'Rydb.', 18),
(12647, 'Picraena', NULL, 'Lindl.', 151),
(12648, 'Picria', NULL, 'Lour.', 423),
(12649, 'Picricarya', NULL, 'Dennst.', 120),
(12650, 'Picris', NULL, 'L.', 18),
(12651, 'Picrocardia', NULL, 'Radlk.', 151),
(12652, 'Picrodendron', NULL, 'Griseb.', 534),
(12653, 'Picroderma', NULL, 'Thorel ex Gagnep.', 106),
(12654, 'Picrolemma', NULL, 'Hook.f.', 151),
(12655, 'Picrorhiza', NULL, 'Royle ex Benth.', 423),
(12656, 'Picrosia', NULL, 'D.Don', 18),
(12657, 'Picrothamnus', NULL, 'Nutt.', 18),
(12658, 'Pictetia', NULL, 'DC.', 68),
(12659, 'Piddingtonia', NULL, 'A.DC.', 30),
(12660, 'Pierardia', NULL, 'Roxb.', 184),
(12661, 'Pieris', NULL, 'D.Don', 64),
(12662, 'Pierranthus', NULL, 'Bonati', 150),
(12663, 'Pierrea', NULL, 'F.Heim', 60),
(12664, 'Pierrina', NULL, 'Engl.', 92),
(12665, 'Pigafetta', NULL, '(Blume) Becc.', 15),
(12666, 'Pigea', NULL, 'DC.', 174),
(12667, 'Pilea', NULL, 'Lindl.', 171),
(12668, 'Pileanthus', NULL, 'Labill.', 116),
(12669, 'Pileocalyx', NULL, 'Gasp.', 49),
(12670, 'Pileus', NULL, 'Ramirez', 34),
(12671, 'Pilgerodendron', NULL, 'Florin', 51),
(12672, 'Pilidiostigma', NULL, 'Burret', 116),
(12673, 'Pilinophyton', NULL, 'Klotzsch', 66),
(12674, 'Piliocalyx', NULL, 'Brongn. & Gris', 116),
(12675, 'Piliostigma', NULL, 'Hochst.', 68),
(12676, 'Piloblephis', NULL, 'Raf.', 90),
(12677, 'Pilocarpus', NULL, 'Vahl', 143),
(12678, 'Pilocosta', NULL, 'Almeda & Whiffin', 105),
(12679, 'Pilogyne', NULL, 'Eckl. ex Schrad.', 49),
(12680, 'Pilophora', NULL, 'Jacq.', 15),
(12681, 'Pilopleura', NULL, 'Schischk.', 9),
(12682, 'Pilosella', NULL, 'Hill', 18),
(12683, 'Piloselloides', NULL, '(Less.) C.Jeffrey', 18),
(12684, 'Pilosperma', NULL, 'Planch. & Triana', 42),
(12685, 'Pilostemon', NULL, 'Iljin', 18),
(12686, 'Pilostigma', NULL, 'Costantin(SUH)', 10),
(12687, 'Pilothecium', NULL, '(Kiaersk.) Kausel', 116),
(12688, 'Pimecaria', NULL, 'Raf.', 119),
(12689, 'Pimelandra', NULL, 'A.DC.', 115),
(12690, 'Pimelea', NULL, 'Banks & Sol.', 164),
(12691, 'Pimenta', NULL, 'Lindl.', 116),
(12692, 'Pimentelia', NULL, 'Wedd.', 142),
(12693, 'Pimentus', NULL, 'Raf.', 116),
(12694, 'Pimia', NULL, 'Seem.', 102),
(12695, 'Pimpinella', NULL, 'L.', 9),
(12696, 'Pinacantha', NULL, 'Gilli', 9),
(12697, 'Pinacopodium', NULL, 'Exell & Mendonca', 65),
(12698, 'Pinaropappus', NULL, 'Less.', 18),
(12699, 'Pinarophyllon', NULL, 'Brandegee', 142),
(12700, 'Pinckneya', NULL, 'Michx.', 142),
(12701, 'Pinda', NULL, 'P.K.Mukh. & Constance', 9),
(12702, 'Pindarea', NULL, 'Barb.Rodr.', 15),
(12703, 'Pineda', NULL, 'Ruiz & Pav.', 145),
(12704, 'Pinellia', NULL, 'Ten.', 12),
(12705, 'Pinillosia', NULL, 'Ossa', 18),
(12706, 'Pinknea', NULL, 'Pers.(SUO)', 142),
(12707, 'Pintoa', NULL, 'Gay', 177),
(12708, 'Pinus', NULL, 'L.', 129),
(12709, 'Pinzona', NULL, 'Mart. & Zucc.', 58),
(12710, 'Pionandra', NULL, 'Miers', 154),
(12711, 'Pionocarpus', NULL, 'S.F.Blake', 18),
(12712, 'Piora', NULL, 'J.Kost.', 18),
(12713, 'Piperanthera', NULL, 'C.DC.', 130),
(12714, 'Pippenalia', NULL, 'McVaugh', 18),
(12715, 'Piptadeniopsis', NULL, 'Burkart', 68),
(12716, 'Piptandra', NULL, 'Turcz.', 116),
(12717, 'Piptanthus', NULL, 'Sweet', 68),
(12718, 'Piptocarpha', NULL, 'R.Br.', 18),
(12719, 'Piptochlamys', NULL, 'C.A.Mey.', 164),
(12720, 'Piptocoma', NULL, 'Cass.', 18),
(12721, 'Piptolepis', NULL, 'Sch.Bip.', 18),
(12722, 'Piptoptera', NULL, 'Bunge', 5),
(12723, 'Piptospatha', NULL, 'N.E.Br.', 12),
(12724, 'Piptothrix', NULL, 'A.Gray', 18),
(12725, 'Piqueria', NULL, 'Cav.', 18),
(12726, 'Piqueriella', NULL, 'R.M.King & H.Rob.', 18),
(12727, 'Piqueriopsis', NULL, 'R.M.King', 18),
(12728, 'Piranhea', NULL, 'Baill.', 534),
(12729, 'Piratinera', NULL, 'Aubl.', 109),
(12730, 'Pirazzia', NULL, 'Chiov.', 197),
(12731, 'Pirea', NULL, 'T.Durand', 197),
(12732, 'Piresodendron', NULL, 'Aubrev.', 148),
(12733, 'Piriadacus', NULL, 'Pichon', 22),
(12734, 'Pirigara', NULL, 'Aubl.', 92),
(12735, 'Piringa', NULL, 'Juss.', 142),
(12736, 'Piriqueta', NULL, 'Aubl.', 169),
(12737, 'Pirottantha', NULL, 'Speg.', 68),
(12738, 'Pisaura', NULL, 'Bonato', 121),
(12739, 'Piscaria', NULL, 'Piper', 66),
(12740, 'Piscidia', NULL, 'L.', 68),
(12741, 'Piscipula', NULL, 'Loefl.', 68),
(12742, 'Pisoniella', NULL, '(Heimerl) Standl.', 117),
(12743, 'Pisophaca', NULL, 'Rydb.', 68),
(12744, 'Pisosperma', NULL, 'Sond.', 49),
(12745, 'Pistacia', NULL, 'L.', 6),
(12746, 'Pistia', NULL, 'L.', 12),
(12747, 'Pistorinia', NULL, 'DC.', 48),
(12748, 'Pisum', NULL, 'L.', 68),
(12749, 'Pitardia', NULL, 'Batt. ex Pit.', 90),
(12750, 'Pitavia', NULL, 'Molina', 143),
(12751, 'Pitcheria', NULL, 'Nutt.', 68),
(12752, 'Pithecoctenium', NULL, 'Mart. ex Meisn.', 22),
(12753, 'Pithecoseris', NULL, 'Mart. ex DC.', 18),
(12754, 'Pithocarpa', NULL, 'Lindl.', 18),
(12755, 'Pithodes', NULL, 'O.F.Cook', 15),
(12756, 'Pitraea', NULL, 'Turcz.', 173),
(12757, 'Pittiera', NULL, 'Cogn.', 49),
(12758, 'Pittierothamnus', NULL, 'Steyerm.', 142),
(12759, 'Pittocaulon', NULL, 'H.Rob. & Brettell', 18),
(12760, 'Pittosporopsis', NULL, 'Craib', 85),
(12761, 'Pituranthos', NULL, 'Viv.', 9),
(12762, 'Pitygentias', NULL, 'Gilg(SUS)', 75),
(12763, 'Pityopsis', NULL, 'Nutt.', 18),
(12764, 'Pityopus', NULL, 'Small', 64),
(12765, 'Pityothamnus', NULL, 'Small', 8),
(12766, 'Pityranthe', NULL, 'Thwaites', 102),
(12767, 'Pityrocarpa', NULL, 'Britton & Rose', 68),
(12768, 'Pityrodia', NULL, 'R.Br.', 90),
(12769, 'Placocarpa', NULL, 'Hook.f.', 142),
(12770, 'Placodium', NULL, 'Hook.f.(SUH)', 142),
(12771, 'Placolobium', NULL, 'Miq.', 68),
(12772, 'Placoma', NULL, 'J.F.Gmel.(SUO)', 142),
(12773, 'Placopoda', NULL, 'Balf.f.', 142),
(12774, 'Placospermum', NULL, 'C.T.White & W.D.Francis', 135),
(12775, 'Pladaroxylon', NULL, '(Endl.) Hook.f.', 18),
(12776, 'Plaesiantha', NULL, 'Hook.f.', 140),
(12777, 'Plaesianthera', NULL, '(C.B.Clarke) Livera', 1),
(12778, 'Plagiacanthus', NULL, 'Nees', 1),
(12779, 'Plagianthera', NULL, 'Rchb.f. & Zoll.', 66),
(12780, 'Plagianthus', NULL, 'J.R.Forst. & G.Forst.', 102),
(12781, 'Plagiobasis', NULL, 'Schrenk', 18),
(12782, 'Plagiobothrys', NULL, 'Fisch. & C.A.Mey.', 25),
(12783, 'Plagiocarpus', NULL, 'Benth.', 68),
(12784, 'Plagioceltis', NULL, 'Mildbr. ex Baehni', 170),
(12785, 'Plagiocheilus', NULL, 'Arn. ex DC.', 18),
(12786, 'Plagiolobium', NULL, 'Sweet', 68),
(12787, 'Plagiolophus', NULL, 'Greenm.', 18),
(12788, 'Plagiopetalum', NULL, 'Rehder', 105),
(12789, 'Plagiopteron', NULL, 'Griff.', 38),
(12790, 'Plagioscyphus', NULL, 'Radlk.', 147),
(12791, 'Plagiosiphon', NULL, 'Harms', 68),
(12792, 'Plagiospermum', NULL, 'Oliv.(SUH)', 141),
(12793, 'Plagiostyles', NULL, 'Pierre', 66),
(12794, 'Plagiotaxis', NULL, 'Wall. ex Kuntze', 106),
(12795, 'Plagiotheca', NULL, 'Chiov.', 1),
(12796, 'Plagius', NULL, 'L''Her. ex DC.', 18),
(12797, 'Planaltoa', NULL, 'Taub.', 18),
(12798, 'Planea', NULL, 'P.O.Karis', 18),
(12799, 'Planera', NULL, 'J.F.Gmel.', 170),
(12800, 'Planodes', NULL, 'Greene', 197),
(12801, 'Plarodrigoa', NULL, 'Looser', 102),
(12802, 'Plastolaena', NULL, 'Pierre ex Chev.', 142),
(12803, 'Platanocarpum', NULL, 'Korth.', 142),
(12804, 'Platanocephalus', NULL, 'Crantz(SUS)', 142),
(12805, 'Plateilema', NULL, '(A.Gray) Cockerell', 18),
(12806, 'Platenia', NULL, 'H.Karst.', 15),
(12807, 'Plathymenia', NULL, 'Benth.', 68),
(12808, 'Platolaria', NULL, 'Raf.', 22),
(12809, 'Platonia', NULL, 'Mart.', 42),
(12810, 'Platostoma', NULL, 'P.Beauv.', 90),
(12811, 'Platyadenia', NULL, 'B.L.Burtt', 76),
(12812, 'Platycalyx', NULL, 'N.E.Br.', 64),
(12813, 'Platycapnos', NULL, '(DC.) Bernh.', 126),
(12814, 'Platycarpha', NULL, 'Less.', 18),
(12815, 'Platycarpum', NULL, 'Bonpl.', 142),
(12816, 'Platycarya', NULL, 'Siebold & Zucc.', 87),
(12817, 'Platycelyphium', NULL, 'Harms', 68),
(12818, 'Platycentrum', NULL, 'Naudin', 105),
(12819, 'Platychaete', NULL, 'Boiss.', 18),
(12820, 'Platycladus', NULL, 'Spach', 51),
(12821, 'Platycodon', NULL, 'A.DC.', 30),
(12822, 'Platycraspedum', NULL, 'O.E.Schulz', 197),
(12823, 'Platycyamus', NULL, 'Benth.', 68),
(12824, 'Platydesma', NULL, 'H.Mann', 143),
(12825, 'Platyelasma', NULL, 'Kitag.', 90),
(12826, 'Platygonia', NULL, 'Naudin', 49),
(12827, 'Platygyna', NULL, 'Mercier', 66),
(12828, 'Platykeleba', NULL, 'N.E.Br.', 10),
(12829, 'Platylobium', NULL, 'Sm.', 68),
(12830, 'Platylophus', NULL, 'D.Don', 50),
(12831, 'Platyluma', NULL, 'Baill.', 148),
(12832, 'Platymerium', NULL, 'Bartl. ex DC.', 142),
(12833, 'Platymitra', NULL, 'Boerl.', 8),
(12834, 'Platynema', NULL, 'Wight & Arn.', 101),
(12835, 'Platyosprion', NULL, '(Maxim.) Maxim.', 68),
(12836, 'Platypholis', NULL, 'Maxim.', 400),
(12837, 'Platypodanthera', NULL, 'R.M.King & H.Rob.', 18),
(12838, 'Platyptelea', NULL, 'J.Drumm. ex Harv.', 50),
(12839, 'Platypterocarpus', NULL, 'Dunkley & Brenan', 38),
(12840, 'Platyraphe', NULL, 'Miq.', 9),
(12841, 'Platysace', NULL, 'Bunge', 9),
(12842, 'Platyschkuhria', NULL, '(A.Gray) Rydb.', 18),
(12843, 'Platysepalum', NULL, 'Welw. ex Baker', 68),
(12844, 'Platyspermum', NULL, 'Hook.', 197),
(12845, 'Platystemma', NULL, 'Wall.', 76),
(12846, 'Platystemon', NULL, 'Benth.', 126),
(12847, 'Platystigma', NULL, 'Benth.', 126),
(12848, 'Platythea', NULL, 'O.F.Cook(SUI)', 15),
(12849, 'Platytheca', NULL, 'Steetz', 62),
(12850, 'Platytinospora', NULL, '(Engl.) Diels', 107),
(12851, 'Plazia', NULL, 'Ruiz & Pav.', 18),
(12852, 'Plecospermum', NULL, 'Trecul', 109),
(12853, 'Plecostachys', NULL, 'Hilliard & B.L.Burtt', 18),
(12854, 'Plectaneia', NULL, 'Thouars', 10),
(12855, 'Plectanthera', NULL, 'Mart. & Zucc.', 118),
(12856, 'Plectis', NULL, 'O.F.Cook', 15),
(12857, 'Plectocephalus', NULL, 'D.Don', 18),
(12858, 'Plectocomia', NULL, 'Mart. ex Blume', 15),
(12859, 'Plectocomiopsis', NULL, 'Becc.', 15),
(12860, 'Plectopoma', NULL, 'Hanst.', 76),
(12861, 'Plectranthastrum', NULL, 'T.C.E.Fr.', 90),
(12862, 'Plectranthus', NULL, 'L''Her.', 90),
(12863, 'Plectrocarpa', NULL, 'Gillies ex Hook. & Arn.', 177),
(12864, 'Plectroniella', NULL, 'Robyns', 142),
(12865, 'Plegmatolemma', NULL, 'Bremek.', 1),
(12866, 'Pleianthemum', NULL, 'K.Schum. ex A.Chev.', 102),
(12867, 'Pleimeris', NULL, 'Raf.', 142),
(12868, 'Pleiocardia', NULL, 'Greene', 197),
(12869, 'Pleiocarpidia', NULL, 'K.Schum.', 142),
(12870, 'Pleioceras', NULL, 'Baill.', 10),
(12871, 'Pleiochiton', NULL, 'Naudin ex A.Gray', 105),
(12872, 'Pleiococca', NULL, 'F.Muell.', 143),
(12873, 'Pleiocoryne', NULL, 'Rauschert', 142),
(12874, 'Pleiocraterium', NULL, 'Bremek.', 142),
(12875, 'Pleiogynium', NULL, 'Engl.', 6),
(12876, 'Pleiokirkia', NULL, 'Capuron', 151),
(12877, 'Pleioluma', NULL, 'Baill.', 148),
(12878, 'Pleiomeris', NULL, 'A.DC.', 115),
(12879, 'Pleiosepalum', NULL, 'Hand.-Mazz.', 141),
(12880, 'Pleiospermium', NULL, '(Engl.) Swingle', 143),
(12881, 'Pleiospora', NULL, 'Harv.', 68),
(12882, 'Pleiostachya', NULL, 'K.Schum.', 103),
(12883, 'Pleiostemon', NULL, 'Sond.', 184),
(12884, 'Pleiotaenia', NULL, 'J.M.Coult. & Rose', 9),
(12885, 'Pleiotaxis', NULL, 'Steetz', 18),
(12886, 'Pleistachyopiper', NULL, 'Trel.', 130),
(12887, 'Plenckia', NULL, 'Reissek', 38),
(12888, 'Pleocarphus', NULL, 'D.Don', 18),
(12889, 'Pleocaulus', NULL, 'Bremek.', 1),
(12890, 'Pleodendron', NULL, 'Tiegh.', 31),
(12891, 'Pleogyne', NULL, 'Miers', 107),
(12892, 'Pleonotoma', NULL, 'Miers', 22),
(12893, 'Pleopadium', NULL, 'Raf.', 66),
(12894, 'Pleotheca', NULL, 'Wall.(SUI)', 142),
(12895, 'Plerandra', NULL, 'A.Gray', 13),
(12896, 'Plerandropsis', NULL, 'R.Vig.', 13),
(12897, 'Pleroma', NULL, 'D.Don', 105),
(12898, 'Plesiatropha', NULL, 'Pierre ex Hutch.', 66),
(12899, 'Plesmonium', NULL, 'Schott', 12),
(12900, 'Plethadenia', NULL, 'Urb.', 143),
(12901, 'Plethiandra', NULL, 'Hook.f.', 105),
(12902, 'Plethyrsis', NULL, 'Raf.', 142),
(12903, 'Pleuradena', NULL, 'Raf.', 66),
(12904, 'Pleurandropsis', NULL, 'Baill.', 143),
(12905, 'Pleuranthemum', NULL, '(Pichon) Pichon', 10),
(12906, 'Pleuranthodes', NULL, 'Weberb.', 139),
(12907, 'Pleureia', NULL, 'Raf.', 142),
(12908, 'Pleuriarum', NULL, 'Nakai', 12),
(12909, 'Pleuricospora', NULL, 'A.Gray', 64),
(12910, 'Pleuripetalum', NULL, 'T.Durand(SUS)', 8),
(12911, 'Pleurisanthes', NULL, 'Baill.', 85),
(12912, 'Pleuroblepharis', NULL, 'Baill.', 1),
(12913, 'Pleurocalyptus', NULL, 'Brongn. & Gris', 116),
(12914, 'Pleurocarpaea', NULL, 'Benth.', 18),
(12915, 'Pleurocarpus', NULL, 'Klotzsch', 142),
(12916, 'Pleurocitrus', NULL, 'Tanaka(SUI)', 143),
(12917, 'Pleurocoffea', NULL, 'Baill.', 142),
(12918, 'Pleurocoronis', NULL, 'R.M.King & H.Rob.', 18),
(12919, 'Pleurogyna', NULL, 'Eschsch. ex Cham. & Schltdl.', 75),
(12920, 'Pleurogyne', NULL, 'Eschsch. ex Griseb.', 75),
(12921, 'Pleurogynella', NULL, 'Ikonn.', 75),
(12922, 'Pleuropappus', NULL, 'F.Muell.', 18),
(12923, 'Pleuropetalum', NULL, 'Hook.f.', 5),
(12924, 'Pleurophora', NULL, 'D.Don', 99),
(12925, 'Pleurophragma', NULL, 'Rydb.', 197),
(12926, 'Pleurophyllum', NULL, 'Hook.f.', 18),
(12927, 'Pleuropterantha', NULL, 'Franch.', 5),
(12928, 'Pleuropteropyrum', NULL, 'Gross', 134),
(12929, 'Pleuroridgea', NULL, 'Tiegh.', 118),
(12930, 'Pleurospa', NULL, 'Raf.', 12),
(12931, 'Pleurospermopsis', NULL, 'C.Norman', 9),
(12932, 'Pleurospermum', NULL, 'Hoffm.', 9),
(12933, 'Pleurostachys', NULL, 'Brongn.', 55),
(12934, 'Pleurostelma', NULL, 'Schltr.(SUH)', 10),
(12935, 'Pleurostima', NULL, 'Raf.', 172),
(12936, 'Pleurostylia', NULL, 'Wight & Arn.', 38),
(12937, 'Plexipus', NULL, 'Raf.', 173),
(12938, 'Plicosepalus', NULL, 'Tiegh.', 98),
(12939, 'Plicula', NULL, 'Raf.', 154),
(12940, 'Pliocarpida', NULL, 'Post & Kuntze(SUO)', 142),
(12941, 'Ploca', NULL, 'Lour. ex Gomes', 68),
(12942, 'Plocama', NULL, 'Aiton', 142),
(12943, 'Plocaniophyllon', NULL, 'Brandegee', 142),
(12944, 'Plocosperma', NULL, 'Benth.', 535),
(12945, 'Plocostemma', NULL, 'Blume', 10),
(12946, 'Plowmania', NULL, 'Hunz. & Subils', 154),
(12947, 'Pluchea', NULL, 'Cass.', 18),
(12948, 'Plukenetia', NULL, 'L.', 66),
(12949, 'Plumea', NULL, 'Lunan', 106),
(12950, 'Plumeriopsis', NULL, 'Rusby & Woodson', 10),
(12951, 'Plummera', NULL, 'A.Gray', 18),
(12952, 'Plutarchia', NULL, 'A.C.Sm.', 64),
(12953, 'Pneumonanthe', NULL, 'Gled.', 75),
(12954, 'Poacynum', NULL, 'Baill.', 10),
(12955, 'Poarium', NULL, 'Desv.', 150),
(12956, 'Pocillaria', NULL, 'Ridl.', 85),
(12957, 'Poculodiscus', NULL, 'Danguy & Choux', 147),
(12958, 'Podachaenium', NULL, 'Benth. ex Oerst.', 18),
(12959, 'Podalyria', NULL, 'Willd.', 68),
(12960, 'Podandra', NULL, 'Baill.', 10),
(12961, 'Podanthes', NULL, 'Haw.', 10),
(12962, 'Podanthum', NULL, 'Boiss.', 30),
(12963, 'Podanthus', NULL, 'Lag.', 18),
(12964, 'Podistera', NULL, 'S.Watson', 9),
(12965, 'Podocaelia', NULL, '(Benth.) A.Fern. & R.Fern.', 105),
(12966, 'Podocalyx', NULL, 'Klotzsch', 534),
(12967, 'Podocarpium', NULL, '(Benth.) Y.C.Yang & P.H.Huang', 68),
(12968, 'Podochrosia', NULL, 'Baill.', 10),
(12969, 'Podococcus', NULL, 'G.Mann & H.Wendl.', 15),
(12970, 'Podocoma', NULL, 'Cass.', 18),
(12971, 'Podocytisus', NULL, 'Boiss. & Heldr.', 68),
(12972, 'Podogynium', NULL, 'Taub.', 68),
(12973, 'Podolasia', NULL, 'N.E.Br.', 12),
(12974, 'Podolepis', NULL, 'Labill.', 18),
(12975, 'Podolotus', NULL, 'Royle', 68),
(12976, 'Podoluma', NULL, 'Baill.', 148),
(12977, 'Podonephelium', NULL, 'Baill.', 147),
(12978, 'Podonosma', NULL, 'Boiss.', 25),
(12979, 'Podoon', NULL, 'Baill.', 6),
(12980, 'Podopetalum', NULL, 'F.Muell.', 68),
(12981, 'Podophania', NULL, 'Baill.', 18),
(12982, 'Podopterus', NULL, 'Bonpl.', 134),
(12983, 'Podorungia', NULL, 'Baill.', 1),
(12984, 'Podosciadium', NULL, 'A.Gray', 9),
(12985, 'Podospermum', NULL, 'DC.', 18),
(12986, 'Podostachys', NULL, 'Klotzsch', 66),
(12987, 'Podostelma', NULL, 'K.Schum.', 10),
(12988, 'Podostemma', NULL, 'Greene', 10),
(12989, 'Podostigma', NULL, 'Elliott', 10),
(12990, 'Podotheca', NULL, 'Cass.', 18),
(12991, 'Podranea', NULL, 'Sprague', 22),
(12992, 'Poecilandra', NULL, 'Tul.', 118),
(12993, 'Poecilanthe', NULL, 'Benth.', 68),
(12994, 'Poecilocalyx', NULL, 'Bremek.', 142),
(12995, 'Poecilocarpus', NULL, 'Nevski', 68),
(12996, 'Poecilochroma', NULL, 'Miers', 154),
(12997, 'Poecilolepis', NULL, 'Grau', 18),
(12998, 'Poeciloneuron', NULL, 'Bedd.', 42),
(12999, 'Poederiopsis', NULL, 'Rusby', 142),
(13000, 'Poenosedum', NULL, 'Holub', 48),
(13001, 'Poeppigia', NULL, 'C.Presl', 68),
(13002, 'Pogenda', NULL, 'Raf.', 120),
(13003, 'Poggea', NULL, 'Gurke', 198),
(13004, 'Poggendorffia', NULL, 'H.Karst.', 127),
(13005, 'Poggeophyton', NULL, 'Pax', 66),
(13006, 'Pogogyne', NULL, 'Benth.', 90),
(13007, 'Pogonanthera', NULL, 'Blume', 105),
(13008, 'Pogonanthus', NULL, 'Montrouz.', 142),
(13009, 'Pogonolepis', NULL, 'Steetz', 18),
(13010, 'Pogonolobus', NULL, 'F.Muell.', 142),
(13011, 'Pogonophora', NULL, 'Miers ex Benth.', 66),
(13012, 'Pogonophyllum', NULL, 'Didr.', 66),
(13013, 'Pogonorrhinum', NULL, 'Betsche', 150),
(13014, 'Pogonospermum', NULL, 'Hochst.', 1),
(13015, 'Pogonotium', NULL, 'J.Dransf.', 15),
(13016, 'Pogonotrophe', NULL, 'Miq.', 109),
(13017, 'Pogostemon', NULL, 'Desf.', 90),
(13018, 'Poicilla', NULL, 'Griseb.', 10),
(13019, 'Poicillopsis', NULL, 'Schltr. ex Rendle', 10),
(13020, 'Poikilacanthus', NULL, 'Lindau', 1),
(13021, 'Poikilogyne', NULL, 'Baker f.', 105),
(13022, 'Poikilospermum', NULL, 'Zipp. ex Miq.', 171),
(13023, 'Poilanedora', NULL, 'Gagnep.', 32),
(13024, 'Poilaniella', NULL, 'Gagnep.', 66),
(13025, 'Poilannammia', NULL, 'C.Hansen', 105),
(13026, 'Poinciana', NULL, 'L.', 68),
(13027, 'Poincianella', NULL, 'Britton & Rose', 68),
(13028, 'Poinsettia', NULL, 'Graham', 66);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(13029, 'Poiretia', NULL, 'Vent.', 68),
(13030, 'Poissonella', NULL, 'Pierre', 148),
(13031, 'Poissonia', NULL, 'Baill.', 68),
(13032, 'Poitea', NULL, 'Vent.', 68),
(13033, 'Poivrea', NULL, 'Comm. ex DC.', 44),
(13034, 'Pojarkovia', NULL, 'Askerova', 18),
(13035, 'Pokornya', NULL, 'Montrouz.', 44),
(13036, 'Polakia', NULL, 'Stapf', 90),
(13037, 'Polakowskia', NULL, 'Pittier', 49),
(13038, 'Polanisia', NULL, 'Raf.', 509),
(13039, 'Polemannia', NULL, 'Eckl. & Zeyh.', 9),
(13040, 'Polemanniopsis', NULL, 'B.L.Burtt', 9),
(13041, 'Polhillia', NULL, 'C.H.Stirt.', 68),
(13042, 'Polianthes', NULL, 'L.', 3),
(13043, 'Poliomintha', NULL, 'A.Gray', 90),
(13044, 'Poliophyton', NULL, 'O.E.Schulz', 197),
(13045, 'Poliothyrsis', NULL, 'Oliv.', 145),
(13046, 'Polyachyrus', NULL, 'Lag.', 18),
(13047, 'Polyadoa', NULL, 'Stapf', 10),
(13048, 'Polyandra', NULL, 'Leal', 66),
(13049, 'Polyandrococos', NULL, 'Barb.Rodr.', 15),
(13050, 'Polyanthina', NULL, 'R.M.King & H.Rob.', 18),
(13051, 'Polyarrhena', NULL, 'Cass.', 18),
(13052, 'Polyaster', NULL, 'Hook.f.', 143),
(13053, 'Polyaulax', NULL, 'Backer', 8),
(13054, 'Polyboea', NULL, 'Klotzsch(SUH)', 64),
(13055, 'Polycalymma', NULL, 'F.Muell. & Sond.', 18),
(13056, 'Polycardia', NULL, 'Juss.', 38),
(13057, 'Polycarena', NULL, 'Benth.', 150),
(13058, 'Polycephalium', NULL, 'Engl.', 85),
(13059, 'Polychrysum', NULL, '(Tzvelev) Kovalevsk.', 18),
(13060, 'Polyclathra', NULL, 'Bertol.', 49),
(13061, 'Polyclita', NULL, 'A.C.Sm.', 64),
(13062, 'Polycnemum', NULL, 'L.', 5),
(13063, 'Polycoryne', NULL, 'Keay(SUH)', 142),
(13064, 'Polyctenium', NULL, 'Greene', 197),
(13065, 'Polycycliska', NULL, 'Ridl.', 142),
(13066, 'Polydiclis', NULL, '(G.Don) Miers', 154),
(13067, 'Polydragma', NULL, 'Hook.f.', 66),
(13068, 'Polygala', NULL, 'L.', 133),
(13069, 'Polygonanthus', NULL, 'Ducke', 7),
(13070, 'Polygonella', NULL, 'Michx.', 134),
(13071, 'Polygonum', NULL, 'L.', 134),
(13072, 'Polylepis', NULL, 'Ruiz & Pav.', 141),
(13073, 'Polylophium', NULL, 'Boiss.', 9),
(13074, 'Polylychnis', NULL, 'Bremek.', 1),
(13075, 'Polymeria', NULL, 'R.Br.', 46),
(13076, 'Polymnia', NULL, 'L.', 18),
(13077, 'Polyozus', NULL, 'Lour.', 142),
(13078, 'Polyphragmon', NULL, 'Desf.', 142),
(13079, 'Polyporandra', NULL, 'Becc.', 85),
(13080, 'Polypsecadium', NULL, 'O.E.Schulz', 197),
(13081, 'Polyrhabda', NULL, 'C.C.Towns.', 5),
(13082, 'Polyscias', NULL, 'J.R.Forst. & G.Forst.', 13),
(13083, 'Polysolen', NULL, 'Rauschert(SUS)', 142),
(13084, 'Polysolenia', NULL, 'Hook.f.', 142),
(13085, 'Polystemma', NULL, 'Decne.', 10),
(13086, 'Polystemon', NULL, 'D.Don(SUI)', 50),
(13087, 'Polystemonanthus', NULL, 'Harms', 68),
(13088, 'Polytaenia', NULL, 'DC.', 9),
(13089, 'Polytaxis', NULL, 'Bunge', 18),
(13090, 'Polythrix', NULL, 'Nees', 1),
(13091, 'Polythysania', NULL, 'Hanst.', 76),
(13092, 'Polytrema', NULL, 'C.B.Clarke', 1),
(13093, 'Polyura', NULL, 'Hook.f.', 142),
(13094, 'Polyzone', NULL, 'Endl.', 116),
(13095, 'Polyzygus', NULL, 'Dalzell', 9),
(13096, 'Pomaderris', NULL, 'Labill.', 139),
(13097, 'Pomangium', NULL, 'Reinw.', 142),
(13098, 'Pomasterion', NULL, 'Miq.', 49),
(13099, 'Pomatium', NULL, 'C.F.Gaertn.', 142),
(13100, 'Pomatostoma', NULL, 'Stapf', 105),
(13101, 'Pomax', NULL, 'Sol. ex DC.', 142),
(13102, 'Pomazota', NULL, 'Ridl.', 142),
(13103, 'Pomelia', NULL, 'Durando ex Pomel', 9),
(13104, 'Pomphidea', NULL, 'Miers', 143),
(13105, 'Ponapea', NULL, 'Becc.', 15),
(13106, 'Poncirus', NULL, 'Raf.', 143),
(13107, 'Pongamia', NULL, 'Vent.', 68),
(13108, 'Pongamiopsis', NULL, 'R.Vig.', 68),
(13109, 'Pongati', NULL, 'Adans.', 30),
(13110, 'Pongatium', NULL, 'Juss.(SUO)', 30),
(13111, 'Pongelia', NULL, 'Raf.', 22),
(13112, 'Pongelion', NULL, 'Adans.', 68),
(13113, 'Pontopidana', NULL, 'Scop.', 92),
(13114, 'Pontya', NULL, 'A.Chev.', 109),
(13115, 'Poortmannia', NULL, 'Drake', 154),
(13116, 'Poponax', NULL, 'Raf.', 68),
(13117, 'Popoviocodonia', NULL, 'Fed.', 30),
(13118, 'Poppya', NULL, 'Neck. ex M.Roem.', 49),
(13119, 'Populina', NULL, 'Baill.', 1),
(13120, 'Populus', NULL, 'L.', 145),
(13121, 'Porana', NULL, 'Burm.f.', 46),
(13122, 'Poranopsis', NULL, 'Roberty', 46),
(13123, 'Poranthera', NULL, 'Rudge', 184),
(13124, 'Poraqueiba', NULL, 'Aubl.', 85),
(13125, 'Poraresia', NULL, 'Gleason', 66),
(13126, 'Porcelia', NULL, 'Ruiz & Pav.', 8),
(13127, 'Porlieria', NULL, 'Ruiz & Pav.', 177),
(13128, 'Porocarpus', NULL, 'Gaertn.', 142),
(13129, 'Porocystis', NULL, 'Radlk.', 147),
(13130, 'Porodittia', NULL, 'G.Don(SUS)', 150),
(13131, 'Porophyllum', NULL, 'Adans.', 18),
(13132, 'Porospermum', NULL, 'F.Muell.', 13),
(13133, 'Porphyranthus', NULL, 'Engl.', 180),
(13134, 'Porphyrocodon', NULL, 'Hook.f.', 197),
(13135, 'Porphyrocoma', NULL, 'Scheidw. ex Hook.', 1),
(13136, 'Porphyroscias', NULL, 'Miq.', 9),
(13137, 'Porphyrospatha', NULL, 'Engl.', 12),
(13138, 'Porphyrostemma', NULL, 'Benth. ex Oliv.', 18),
(13139, 'Portaea', NULL, 'Ten.', 154),
(13140, 'Portenschlagia', NULL, 'Vis.(SUH)', 9),
(13141, 'Portenschlagiella', NULL, 'Tutin', 9),
(13142, 'Porteranthus', NULL, 'Britton', 141),
(13143, 'Portesia', NULL, 'Cav.', 106),
(13144, 'Portlandia', NULL, 'P.Browne', 142),
(13145, 'Posadaea', NULL, 'Cogn.', 49),
(13146, 'Posoria', NULL, 'Raf.', 142),
(13147, 'Possira', NULL, 'Aubl.', 68),
(13148, 'Postia', NULL, 'Boiss. & Blanche(SUH)', 18),
(13149, 'Postuera', NULL, 'Raf.', 120),
(13150, 'Potameia', NULL, 'Thouars', 91),
(13151, 'Potamoganos', NULL, 'Sandwith', 22),
(13152, 'Potamoxylon', NULL, 'Raf.', 22),
(13153, 'Potaninia', NULL, 'Maxim.', 141),
(13154, 'Potentilla', NULL, 'L.', 141),
(13155, 'Poteranthera', NULL, 'Bong.', 105),
(13156, 'Poteridium', NULL, 'Spach', 141),
(13157, 'Poterium', NULL, 'L.', 141),
(13158, 'Pothoidium', NULL, 'Schott', 12),
(13159, 'Pothomorphe', NULL, 'Miq.', 130),
(13160, 'Pothos', NULL, 'L.', 12),
(13161, 'Potima', NULL, 'R.Hedw.', 142),
(13162, 'Potoxylon', NULL, 'Kosterm.', 91),
(13163, 'Pottingeria', NULL, 'Prain', 537),
(13164, 'Pottsia', NULL, 'Hook. & Arn.', 10),
(13165, 'Pouchetia', NULL, 'A.Rich.', 142),
(13166, 'Pounguia', NULL, 'Benoist', 1),
(13167, 'Poupartia', NULL, 'Comm. ex Juss.', 6),
(13168, 'Pouzolzia', NULL, 'Gaudich.', 171),
(13169, 'Povedadaphne', NULL, 'W.C.Burger', 91),
(13170, 'Pozoa', NULL, 'Lag.', 9),
(13171, 'Praecitrullus', NULL, 'Pangalo', 49),
(13172, 'Prageluria', NULL, 'N.E.Br.', 10),
(13173, 'Pragmotessara', NULL, 'Pierre', 38),
(13174, 'Pragmotropa', NULL, 'Pierre', 38),
(13175, 'Pranceacanthus', NULL, 'Wassh.', 1),
(13176, 'Prangos', NULL, 'Lindl.', 9),
(13177, 'Prasium', NULL, 'L.', 90),
(13178, 'Prasopepon', NULL, 'Naudin', 49),
(13179, 'Prasoxylon', NULL, 'M.Roem.', 106),
(13180, 'Pratia', NULL, 'Gaudich.', 30),
(13181, 'Pravinaria', NULL, 'Bremek.', 142),
(13182, 'Praxeliopsis', NULL, 'G.M.Barroso', 18),
(13183, 'Praxelis', NULL, 'Cass.', 18),
(13184, 'Prenanthella', NULL, 'Rydb.', 18),
(13185, 'Prenanthes', NULL, 'L.', 18),
(13186, 'Prepusa', NULL, 'Mart.', 75),
(13187, 'Preslia', NULL, 'Opiz', 90),
(13188, 'Prestonia', NULL, 'R.Br.', 10),
(13189, 'Preussiella', NULL, 'Gilg', 105),
(13190, 'Preussiodora', NULL, 'Keay', 142),
(13191, 'Prevostea', NULL, 'Choisy', 46),
(13192, 'Priamosia', NULL, 'Urb.', 145),
(13193, 'Priestleya', NULL, 'DC.', 68),
(13194, 'Prieurella', NULL, 'Pierre', 148),
(13195, 'Prieuria', NULL, 'DC.', 121),
(13196, 'Primularia', NULL, 'Brenan', 105),
(13197, 'Primulina', NULL, 'Hance', 76),
(13198, 'Princea', NULL, 'Dubard & Dop', 142),
(13199, 'Principina', NULL, 'Uittien', 55),
(13200, 'Pringlea', NULL, 'T.Anderson ex Hook.f.', 197),
(13201, 'Pringleophytum', NULL, 'A.Gray', 1),
(13202, 'Prinsepia', NULL, 'Royle', 141),
(13203, 'Printzia', NULL, 'Cass.', 18),
(13204, 'Prionitis', NULL, 'Oerst.', 1),
(13205, 'Prionoplectus', NULL, 'Oerst.', 76),
(13206, 'Prionopsis', NULL, 'Nutt.', 18),
(13207, 'Prionosciadium', NULL, 'S.Watson', 9),
(13208, 'Prionostemma', NULL, 'Miers', 38),
(13209, 'Prionotes', NULL, 'R.Br.', 64),
(13210, 'Prionotrichon', NULL, 'Botsch. & Vved.', 197),
(13211, 'Priotropis', NULL, 'Wight & Arn.', 68),
(13212, 'Prismatocarpus', NULL, 'L''Her.', 30),
(13213, 'Pristidia', NULL, 'Thwaites', 142),
(13214, 'Pristimera', NULL, 'Miers', 38),
(13215, 'Pritchardia', NULL, 'Seem. & H.Wendl.', 15),
(13216, 'Pritchardiopsis', NULL, 'Becc.', 15),
(13217, 'Pritzelago', NULL, 'Kuntze', 197),
(13218, 'Pritzelia', NULL, 'Schauer', 116),
(13219, 'Priva', NULL, 'Adans.', 173),
(13220, 'Proatriplex', NULL, 'Stutz & G.L.Chu', 5),
(13221, 'Problastes', NULL, 'Reinw.', 44),
(13222, 'Probletostemon', NULL, 'K.Schum.', 142),
(13223, 'Prochnyanthes', NULL, 'S.Watson', 3),
(13224, 'Prockiopsis', NULL, 'Baill.', 198),
(13225, 'Proclesia', NULL, 'Klotzsch', 64),
(13226, 'Procopiana', NULL, 'Gusul.(SUO)', 25),
(13227, 'Procopiania', NULL, 'Gusul.', 25),
(13228, 'Procrassula', NULL, 'Griseb.', 48),
(13229, 'Procris', NULL, 'Comm. ex Juss.', 171),
(13230, 'Prolobus', NULL, 'R.M.King & H.Rob.', 18),
(13231, 'Prolongoa', NULL, 'Boiss.', 18),
(13232, 'Prometheum', NULL, '(A.Berger) H.Ohba', 48),
(13233, 'Prosanerpis', NULL, 'S.F.Blake', 105),
(13234, 'Prosartema', NULL, 'Gagnep.', 66),
(13235, 'Proscephaleium', NULL, 'Korth.', 142),
(13236, 'Prosopidastrum', NULL, 'Burkart', 68),
(13237, 'Prosopostelma', NULL, 'Baill.', 10),
(13238, 'Prosorus', NULL, 'Dalzell', 184),
(13239, 'Prostanthera', NULL, 'Labill.', 90),
(13240, 'Prosthecidiscus', NULL, 'Donn.Sm.', 10),
(13241, 'Protarum', NULL, 'Engl.', 12),
(13242, 'Protea', NULL, 'L.', 135),
(13243, 'Proteopsis', NULL, 'Mart. & Zucc. ex Sch.Bip.', 18),
(13244, 'Protocyrtandra', NULL, 'Hosok.', 76),
(13245, 'Protogabunia', NULL, 'Boiteau', 10),
(13246, 'Protorhus', NULL, 'Engl.', 6),
(13247, 'Protoschwenckia', NULL, 'Soler.', 154),
(13248, 'Proustia', NULL, 'Lag.', 18),
(13249, 'Prozetia', NULL, 'Neck.(SUI)', 148),
(13250, 'Prumnopitys', NULL, 'Phil.', 132),
(13251, 'Prunella', NULL, 'L.', 90),
(13252, 'Prunellopsis', NULL, 'Kudo', 90),
(13253, 'Pryona', NULL, 'Miq.', 68),
(13254, 'Przewalskia', NULL, 'Maxim.', 154),
(13255, 'Psacadocalymma', NULL, 'Bremek.', 1),
(13256, 'Psacadopaepale', NULL, 'Bremek.', 1),
(13257, 'Psacaliopsis', NULL, 'H.Rob. & Brettell', 18),
(13258, 'Psacalium', NULL, 'Cass.', 18),
(13259, 'Psammetes', NULL, 'Hepper', 423),
(13260, 'Psammogeton', NULL, 'Edgew.', 9),
(13261, 'Psammomoya', NULL, 'Diels & Loes.', 38),
(13262, 'Psathura', NULL, 'Comm. ex Juss.', 142),
(13263, 'Psathyranthus', NULL, 'Ule', 98),
(13264, 'Psathyrotes', NULL, 'A.Gray', 18),
(13265, 'Psathyrotopsis', NULL, 'Rydb.', 18),
(13266, 'Psednotrichia', NULL, 'Hiern', 18),
(13267, 'Pseudabutilon', NULL, 'R.E.Fr.', 102),
(13268, 'Pseudacanthopale', NULL, 'Benoist', 1),
(13269, 'Pseudactis', NULL, 'S.Moore', 18),
(13270, 'Pseudaechmanthera', NULL, 'Bremek.', 1),
(13271, 'Pseudagrostistachys', NULL, 'Pax & K.Hoffm.', 66),
(13272, 'Pseudaidia', NULL, 'Tirveng.', 142),
(13273, 'Pseudais', NULL, 'Decne.', 164),
(13274, 'Pseudalbizzia', NULL, 'Britton & Rose', 68),
(13275, 'Pseudaleia', NULL, 'Thouars', 119),
(13276, 'Pseudammi', NULL, 'H.Wolff', 9),
(13277, 'Pseudanamomis', NULL, 'Kausel', 116),
(13278, 'Pseudannona', NULL, '(Baill.) Saff.', 8),
(13279, 'Pseudanthus', NULL, 'Sieber ex A.Spreng.', 534),
(13280, 'Pseudarabidella', NULL, 'O.E.Schulz', 197),
(13281, 'Pseudartabotrys', NULL, 'Pellegr.', 8),
(13282, 'Pseudarthria', NULL, 'Wight & Arn.', 68),
(13283, 'Pseudelephantopus', NULL, 'Rohr', 18),
(13284, 'Pseudellipanthus', NULL, 'Schellenb.', 45),
(13285, 'Pseudeminia', NULL, 'Verdc.', 68),
(13286, 'Pseudephedranthus', NULL, 'Aristeg.', 8),
(13287, 'Pseuderemostachys', NULL, 'Popov', 90),
(13288, 'Pseuderucaria', NULL, '(Boiss.) O.E.Schulz', 197),
(13289, 'Pseudibatia', NULL, 'Malme', 10),
(13290, 'Pseudixora', NULL, 'Miq.', 142),
(13291, 'Pseudo-Barleria', NULL, 'Oerst.', 1),
(13292, 'Pseudo-Lysimachium', NULL, '(W.D.J.Koch) Opiz(SUO)', 150),
(13293, 'Pseudoanastatica', NULL, '(Boiss.) Grossh.', 197),
(13294, 'Pseudobaccharis', NULL, 'Cabrera', 18),
(13295, 'Pseudobahia', NULL, '(A.Gray) Rydb.', 18),
(13296, 'Pseudobarleria', NULL, 'T.Anderson', 1),
(13297, 'Pseudobartlettia', NULL, 'Rydb.', 18),
(13298, 'Pseudobartsia', NULL, 'D.Y.Hong', 400),
(13299, 'Pseudobastardia', NULL, 'Hassl.', 102),
(13300, 'Pseudobersama', NULL, 'Verdc.', 106),
(13301, 'Pseudobesleria', NULL, 'Oerst.', 76),
(13302, 'Pseudoblepharis', NULL, 'Baill.(SUH)', 1),
(13303, 'Pseudoblepharispermum', NULL, 'J.-P.Lebrun & Stork', 18),
(13304, 'Pseudoboivinella', NULL, 'Aubrev. & Pellegr.', 148),
(13305, 'Pseudobotrys', NULL, 'Moeser', 255),
(13306, 'Pseudobrassaiopsis', NULL, 'R.N.Banerjee', 13),
(13307, 'Pseudobravoa', NULL, 'Rose', 3),
(13308, 'Pseudobraya', NULL, 'Korsh.', 197),
(13309, 'Pseudobrazzeia', NULL, 'Engl.', 92),
(13310, 'Pseudobrickellia', NULL, 'R.M.King & H.Rob.', 18),
(13311, 'Pseudocadia', NULL, 'Harms', 68),
(13312, 'Pseudocadiscus', NULL, 'Lisowski', 18),
(13313, 'Pseudocalymma', NULL, 'A.Samp. & Kuhlm.', 22),
(13314, 'Pseudocalyx', NULL, 'Radlk.', 1),
(13315, 'Pseudocamelina', NULL, '(Boiss.) N.Busch', 197),
(13316, 'Pseudocampanula', NULL, 'Kolak.', 30),
(13317, 'Pseudocapsicum', NULL, 'Medik.', 154),
(13318, 'Pseudocarapa', NULL, 'Hemsl.', 106),
(13319, 'Pseudocarpidium', NULL, 'Millsp.', 90),
(13320, 'Pseudocarum', NULL, 'C.Norman', 9),
(13321, 'Pseudocaryophyllus', NULL, 'O.Berg', 116),
(13322, 'Pseudocassia', NULL, 'Britton & Rose', 68),
(13323, 'Pseudocassine', NULL, 'Bredell', 38),
(13324, 'Pseudocatalpa', NULL, 'A.H.Gentry', 22),
(13325, 'Pseudocedrela', NULL, 'Harms', 106),
(13326, 'Pseudochimarrhis', NULL, 'Ducke', 142),
(13327, 'Pseudochirita', NULL, 'W.T.Wang', 76),
(13328, 'Pseudochrosia', NULL, 'Blume', 10),
(13329, 'Pseudocimum', NULL, 'Bremek.', 90),
(13330, 'Pseudocinchona', NULL, 'A.Chev.', 142),
(13331, 'Pseudocladia', NULL, 'Pierre', 148),
(13332, 'Pseudoclappia', NULL, 'Rydb.', 18),
(13333, 'Pseudoclausia', NULL, 'Popov', 197),
(13334, 'Pseudoconnarus', NULL, 'Radlk.', 45),
(13335, 'Pseudoconyza', NULL, 'Cuatrec.', 18),
(13336, 'Pseudocopaiva', NULL, 'Britton & P.Wilson', 68),
(13337, 'Pseudocorchorus', NULL, 'Capuron', 102),
(13338, 'Pseudocroton', NULL, 'Mull.Arg.', 66),
(13339, 'Pseudocryptocarya', NULL, 'Teschner', 91),
(13340, 'Pseudocunila', NULL, 'Brade', 90),
(13341, 'Pseudocyclanthera', NULL, 'Mart.Crov.', 49),
(13342, 'Pseudocydonia', NULL, '(C.K.Schneid.) C.K.Schneid.', 141),
(13343, 'Pseudocymopterus', NULL, 'J.M.Coult. & Rose', 9),
(13344, 'Pseudocynometra', NULL, 'Kuntze', 68),
(13345, 'Pseudocytisus', NULL, 'Kuntze', 197),
(13346, 'Pseudodatura', NULL, 'Zijp', 154),
(13347, 'Pseudodicliptera', NULL, 'Benoist', 1),
(13348, 'Pseudodigera', NULL, 'Chiov.', 5),
(13349, 'Pseudodissochaeta', NULL, 'M.P.Nayar', 105),
(13350, 'Pseudodracontium', NULL, 'N.E.Br.', 12),
(13351, 'Pseudoechinopepon', NULL, '(Cogn.) Cockerell', 49),
(13352, 'Pseudoentada', NULL, 'Britton & Rose', 68),
(13353, 'Pseudoeriosema', NULL, 'Hauman', 68),
(13354, 'Pseudoernestia', NULL, '(Cogn.) Krasser', 105),
(13355, 'Pseudoeurya', NULL, 'Yamam.', 162),
(13356, 'Pseudoeverardia', NULL, 'Gilly', 55),
(13357, 'Pseudofortuynia', NULL, 'Hedge', 197),
(13358, 'Pseudofumaria', NULL, 'Medik.', 126),
(13359, 'Pseudogaillonia', NULL, 'Lincz.', 142),
(13360, 'Pseudogardenia', NULL, 'Keay', 142),
(13361, 'Pseudogardneria', NULL, 'Racib.', 97),
(13362, 'Pseudoglochidion', NULL, 'Gamble', 184),
(13363, 'Pseudoglycine', NULL, 'F.J.Herm.', 68),
(13364, 'Pseudognaphalium', NULL, 'Kirp.', 18),
(13365, 'Pseudognidia', NULL, 'E.Phillips', 164),
(13366, 'Pseudogomphrena', NULL, 'R.E.Fr.', 5),
(13367, 'Pseudogonocalyx', NULL, 'Bisse & Berazain', 64),
(13368, 'Pseudogynoxys', NULL, '(Greenm.) Cabrera', 18),
(13369, 'Pseudohamelia', NULL, 'Wernham', 142),
(13370, 'Pseudohandelia', NULL, 'Tzvelev', 18),
(13371, 'Pseudohomalomena', NULL, 'A.D.Hawkes', 12),
(13372, 'Pseudohydrosme', NULL, 'Engl.', 12),
(13373, 'Pseudojacobaea', NULL, '(Hook.f.) R.Mathur', 18),
(13374, 'Pseudokyrsteniopsis', NULL, 'R.M.King & H.Rob.', 18),
(13375, 'Pseudolabatia', NULL, 'Aubrev. & Pellegr.', 148),
(13376, 'Pseudolachnostylis', NULL, 'Pax', 184),
(13377, 'Pseudolarix', NULL, 'Gordon', 129),
(13378, 'Pseudoligandra', NULL, 'Dillon & Sagast.', 18),
(13379, 'Pseudolitchi', NULL, 'Danguy & Choux', 147),
(13380, 'Pseudolithos', NULL, 'Bally', 10),
(13381, 'Pseudolopezia', NULL, 'Rose', 121),
(13382, 'Pseudolophanthus', NULL, 'Levin', 90),
(13383, 'Pseudolotus', NULL, 'Rech.f.', 68),
(13384, 'Pseudoludovia', NULL, 'Harling', 54),
(13385, 'Pseudolysimachion', NULL, '(W.D.J.Koch) Opiz', 150),
(13386, 'Pseudomachaerium', NULL, 'Hassl.', 68),
(13387, 'Pseudomacrolobium', NULL, 'Hauman', 68),
(13388, 'Pseudomantalania', NULL, 'J.-F.Leroy', 142),
(13389, 'Pseudomariscus', NULL, 'Rauschert(SUS)', 55),
(13390, 'Pseudomarrubium', NULL, 'Popov', 90),
(13391, 'Pseudomarsdenia', NULL, 'Baill.', 10),
(13392, 'Pseudomelissitus', NULL, 'Ovcz., Rassulova & Kinzik.', 68),
(13393, 'Pseudomertensia', NULL, 'Riedl', 25),
(13394, 'Pseudomorus', NULL, 'Bureau', 109),
(13395, 'Pseudomyrcianthes', NULL, 'Kausel', 116),
(13396, 'Pseudonemacladus', NULL, 'McVaugh', 30),
(13397, 'Pseudonephelium', NULL, 'Radlk.', 147),
(13398, 'Pseudonesohedyotis', NULL, 'Tennant', 142),
(13399, 'Pseudonoseris', NULL, 'H.Rob. & Brettell', 18),
(13400, 'Pseudopachystela', NULL, 'Aubrev. & Pellegr.', 148),
(13401, 'Pseudopaegma', NULL, 'Urb.', 22),
(13402, 'Pseudopanax', NULL, 'K.Koch', 13),
(13403, 'Pseudopancovia', NULL, 'Pellegr.', 147),
(13404, 'Pseudopavonia', NULL, 'Hassl.', 102),
(13405, 'Pseudopectinaria', NULL, 'Lavranos', 10),
(13406, 'Pseudopeponidium', NULL, 'Homolle ex Arenes', 142),
(13407, 'Pseudophoenix', NULL, 'H.Wendl. ex Sarg.', 15),
(13408, 'Pseudopinanga', NULL, 'Burret', 15),
(13409, 'Pseudopipturus', NULL, 'Skottsb.', 171),
(13410, 'Pseudoplantago', NULL, 'Suess.', 5),
(13411, 'Pseudoprosopis', NULL, 'Harms', 68),
(13412, 'Pseudoprotorhus', NULL, 'H.Perrier', 147),
(13413, 'Pseudopteris', NULL, 'Baill.', 147),
(13414, 'Pseudopyxis', NULL, 'Miq.', 142),
(13415, 'Pseudorachicallis', NULL, 'Post & Kuntze(SUO)', 142),
(13416, 'Pseudorhachicallis', NULL, 'Hook.f.', 142),
(13417, 'Pseudorlaya', NULL, '(Murb.) Murb.', 9),
(13418, 'Pseudorobanche', NULL, 'Rouy', 400),
(13419, 'Pseudorontium', NULL, '(A.Gray) Rothm.', 423),
(13420, 'Pseudorosularia', NULL, 'Gurgen.', 48),
(13421, 'Pseudoruellia', NULL, 'Benoist', 1),
(13422, 'Pseudosabicea', NULL, 'N.Halle', 142),
(13423, 'Pseudosagotia', NULL, 'Secco', 66),
(13424, 'Pseudosalacia', NULL, 'Codd', 38),
(13425, 'Pseudosantalum', NULL, 'Kuntze', 13),
(13426, 'Pseudosarcolobus', NULL, 'Costantin', 10),
(13427, 'Pseudosassafras', NULL, 'Lecomte', 91),
(13428, 'Pseudosbeckia', NULL, 'A.Fern. & R.Fern.', 105),
(13429, 'Pseudoschoenus', NULL, '(C.B.Clarke) Oteng-Yeb.', 55),
(13430, 'Pseudosciadium', NULL, 'Baill.', 525),
(13431, 'Pseudoscolopia', NULL, 'Gilg', 145),
(13432, 'Pseudosedum', NULL, '(Boiss.) A.Berger', 48),
(13433, 'Pseudoselinum', NULL, 'C.Norman', 9),
(13434, 'Pseudosempervivum', NULL, '(Boiss.) Grossh.', 197),
(13435, 'Pseudosericocoma', NULL, 'Cavaco', 5),
(13436, 'Pseudosicydium', NULL, 'Harms', 49),
(13437, 'Pseudosindora', NULL, 'Symington', 68),
(13438, 'Pseudosmelia', NULL, 'Sleumer', 145),
(13439, 'Pseudosmilax', NULL, 'Hayata', 153),
(13440, 'Pseudosmodingium', NULL, 'Engl.', 6),
(13441, 'Pseudosopubia', NULL, 'Engl.', 400),
(13442, 'Pseudosorocea', NULL, 'Baill.', 109),
(13443, 'Pseudospigelia', NULL, 'Klett', 97),
(13444, 'Pseudostenosiphonium', NULL, 'Lindau', 1),
(13445, 'Pseudostifftia', NULL, 'H.Rob.', 18),
(13446, 'Pseudostreblus', NULL, 'Bureau', 109),
(13447, 'Pseudostriga', NULL, 'Bonati', 400),
(13448, 'Pseudostrophis', NULL, 'T.Durand & B.D.Jacks.', 109),
(13449, 'Pseudotaenidia', NULL, 'Mack.', 9),
(13450, 'Pseudotragia', NULL, 'Pax', 66),
(13451, 'Pseudotrewia', NULL, 'Miq.', 66),
(13452, 'Pseudotrophis', NULL, 'Warb.', 109),
(13453, 'Pseudotsuga', NULL, 'Carriere', 129),
(13454, 'Pseudovesicaria', NULL, '(Boiss.) Rupr.', 197),
(13455, 'Pseudovigna', NULL, '(Harms) Verdc.', 68),
(13456, 'Pseudovouapa', NULL, 'Britton & Rose', 68),
(13457, 'Pseudoweinmannia', NULL, 'Engl.', 50),
(13458, 'Pseudowillughbeia', NULL, 'Markgr.', 10),
(13459, 'Pseudowintera', NULL, 'Dandy', 176),
(13460, 'Pseudowolffia', NULL, 'Hartog & Plas', 12),
(13461, 'Pseudoxalis', NULL, 'Rose', 124),
(13462, 'Pseudoxandra', NULL, 'R.E.Fr.', 8),
(13463, 'Pseudoxythece', NULL, 'Aubrev.', 148),
(13464, 'Pseusmagennetus', NULL, 'Ruschenb.', 10),
(13465, 'Psiadia', NULL, 'Jacq.', 18),
(13466, 'Psiadiella', NULL, 'Humbert', 18),
(13467, 'Psidiastrum', NULL, 'Bello', 116),
(13468, 'Psidiomyrtus', NULL, 'Guillaumin', 116),
(13469, 'Psidiopsis', NULL, 'O.Berg', 116),
(13470, 'Psiguria', NULL, 'Neck. ex Arn.', 49),
(13471, 'Psila', NULL, 'Phil.', 18),
(13472, 'Psilactis', NULL, 'A.Gray', 18),
(13473, 'Psilanthele', NULL, 'Lindau', 1),
(13474, 'Psilanthopsis', NULL, 'A.Chev.', 142),
(13475, 'Psilobium', NULL, 'Jack', 142),
(13476, 'Psilocarphus', NULL, 'Nutt.', 18),
(13477, 'Psilocarya', NULL, 'Torr.', 55),
(13478, 'Psilodigera', NULL, 'Suess.', 5),
(13479, 'Psiloesthes', NULL, 'Benoist', 1),
(13480, 'Psilolaemus', NULL, 'I.M.Johnst.', 25),
(13481, 'Psilonema', NULL, 'C.A.Mey.', 197),
(13482, 'Psilopeganum', NULL, 'Hemsl.', 143),
(13483, 'Psilostachys', NULL, 'Hochst.(SUH)', 5),
(13484, 'Psilostoma', NULL, 'Klotzsch', 142),
(13485, 'Psilostrophe', NULL, 'DC.', 18),
(13486, 'Psilotrichopsis', NULL, 'C.C.Towns.', 5),
(13487, 'Psilotrichum', NULL, 'Blume', 5),
(13488, 'Psiloxylon', NULL, 'Thouars ex Tul.', 116),
(13489, 'Psittacanthus', NULL, 'Mart.', 98),
(13490, 'Psophocarpus', NULL, 'DC.', 68),
(13491, 'Psoralea', NULL, 'L.', 68),
(13492, 'Psoralidium', NULL, 'Rydb.', 68),
(13493, 'Psorobatus', NULL, 'Rydb.', 68),
(13494, 'Psorodendron', NULL, 'Rydb.', 68),
(13495, 'Psorothamnus', NULL, 'Rydb.', 68),
(13496, 'Pstathura', NULL, 'Raf.(SUO)', 142),
(13497, 'Psychine', NULL, 'Desf.', 197),
(13498, 'Psychotrophum', NULL, 'P.Browne', 142),
(13499, 'Psychrogeton', NULL, 'Boiss.', 18),
(13500, 'Psychrophyton', NULL, 'Beauverd', 18),
(13501, 'Psyllocarpus', NULL, 'Mart. & Zucc.', 142),
(13502, 'Ptaeroxylon', NULL, 'Eckl. & Zeyh.', 143),
(13503, 'Ptelea', NULL, 'L.', 143),
(13504, 'Ptelidium', NULL, 'Thouars', 38),
(13505, 'Pteracanthus', NULL, '(Nees) Bremek.', 1),
(13506, 'Pterachenia', NULL, '(Benth.) Lipsch.', 18),
(13507, 'Pteralyxia', NULL, 'K.Schum.', 10),
(13508, 'Pterandra', NULL, 'A.Juss.', 101),
(13509, 'Pteridocalyx', NULL, 'Wernham', 142),
(13510, 'Pteridophyllum', NULL, 'Siebold & Zucc.', 126),
(13511, 'Pterigeron', NULL, '(DC.) Benth.', 18),
(13512, 'Pterilema', NULL, 'Reinw.', 87),
(13513, 'Pterisanthes', NULL, 'Blume', 181),
(13514, 'Pternopetalum', NULL, 'Franch.', 9),
(13515, 'Pterobesleria', NULL, 'C.V.Morton', 76),
(13516, 'Pterocarya', NULL, 'Kunth', 87),
(13517, 'Pterocassia', NULL, 'Britton & Rose', 68),
(13518, 'Pterocaulon', NULL, 'Elliott', 18),
(13519, 'Pterocelastrus', NULL, 'Meisn.', 38),
(13520, 'Pteroceltis', NULL, 'Maxim.', 253),
(13521, 'Pterochlamys', NULL, 'Roberty', 46),
(13522, 'Pterochrosia', NULL, 'Baill.', 10),
(13523, 'Pterocissus', NULL, 'Urb. & Ekman', 181),
(13524, 'Pterocladon', NULL, 'Hook.f.', 105),
(13525, 'Pterococcus', NULL, 'Pall.(SUH)', 66),
(13526, 'Pterocyclus', NULL, 'Klotzsch', 9),
(13527, 'Pterocypsela', NULL, 'C.Shih', 18),
(13528, 'Pterodon', NULL, 'Vogel', 68),
(13529, 'Pterogaillonia', NULL, 'Lincz.', 142),
(13530, 'Pterogastra', NULL, 'Naudin', 105),
(13531, 'Pterogyne', NULL, 'Tul.', 68),
(13532, 'Pterolepis', NULL, '(DC.) Miq.', 105),
(13533, 'Pterolobium', NULL, 'R.Br. ex Wight & Arn.', 68),
(13534, 'Pteroloma', NULL, 'Hochst. & Steud.', 32),
(13535, 'Pteromimosa', NULL, 'Britton', 68),
(13536, 'Pteromischus', NULL, 'Pichon', 22),
(13537, 'Pteronia', NULL, 'L.', 18),
(13538, 'Pteropavonia', NULL, 'Mattei', 102),
(13539, 'Pteropepon', NULL, '(Cogn.) Cogn.', 49),
(13540, 'Pteropetalum', NULL, 'Pax', 32),
(13541, 'Pterophacos', NULL, 'Rydb.', 68),
(13542, 'Pterophora', NULL, 'Harv.', 10),
(13543, 'Pterophylla', NULL, 'D.Don', 50),
(13544, 'Pteropodium', NULL, 'DC. ex Meisn.', 22),
(13545, 'Pteroptychia', NULL, 'Bremek.', 1),
(13546, 'Pteropyrum', NULL, 'Jaub. & Spach', 134),
(13547, 'Pterorhachis', NULL, 'Harms', 106),
(13548, 'Pteroscleria', NULL, 'Nees', 55),
(13549, 'Pterosicyos', NULL, 'Brandegee', 49),
(13550, 'Pterosiphon', NULL, 'Turcz.', 106),
(13551, 'Pterospora', NULL, 'Nutt.', 64),
(13552, 'Pterostegia', NULL, 'Fisch. & C.A.Mey.', 134),
(13553, 'Pterostelma', NULL, 'Wight', 10),
(13554, 'Pterostephus', NULL, 'C.Presl', 142),
(13555, 'Pterostyrax', NULL, 'Siebold & Zucc.', 158),
(13556, 'Pterotaberna', NULL, 'Stapf', 10),
(13557, 'Pterothrix', NULL, 'DC.', 18),
(13558, 'Pterotropia', NULL, 'W.F.Hillebr.', 13),
(13559, 'Pteroxygonum', NULL, 'Dammer & Diels', 134),
(13560, 'Pterygiella', NULL, 'Oliv.', 150),
(13561, 'Pterygiosperma', NULL, 'O.E.Schulz', 197),
(13562, 'Pterygocalyx', NULL, 'Maxim.', 75),
(13563, 'Pterygoloma', NULL, 'Hanst.', 76),
(13564, 'Pterygopappus', NULL, 'Hook.f.', 18),
(13565, 'Pterygopleurum', NULL, 'Kitag.', 9),
(13566, 'Pterygopodium', NULL, 'Harms', 68),
(13567, 'Pterygostemon', NULL, 'V.V.Botschantz.', 197),
(13568, 'Pteryxia', NULL, '(Nutt.) J.M.Coult. & Rose', 9),
(13569, 'Ptilanthelium', NULL, 'Steud.', 55),
(13570, 'Ptilanthus', NULL, 'Gleason', 105),
(13571, 'Ptilepida', NULL, 'Raf.', 18),
(13572, 'Ptilimnium', NULL, 'Raf.', 9),
(13573, 'Ptilocalais', NULL, 'A.Gray ex Greene', 18),
(13574, 'Ptilocalyx', NULL, 'Torr. & A.Gray', 25),
(13575, 'Ptilochaeta', NULL, 'Turcz.', 101),
(13576, 'Ptilostemon', NULL, 'Cass.', 18),
(13577, 'Ptilotrichum', NULL, 'C.A.Mey.', 197),
(13578, 'Ptilotus', NULL, 'R.Br.', 5),
(13579, 'Ptycanthera', NULL, 'Decne.', 10),
(13580, 'Ptychandra', NULL, 'Scheff.', 15),
(13581, 'Ptychocarpus', NULL, 'Kuhlm.', 145),
(13582, 'Ptychococcus', NULL, 'Becc.', 15),
(13583, 'Ptychodea', NULL, 'Willd. ex Cham. & Schltdl.(SUI)', 142),
(13584, 'Ptychodon', NULL, 'Klotzsch ex Rchb.', 99),
(13585, 'Ptycholobium', NULL, 'Harms', 68),
(13586, 'Ptychoraphis', NULL, 'Becc.', 15),
(13587, 'Ptychosema', NULL, 'Benth.', 68),
(13588, 'Ptychosperma', NULL, 'Labill.', 15),
(13589, 'Ptychostigma', NULL, 'Hochst.(SUI)', 142),
(13590, 'Ptychostylus', NULL, 'Tiegh.', 98),
(13591, 'Ptychotis', NULL, 'W.D.J.Koch', 9),
(13592, 'Ptyssiglottis', NULL, 'T.Anderson', 1),
(13593, 'Pubeta', NULL, 'L.', 142),
(13594, 'Pubistylus', NULL, 'Thoth.', 142),
(13595, 'Puccionia', NULL, 'Chiov.', 509),
(13596, 'Pueraria', NULL, 'DC.', 68),
(13597, 'Pugionium', NULL, 'Gaertn.', 197),
(13598, 'Pukanthus', NULL, 'Raf.', 154),
(13599, 'Pulchranthus', NULL, 'V.M.Baum, Reveal & Nowicke', 1),
(13600, 'Pulicaria', NULL, 'Gaertn.', 18),
(13601, 'Pullea', NULL, 'Schltr.', 50),
(13602, 'Pulmonaria', NULL, 'L.', 25),
(13603, 'Pultenaea', NULL, 'Sm.', 68),
(13604, 'Pulvinaria', NULL, 'E.Fourn.', 10),
(13605, 'Puneeria', NULL, 'Stocks', 154),
(13606, 'Punica', NULL, 'L.', 99),
(13607, 'Punicella', NULL, 'Turcz.', 116),
(13608, 'Punjuba', NULL, 'Britton & Rose', 68),
(13609, 'Puntia', NULL, 'Hedge', 90),
(13610, 'Pupalia', NULL, 'Juss.', 5),
(13611, 'Pupilla', NULL, 'Rizzini', 1),
(13612, 'Purdiaea', NULL, 'Planch.', 56),
(13613, 'Purdieanthus', NULL, 'Gilg', 75),
(13614, 'Purpurella', NULL, 'Naudin', 105),
(13615, 'Purpureostemon', NULL, 'Gugerli', 116),
(13616, 'Purpusia', NULL, 'Brandegee', 141),
(13617, 'Purshia', NULL, 'DC. ex Poir.', 141),
(13618, 'Pusaetha', NULL, 'Kuntze', 68),
(13619, 'Putoria', NULL, 'Pers.', 142),
(13620, 'Putranjiva', NULL, 'Wall.', 538),
(13621, 'Putterlickia', NULL, 'Endl.', 38),
(13622, 'Pycnandra', NULL, 'Benth.', 148),
(13623, 'Pycnanthemum', NULL, 'Michx.', 90),
(13624, 'Pycnarrhena', NULL, 'Miers ex Hook.f. & Thomson', 107),
(13625, 'Pycnobolus', NULL, 'Willd. ex O.E.Schulz', 197),
(13626, 'Pycnobotrya', NULL, 'Benth.', 10),
(13627, 'Pycnobregma', NULL, 'Baill.', 10),
(13628, 'Pycnocephalum', NULL, '(Less.) DC.', 18),
(13629, 'Pycnocycla', NULL, 'Lindl.', 9),
(13630, 'Pycnoneurum', NULL, 'Decne.', 10),
(13631, 'Pycnoplinthopsis', NULL, 'Jafri', 197),
(13632, 'Pycnoplinthus', NULL, 'O.E.Schulz', 197),
(13633, 'Pycnorhachis', NULL, 'Benth.', 10),
(13634, 'Pycnosandra', NULL, 'Blume', 66),
(13635, 'Pycnospatha', NULL, 'Thorel ex Gagnep.', 12),
(13636, 'Pycnosphace', NULL, 'Rydb.', 90),
(13637, 'Pycnosphaera', NULL, 'Gilg', 75),
(13638, 'Pycnospora', NULL, 'R.Br. ex Wight & Arn.', 68),
(13639, 'Pycnostachys', NULL, 'Hook.', 90),
(13640, 'Pycnostelma', NULL, 'Bunge ex Decne.', 10),
(13641, 'Pycnostylis', NULL, 'Pierre', 107),
(13642, 'Pycnothymus', NULL, '(Benth.) Small', 90),
(13643, 'Pycreus', NULL, 'P.Beauv.', 55),
(13644, 'Pygeum', NULL, 'Gaertn.', 141),
(13645, 'Pygmaeopremna', NULL, 'Merr.', 90),
(13646, 'Pygmaeothamnus', NULL, 'Robyns', 142),
(13647, 'Pygmea', NULL, 'Hook.f.(SUH)', 150),
(13648, 'Pynaertiodendron', NULL, 'De Wild.', 68),
(13649, 'Pyracantha', NULL, 'M.Roem.', 141),
(13650, 'Pyragma', NULL, 'Noronha', 8),
(13651, 'Pyragra', NULL, 'Bremek.', 142),
(13652, 'Pyramia', NULL, 'Cham.', 105),
(13653, 'Pyramidanthe', NULL, 'Miq.', 8),
(13654, 'Pyramidium', NULL, 'Boiss.', 197),
(13655, 'Pyramidocarpus', NULL, 'Oliv.', 73),
(13656, 'Pyramidoptera', NULL, 'Boiss.', 9),
(13657, 'Pyrenacantha', NULL, 'Wight', 85),
(13658, 'Pyrenocarpa', NULL, 'H.T.Chang & R.H.Miao', 116),
(13659, 'Pyrenoglyphis', NULL, 'H.Karst.', 15),
(13660, 'Pyrethrum', NULL, 'Zinn', 18),
(13661, 'Pyriluma', NULL, 'Baill.', 148),
(13662, 'Pyrogennema', NULL, 'Lunell', 121),
(13663, 'Pyrola', NULL, 'L.', 64),
(13664, 'Pyrospermum', NULL, 'Miq.', 38),
(13665, 'Pyrostegia', NULL, 'C.Presl', 22),
(13666, 'Pyrostria', NULL, 'Comm. ex Juss.', 142),
(13667, 'Pyrrhanthus', NULL, 'Jack', 44),
(13668, 'Pyrrhopappus', NULL, 'DC.', 18),
(13669, 'Pyrrocoma', NULL, 'Hook.', 18),
(13670, 'Pyrrothrix', NULL, 'Bremek.', 1),
(13671, 'Pyrularia', NULL, 'Michx.', 146),
(13672, 'Pyrus', NULL, 'L.', 141),
(13673, 'Pythius', NULL, 'B.D.Jacks.', 66),
(13674, 'Pyxidanthus', NULL, 'Naudin', 105),
(13675, 'Qaisera', NULL, 'Omer', 75),
(13676, 'Quadrangula', NULL, 'Baum.-Bod.(SUI)', 36),
(13677, 'Quadrella', NULL, 'J.Presl', 32),
(13678, 'Quadricasaea', NULL, 'Woodson', 10),
(13679, 'Quadricosta', NULL, 'Dulac(SUS)', 121),
(13680, 'Quadripterygium', NULL, 'Tardieu(SUS)', 38),
(13681, 'Quamoclidion', NULL, 'Choisy', 117),
(13682, 'Quamoclit', NULL, 'Moench(SUH)', 46),
(13683, 'Quapoya', NULL, 'Aubl.', 42),
(13684, 'Quaqua', NULL, 'N.E.Br.', 10),
(13685, 'Quartinia', NULL, 'Endl.', 99),
(13686, 'Quaternella', NULL, 'Pedersen', 5),
(13687, 'Quebrachia', NULL, 'Griseb.', 6),
(13688, 'Queenslandiella', NULL, 'Domin', 55),
(13689, 'Quelchia', NULL, 'N.E.Br.', 18),
(13690, 'Quelusia', NULL, 'Vand.', 121),
(13691, 'Quezelia', NULL, 'H.Scholz(SUH)', 197),
(13692, 'Quezeliantha', NULL, 'H.Scholz ex Rauschert', 197),
(13693, 'Quidproquo', NULL, 'Greuter & Burdet', 197),
(13694, 'Quiliusa', NULL, 'Hook.f.(SUO)', 121),
(13695, 'Quillaja', NULL, 'Molina', 539),
(13696, 'Quinchamalium', NULL, 'Molina', 146),
(13697, 'Quincula', NULL, 'Raf.', 154),
(13698, 'Quinetia', NULL, 'Cass.', 18),
(13699, 'Quinqueremulus', NULL, 'Paul G.Wilson', 18),
(13700, 'Quinquina', NULL, 'Boehm.', 142),
(13701, 'Quintilia', NULL, 'Endl.', 76),
(13702, 'Quiotania', NULL, 'Zarucchi', 10),
(13703, 'Quirosia', NULL, 'Blanco', 68),
(13704, 'Quisqualis', NULL, 'L.', 44),
(13705, 'Quisumbingia', NULL, 'Merr.', 10),
(13706, 'Quivisia', NULL, 'Cav.', 106),
(13707, 'Quivisianthe', NULL, 'Baill.', 106),
(13708, 'Rabdosia', NULL, 'Hassk.', 90),
(13709, 'Rabdosiella', NULL, 'Codd', 90),
(13710, 'Rabelaisia', NULL, 'Planch.', 143),
(13711, 'Racapa', NULL, 'M.Roem.', 106),
(13712, 'Rachicallis', NULL, 'DC.(SUO)', 142),
(13713, 'Raclathris', NULL, 'Raf.', 25),
(13714, 'Racosperma', NULL, 'Mart.', 68),
(13715, 'Radamaea', NULL, 'Benth.', 400),
(13716, 'Radia', NULL, 'Noronha(SUI)', 148),
(13717, 'Radiola', NULL, 'Hill', 95),
(13718, 'Radlkoferella', NULL, 'Pierre', 148),
(13719, 'Radlkoferotoma', NULL, 'Kuntze', 18),
(13720, 'Radyera', NULL, 'Bullock', 102),
(13721, 'Raffenaldia', NULL, 'Godr.', 197),
(13722, 'Rafinesquia', NULL, 'Raf.(SUH)', 18),
(13723, 'Rafnia', NULL, 'Thunb.', 68),
(13724, 'Ragala', NULL, 'Pierre', 148),
(13725, 'Rahowardiana', NULL, 'D''Arcy', 154),
(13726, 'Raillardella', NULL, '(A.Gray) Benth.', 18),
(13727, 'Raillardia', NULL, 'Gaudich.', 18),
(13728, 'Raillardiopsis', NULL, 'Rydb.', 18),
(13729, 'Raimannia', NULL, 'Rose', 121),
(13730, 'Raimondia', NULL, 'Saff.', 8),
(13731, 'Raimondianthus', NULL, 'Harms', 68),
(13732, 'Rainiera', NULL, 'Greene', 18),
(13733, 'Rajania', NULL, 'L.', 59),
(13734, 'Raleighia', NULL, 'Gardner', 145),
(13735, 'Ramatuela', NULL, 'Kunth', 44),
(13736, 'Ramatuella', NULL, 'Kunth(SUO)', 44),
(13737, 'Ramelia', NULL, 'Baill.', 66),
(13738, 'Rameya', NULL, 'Baill.', 107),
(13739, 'Ramirezella', NULL, 'Rose', 68),
(13740, 'Ramischia', NULL, 'Opiz ex Garcke', 64),
(13741, 'Ramisia', NULL, 'Glaz. ex Baill.', 117),
(13742, 'Ramona', NULL, 'Greene', 90),
(13743, 'Ramonda', NULL, 'Rich.', 76),
(13744, 'Ramorinoa', NULL, 'Speg.', 68),
(13745, 'Ramosmania', NULL, 'Tirveng. & Verdc.', 142),
(13746, 'Rampinia', NULL, 'C.B.Clarke', 49),
(13747, 'Ramsdenia', NULL, 'Britton', 184),
(13748, 'Ramspekia', NULL, 'Scop.', 142),
(13749, 'Ramusia', NULL, 'Nees', 1),
(13750, 'Ranevea', NULL, 'L.H.Bailey', 15),
(13751, 'Rangia', NULL, 'Griseb.(SUO)', 142),
(13752, 'Rangium', NULL, 'Juss.', 120),
(13753, 'Ranopisoa', NULL, 'J.-F.Leroy', 150),
(13754, 'Ranugia', NULL, '(Schltdl.) Post & Kuntze', 49),
(13755, 'Raoulia', NULL, 'Hook.f. ex Raoul', 18),
(13756, 'Raouliopsis', NULL, 'S.F.Blake', 18),
(13757, 'Raparia', NULL, 'F.K.Mey.', 197),
(13758, 'Raphanistrocarpus', NULL, '(Baill.) Pax', 49),
(13759, 'Raphanocarpus', NULL, 'Hook.f.', 49),
(13760, 'Raphanorhyncha', NULL, 'Rollins', 197),
(13761, 'Raphanus', NULL, 'L.', 197),
(13762, 'Raphiacme', NULL, 'K.Schum.', 10),
(13763, 'Raphidiocystis', NULL, 'Hook.f.', 49),
(13764, 'Raphiocarpus', NULL, 'Chun', 76),
(13765, 'Raphionacme', NULL, 'Harv.', 10),
(13766, 'Raphistemma', NULL, 'Wall.', 10),
(13767, 'Rapinia', NULL, 'Lour.', 30),
(13768, 'Rapistrum', NULL, 'Crantz', 197),
(13769, 'Rapona', NULL, 'Baill.', 46),
(13770, 'Rapunculus', NULL, 'Mill.', 30),
(13771, 'Rapuntia', NULL, 'Chevall.', 30),
(13772, 'Rapuntium', NULL, 'Mill.', 30),
(13773, 'Raputia', NULL, 'Aubl.', 143),
(13774, 'Raputiarana', NULL, 'Emmerich', 143),
(13775, 'Rastrophyllum', NULL, 'Wild & G.V.Pope', 18),
(13776, 'Rathea', NULL, 'H.Karst.', 15),
(13777, 'Ratibida', NULL, 'Raf.', 18),
(13778, 'Rauia', NULL, 'Nees & Mart.', 143),
(13779, 'Raukana', NULL, 'Seem.', 13),
(13780, 'Raulinoa', NULL, 'R.S.Cowan', 143),
(13781, 'Raulinoreitzia', NULL, 'R.M.King & H.Rob.', 18),
(13782, 'Rauwenhoffia', NULL, 'Scheff.', 8),
(13783, 'Rauwolfia', NULL, 'L.(SUO)', 10),
(13784, 'Ravenala', NULL, 'Adans.', 157),
(13785, 'Ravenea', NULL, 'C.D.Bouche', 15),
(13786, 'Ravenia', NULL, 'Vell.', 143),
(13787, 'Raveniopsis', NULL, 'Gleason', 143),
(13788, 'Ravensara', NULL, 'Sonn.', 91),
(13789, 'Ravnia', NULL, 'Oerst.', 142),
(13790, 'Rawsonia', NULL, 'Harv. & Sond.', 198),
(13791, 'Rayera', NULL, 'Gaudich.', 154),
(13792, 'Rayleya', NULL, 'Cristobal', 102),
(13793, 'Raynalia', NULL, 'Sojak', 55),
(13794, 'Razisea', NULL, 'Oerst.', 1),
(13795, 'Razoumofskia', NULL, 'Hoffm.', 146),
(13796, 'Razumovia', NULL, 'Spreng.', 150),
(13797, 'Rea', NULL, 'Bertero ex Decne.', 18),
(13798, 'Readea', NULL, 'Gillespie', 142),
(13799, 'Reaumuria', NULL, 'L.', 160),
(13800, 'Reboudia', NULL, 'Coss. & Durieu', 197),
(13801, 'Recchia', NULL, 'Moc. & Sesse ex DC.', 475),
(13802, 'Rechsteineria', NULL, 'Regel', 76),
(13803, 'Recordia', NULL, 'Moldenke', 173),
(13804, 'Recordoxylon', NULL, 'Ducke', 68),
(13805, 'Rectomitra', NULL, 'Blume', 105),
(13806, 'Redia', NULL, 'Casar.', 66),
(13807, 'Redowskia', NULL, 'Cham. & Schltdl.', 197),
(13808, 'Reedia', NULL, 'F.Muell.', 55),
(13809, 'Reedrollinsia', NULL, 'J.W.Walker', 8),
(13810, 'Reevesia', NULL, 'Lindl.', 102),
(13811, 'Regelia', NULL, 'Schauer', 116),
(13812, 'Registaniella', NULL, 'Rech.f.', 9),
(13813, 'Regmus', NULL, 'Dulac(SUS)', 121),
(13814, 'Regnaldia', NULL, 'Baill.', 66),
(13815, 'Rehdera', NULL, 'Moldenke', 173),
(13816, 'Rehderodendron', NULL, 'Hu', 158),
(13817, 'Rehderophoenix', NULL, 'Burret', 15),
(13818, 'Rehmannia', NULL, 'Libosch. ex Fisch. & C.A.Mey.', 150),
(13819, 'Rehsonia', NULL, 'Stritch', 68),
(13820, 'Reichardia', NULL, 'Roth', 18),
(13821, 'Reichea', NULL, 'Kausel', 116),
(13822, 'Reicheia', NULL, 'Kausel(SUO)', 116),
(13823, 'Reichenbachia', NULL, 'Spreng.', 117),
(13824, 'Reidia', NULL, 'Wight', 184),
(13825, 'Reifferscheidia', NULL, 'C.Presl', 58),
(13826, 'Reinhardtia', NULL, 'Liebm.', 15),
(13827, 'Reinwardtia', NULL, 'Dumort.', 95),
(13828, 'Reissantia', NULL, 'N.Halle', 38),
(13829, 'Reissekia', NULL, 'Endl.', 139),
(13830, 'Reissipa', NULL, 'Steud. ex Klotzsch', 66),
(13831, 'Rejoua', NULL, 'Gaudich.', 10),
(13832, 'Relbunium', NULL, '(Endl.) Hook.f.', 142),
(13833, 'Reldia', NULL, 'Wiehler', 76),
(13834, 'Relhania', NULL, 'L''Her.', 18),
(13835, 'Remijia', NULL, 'DC.', 142),
(13836, 'Remirea', NULL, 'Aubl.', 55),
(13837, 'Remirema', NULL, 'Kerr', 46),
(13838, 'Remusatia', NULL, 'Schott', 12),
(13839, 'Remya', NULL, 'W.F.Hillebr. ex Benth.', 18),
(13840, 'Renarda', NULL, 'Regel', 9),
(13841, 'Renggeria', NULL, 'Meisn.', 42),
(13842, 'Rengifa', NULL, 'Poepp. & Endl.', 42),
(13843, 'Rennera', NULL, 'Merxm.', 18),
(13844, 'Renschia', NULL, 'Vatke', 90),
(13845, 'Rensonia', NULL, 'S.F.Blake', 18),
(13846, 'Rephesis', NULL, 'Raf.', 109),
(13847, 'Reptonia', NULL, 'A.DC.', 148),
(13848, 'Requienia', NULL, 'DC.', 68),
(13849, 'Resia', NULL, 'H.E.Moore', 76),
(13850, 'Resinaria', NULL, 'Comm. ex Lam.', 44),
(13851, 'Restella', NULL, 'Pobed.', 164),
(13852, 'Restiaria', NULL, 'Lour.', 142),
(13853, 'Retama', NULL, 'Raf.', 68),
(13854, 'Retanilla', NULL, '(DC.) Brongn.', 139),
(13855, 'Retiniphyllum', NULL, 'Bonpl.', 142),
(13856, 'Retinodendron', NULL, 'Korth.', 60),
(13857, 'Retispatha', NULL, 'J.Dransf.', 15),
(13858, 'Retrophyllum', NULL, 'C.N.Page', 132),
(13859, 'Reutealis', NULL, 'Airy Shaw', 66),
(13860, 'Reutera', NULL, 'Boiss.', 9),
(13861, 'Revealia', NULL, 'R.M.King & H.Rob.', 18),
(13862, 'Reverchonia', NULL, 'A.Gray', 184),
(13863, 'Reyesia', NULL, 'Gay', 154),
(13864, 'Reynoldsia', NULL, 'A.Gray', 13),
(13865, 'Reynosia', NULL, 'Griseb.', 139),
(13866, 'Reynoutria', NULL, 'Houtt.', 134),
(13867, 'Rhabdadenia', NULL, 'Mull.Arg.', 10),
(13868, 'Rhabdia', NULL, 'Mart.', 25),
(13869, 'Rhabdocalyx', NULL, 'Lindl.', 25),
(13870, 'Rhabdocaulon', NULL, '(Benth.) Epling', 90),
(13871, 'Rhabdodendron', NULL, 'Gilg & Pilg.', 138),
(13872, 'Rhabdosciadium', NULL, 'Boiss.', 9),
(13873, 'Rhabdostigma', NULL, 'Hook.f.', 142),
(13874, 'Rhabdothamnopsis', NULL, 'Hemsl.', 76),
(13875, 'Rhabdothamnus', NULL, 'A.Cunn.', 76),
(13876, 'Rhabdotosperma', NULL, 'Hartl', 150),
(13877, 'Rhachicallis', NULL, 'DC.', 142),
(13878, 'Rhacodiscus', NULL, 'Lindau', 1),
(13879, 'Rhacoma', NULL, 'P.Browne ex L.', 38),
(13880, 'Rhadinopus', NULL, 'S.Moore', 142),
(13881, 'Rhadinothamnus', NULL, 'Paul G.Wilson', 143),
(13882, 'Rhagadiolus', NULL, 'Scop.', 18),
(13883, 'Rhagodia', NULL, 'R.Br.', 5),
(13884, 'Rhammatophyllum', NULL, 'O.E.Schulz', 197),
(13885, 'Rhamnella', NULL, 'Miq.', 139),
(13886, 'Rhamnoluma', NULL, 'Baill.', 148),
(13887, 'Rhamnoneuron', NULL, 'Gilg', 164),
(13888, 'Rhamnus', NULL, 'L.', 139),
(13889, 'Rhamphicarpa', NULL, 'Benth.', 400),
(13890, 'Rhamphocarya', NULL, 'Kuang', 87),
(13891, 'Rhamphogyne', NULL, 'S.Moore', 18),
(13892, 'Rhanteriopsis', NULL, 'Rauschert', 18),
(13893, 'Rhanterium', NULL, 'Desf.', 18),
(13894, 'Rhaphidanthe', NULL, 'Hiern ex Gurke', 61),
(13895, 'Rhaphidophora', NULL, 'Hassk.', 12),
(13896, 'Rhaphidophyton', NULL, 'Iljin', 5),
(13897, 'Rhaphidospora', NULL, 'Nees', 1),
(13898, 'Rhaphidura', NULL, 'Bremek.', 142),
(13899, 'Rhaphiodon', NULL, 'Schauer', 90),
(13900, 'Rhaphiolepis', NULL, 'Lindl.', 141),
(13901, 'Rhaphiophallus', NULL, 'Schott', 12),
(13902, 'Rhaphiostylis', NULL, 'Planch. ex Benth.', 85),
(13903, 'Rhaphispermum', NULL, 'Benth.', 400),
(13904, 'Rhaphithamnus', NULL, 'Miers', 173),
(13905, 'Rhapidophyllum', NULL, 'H.Wendl. & Drude', 15),
(13906, 'Rhapis', NULL, 'L.f. ex Aiton', 15),
(13907, 'Rhaponticum', NULL, 'Ludw.(SUH)', 18),
(13908, 'Rhaptonema', NULL, 'Miers', 107),
(13909, 'Rhaptostylum', NULL, 'Humb. & Bonpl.', 119),
(13910, 'Rhazya', NULL, 'Decne.', 10),
(13911, 'Rheithrophyllum', NULL, 'Hassk.', 76),
(13912, 'Rhektophyllum', NULL, 'N.E.Br.', 12),
(13913, 'Rhetinodendron', NULL, 'Meisn.', 18),
(13914, 'Rhetinosperma', NULL, 'Radlk.', 106),
(13915, 'Rheum', NULL, 'L.', 134),
(13916, 'Rhexia', NULL, 'L.', 105),
(13917, 'Rhigiocarya', NULL, 'Miers', 107),
(13918, 'Rhigiophyllum', NULL, 'Hochst.', 30),
(13919, 'Rhigospira', NULL, 'Miers', 10),
(13920, 'Rhigozum', NULL, 'Burch.', 22),
(13921, 'Rhinacanthus', NULL, 'Nees', 1),
(13922, 'Rhinanthus', NULL, 'L.', 400),
(13923, 'Rhinopetalum', NULL, 'Fisch. ex D.Don', 94),
(13924, 'Rhinopterys', NULL, 'Nied.', 101),
(13925, 'Rhiphidosperma', NULL, 'G.Don(SUO)', 1),
(13926, 'Rhipidantha', NULL, 'Bremek.', 142),
(13927, 'Rhipidia', NULL, 'Markgr.', 10),
(13928, 'Rhizanota', NULL, 'Lour. ex Gomes', 102),
(13929, 'Rhizanthemum', NULL, 'Tiegh.', 98),
(13930, 'Rhizobotrya', NULL, 'Tausch', 197),
(13931, 'Rhizocephalum', NULL, 'Wedd.', 30),
(13932, 'Rhizomonanthes', NULL, 'Danser', 98),
(13933, 'Rhodanthe', NULL, 'Lindl.', 18),
(13934, 'Rhodiola', NULL, 'L.', 48),
(13935, 'Rhodocalyx', NULL, 'Mull.Arg.', 10),
(13936, 'Rhodochiton', NULL, 'Zucc. ex Otto & A.Dietr.', 423),
(13937, 'Rhodocolea', NULL, 'Baill.', 22),
(13938, 'Rhododon', NULL, 'Epling', 90),
(13939, 'Rhodogeron', NULL, 'Griseb.', 18),
(13940, 'Rhodognaphalon', NULL, '(Ulbr.) Roberty', 102),
(13941, 'Rhodognaphalopsis', NULL, 'A.Robyns', 102),
(13942, 'Rhodomyrtus', NULL, '(DC.) Rchb.', 116),
(13943, 'Rhodopis', NULL, 'Urb.', 68),
(13944, 'Rhodosciadium', NULL, 'S.Watson', 9),
(13945, 'Rhodosepala', NULL, 'Baker', 105),
(13946, 'Rhodospatha', NULL, 'Poepp.', 12),
(13947, 'Rhodosphaera', NULL, 'Engl.', 6),
(13948, 'Rhodostoma', NULL, 'Scheidw.', 142),
(13949, 'Rhodothamnus', NULL, 'Rchb.', 64),
(13950, 'Rhodotypos', NULL, 'Siebold & Zucc.', 141),
(13951, 'Rhoiacarpos', NULL, 'A.DC.', 146),
(13952, 'Rhoicissus', NULL, 'Planch.', 181),
(13953, 'Rhombochlamys', NULL, 'Lindau', 1),
(13954, 'Rhombonema', NULL, 'Schltr.', 10),
(13955, 'Rhombospora', NULL, 'Korth.', 142),
(13956, 'Rhoogeton', NULL, 'Leeuwenb.', 76),
(13957, 'Rhopaloblaste', NULL, 'Scheff.', 15),
(13958, 'Rhopalobrachium', NULL, 'Schltr. & K.Krause', 142),
(13959, 'Rhopalocarpus', NULL, 'Teijsm. & Binn. ex Miq.(SUH)', 465),
(13960, 'Rhopalopilia', NULL, 'Pierre', 122),
(13961, 'Rhopalosciadium', NULL, 'Rech.f.', 9),
(13962, 'Rhopalostigma', NULL, 'Phil.', 154),
(13963, 'Rhopalostylis', NULL, 'Klotzsch ex Baill.(SUH)', 15),
(13964, 'Rhopalota', NULL, 'N.E.Br.', 48),
(13965, 'Rhopium', NULL, 'Schreb.', 184),
(13966, 'Rhyacophila', NULL, 'Hochst.', 99),
(13967, 'Rhynchanthera', NULL, 'DC.', 105),
(13968, 'Rhyncharrhena', NULL, 'F.Muell.', 10),
(13969, 'Rhynchocarpa', NULL, 'Schrad. ex Endl.', 49),
(13970, 'Rhynchocladium', NULL, 'T.Koyama', 55),
(13971, 'Rhynchocorys', NULL, 'Griseb.', 150),
(13972, 'Rhynchodia', NULL, 'Benth.', 10),
(13973, 'Rhynchodium', NULL, 'C.Presl', 68),
(13974, 'Rhynchoglossum', NULL, 'Blume', 76),
(13975, 'Rhynchophora', NULL, 'Arenes', 101),
(13976, 'Rhynchopyle', NULL, 'Engl.', 12),
(13977, 'Rhynchosia', NULL, 'Lour.', 71),
(13978, 'Rhynchosida', NULL, 'Fryxell', 102),
(13979, 'Rhynchosinapis', NULL, 'Hayek', 197),
(13980, 'Rhynchospermum', NULL, 'Reinw.', 18),
(13981, 'Rhynchospora', NULL, 'Vahl', 55),
(13982, 'Rhynchostigma', NULL, 'Benth.', 10),
(13983, 'Rhynchotechum', NULL, 'Blume', 76),
(13984, 'Rhynchotropis', NULL, 'Harms', 68),
(13985, 'Rhynea', NULL, 'DC.(SUH)', 18),
(13986, 'Rhysolepis', NULL, 'S.F.Blake', 18),
(13987, 'Rhysopterus', NULL, 'J.M.Coult. & Rose', 9),
(13988, 'Rhysospermum', NULL, 'C.F.Gaertn.', 120),
(13989, 'Rhysotoechia', NULL, 'Radlk.', 147),
(13990, 'Rhyssocarpus', NULL, 'Endl.', 142),
(13991, 'Rhyssolobium', NULL, 'E.Mey.', 10),
(13992, 'Rhyssopterys', NULL, 'Blume ex A.Juss.(SUO)', 101),
(13993, 'Rhyssostelma', NULL, 'Decne.', 10),
(13994, 'Rhyticalymma', NULL, 'Bremek.', 1),
(13995, 'Rhyticarpus', NULL, 'Sond.', 9),
(13996, 'Rhyticaryum', NULL, 'Becc.', 85),
(13997, 'Rhyticocos', NULL, 'Becc.', 15),
(13998, 'Rhytidanthera', NULL, '(Planch.) Tiegh.', 118),
(13999, 'Rhytidocaulon', NULL, 'Bally', 10),
(14000, 'Rhytidomene', NULL, 'Rydb.', 68),
(14001, 'Rhytidophyllum', NULL, 'Mart.', 76),
(14002, 'Rhytidostylis', NULL, 'Rchb.(SUO)', 49),
(14003, 'Rhytidotus', NULL, 'Hook.f.(SUO)', 142),
(14004, 'Rhytiglossa', NULL, 'Nees ex Lindl.', 1),
(14005, 'Rhytis', NULL, 'Lour.', 184),
(14006, 'Rhytispermum', NULL, 'Link(SUS)', 25),
(14007, 'Ricardia', NULL, 'Adans.(SUO)', 142),
(14008, 'Richaeia', NULL, 'Thouars', 140),
(14009, 'Richardella', NULL, 'Pierre', 148),
(14010, 'Richardia', NULL, 'Kunth(SUH)', 142),
(14011, 'Richardsonia', NULL, 'Kunth', 142),
(14012, 'Richea', NULL, 'R.Br.', 64),
(14013, 'Richella', NULL, 'A.Gray', 8),
(14014, 'Richeopsis', NULL, 'Arenes', 145),
(14015, 'Richeriella', NULL, 'Pax & K.Hoffm.', 184),
(14016, 'Richteria', NULL, 'Kar. & Kir.', 18),
(14017, 'Ricinella', NULL, 'Mull.Arg.', 66),
(14018, 'Ricinocarpos', NULL, 'Desf.', 66),
(14019, 'Ricinocarpus', NULL, 'Kuntze', 66),
(14020, 'Ricinoides', NULL, 'Moench', 66),
(14021, 'Ricotia', NULL, 'L.', 197),
(14022, 'Ridolfia', NULL, 'Moris', 9),
(14023, 'Riedeliella', NULL, 'Harms', 68),
(14024, 'Riencourtia', NULL, 'Cass.', 18),
(14025, 'Riesenbachia', NULL, 'C.Presl', 121),
(14026, 'Rigiolepis', NULL, 'Hook.f.', 64),
(14027, 'Rigiopappus', NULL, 'A.Gray', 18),
(14028, 'Rigiostachys', NULL, 'Planch.', 151),
(14029, 'Rikliella', NULL, 'J.Raynal', 55),
(14030, 'Rindera', NULL, 'Pall.', 25),
(14031, 'Ringentiarum', NULL, 'Nakai', 12),
(14032, 'Rinoreocarpus', NULL, 'Ducke', 174),
(14033, 'Rinzia', NULL, 'Schauer', 116),
(14034, 'Riocreuxia', NULL, 'Decne.', 10),
(14035, 'Riqueuria', NULL, 'Ruiz & Pav.', 142),
(14036, 'Riseleya', NULL, 'Hemsl.', 66),
(14037, 'Ristantia', NULL, 'Peter G.Wilson & J.T.Waterh.', 116),
(14038, 'Ritchieophyton', NULL, 'Pax', 66),
(14039, 'Ritonia', NULL, 'Benoist', 1),
(14040, 'Rivasgodaya', NULL, 'Esteve', 68),
(14041, 'Rivea', NULL, 'Choisy', 46),
(14042, 'Riveria', NULL, 'Kunth', 68),
(14043, 'Rivina', NULL, 'L.', 128),
(14044, 'Rivinoides', NULL, 'Afzel. ex Prain', 66),
(14045, 'Rizoa', NULL, 'Cav.', 90),
(14046, 'Robbia', NULL, 'A.DC.', 10),
(14047, 'Robertia', NULL, 'Scop.', 148),
(14048, 'Robeschia', NULL, 'Hochst. ex O.E.Schulz', 197),
(14049, 'Robinia', NULL, 'L.', 68),
(14050, 'Robinsonella', NULL, 'Rose & Baker f.', 102),
(14051, 'Robinsonia', NULL, 'DC.', 18),
(14052, 'Robinsoniodendron', NULL, 'Merr.', 171),
(14053, 'Roborowskia', NULL, 'Batalin', 126),
(14054, 'Robynsia', NULL, 'Hutch.', 142),
(14055, 'Robynsiella', NULL, 'Suess.', 5),
(14056, 'Robynsiophyton', NULL, 'R.Wilczek', 68),
(14057, 'Rochea', NULL, 'DC.', 48),
(14058, 'Rochefortia', NULL, 'Sw.', 25),
(14059, 'Rochelia', NULL, 'Rchb.', 25),
(14060, 'Rochetia', NULL, 'Delile', 106),
(14061, 'Rochonia', NULL, 'DC.', 18),
(14062, 'Rockia', NULL, 'Heimerl', 117),
(14063, 'Rockinghamia', NULL, 'Airy Shaw', 66),
(14064, 'Rodatia', NULL, 'Raf.', 1),
(14065, 'Rodetia', NULL, 'Moq.', 5),
(14066, 'Rodgersia', NULL, 'A.Gray', 149),
(14067, 'Roebelia', NULL, 'Engel', 15),
(14068, 'Roella', NULL, 'L.', 30),
(14069, 'Roemeria', NULL, 'Medik.', 126),
(14070, 'Roentgenia', NULL, 'Urb.', 22),
(14071, 'Roepera', NULL, 'A.Juss.', 177),
(14072, 'Roeperia', NULL, 'Spreng.', 66),
(14073, 'Roettlera', NULL, 'Vahl', 76),
(14074, 'Roezlia', NULL, 'Regel', 105),
(14075, 'Rogeonella', NULL, 'Chev.', 148),
(14076, 'Rogersonanthus', NULL, 'Maguire & B.M.Boom', 75),
(14077, 'Rogiera', NULL, 'Planch.', 142),
(14078, 'Roia', NULL, 'Scop.', 106),
(14079, 'Roigella', NULL, 'Borhidi & M.Fernandez Zeq.', 142),
(14080, 'Roigia', NULL, 'Britton', 184),
(14081, 'Rojasia', NULL, 'Malme', 10),
(14082, 'Rojasianthe', NULL, 'Standl. & Steyerm.', 18),
(14083, 'Rojasimalva', NULL, 'Fryxell', 102),
(14084, 'Rojasiophytum', NULL, 'Hassl.', 22),
(14085, 'Rojoc', NULL, 'Adans.', 142),
(14086, 'Rolandra', NULL, 'Rottb.', 18),
(14087, 'Roldana', NULL, 'La Llave', 18),
(14088, 'Rollandia', NULL, 'Gaudich.', 30),
(14089, 'Rolliniopsis', NULL, 'Saff.', 8),
(14090, 'Rollinsia', NULL, 'Al-Shehbaz', 197),
(14091, 'Romanoa', NULL, 'Trevis.', 66),
(14092, 'Romanowia', NULL, 'Sander ex Andre', 15),
(14093, 'Romanschulzia', NULL, 'O.E.Schulz', 197),
(14094, 'Romanzoffia', NULL, 'Cham.', 25),
(14095, 'Romeroa', NULL, 'Dugand', 22),
(14096, 'Romneya', NULL, 'Harv.', 126),
(14097, 'Ronabea', NULL, 'Aubl.', 142),
(14098, 'Ronabia', NULL, 'St.-Lag.(SUO)', 142),
(14099, 'Ronnowia', NULL, 'Buc''hoz', 66),
(14100, 'Rooseveltia', NULL, 'O.F.Cook', 15),
(14101, 'Ropalopetalum', NULL, 'Griff.', 8),
(14102, 'Ropourea', NULL, 'Aubl.', 61),
(14103, 'Roraimanthus', NULL, 'Gleason', 118),
(14104, 'Rorida', NULL, 'J.F.Gmel.', 32),
(14105, 'Roripella', NULL, '(Maire) Greuter & Burdet', 197),
(14106, 'Rorippa', NULL, 'Scop.', 197),
(14107, 'Rosa', NULL, 'L.', 141),
(14108, 'Rosanowia', NULL, 'Regel', 76),
(14109, 'Rosanthus', NULL, 'Small', 101),
(14110, 'Roscheria', NULL, 'H.Wendl. ex Balf.f.', 15),
(14111, 'Rosea', NULL, 'Klotzsch', 142),
(14112, 'Roseanthus', NULL, 'Cogn.', 49),
(14113, 'Rosenia', NULL, 'Thunb.', 18),
(14114, 'Rosifax', NULL, 'C.C.Towns.', 5),
(14115, 'Rosilla', NULL, 'Less.', 18),
(14116, 'Rosmarinus', NULL, 'L.', 90),
(14117, 'Rostellaria', NULL, 'Nees(SUH)', 1),
(14118, 'Rostellularia', NULL, 'Rchb.', 1),
(14119, 'Rostrinucula', NULL, 'Kudo', 90),
(14120, 'Rosularia', NULL, '(DC.) Stapf', 48),
(14121, 'Rotala', NULL, 'L.', 99),
(14122, 'Rotang', NULL, 'Adans.', 15),
(14123, 'Rotanga', NULL, 'Boehm.', 15),
(14124, 'Rotantha', NULL, 'Small(SUH)', 30),
(14125, 'Rotheria', NULL, 'Meyen', 142),
(14126, 'Rothmaleria', NULL, 'Font Quer', 18),
(14127, 'Rothrockia', NULL, 'A.Gray', 10),
(14128, 'Rottboelia', NULL, 'Scop.', 119),
(14129, 'Rottlera', NULL, 'Willd. (1797)', 66),
(14130, 'Rotula', NULL, 'Lour.', 25),
(14131, 'Roubieva', NULL, 'Moq.', 5),
(14132, 'Roucheria', NULL, 'Planch.', 95),
(14133, 'Roulinia', NULL, 'Decne.', 10),
(14134, 'Rouliniella', NULL, 'Vail', 10),
(14135, 'Roupellia', NULL, 'Wall. & Hook.', 10),
(14136, 'Roupellina', NULL, '(Baill.) Pichon', 10),
(14137, 'Roureopsis', NULL, 'Planch.', 45),
(14138, 'Rousseauxia', NULL, 'DC.', 105),
(14139, 'Rousselia', NULL, 'Gaudich.', 171),
(14140, 'Rouya', NULL, 'Coincy', 9),
(14141, 'Roycea', NULL, 'C.A.Gardner', 5),
(14142, 'Roydsia', NULL, 'Roxb.', 32),
(14143, 'Royena', NULL, 'L.', 61),
(14144, 'Roylea', NULL, 'Wall. ex Benth.', 90),
(14145, 'Rubachia', NULL, 'O.Berg', 116),
(14146, 'Rubeola', NULL, 'Hill(SUH)', 142),
(14147, 'Rubia', NULL, 'L.', 142),
(14148, 'Rubina', NULL, 'Noronha', 184),
(14149, 'Rubioides', NULL, 'Perkins', 142),
(14150, 'Rubiteucris', NULL, 'Kudo', 90),
(14151, 'Rubrivena', NULL, 'Kral', 134),
(14152, 'Rubus', NULL, 'L.', 141),
(14153, 'Rudbeckia', NULL, 'Adans.(SUH)', 18),
(14154, 'Ruddia', NULL, 'Yakovlev', 68),
(14155, 'Rudua', NULL, 'F.Maek.', 68),
(14156, 'Ruehssia', NULL, 'H.Karst. ex Schltdl.', 10),
(14157, 'Ruellia', NULL, 'L.', 1),
(14158, 'Ruelliola', NULL, 'Baill.', 1),
(14159, 'Ruelliopsis', NULL, 'C.B.Clarke', 1),
(14160, 'Rufodorsia', NULL, 'Wiehler', 76),
(14161, 'Rugelia', NULL, 'Shuttlew. ex Chapm.', 18),
(14162, 'Ruilopezia', NULL, 'Cuatrec.', 18),
(14163, 'Ruizia', NULL, 'Cav.', 102),
(14164, 'Ruizterania', NULL, 'Marc.-Berti', 175),
(14165, 'Rulingia', NULL, 'R.Br.', 102),
(14166, 'Rumex', NULL, 'L.', 134),
(14167, 'Rumfordia', NULL, 'DC.', 18),
(14168, 'Rumia', NULL, 'Hoffm.', 9),
(14169, 'Rumicicarpus', NULL, 'Chiov.', 102),
(14170, 'Runyonia', NULL, 'Rose', 3),
(14171, 'Rupicapnos', NULL, 'Pomel', 126);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(14172, 'Rupicola', NULL, 'Maiden & Betche', 64),
(14173, 'Rupiphila', NULL, 'Pimenov & Lavrova', 9),
(14174, 'Rusbya', NULL, 'Britton', 64),
(14175, 'Rusbyanthus', NULL, 'Gilg', 75),
(14176, 'Ruspolia', NULL, 'Lindau', 1),
(14177, 'Russelia', NULL, 'Jacq.', 423),
(14178, 'Russowia', NULL, 'C.Winkl.', 18),
(14179, 'Rustia', NULL, 'Klotzsch', 142),
(14180, 'Ruta', NULL, 'L.', 143),
(14181, 'Rutaneblina', NULL, 'Steyerm. & Luteyn', 143),
(14182, 'Rutea', NULL, 'M.Roem.', 106),
(14183, 'Ruthalicia', NULL, 'C.Jeffrey', 49),
(14184, 'Ruthea', NULL, 'Bolle(SUH)', 9),
(14185, 'Rutheopsis', NULL, 'A.Hansen & Kunkel', 9),
(14186, 'Ruthiella', NULL, 'Steenis', 30),
(14187, 'Rutidea', NULL, 'DC.', 142),
(14188, 'Rutidosis', NULL, 'DC.', 18),
(14189, 'Rutosma', NULL, 'A.Gray', 143),
(14190, 'Ruttya', NULL, 'Harv.', 1),
(14191, 'Ruyschia', NULL, 'Jacq.', 104),
(14192, 'Rylstonea', NULL, 'R.T.Baker', 116),
(14193, 'Ryncholeucaena', NULL, 'Britton & Rose', 68),
(14194, 'Ryssopterys', NULL, 'Blume ex A.Juss.', 101),
(14195, 'Rytidea', NULL, 'Spreng.(SUO)', 142),
(14196, 'Rytidocarpus', NULL, 'Coss.', 197),
(14197, 'Rytidostylis', NULL, 'Hook. & Arn.', 49),
(14198, 'Rytidotus', NULL, 'Hook.f.', 142),
(14199, 'Rzedowskia', NULL, 'Medrano', 38),
(14200, 'Saba', NULL, '(Pichon) Pichon', 10),
(14201, 'Sabal', NULL, 'Adans.', 15),
(14202, 'Sabatia', NULL, 'Adans.', 75),
(14203, 'Sabaudia', NULL, 'Buscal. & Muschl.', 90),
(14204, 'Sabaudiella', NULL, 'Chiov.', 46),
(14205, 'Sabazia', NULL, 'Cass.', 18),
(14206, 'Sabia', NULL, 'Colebr.', 144),
(14207, 'Sabicea', NULL, 'Aubl.', 142),
(14208, 'Sabina', NULL, 'Mill.', 51),
(14209, 'Sabinea', NULL, 'DC.', 68),
(14210, 'Saccanthus', NULL, 'Herzog', 150),
(14211, 'Saccardophytum', NULL, 'Speg.', 154),
(14212, 'Saccellium', NULL, 'Bonpl.', 25),
(14213, 'Saccifolium', NULL, 'Maguire & Pires', 75),
(14214, 'Saccocalyx', NULL, 'Coss. & Durieu', 90),
(14215, 'Saccolena', NULL, 'Gleason', 105),
(14216, 'Sacconia', NULL, 'Endl.', 142),
(14217, 'Saccoplectus', NULL, 'Oerst.', 76),
(14218, 'Saccularia', NULL, 'Kellogg', 150),
(14219, 'Sachokiella', NULL, 'Kolak.', 30),
(14220, 'Sachsia', NULL, 'Griseb.', 18),
(14221, 'Sacleuxia', NULL, 'Baill.', 10),
(14222, 'Sacosperma', NULL, 'G.Taylor', 142),
(14223, 'Sadiria', NULL, 'Mez', 115),
(14224, 'Saffordiella', NULL, 'Merr.', 116),
(14225, 'Sageretia', NULL, 'Brongn.', 139),
(14226, 'Sagittipetalum', NULL, 'Merr.', 140),
(14227, 'Saglorithys', NULL, 'Rizzini', 1),
(14228, 'Sagotanthus', NULL, 'Tiegh.', 119),
(14229, 'Sagraea', NULL, 'DC.', 105),
(14230, 'Saguaster', NULL, 'Kuntze', 15),
(14231, 'Saguerus', NULL, 'Steck', 15),
(14232, 'Sagus', NULL, 'Gaertn.', 15),
(14233, 'Sahagunia', NULL, 'Liebm.', 109),
(14234, 'Sahlbergia', NULL, 'Neck.(SUI)', 142),
(14235, 'Saintpaulia', NULL, 'H.Wendl.', 76),
(14236, 'Saintpauliopsis', NULL, 'Staner', 1),
(14237, 'Saipania', NULL, 'Hosok.', 66),
(14238, 'Sairanthus', NULL, 'G.Don', 154),
(14239, 'Sairocarpus', NULL, 'D.A.Sutton', 423),
(14240, 'Sajanella', NULL, 'Sojak', 9),
(14241, 'Sajania', NULL, 'Pimenov(SUH)', 9),
(14242, 'Sajorium', NULL, 'Endl.', 66),
(14243, 'Sakakia', NULL, 'Nakai(SUS)', 162),
(14244, 'Sakersia', NULL, 'Hook.f.', 105),
(14245, 'Sakoanala', NULL, 'R.Vig.', 68),
(14246, 'Salacca', NULL, 'Reinw.', 15),
(14247, 'Salacicratea', NULL, 'Loes.', 38),
(14248, 'Salacighia', NULL, 'Loes.', 38),
(14249, 'Salaciopsis', NULL, 'Baker f.', 38),
(14250, 'Salaxis', NULL, 'Salisb.', 64),
(14251, 'Salazaria', NULL, 'Torr.', 90),
(14252, 'Saldanha', NULL, 'Vell.', 142),
(14253, 'Saldanhaea', NULL, 'Bureau', 22),
(14254, 'Saldania', NULL, 'Sim', 68),
(14255, 'Saldinia', NULL, 'A.Rich. ex DC.', 142),
(14256, 'Salicaria', NULL, 'Adans.', 99),
(14257, 'Salicornia', NULL, 'L.', 5),
(14258, 'Salisia', NULL, 'Regel(SUH)', 76),
(14259, 'Salix', NULL, 'L.', 145),
(14260, 'Salmalia', NULL, 'Schott & Endl.', 102),
(14261, 'Salmasia', NULL, 'Schreb.(SUS)', 40),
(14262, 'Salmea', NULL, 'DC.', 18),
(14263, 'Salmeopsis', NULL, 'Benth.', 18),
(14264, 'Salmonia', NULL, 'Scop.', 175),
(14265, 'Salomonia', NULL, 'Lour.', 133),
(14266, 'Salpianthus', NULL, 'Bonpl.', 117),
(14267, 'Salpichroa', NULL, 'Miers', 154),
(14268, 'Salpiglossis', NULL, 'Ruiz & Pav.', 154),
(14269, 'Salpinctes', NULL, 'Woodson', 10),
(14270, 'Salpinctium', NULL, 'T.J.Edwards', 1),
(14271, 'Salpinga', NULL, 'Mart. ex DC.', 105),
(14272, 'Salpingantha', NULL, 'Lem.(SUO)', 1),
(14273, 'Salpingia', NULL, '(Torr. & A.Gray) Raim.', 121),
(14274, 'Salpinxantha', NULL, 'Urb.(SUO)', 1),
(14275, 'Salpixantha', NULL, 'Hook.', 1),
(14276, 'Salsola', NULL, 'L.', 5),
(14277, 'Saltia', NULL, 'R.Br. ex Moq.', 5),
(14278, 'Salvadoropsis', NULL, 'H.Perrier', 38),
(14279, 'Salvertia', NULL, 'A.St.-Hil.', 175),
(14280, 'Salvia', NULL, 'L.', 90),
(14281, 'Salviacanthus', NULL, 'Lindau', 1),
(14282, 'Salviastrum', NULL, 'Scheele', 90),
(14283, 'Salweenia', NULL, 'Baker f.', 68),
(14284, 'Salzmannia', NULL, 'DC.', 142),
(14285, 'Samadera', NULL, 'Gaertn.', 151),
(14286, 'Samara', NULL, 'L.', 115),
(14287, 'Samaropyxis', NULL, 'Miq.', 184),
(14288, 'Samarpsea', NULL, 'Raf.', 120),
(14289, 'Sambucus', NULL, 'L.', 203),
(14290, 'Sameraria', NULL, 'Desv.', 197),
(14291, 'Samolus', NULL, 'L.', 163),
(14292, 'Sampaiella', NULL, 'J.C.Gomes', 22),
(14293, 'Sampantaea', NULL, 'Airy Shaw', 66),
(14294, 'Samuela', NULL, 'Trel.', 3),
(14295, 'Samuelssonia', NULL, 'Urb. & Ekman', 1),
(14296, 'Sanango', NULL, 'Bunting & Duke', 76),
(14297, 'Sanblasia', NULL, 'L.Andersson', 103),
(14298, 'Sanchezia', NULL, 'Ruiz & Pav.', 1),
(14299, 'Sandbergia', NULL, 'Greene', 197),
(14300, 'Sandemania', NULL, 'Gleason', 105),
(14301, 'Sandwithia', NULL, 'Lanj.', 66),
(14302, 'Sandwithiodoxa', NULL, 'Aubrev. & Pellegr.', 148),
(14303, 'Sanguinaria', NULL, 'L.', 126),
(14304, 'Sanguisorba', NULL, 'L.', 141),
(14305, 'Sanhilaria', NULL, 'Baill.', 22),
(14306, 'Sanicula', NULL, 'L.', 9),
(14307, 'Santalina', NULL, 'Baill.', 142),
(14308, 'Santalodes', NULL, 'Kuntze(SUH)', 45),
(14309, 'Santaloidella', NULL, 'Schellenb.', 45),
(14310, 'Santaloides', NULL, 'Schellenb.', 45),
(14311, 'Santalum', NULL, 'L.', 146),
(14312, 'Santapaua', NULL, 'N.P.Balakr. & Subr.', 1),
(14313, 'Santia', NULL, 'Wight & Arn.(SUH)', 142),
(14314, 'Santiriopsis', NULL, 'Engl.', 27),
(14315, 'Santisukia', NULL, 'Brummitt', 22),
(14316, 'Santolina', NULL, 'L.', 18),
(14317, 'Santosia', NULL, 'R.M.King & H.Rob.', 18),
(14318, 'Sanvitalia', NULL, 'Lam.', 18),
(14319, 'Sapindopsis', NULL, 'F.C.How & C.N.Ho(SUH)', 147),
(14320, 'Sapiopsis', NULL, 'Mull.Arg.', 66),
(14321, 'Saposhnikovia', NULL, 'Schischk.', 9),
(14322, 'Sapota', NULL, 'Mill.', 148),
(14323, 'Sapphoa', NULL, 'Urb.', 1),
(14324, 'Sapranthus', NULL, 'Seem.', 8),
(14325, 'Sapucaya', NULL, 'R.Knuth', 92),
(14326, 'Saracha', NULL, 'Ruiz & Pav.', 154),
(14327, 'Saranthe', NULL, '(Regel & Korn.) Eichler', 103),
(14328, 'Sararanga', NULL, 'Hemsl.', 125),
(14329, 'Sarawakodendron', NULL, 'Ding Hou', 38),
(14330, 'Sarcandra', NULL, 'Gardner', 39),
(14331, 'Sarcanthidion', NULL, 'Baill.', 85),
(14332, 'Sarcobotrya', NULL, 'R.Vig.', 68),
(14333, 'Sarcocapnos', NULL, 'DC.', 126),
(14334, 'Sarcochlamys', NULL, 'Gaudich.', 171),
(14335, 'Sarcoclinium', NULL, 'Wight', 66),
(14336, 'Sarcococca', NULL, 'Lindl.', 28),
(14337, 'Sarcocornia', NULL, 'A.J.Scott', 5),
(14338, 'Sarcodes', NULL, 'Torr.', 64),
(14339, 'Sarcodraba', NULL, 'Gilg & Muschl.', 197),
(14340, 'Sarcodrimys', NULL, '(Baill.) Baum.-Bod.(SUI)', 176),
(14341, 'Sarcodum', NULL, 'Lour.', 68),
(14342, 'Sarcolobus', NULL, 'R.Br.', 10),
(14343, 'Sarcolophium', NULL, 'Troupin', 107),
(14344, 'Sarcomelicope', NULL, 'Engl.', 143),
(14345, 'Sarcomphalus', NULL, 'P.Browne', 139),
(14346, 'Sarcopetalum', NULL, 'F.Muell.', 107),
(14347, 'Sarcophagophilus', NULL, 'Dinter', 10),
(14348, 'Sarcopharyngia', NULL, '(Stapf) Boiteau', 10),
(14349, 'Sarcophrynium', NULL, 'K.Schum.', 103),
(14350, 'Sarcophysa', NULL, 'Miers', 154),
(14351, 'Sarcopilea', NULL, 'Urb.', 171),
(14352, 'Sarcopoterium', NULL, 'Spach', 141),
(14353, 'Sarcopteryx', NULL, 'Radlk.', 147),
(14354, 'Sarcopygme', NULL, 'Setch. & Christoph.', 142),
(14355, 'Sarcopyramis', NULL, 'Wall.', 105),
(14356, 'Sarcorhachis', NULL, 'Trel.', 130),
(14357, 'Sarcorrhiza', NULL, 'Bullock', 10),
(14358, 'Sarcosperma', NULL, 'Hook.f.', 148),
(14359, 'Sarcostemma', NULL, 'R.Br.', 10),
(14360, 'Sarcostigma', NULL, 'Wight & Arn.', 85),
(14361, 'Sarcotoechia', NULL, 'Radlk.', 147),
(14362, 'Sarcoyucca', NULL, '(Engelm.) Linding.', 3),
(14363, 'Sarcozygium', NULL, 'Bunge', 177),
(14364, 'Sardinia', NULL, 'Vell.', 142),
(14365, 'Sargentia', NULL, 'S.Watson', 143),
(14366, 'Saribus', NULL, 'Blume', 15),
(14367, 'Sarinia', NULL, 'O.F.Cook', 15),
(14368, 'Sarissus', NULL, 'Gaertn.', 142),
(14369, 'Saritaea', NULL, 'Dugand', 22),
(14370, 'Sarmentaria', NULL, 'Naudin', 105),
(14371, 'Sarmienta', NULL, 'Ruiz & Pav.', 76),
(14372, 'Sarojusticia', NULL, 'Bremek.', 1),
(14373, 'Sarothamnus', NULL, 'Wimm.', 68),
(14374, 'Sarotheca', NULL, 'Nees', 1),
(14375, 'Sarothrostachys', NULL, 'Klotzsch', 66),
(14376, 'Sartoria', NULL, 'Boiss. & Heldr.', 68),
(14377, 'Sartorina', NULL, 'R.M.King & H.Rob.', 18),
(14378, 'Sartwellia', NULL, 'A.Gray', 18),
(14379, 'Saruma', NULL, 'Oliv.', 16),
(14380, 'Sarx', NULL, 'H.St.John', 49),
(14381, 'Sassafras', NULL, 'Nees', 91),
(14382, 'Sassafridium', NULL, 'Meisn.', 91),
(14383, 'Sassia', NULL, 'Molina', 124),
(14384, 'Satakentia', NULL, 'H.E.Moore', 15),
(14385, 'Satanocrater', NULL, 'Schweinf.', 1),
(14386, 'Sattadia', NULL, 'E.Fourn.', 10),
(14387, 'Satureja', NULL, 'L.', 90),
(14388, 'Satyria', NULL, 'Klotzsch', 64),
(14389, 'Sauromatum', NULL, 'Schott', 12),
(14390, 'Saussurea', NULL, 'DC.', 18),
(14391, 'Sautiera', NULL, 'Decne.', 1),
(14392, 'Sauvagesia', NULL, 'L.', 118),
(14393, 'Sauvallella', NULL, 'Rydb.', 68),
(14394, 'Savia', NULL, 'Willd.', 184),
(14395, 'Savignya', NULL, 'DC.', 197),
(14396, 'Saxegothaea', NULL, 'Lindl.', 132),
(14397, 'Saxifraga', NULL, 'L.', 149),
(14398, 'Saxifragella', NULL, 'Engl.', 149),
(14399, 'Saxifragodes', NULL, 'D.M.Moore', 149),
(14400, 'Saxifragopsis', NULL, 'Small', 149),
(14401, 'Scagea', NULL, 'McPherson', 534),
(14402, 'Scalesia', NULL, 'Arn.', 18),
(14403, 'Scaligeria', NULL, 'DC.', 9),
(14404, 'Scambopus', NULL, 'O.E.Schulz', 197),
(14405, 'Scandia', NULL, 'J.W.Dawson', 9),
(14406, 'Scandicium', NULL, 'Thell.', 9),
(14407, 'Scandivepres', NULL, 'Loes.', 38),
(14408, 'Scandix', NULL, 'L.', 9),
(14409, 'Scaphispatha', NULL, 'Brongn. ex Schott', 12),
(14410, 'Scaphospermum', NULL, 'Korovin(SUH)', 9),
(14411, 'Scapicephalus', NULL, 'Ovcz. & Czukav.', 25),
(14412, 'Scariola', NULL, 'F.W.Schmidt', 18),
(14413, 'Scassellatia', NULL, 'Chiov.', 6),
(14414, 'Scepa', NULL, 'Lindl.', 184),
(14415, 'Scepasma', NULL, 'Blume', 184),
(14416, 'Scepseothamnus', NULL, 'Cham.', 142),
(14417, 'Sceptrocnide', NULL, 'Maxim.', 171),
(14418, 'Schachtia', NULL, 'H.Karst.', 142),
(14419, 'Schaefferia', NULL, 'Jacq.', 38),
(14420, 'Schaetzellia', NULL, 'Sch.Bip.(SUH)', 18),
(14421, 'Schaueria', NULL, 'Nees', 1),
(14422, 'Scheeria', NULL, 'Seem.', 76),
(14423, 'Schefferella', NULL, 'Pierre', 148),
(14424, 'Schefferomitra', NULL, 'Diels', 8),
(14425, 'Schefflerodendron', NULL, 'Harms', 68),
(14426, 'Scheffleropsis', NULL, 'Ridl.', 13),
(14427, 'Schellenbergia', NULL, 'C.E.Parkinson', 45),
(14428, 'Schenckia', NULL, 'K.Schum.', 142),
(14429, 'Scherya', NULL, 'R.M.King & H.Rob.', 18),
(14430, 'Schetti', NULL, 'Adans.', 142),
(14431, 'Schidiomyrtus', NULL, 'Schauer', 116),
(14432, 'Schiedophytum', NULL, 'H.Wolff', 9),
(14433, 'Schimpera', NULL, 'Steud. & Hochst. ex Endl.', 197),
(14434, 'Schimperella', NULL, 'H.Wolff', 9),
(14435, 'Schimperina', NULL, 'Tiegh.', 98),
(14436, 'Schindleria', NULL, 'H.Walter', 128),
(14437, 'Schinopsis', NULL, 'Engl.', 6),
(14438, 'Schinus', NULL, 'L.', 6),
(14439, 'Schinziella', NULL, 'Gilg', 75),
(14440, 'Schinziophyton', NULL, 'Hutch. ex Radcl.-Sm.', 66),
(14441, 'Schippia', NULL, 'Burret', 15),
(14442, 'Schischkinia', NULL, 'Iljin', 18),
(14443, 'Schismatoclada', NULL, 'Baker', 142),
(14444, 'Schismatoglottis', NULL, 'Zoll. & Moritzi', 12),
(14445, 'Schismatopera', NULL, 'Klotzsch', 66),
(14446, 'Schistocarpaea', NULL, 'F.Muell.', 139),
(14447, 'Schistocarpha', NULL, 'Less.', 18),
(14448, 'Schistocaryum', NULL, 'Franch.', 25),
(14449, 'Schistogyne', NULL, 'Hook. & Arn.', 10),
(14450, 'Schistonema', NULL, 'Schltr.', 10),
(14451, 'Schistophragma', NULL, 'Benth. ex Endl.', 423),
(14452, 'Schistophyllidium', NULL, '(Juz. ex Fed.) Ikonn.', 141),
(14453, 'Schistostemon', NULL, '(Urb.) Cuatrec.', 83),
(14454, 'Schistostephium', NULL, 'Less.', 18),
(14455, 'Schistostigma', NULL, 'Lauterb.', 184),
(14456, 'Schivereckia', NULL, 'Andrz. ex DC.', 197),
(14457, 'Schizangium', NULL, 'Bartl. ex DC.', 142),
(14458, 'Schizanthus', NULL, 'Ruiz & Pav.', 154),
(14459, 'Schizeilema', NULL, '(Hook.f.) Domin', 9),
(14460, 'Schizenterospermum', NULL, 'Homolle ex Arenes', 142),
(14461, 'Schizoboea', NULL, '(Fritsch) B.L.Burtt', 76),
(14462, 'Schizocaena', NULL, 'J.Sm. ex Hook.', 52),
(14463, 'Schizocalomyrtus', NULL, 'Kausel', 116),
(14464, 'Schizocalyx', NULL, 'Wedd.', 142),
(14465, 'Schizocapsa', NULL, 'Hance', 59),
(14466, 'Schizocardia', NULL, 'A.C.Sm. & Standl.', 56),
(14467, 'Schizocarpum', NULL, 'Schrad.', 49),
(14468, 'Schizocarya', NULL, 'Spach', 121),
(14469, 'Schizocasia', NULL, 'Schott', 12),
(14470, 'Schizocentron', NULL, 'Meisn.', 105),
(14471, 'Schizochiton', NULL, 'Spreng.', 106),
(14472, 'Schizococcus', NULL, 'Eastw.', 64),
(14473, 'Schizocolea', NULL, 'Bremek.', 142),
(14474, 'Schizoglossum', NULL, 'E.Mey.', 10),
(14475, 'Schizogyne', NULL, 'Cass.', 18),
(14476, 'Schizomeria', NULL, 'D.Don', 50),
(14477, 'Schizomeryta', NULL, 'R.Vig.', 13),
(14478, 'Schizomussaenda', NULL, 'H.L.Li', 142),
(14479, 'Schizonepeta', NULL, '(Benth.) Briq.', 90),
(14480, 'Schizonotus', NULL, 'A.Gray(SUH)', 10),
(14481, 'Schizopepon', NULL, 'Maxim.', 49),
(14482, 'Schizopetalon', NULL, 'Sims', 197),
(14483, 'Schizopleura', NULL, 'Endl.', 116),
(14484, 'Schizopremna', NULL, 'Baill.', 90),
(14485, 'Schizopsis', NULL, 'Bureau', 22),
(14486, 'Schizoptera', NULL, 'Turcz.', 18),
(14487, 'Schizoscyphus', NULL, 'K.Schum. ex Taub.', 68),
(14488, 'Schizosepala', NULL, 'G.M.Barroso', 150),
(14489, 'Schizosiphon', NULL, 'K.Schum.', 68),
(14490, 'Schizospatha', NULL, 'Furtado', 15),
(14491, 'Schizospermum', NULL, 'Boivin ex Baill.', 142),
(14492, 'Schizostephanus', NULL, 'Hochst. ex K.Schum.', 10),
(14493, 'Schizostigma', NULL, 'Arn. ex Meisn.', 142),
(14494, 'Schizotorenia', NULL, 'T.Yamaz.', 150),
(14495, 'Schizotrichia', NULL, 'Benth.', 18),
(14496, 'Schizozygia', NULL, 'Baill.', 10),
(14497, 'Schkuhria', NULL, 'Roth', 18),
(14498, 'Schlechtendalia', NULL, 'Less.', 18),
(14499, 'Schlechteria', NULL, 'Bolus', 197),
(14500, 'Schlechterianthus', NULL, 'Quisumb.', 10),
(14501, 'Schlechterina', NULL, 'Harms', 127),
(14502, 'Schlechterosciadium', NULL, 'H.Wolff', 9),
(14503, 'Schlegelia', NULL, 'Miq.', 540),
(14504, 'Schleinitzia', NULL, 'Warb.', 68),
(14505, 'Schliebenia', NULL, 'Mildbr.', 1),
(14506, 'Schmalhausenia', NULL, 'C.Winkl.', 18),
(14507, 'Schmardaea', NULL, 'H.Karst.', 106),
(14508, 'Schmidtottia', NULL, 'Urb.', 142),
(14509, 'Schnabelia', NULL, 'Hand.-Mazz.', 90),
(14510, 'Schnella', NULL, 'Raddi', 68),
(14511, 'Schnittspahnia', NULL, 'Rchb.', 8),
(14512, 'Schoenia', NULL, 'Steetz', 18),
(14513, 'Schoenleinia', NULL, 'Klotzsch', 142),
(14514, 'Schoenocrambe', NULL, 'Greene', 197),
(14515, 'Schoenodendron', NULL, 'Engl.', 55),
(14516, 'Schoenoides', NULL, 'Seberg', 55),
(14517, 'Schoenolaena', NULL, 'Bunge', 9),
(14518, 'Schoenoplectus', NULL, '(Rchb.) Palla', 55),
(14519, 'Schoenoxiphium', NULL, 'Nees', 55),
(14520, 'Schoenus', NULL, 'L.', 55),
(14521, 'Schoepfiopsis', NULL, 'Miers', 119),
(14522, 'Scholtzia', NULL, 'Schauer', 116),
(14523, 'Schorigeram', NULL, 'Adans.', 66),
(14524, 'Schotia', NULL, 'Jacq.', 68),
(14525, 'Schousboea', NULL, 'Willd.', 44),
(14526, 'Schouwia', NULL, 'DC.', 197),
(14527, 'Schradera', NULL, 'Willd.(SUH)', 142),
(14528, 'Schraderia', NULL, 'Medik.', 90),
(14529, 'Schrameckia', NULL, 'Danguy', 108),
(14530, 'Schrammia', NULL, 'Britton & Rose', 68),
(14531, 'Schranckiastrum', NULL, 'Hassl.', 68),
(14532, 'Schrankia', NULL, 'Willd.', 68),
(14533, 'Schreibersia', NULL, 'Pohl', 142),
(14534, 'Schrenkia', NULL, 'Fisch. & C.A.Mey.', 9),
(14535, 'Schroeterella', NULL, 'Briq.', 177),
(14536, 'Schtschurowskia', NULL, 'Regel & Schmalh.', 9),
(14537, 'Schubertia', NULL, 'Mart.', 10),
(14538, 'Schuechia', NULL, 'Endl.', 175),
(14539, 'Schuermannia', NULL, 'F.Muell.', 116),
(14540, 'Schufia', NULL, 'Spach', 121),
(14541, 'Schultesia', NULL, 'Mart.', 75),
(14542, 'Schultesianthus', NULL, 'Hunz.', 154),
(14543, 'Schultesiophytum', NULL, 'Harling', 54),
(14544, 'Schulzia', NULL, 'Spreng.', 9),
(14545, 'Schumannia', NULL, 'Kuntze', 9),
(14546, 'Schumannianthus', NULL, 'Gagnep.', 103),
(14547, 'Schumeria', NULL, 'Iljin', 18),
(14548, 'Schunda-Pana', NULL, 'Adans.', 15),
(14549, 'Schuurmansia', NULL, 'Blume', 118),
(14550, 'Schuurmansiella', NULL, 'Hallier f.', 118),
(14551, 'Schwabea', NULL, 'Endl.', 1),
(14552, 'Schwackaea', NULL, 'Cogn.', 105),
(14553, 'Schwalbea', NULL, 'L.', 400),
(14554, 'Schwannia', NULL, 'Endl.', 101),
(14555, 'Schwecnkiopsis', NULL, 'Dammer', 154),
(14556, 'Schweiggeria', NULL, 'Spreng.', 174),
(14557, 'Schweinfurthia', NULL, 'A.Braun', 423),
(14558, 'Schweinitzia', NULL, 'Elliott ex Nutt.', 64),
(14559, 'Schwenckia', NULL, 'L.', 154),
(14560, 'Schwendenera', NULL, 'K.Schum.', 142),
(14561, 'Schwenkfelda', NULL, 'Schreb.', 142),
(14562, 'Schwenkfeldia', NULL, 'Willd.(SUO)', 142),
(14563, 'Schwerinia', NULL, 'H.Karst.', 105),
(14564, 'Sciacassia', NULL, 'Britton', 68),
(14565, 'Sciadiodaphne', NULL, 'Rchb.', 91),
(14566, 'Sciadocalyx', NULL, 'Regel', 76),
(14567, 'Sciadocephala', NULL, 'Mattf.', 18),
(14568, 'Sciadopanax', NULL, 'Seem.', 13),
(14569, 'Sciadophyllum', NULL, 'P.Browne', 13),
(14570, 'Sciadotenia', NULL, 'Miers', 107),
(14571, 'Sciaplea', NULL, 'Rauschert', 68),
(14572, 'Scindapsus', NULL, 'Schott', 12),
(14573, 'Scirpidiella', NULL, 'Rauschert', 55),
(14574, 'Scirpodendron', NULL, 'Zipp. ex Kurz', 55),
(14575, 'Scirpoides', NULL, 'Seg.', 55),
(14576, 'Scirpus', NULL, 'L.', 55),
(14577, 'Scleranthera', NULL, 'Pichon', 10),
(14578, 'Scleria', NULL, 'Bergius', 55),
(14579, 'Sclerobassia', NULL, 'Ulbr.', 5),
(14580, 'Scleroblitum', NULL, 'Ulbr.', 5),
(14581, 'Sclerocalyx', NULL, 'Nees', 1),
(14582, 'Sclerocarpus', NULL, 'Jacq.', 18),
(14583, 'Sclerocarya', NULL, 'Hochst.', 6),
(14584, 'Sclerocaryopsis', NULL, 'Brand', 25),
(14585, 'Sclerochiton', NULL, 'Harv.', 1),
(14586, 'Sclerochorton', NULL, 'Boiss.', 9),
(14587, 'Sclerocladus', NULL, 'Raf.', 148),
(14588, 'Sclerococcus', NULL, 'Bartl.(SUI)', 142),
(14589, 'Sclerocroton', NULL, 'Hochst.', 66),
(14590, 'Sclerocyathium', NULL, 'Prokh.', 66),
(14591, 'Sclerolepis', NULL, 'Cass.', 18),
(14592, 'Sclerolinon', NULL, 'C.M.Rogers', 95),
(14593, 'Scleromelum', NULL, 'K.Schum. & Lauterb.', 146),
(14594, 'Scleromitrion', NULL, 'Wight & Arn.', 142),
(14595, 'Scleronema', NULL, 'Benth.', 102),
(14596, 'Sclerophylax', NULL, 'Miers', 154),
(14597, 'Sclerorhachis', NULL, '(Rech.f.) Rech.f.', 18),
(14598, 'Sclerosciadium', NULL, 'W.D.J.Koch ex DC.', 9),
(14599, 'Sclerosperma', NULL, 'G.Mann & H.Wendl.', 15),
(14600, 'Sclerostegia', NULL, 'Paul G.Wilson', 5),
(14601, 'Sclerostephane', NULL, 'Chiov.', 18),
(14602, 'Sclerotheca', NULL, 'A.DC.', 30),
(14603, 'Sclerotiaria', NULL, 'Korovin', 9),
(14604, 'Sclerozus', NULL, 'Raf.', 148),
(14605, 'Scobinaria', NULL, 'Seibert', 22),
(14606, 'Scoliaxon', NULL, 'Payson', 197),
(14607, 'Scoliopus', NULL, 'Torr.', 94),
(14608, 'Scoliotheca', NULL, 'Baill.', 76),
(14609, 'Scolophyllum', NULL, 'T.Yamaz.', 150),
(14610, 'Scolosanthus', NULL, 'Vahl', 142),
(14611, 'Scolymus', NULL, 'L.', 18),
(14612, 'Scoparia', NULL, 'L.', 423),
(14613, 'Scopolia', NULL, 'Jacq.', 154),
(14614, 'Scorodophloeus', NULL, 'Harms', 68),
(14615, 'Scorodosma', NULL, 'Bunge', 9),
(14616, 'Scorpiothyrsus', NULL, 'H.L.Li', 105),
(14617, 'Scorpiurus', NULL, 'L.', 68),
(14618, 'Scortechinia', NULL, 'Hook.f.(SUH)', 66),
(14619, 'Scorzonella', NULL, 'Nutt.', 18),
(14620, 'Scorzonera', NULL, 'L.', 18),
(14621, 'Scotanthus', NULL, 'Naudin', 49),
(14622, 'Scottia', NULL, 'Thunb.', 68),
(14623, 'Scrobicaria', NULL, 'Cass.', 18),
(14624, 'Scrobicularia', NULL, 'Mansf.', 105),
(14625, 'Scrofella', NULL, 'Maxim.', 423),
(14626, 'Scrophularia', NULL, 'L.', 150),
(14627, 'Scubulus', NULL, 'Raf.', 154),
(14628, 'Scurrula', NULL, 'L.', 98),
(14629, 'Scutellaria', NULL, 'L.', 90),
(14630, 'Scutia', NULL, '(DC.) Brongn.', 139),
(14631, 'Scutula', NULL, 'Lour.', 105),
(14632, 'Scyphellandra', NULL, 'Thwaites', 174),
(14633, 'Scyphiphora', NULL, 'C.F.Gaertn.', 142),
(14634, 'Scyphochlamys', NULL, 'Balf.f.', 142),
(14635, 'Scyphocoronis', NULL, 'A.Gray', 18),
(14636, 'Scyphogyne', NULL, 'Decne.', 64),
(14637, 'Scyphonychium', NULL, 'Radlk.', 147),
(14638, 'Scyphopappus', NULL, 'B.Nord.', 18),
(14639, 'Scyphopetalum', NULL, 'Hiern', 147),
(14640, 'Scyphostachys', NULL, 'Thwaites', 142),
(14641, 'Scyphostegia', NULL, 'Stapf', 145),
(14642, 'Scyphostelma', NULL, 'Baill.', 10),
(14643, 'Scyphostigma', NULL, 'M.Roem.', 106),
(14644, 'Scyphostrychnos', NULL, 'S.Moore', 97),
(14645, 'Scyphosyce', NULL, 'Baill.', 109),
(14646, 'Scytanthus', NULL, 'T.Anderson ex Benth.(SUH)', 1),
(14647, 'Seaforthia', NULL, 'R.Br.', 15),
(14648, 'Searsia', NULL, 'F.A.Barkley', 6),
(14649, 'Sebaea', NULL, 'Sol. ex R.Br.', 75),
(14650, 'Sebastiania', NULL, 'Spreng.', 66),
(14651, 'Sebastiano-Schaueria', NULL, 'Nees', 1),
(14652, 'Sebertia', NULL, 'Pierre', 148),
(14653, 'Seborium', NULL, 'Raf.', 66),
(14654, 'Secamone', NULL, 'R.Br.', 10),
(14655, 'Secamonopsis', NULL, 'Jum.', 10),
(14656, 'Sechiopsis', NULL, 'Naudin', 49),
(14657, 'Sechium', NULL, 'P.Browne', 49),
(14658, 'Secondatia', NULL, 'A.DC.', 10),
(14659, 'Secula', NULL, 'Small', 68),
(14660, 'Securidaca', NULL, 'L.', 133),
(14661, 'Securigera', NULL, 'DC.', 68),
(14662, 'Securinega', NULL, 'Comm. ex Juss.', 184),
(14663, 'Sedastrum', NULL, 'Rose', 48),
(14664, 'Seddera', NULL, 'Hochst.', 46),
(14665, 'Sedderopsis', NULL, 'Roberty', 46),
(14666, 'Sedella', NULL, 'Fourr.(SUI)', 48),
(14667, 'Sedum', NULL, 'L.', 48),
(14668, 'Seemannantha', NULL, 'Alef.', 68),
(14669, 'Seemannaralia', NULL, 'R.Vig.', 13),
(14670, 'Seemannia', NULL, 'Regel(SUH)', 76),
(14671, 'Seetzenia', NULL, 'R.Br. ex Decne.', 177),
(14672, 'Seguiera', NULL, 'Rchb. ex Oliv.', 44),
(14673, 'Seguieria', NULL, 'Loefl.', 128),
(14674, 'Seidelia', NULL, 'Baill.', 66),
(14675, 'Seidlitzia', NULL, 'Bunge ex Boiss.', 5),
(14676, 'Selago', NULL, 'Hill(SUH)', 150),
(14677, 'Selatium', NULL, 'G.Don', 75),
(14678, 'Selbya', NULL, 'M.Roem.', 106),
(14679, 'Selenia', NULL, 'Nutt.', 197),
(14680, 'Selenothamnus', NULL, 'Melville', 102),
(14681, 'Selera', NULL, 'Ulbr.', 102),
(14682, 'Selinocarpus', NULL, 'A.Gray', 117),
(14683, 'Selinopsis', NULL, 'Coss. & Durieu ex Batt. & Trab.', 9),
(14684, 'Selinum', NULL, 'L.', 9),
(14685, 'Selkirkia', NULL, 'Hemsl.', 25),
(14686, 'Selleophytum', NULL, 'Urb.', 18),
(14687, 'Selloa', NULL, 'Kunth', 18),
(14688, 'Sellocharis', NULL, 'Taub.', 68),
(14689, 'Selmation', NULL, 'T.Durand', 10),
(14690, 'Selysia', NULL, 'Cogn.', 49),
(14691, 'Sematanthera', NULL, 'Pierre ex Harms', 127),
(14692, 'Semeiandra', NULL, 'Hook. & Arn.', 121),
(14693, 'Semenovia', NULL, 'Regel & Herder', 9),
(14694, 'Semetum', NULL, 'Raf.', 197),
(14695, 'Semialarium', NULL, 'N.Halle', 38),
(14696, 'Semibegoniella', NULL, 'C.E.C.Fisch.', 20),
(14697, 'Semicipium', NULL, 'Pierre', 148),
(14698, 'Semilta', NULL, 'Raf.', 66),
(14699, 'Semiramisia', NULL, 'Klotzsch', 64),
(14700, 'Semnostachya', NULL, 'Bremek.', 1),
(14701, 'Semnothyrsus', NULL, 'Bremek.', 1),
(14702, 'Sempervivella', NULL, 'Stapf', 48),
(14703, 'Sempervivum', NULL, 'L.', 48),
(14704, 'Senaea', NULL, 'Taub.', 75),
(14705, 'Senckenbergia', NULL, 'Post & Kuntze', 117),
(14706, 'Senecio', NULL, 'L.', 18),
(14707, 'Senecioides', NULL, 'Post & Kuntze(SUS)', 18),
(14708, 'Senefeldera', NULL, 'Mart.', 66),
(14709, 'Senefelderopsis', NULL, 'Steyerm.', 66),
(14710, 'Senegalia', NULL, 'Raf.', 68),
(14711, 'Senniella', NULL, 'Aellen', 5),
(14712, 'Senra', NULL, 'Cav.', 102),
(14713, 'Sepikea', NULL, 'Schltr.', 76),
(14714, 'Septimetula', NULL, 'Tiegh.', 98),
(14715, 'Septogarcinia', NULL, 'Kosterm.', 42),
(14716, 'Septotheca', NULL, 'Ulbr.', 102),
(14717, 'Septulina', NULL, 'Tiegh.', 98),
(14718, 'Sequoia', NULL, 'Endl.', 51),
(14719, 'Sequoiadendron', NULL, 'Buchholz', 51),
(14720, 'Serenoa', NULL, 'Hook.f.', 15),
(14721, 'Seretoberlinia', NULL, 'P.A.Duvign.', 68),
(14722, 'Sergia', NULL, 'Fed.', 30),
(14723, 'Serialbizzia', NULL, 'Kosterm.', 68),
(14724, 'Serianthes', NULL, 'Benth.', 68),
(14725, 'Sericeocassia', NULL, 'Britton', 68),
(14726, 'Sericocalyx', NULL, 'Bremek.', 1),
(14727, 'Sericocarpus', NULL, 'Nees', 18),
(14728, 'Sericocoma', NULL, 'Fenzl', 5),
(14729, 'Sericocomopsis', NULL, 'Schinz', 5),
(14730, 'Sericodes', NULL, 'A.Gray', 177),
(14731, 'Sericographis', NULL, 'Nees', 1),
(14732, 'Sericolea', NULL, 'Schltr.', 62),
(14733, 'Sericorema', NULL, '(Hook.f.) Lopr.', 5),
(14734, 'Sericostachys', NULL, 'Gilg & Lopr.', 5),
(14735, 'Sericostoma', NULL, 'Stocks', 25),
(14736, 'Sericotheca', NULL, 'Raf.', 141),
(14737, 'Seringia', NULL, 'J.Gay', 102),
(14738, 'Seriola', NULL, 'L.', 18),
(14739, 'Seriphidium', NULL, '(Besser) Poljak.', 18),
(14740, 'Serissa', NULL, 'Comm. ex Juss.', 142),
(14741, 'Serjania', NULL, 'Mill.', 147),
(14742, 'Serophyton', NULL, 'Benth.', 66),
(14743, 'Serratula', NULL, 'L.', 18),
(14744, 'Serruria', NULL, 'Salisb.', 135),
(14745, 'Sersalisia', NULL, 'R.Br.', 148),
(14746, 'Sesban', NULL, 'Adans.', 68),
(14747, 'Sesbania', NULL, 'Scop.', 68),
(14748, 'Seseli', NULL, 'L.', 9),
(14749, 'Seselopsis', NULL, 'Schischk.', 9),
(14750, 'Seshagiria', NULL, 'Ansari & Hemadri', 10),
(14751, 'Sessea', NULL, 'Ruiz & Pav.', 154),
(14752, 'Sesseopsis', NULL, 'Hassl.', 154),
(14753, 'Sestinia', NULL, 'Boiss. & Hohen.', 142),
(14754, 'Setchellanthus', NULL, 'Brandegee', 542),
(14755, 'Setilobus', NULL, 'Baill.', 22),
(14756, 'Sevada', NULL, 'Moq.', 5),
(14757, 'Severinia', NULL, 'Ten.', 143),
(14758, 'Sewerzowia', NULL, 'Regel & Schmalh.', 68),
(14759, 'Seymeria', NULL, 'Pursh', 400),
(14760, 'Seymeriopsis', NULL, 'Tzvelev', 150),
(14761, 'Seyrigia', NULL, 'Keraudren', 49),
(14762, 'Shafera', NULL, 'Greenm.', 18),
(14763, 'Shaferocharis', NULL, 'Urb.', 142),
(14764, 'Shaferodendron', NULL, 'Gilly', 148),
(14765, 'Shantzia', NULL, 'Lewton', 102),
(14766, 'Sheadendron', NULL, 'G.Bertol.', 44),
(14767, 'Sheareria', NULL, 'S.Moore', 18),
(14768, 'Sheilanthera', NULL, 'I.Williams', 143),
(14769, 'Sherardia', NULL, 'L.', 142),
(14770, 'Sherbournia', NULL, 'G.Don', 142),
(14771, 'Shinnersia', NULL, 'R.M.King & H.Rob.', 18),
(14772, 'Shinnersoseris', NULL, 'Tomb', 18),
(14773, 'Shirakia', NULL, 'Hurus.', 66),
(14774, 'Shiuyinghua', NULL, 'Paclt', 150),
(14775, 'Shoshonea', NULL, 'Evert & Constance', 9),
(14776, 'Shuteria', NULL, 'Wight & Arn.', 68),
(14777, 'Siamosia', NULL, 'K.Larsen & Pedersen', 5),
(14778, 'Sibara', NULL, 'Greene', 197),
(14779, 'Sibbaldia', NULL, 'L.', 141),
(14780, 'Sibbaldianthe', NULL, 'Juz.', 141),
(14781, 'Sibbaldiopsis', NULL, 'Rydb.', 141),
(14782, 'Sibiraea', NULL, 'Maxim.', 141),
(14783, 'Sibthorpia', NULL, 'L.', 423),
(14784, 'Sicana', NULL, 'Naudin', 49),
(14785, 'Sicelium', NULL, 'P.Browne', 142),
(14786, 'Sickingia', NULL, 'Willd.', 142),
(14787, 'Sicklera', NULL, 'Sendtn.', 154),
(14788, 'Sickmannia', NULL, 'Nees', 55),
(14789, 'Sicrea', NULL, '(Pierre) Hallier f.', 102),
(14790, 'Sicydium', NULL, 'Schltdl.', 49),
(14791, 'Sicyocarya', NULL, '(A.Gray) H.St.John', 49),
(14792, 'Sicyocaulis', NULL, 'Wiggins', 49),
(14793, 'Sicyoides', NULL, 'Mill.', 49),
(14794, 'Sicyos', NULL, 'L.', 49),
(14795, 'Sicyosperma', NULL, 'A.Gray', 49),
(14796, 'Sicyus', NULL, 'Clem.(SUO)', 49),
(14797, 'Sida', NULL, 'L.', 102),
(14798, 'Sidalcea', NULL, 'A.Gray', 102),
(14799, 'Sidastrum', NULL, 'Baker f.', 102),
(14800, 'Sideria', NULL, 'Ewart & A.H.K.Petrie', 102),
(14801, 'Sideritis', NULL, 'L.', 90),
(14802, 'Siderobombyx', NULL, 'Bremek.', 142),
(14803, 'Siderocarpos', NULL, 'Small', 68),
(14804, 'Siderocarpus', NULL, 'Pierre', 148),
(14805, 'Siderodendrum', NULL, 'Schreb.', 142),
(14806, 'Sideropogon', NULL, 'Pichon', 22),
(14807, 'Sideroxyloides', NULL, 'Jacq.', 142),
(14808, 'Sidopsis', NULL, 'Rydb.', 102),
(14809, 'Siebera', NULL, 'J.Gay', 18),
(14810, 'Siegfriedia', NULL, 'C.A.Gardner', 139),
(14811, 'Siemensia', NULL, 'Urb.', 142),
(14812, 'Sieversia', NULL, 'Willd.', 141),
(14813, 'Sigesbeckia', NULL, 'L.', 18),
(14814, 'Sigmatanthus', NULL, 'Huber ex Emmerich', 143),
(14815, 'Silaum', NULL, 'Mill.', 9),
(14816, 'Silaus', NULL, 'Bernh.', 9),
(14817, 'Siler', NULL, 'Mill.', 9),
(14818, 'Silicularia', NULL, 'Compton', 197),
(14819, 'Siloxerus', NULL, 'Labill.', 18),
(14820, 'Silphium', NULL, 'L.', 18),
(14821, 'Silvaea', NULL, 'Hook. & Arn.(SUH)', 431),
(14822, 'Silvia', NULL, 'Allemao(SUH)', 91),
(14823, 'Silviella', NULL, 'Pennell', 400),
(14824, 'Silybum', NULL, 'Adans.', 18),
(14825, 'Simicratea', NULL, 'N.Halle', 38),
(14826, 'Similisinocarum', NULL, 'Cauwet & Farille', 9),
(14827, 'Simirestis', NULL, 'N.Halle', 38),
(14828, 'Simocheilus', NULL, 'Klotzsch', 64),
(14829, 'Simonisia', NULL, 'Nees', 1),
(14830, 'Simpsonia', NULL, 'O.F.Cook', 15),
(14831, 'Simsia', NULL, 'Pers.', 18),
(14832, 'Sinacalia', NULL, 'H.Rob. & Brettell', 18),
(14833, 'Sinapidendron', NULL, 'Lowe', 197),
(14834, 'Sinapis', NULL, 'L.', 197),
(14835, 'Sinclairia', NULL, 'Hook. & Arn.', 18),
(14836, 'Sindechites', NULL, 'Oliv.', 10),
(14837, 'Sindoropsis', NULL, 'J.Leonard', 68),
(14838, 'Sindroa', NULL, 'Jum.', 15),
(14839, 'Sinia', NULL, 'Diels', 118),
(14840, 'Sinningia', NULL, 'Nees', 76),
(14841, 'Sinoadina', NULL, 'Ridsdale', 142),
(14842, 'Sinoboea', NULL, 'Chun', 76),
(14843, 'Sinocarum', NULL, 'H.Wolff', 9),
(14844, 'Sinocrassula', NULL, 'A.Berger', 48),
(14845, 'Sinodielsia', NULL, 'H.Wolff', 9),
(14846, 'Sinodolichos', NULL, 'Verdc.', 68),
(14847, 'Sinoga', NULL, 'S.T.Blake', 116),
(14848, 'Sinojackia', NULL, 'Hu', 158),
(14849, 'Sinojohnstonia', NULL, 'Hu', 25),
(14850, 'Sinoleontopodium', NULL, 'Y.L.Chen', 18),
(14851, 'Sinolimprichtia', NULL, 'H.Wolff', 9),
(14852, 'Sinomenium', NULL, 'Diels', 107),
(14853, 'Sinomerrillia', NULL, 'Hu', 46),
(14854, 'Sinopanax', NULL, 'H.L.Li', 13),
(14855, 'Sinopimelodendron', NULL, 'Tsiang', 66),
(14856, 'Sinoplagiospermum', NULL, 'Rauschert', 141),
(14857, 'Sinoradlkofera', NULL, 'F.G.Mey.', 147),
(14858, 'Sinosassafras', NULL, 'H.W.Li', 91),
(14859, 'Sinosenecio', NULL, 'B.Nord.', 18),
(14860, 'Sinosideroxylon', NULL, '(Engl.) Aubrev.', 148),
(14861, 'Sinthroblastes', NULL, 'Bremek.', 1),
(14862, 'Siolmatra', NULL, 'Baill.', 49),
(14863, 'Sipanea', NULL, 'Aubl.', 142),
(14864, 'Sipaneopsis', NULL, 'Steyerm.', 142),
(14865, 'Sipapoa', NULL, 'Maguire', 101),
(14866, 'Sipapoantha', NULL, 'Maguire & B.M.Boom', 75),
(14867, 'Siphanthera', NULL, 'Pohl', 105),
(14868, 'Siphantheropsis', NULL, 'Brade', 105),
(14869, 'Siphaulax', NULL, 'Raf.', 154),
(14870, 'Siphoboea', NULL, 'Baill.', 90),
(14871, 'Siphocampylus', NULL, 'Pohl', 30),
(14872, 'Siphocodon', NULL, 'Turcz.', 30),
(14873, 'Siphocolea', NULL, 'Baill.', 22),
(14874, 'Siphocranion', NULL, 'Kudo', 90),
(14875, 'Siphokentia', NULL, 'Burret', 15),
(14876, 'Siphomeris', NULL, 'Bojer', 142),
(14877, 'Siphonandra', NULL, 'Klotzsch', 64),
(14878, 'Siphonandrium', NULL, 'K.Schum.', 142),
(14879, 'Siphonanthus', NULL, 'Schreb. ex Baill.', 66),
(14880, 'Siphonema', NULL, 'Raf.', 154),
(14881, 'Siphoneugena', NULL, 'O.Berg', 116),
(14882, 'Siphonia', NULL, 'Rich.(SUS)', 66),
(14883, 'Siphonidium', NULL, 'J.B.Armstr.', 150),
(14884, 'Siphonoglossa', NULL, 'Oerst.', 1),
(14885, 'Siphonosmanthus', NULL, 'Stapf', 120),
(14886, 'Siphonostegia', NULL, 'Benth.', 400),
(14887, 'Siphonostelma', NULL, 'Schltr.', 10),
(14888, 'Siphonostema', NULL, 'Griseb.', 64),
(14889, 'Sipolisia', NULL, 'Glaz. ex Oliv.', 18),
(14890, 'Siraitia', NULL, 'Merr.', 49),
(14891, 'Sison', NULL, 'L.', 9),
(14892, 'Sisymbrella', NULL, 'Spach', 197),
(14893, 'Sisymbrianthus', NULL, 'Chevall.', 197),
(14894, 'Sisymbriopsis', NULL, 'Botsch. & Tzvelev', 197),
(14895, 'Sisymbrium', NULL, 'L.', 197),
(14896, 'Sisyndite', NULL, 'E.Mey. ex Sond.', 177),
(14897, 'Sisyranthus', NULL, 'E.Mey.', 10),
(14898, 'Sisyrolepis', NULL, 'Radlk.', 147),
(14899, 'Sitella', NULL, 'L.H.Bailey', 102),
(14900, 'Sitilias', NULL, 'Raf.', 18),
(14901, 'Sitodium', NULL, 'Parkinson', 109),
(14902, 'Sium', NULL, 'L.', 9),
(14903, 'Skapanthus', NULL, 'C.Y.Wu', 90),
(14904, 'Skimmia', NULL, 'Thunb.', 143),
(14905, 'Skinnera', NULL, 'J.R.Forst. & G.Forst.', 121),
(14906, 'Skinneria', NULL, 'Choisy(SUH)', 46),
(14907, 'Skiophila', NULL, 'Hanst.', 76),
(14908, 'Skoliopterys', NULL, 'Cuatrec.', 101),
(14909, 'Skoliostigma', NULL, 'Lauterb.', 6),
(14910, 'Skottsbergianthus', NULL, 'Boelcke', 197),
(14911, 'Skottsbergiella', NULL, 'Boelcke(SUH)', 197),
(14912, 'Skottsbergiliana', NULL, 'H.St.John', 49),
(14913, 'Skutchia', NULL, 'Pax & K.Hoffm. ex C.V.Morton', 109),
(14914, 'Skytanthus', NULL, 'Meyen', 10),
(14915, 'Slackia', NULL, 'Griff.(SUH)', 76),
(14916, 'Sladenia', NULL, 'Kurz', 543),
(14917, 'Sleumerodendron', NULL, 'Virot', 135),
(14918, 'Sloetia', NULL, 'Teijsm. & Binn. ex Kurz', 109),
(14919, 'Sloetiopsis', NULL, 'Engl.', 109),
(14920, 'Smallanthus', NULL, 'Mack.', 18),
(14921, 'Smeathmannia', NULL, 'Sol. ex R.Br.', 127),
(14922, 'Smelophyllum', NULL, 'Radlk.', 147),
(14923, 'Smelowskia', NULL, 'C.A.Mey.', 197),
(14924, 'Smirnowia', NULL, 'Bunge', 68),
(14925, 'Smithia', NULL, 'Aiton', 68),
(14926, 'Smithiantha', NULL, 'Kuntze', 76),
(14927, 'Smithiella', NULL, 'Dunn(SUH)', 171),
(14928, 'Smithiodendron', NULL, 'Hu', 109),
(14929, 'Smodingium', NULL, 'E.Mey. ex Sond.', 6),
(14930, 'Smyrniopsis', NULL, 'Boiss.', 9),
(14931, 'Smyrnium', NULL, 'L.', 9),
(14932, 'Smythea', NULL, 'Seem.', 139),
(14933, 'Soala', NULL, 'Blanco', 8),
(14934, 'Soaresia', NULL, 'Sch.Bip.', 18),
(14935, 'Sobolewskia', NULL, 'M.Bieb.', 197),
(14936, 'Socotora', NULL, 'Balf.f.', 10),
(14937, 'Socotranthus', NULL, 'Kuntze', 10),
(14938, 'Socotria', NULL, 'Levin', 99),
(14939, 'Socratesia', NULL, 'Klotzsch', 64),
(14940, 'Socratina', NULL, 'Balle', 98),
(14941, 'Soemmeringia', NULL, 'Mart.', 68),
(14942, 'Sogerianthe', NULL, 'Danser', 98),
(14943, 'Solanastrum', NULL, 'Fabr.', 154),
(14944, 'Solandra', NULL, 'Sw.', 154),
(14945, 'Solanecio', NULL, '(Sch.Bip.) Walp.', 18),
(14946, 'Solanoa', NULL, 'Greene', 10),
(14947, 'Solanocharis', NULL, 'Bitter', 154),
(14948, 'Solanopsis', NULL, 'Bitter', 154),
(14949, 'Soleirolia', NULL, 'Gaudich.', 171),
(14950, 'Solena', NULL, 'Willd.(SUH)', 49),
(14951, 'Solenandra', NULL, 'Hook.f.', 142),
(14952, 'Solenanthus', NULL, 'Ledeb.', 25),
(14953, 'Solenixora', NULL, 'Baill.', 142),
(14954, 'Solenocalyx', NULL, 'Tiegh.', 98),
(14955, 'Solenocarpus', NULL, 'Wight & Arn.', 6),
(14956, 'Solenochasma', NULL, 'Fenzl', 1),
(14957, 'Solenogyne', NULL, 'Cass.', 18),
(14958, 'Solenophora', NULL, 'Benth.', 76),
(14959, 'Solenopsis', NULL, 'C.Presl', 30),
(14960, 'Solenoruellia', NULL, 'Baill.', 1),
(14961, 'Solenospermum', NULL, 'Zoll.', 38),
(14962, 'Solenostemma', NULL, 'Hayne', 10),
(14963, 'Solenostemon', NULL, 'Thonn.', 90),
(14964, 'Solfia', NULL, 'Rech.', 15),
(14965, 'Solidago', NULL, 'L.', 18),
(14966, 'Soliera', NULL, 'Clos', 90),
(14967, 'Soliva', NULL, 'Ruiz & Pav.', 18),
(14968, 'Solms-Laubachia', NULL, 'Muschl.', 197),
(14969, 'Solmsia', NULL, 'Baill.', 164),
(14970, 'Solonia', NULL, 'Urb.', 115),
(14971, 'Sommera', NULL, 'Schltdl.', 142),
(14972, 'Sommerfeltia', NULL, 'Less.', 18),
(14973, 'Sommieria', NULL, 'Becc.', 15),
(14974, 'Somphoxylon', NULL, 'Eichler', 107),
(14975, 'Sonchus', NULL, 'L.', 18),
(14976, 'Sonderina', NULL, 'H.Wolff', 9),
(14977, 'Sondottia', NULL, 'P.S.Short', 18),
(14978, 'Sonerila', NULL, 'Roxb.', 105),
(14979, 'Sonneratia', NULL, 'L.f.', 99),
(14980, 'Sooia', NULL, 'Pocs', 1),
(14981, 'Sooja', NULL, 'Siebold', 68),
(14982, 'Sophiopsis', NULL, 'O.E.Schulz', 197),
(14983, 'Sophoclesia', NULL, 'Klotzsch', 64),
(14984, 'Sophora', NULL, 'L.', 68),
(14985, 'Sophronanthe', NULL, 'Benth.', 150),
(14986, 'Sopropis', NULL, 'Britton & Rose', 68),
(14987, 'Sopubia', NULL, 'Buch.-Ham. ex D.Don', 400),
(14988, 'Soranthus', NULL, 'Ledeb.', 9),
(14989, 'Sorbaria', NULL, '(Ser. ex DC.) A.Braun', 141),
(14990, 'Sorbus', NULL, 'L.', 141),
(14991, 'Sorema', NULL, 'Lindl.', 154),
(14992, 'Sorindeiopsis', NULL, 'Engl.', 6),
(14993, 'Sorocephalus', NULL, 'R.Br.', 135),
(14994, 'Soroseris', NULL, 'Stebbins', 18),
(14995, 'Sorostachys', NULL, 'Steud.', 55),
(14996, 'Sotor', NULL, 'Fenzl', 22),
(14997, 'Soulamea', NULL, 'Lam.', 151),
(14998, 'Souroubea', NULL, 'Aubl.', 104),
(14999, 'Soymida', NULL, 'A.Juss.', 106),
(15000, 'Spachia', NULL, 'Lilja', 121),
(15001, 'Spallanzania', NULL, 'DC.(SUH)', 142),
(15002, 'Spananthe', NULL, 'Jacq.', 9),
(15003, 'Spaniopappus', NULL, 'B.L.Rob.', 18),
(15004, 'Sparattanthelium', NULL, 'Mart.', 79),
(15005, 'Sparattosperma', NULL, 'Mart. ex Meisn.', 22),
(15006, 'Sparattosyce', NULL, 'Bureau', 109),
(15007, 'Sparganophorus', NULL, 'Boehm.', 18),
(15008, 'Sparmannia', NULL, 'L.f.(SUO)', 102),
(15009, 'Sparrea', NULL, 'Hunz. & Dottori', 170),
(15010, 'Sparrmannia', NULL, 'L.f.', 102),
(15011, 'Spartidium', NULL, 'Pomel', 68),
(15012, 'Spartium', NULL, 'L.', 68),
(15013, 'Spartocytisus', NULL, 'Webb & Berthel.', 68),
(15014, 'Spartothamnella', NULL, 'Briq.', 90),
(15015, 'Spatalla', NULL, 'Salisb.', 135),
(15016, 'Spatallopsis', NULL, 'E.Phillips', 135),
(15017, 'Spathacanthus', NULL, 'Baill.', 1),
(15018, 'Spathandra', NULL, 'Guill. & Perr.', 105),
(15019, 'Spathantheum', NULL, 'Schott', 12),
(15020, 'Spathelia', NULL, 'L.', 143),
(15021, 'Spathicalyx', NULL, 'J.C.Gomes', 22),
(15022, 'Spathicarpa', NULL, 'Hook.', 12),
(15023, 'Spathichlamys', NULL, 'R.Parker', 142),
(15024, 'Spathidolepis', NULL, 'Schltr.', 10),
(15025, 'Spathionema', NULL, 'Taub.', 68),
(15026, 'Spathiostemon', NULL, 'Blume', 66),
(15027, 'Spathipappus', NULL, 'Tzvelev', 18),
(15028, 'Spathiphyllum', NULL, 'Schott', 12),
(15029, 'Spathodeopsis', NULL, 'Dop', 22),
(15030, 'Spatholobus', NULL, 'Hassk.', 68),
(15031, 'Spathoscaphe', NULL, 'Oerst.', 15),
(15032, 'Spathulata', NULL, '(Boriss.) A.Love & D.Love', 48),
(15033, 'Spathulopetalum', NULL, 'Chiov.', 10),
(15034, 'Specularia', NULL, 'A.DC.', 30),
(15035, 'Speirema', NULL, 'Hook.f. & Thomson', 30),
(15036, 'Spenceria', NULL, 'Trimen', 141),
(15037, 'Spennera', NULL, 'Mart. ex DC.', 105),
(15038, 'Speranskia', NULL, 'Baill.', 66),
(15039, 'Spermacoce', NULL, 'L.', 142),
(15040, 'Spermacoceodes', NULL, 'Kuntze', 142),
(15041, 'Spermacon', NULL, 'Raf.', 142),
(15042, 'Spermadictyon', NULL, 'Roxb.', 142),
(15043, 'Spermaxyrum', NULL, 'Labill.', 119),
(15044, 'Spermolepis', NULL, 'Brongn. & Gris(SUH)', 9),
(15045, 'Sphacanthus', NULL, 'Benoist', 1),
(15046, 'Sphacele', NULL, 'Benth.', 90),
(15047, 'Sphacophyllum', NULL, 'Benth.', 18),
(15048, 'Sphaenolobium', NULL, 'Pimenov', 9),
(15049, 'Sphaeradenia', NULL, 'Harling', 54),
(15050, 'Sphaeralcea', NULL, 'A.St.-Hil.', 102),
(15051, 'Sphaeranthus', NULL, 'L.', 18),
(15052, 'Sphaerantia', NULL, 'Peter G.Wilson & B.Hyland', 116),
(15053, 'Sphaereupatorium', NULL, '(O.Hoffm.) Kuntze ex B.L.Rob.', 18),
(15054, 'Sphaerocardamum', NULL, 'Nees & Schauer', 197),
(15055, 'Sphaeroclinium', NULL, '(DC.) Sch.Bip.', 18),
(15056, 'Sphaerocodon', NULL, 'Benth.', 10),
(15057, 'Sphaerocoryne', NULL, '(Boerl.) Scheff. ex Ridl.', 8),
(15058, 'Sphaerocyperus', NULL, 'Lye', 55),
(15059, 'Sphaerodendron', NULL, 'Seem.', 13),
(15060, 'Sphaerodiscus', NULL, 'Nakai', 38),
(15061, 'Sphaerogyne', NULL, 'Naudin', 105),
(15062, 'Sphaerolobium', NULL, 'Sm.', 68),
(15063, 'Sphaeromariscus', NULL, 'E.G.Camus', 55),
(15064, 'Sphaeromeria', NULL, 'Nutt.', 18),
(15065, 'Sphaeromorphaea', NULL, 'DC.', 18),
(15066, 'Sphaerophora', NULL, 'Blume', 142),
(15067, 'Sphaerophysa', NULL, 'DC.', 68),
(15068, 'Sphaerosacme', NULL, 'Wall. ex M.Roem.', 106),
(15069, 'Sphaerosciadium', NULL, 'Pimenov & Kljuykov', 9),
(15070, 'Sphaerosicyos', NULL, 'Hook.f.', 49),
(15071, 'Sphaerostigma', NULL, '(Ser.) Fisch. & C.A.Mey.', 121),
(15072, 'Sphaerostylis', NULL, 'Baill.', 66),
(15073, 'Sphaerothalamus', NULL, 'Hook.f.', 8),
(15074, 'Sphaerotylos', NULL, 'C.J.Chen', 171),
(15075, 'Sphagneticola', NULL, 'O.Hoffm.', 18),
(15076, 'Sphalanthus', NULL, 'Jack', 44),
(15077, 'Sphallerocarpus', NULL, 'Besser ex DC.', 9),
(15078, 'Sphalmium', NULL, 'B.G.Briggs, B.Hyland & L.A.S.Joh', 135),
(15079, 'Sphedamnocarpus', NULL, 'Planch. ex Benth.', 101),
(15080, 'Sphenandra', NULL, 'Benth.', 150),
(15081, 'Sphenantha', NULL, 'Schrad.', 49),
(15082, 'Sphenista', NULL, 'Raf.', 40),
(15083, 'Sphenocarpus', NULL, 'Korovin', 9),
(15084, 'Sphenocentrum', NULL, 'Pierre', 107),
(15085, 'Sphenoclea', NULL, 'Gaertn.', 544),
(15086, 'Sphenodesme', NULL, 'Jack', 90),
(15087, 'Sphenogyne', NULL, 'R.Br.', 18),
(15088, 'Sphenosciadium', NULL, 'A.Gray', 9),
(15089, 'Sphenostylis', NULL, 'E.Mey.', 68),
(15090, 'Sphenotoma', NULL, 'R.Br. ex Sweet', 64),
(15091, 'Sphinctacanthus', NULL, 'Benth.', 1),
(15092, 'Sphinctanthus', NULL, 'Benth.', 142),
(15093, 'Sphinctospermum', NULL, 'Rose', 68),
(15094, 'Sphingiphila', NULL, 'A.H.Gentry', 22),
(15095, 'Sphragidia', NULL, 'Thwaites', 66),
(15096, 'Sphyranthera', NULL, 'Hook.f.', 66),
(15097, 'Sphyrospermum', NULL, 'Poepp. & Endl.', 64),
(15098, 'Spicillaria', NULL, 'A.Rich.', 142),
(15099, 'Spiciviscum', NULL, 'Engelm.', 146),
(15100, 'Spielmannia', NULL, 'Medik.(SUS)', 150),
(15101, 'Spigelia', NULL, 'L.', 97),
(15102, 'Spiladocorys', NULL, 'Ridl.', 10),
(15103, 'Spilanthes', NULL, 'Jacq.', 18),
(15104, 'Spilocarpus', NULL, 'Lem.', 25),
(15105, 'Spinacia', NULL, 'L.', 5),
(15106, 'Spiniluma', NULL, '(Baill.) Aubrev.', 148),
(15107, 'Spiracantha', NULL, 'Kunth', 18),
(15108, 'Spiradiclis', NULL, 'Blume', 142),
(15109, 'Spiraea', NULL, 'L.', 141),
(15110, 'Spiraeanthemum', NULL, 'A.Gray', 50),
(15111, 'Spiraeanthus', NULL, '(Fisch. & C.A.Mey.) Maxim.', 141),
(15112, 'Spiraeopsis', NULL, 'Miq.(SUI)', 50),
(15113, 'Spiranthera', NULL, 'A.St.-Hil.', 143),
(15114, 'Spirella', NULL, 'Costantin', 10),
(15115, 'Spiroceratium', NULL, 'H.Wolff', 9),
(15116, 'Spirodela', NULL, 'Schleid.', 12),
(15117, 'Spirogardnera', NULL, 'Stauffer', 146),
(15118, 'Spirolobium', NULL, 'Baill.', 10),
(15119, 'Spiropetalum', NULL, 'Gilg', 45),
(15120, 'Spirorhynchus', NULL, 'Kar. & Kir.', 197),
(15121, 'Spiroseris', NULL, 'Rech.f.', 18),
(15122, 'Spirospermum', NULL, 'Thouars', 107),
(15123, 'Spirostachys', NULL, 'Ung.-Sternb.(SUH)', 66),
(15124, 'Spirostegia', NULL, 'Ivanina', 150),
(15125, 'Spirostigma', NULL, 'Nees', 1),
(15126, 'Spirostylis', NULL, 'C.Presl ex Schult. & Schult.f.', 98),
(15127, 'Spirotecoma', NULL, 'Baill. ex Dalla Torre & Harms', 22),
(15128, 'Spirotropis', NULL, 'Tul.', 68),
(15129, 'Spixia', NULL, 'Leandro', 66),
(15130, 'Spondogona', NULL, 'Raf.', 148),
(15131, 'Spongiocarpella', NULL, 'Yakovlev & N.Ulziykh.', 68),
(15132, 'Spongiosperma', NULL, 'Zarucchi', 10),
(15133, 'Spongiosyndesmus', NULL, 'Gilli', 9),
(15134, 'Sponia', NULL, 'Comm. ex Decne.', 170),
(15135, 'Sporoxeia', NULL, 'W.W.Sm.', 105),
(15136, 'Spragueanella', NULL, 'Balle', 98),
(15137, 'Sprengelia', NULL, 'Sm.', 64),
(15138, 'Sprengeria', NULL, 'Greene', 197),
(15139, 'Sprucea', NULL, 'Benth.', 142),
(15140, 'Spruceanthus', NULL, 'Sleumer', 145),
(15141, 'Sprucella', NULL, 'Pierre', 148),
(15142, 'Sprucina', NULL, 'Nied.', 101),
(15143, 'Spryginia', NULL, 'Popov', 197),
(15144, 'Spuriodaucus', NULL, 'C.Norman', 9),
(15145, 'Spuriopimpinella', NULL, 'Kitag.', 9),
(15146, 'Spyridium', NULL, 'Fenzl', 139),
(15147, 'Squamellaria', NULL, 'Becc.', 142),
(15148, 'Squamopappus', NULL, 'Jansen, Harriman & Urbatsch', 18),
(15149, 'Sreemadhavana', NULL, 'Rauschert', 1),
(15150, 'Stachyandra', NULL, 'J.-F.Leroy ex Radcl.-Sm.', 534),
(15151, 'Stachycarpus', NULL, '(Endl.) Tiegh.', 132),
(15152, 'Stachycephalum', NULL, 'Sch.Bip. ex Benth.', 18),
(15153, 'Stachydeoma', NULL, 'Small', 90),
(15154, 'Stachyococcus', NULL, 'Standl.', 142),
(15155, 'Stachyophorbe', NULL, '(Liebm. ex Mart.) Liebm.', 15),
(15156, 'Stachyopsis', NULL, 'Popov & Vved.', 90),
(15157, 'Stachyothyrsus', NULL, 'Harms', 68),
(15158, 'Stachyphrynium', NULL, 'K.Schum.', 103),
(15159, 'Stachyphyllum', NULL, 'Tiegh.', 63),
(15160, 'Stachys', NULL, 'L.', 90),
(15161, 'Stachystemon', NULL, 'Planch.', 534),
(15162, 'Stachytarpheta', NULL, 'Vahl', 173),
(15163, 'Stackhousia', NULL, 'Sm.', 38),
(15164, 'Stadmannia', NULL, 'Lam.', 147),
(15165, 'Staehelina', NULL, 'L.', 18),
(15166, 'Staelia', NULL, 'Cham. & Schltdl.', 142),
(15167, 'Stagmaria', NULL, 'Jack', 6),
(15168, 'Stahelia', NULL, 'Jonker', 75),
(15169, 'Stahlia', NULL, 'Bello', 68),
(15170, 'Staintoniella', NULL, 'Hara', 197),
(15171, 'Standleya', NULL, 'Brade', 142),
(15172, 'Standleyacanthus', NULL, 'Leonard', 1),
(15173, 'Standleyanthus', NULL, 'R.M.King & H.Rob.', 18),
(15174, 'Stanfieldia', NULL, 'Small', 18),
(15175, 'Stanfordia', NULL, 'S.Watson', 197),
(15176, 'Stanleya', NULL, 'Nutt.', 197),
(15177, 'Stanleyella', NULL, 'Rydb.', 197),
(15178, 'Stannia', NULL, 'H.Karst.', 142),
(15179, 'Stapelia', NULL, 'L.', 10),
(15180, 'Stapelianthus', NULL, 'Choux ex A.C.White & B.Sloane', 10),
(15181, 'Stapeliopsis', NULL, 'Pillans', 10),
(15182, 'Stapfiella', NULL, 'Gilg', 169),
(15183, 'Stapfiophyton', NULL, 'H.L.Li', 105),
(15184, 'Staphidiastrum', NULL, 'Naudin', 105),
(15185, 'Staphidium', NULL, 'Naudin', 105),
(15186, 'Staphylea', NULL, 'L.', 155),
(15187, 'Staphylosyce', NULL, 'Hook.f.', 49),
(15188, 'Staphysora', NULL, 'Pierre', 184),
(15189, 'Stathmostelma', NULL, 'K.Schum.', 10),
(15190, 'Stauracanthus', NULL, 'Link', 68),
(15191, 'Stauranthera', NULL, 'Benth.', 76),
(15192, 'Staurochlamys', NULL, 'Baker', 18),
(15193, 'Staurogyne', NULL, 'Wall.', 1),
(15194, 'Staurogynopsis', NULL, 'Mangenot & Ake Assi', 1),
(15195, 'Staurophragma', NULL, 'Fisch. & C.A.Mey.', 150),
(15196, 'Staurospermum', NULL, 'Thonn.', 142),
(15197, 'Staurostigma', NULL, 'Scheidw.', 12),
(15198, 'Staurothylax', NULL, 'Griff.', 184),
(15199, 'Stebbinsoseris', NULL, 'K.L.Chambers', 18),
(15200, 'Steenisia', NULL, 'Bakh.f.', 142),
(15201, 'Stefanoffia', NULL, 'H.Wolff', 9),
(15202, 'Steganotaenia', NULL, 'Hochst.', 9),
(15203, 'Steganotropis', NULL, 'Lehm.', 68),
(15204, 'Steganthera', NULL, 'Perkins', 108),
(15205, 'Steganthus', NULL, 'Knobl.', 120),
(15206, 'Stegastrum', NULL, 'Tiegh.(SUH)', 98),
(15207, 'Stegnocarpus', NULL, 'Torr. & A.Gray', 25),
(15208, 'Steigeria', NULL, 'Mull.Arg.', 66),
(15209, 'Steinbachiella', NULL, 'Harms', 68),
(15210, 'Steinheilia', NULL, 'Decne.', 10),
(15211, 'Steiractinia', NULL, 'S.F.Blake', 18),
(15212, 'Steirodiscus', NULL, 'Less.', 18),
(15213, 'Steironema', NULL, 'Raf.', 115),
(15214, 'Steirosanchezia', NULL, 'Lindau', 1),
(15215, 'Steirotis', NULL, 'Raf.', 98),
(15216, 'Stelechanteria', NULL, 'Thouars ex Baill.', 66),
(15217, 'Stelechantha', NULL, 'Bremek.', 142),
(15218, 'Steleocodon', NULL, 'Gilli', 18),
(15219, 'Steleostemma', NULL, 'Schltr.', 10),
(15220, 'Stelestylis', NULL, 'Drude', 54),
(15221, 'Stellariopsis', NULL, '(Baill.) Rydb.', 141),
(15222, 'Stellera', NULL, 'L.', 164),
(15223, 'Stelleropsis', NULL, 'Pobed.', 164),
(15224, 'Stelligera', NULL, 'A.J.Scott', 5),
(15225, 'Stellix', NULL, 'Noronha', 142),
(15226, 'Stellularia', NULL, 'Benth.', 150),
(15227, 'Stelmacrypton', NULL, 'Baill.', 10),
(15228, 'Stelmanis', NULL, 'Raf.(SUH)', 142),
(15229, 'Stelmation', NULL, 'E.Fourn.', 10),
(15230, 'Stelmatocodon', NULL, 'Schltr.', 10),
(15231, 'Stelmatocrypton', NULL, 'Baill.', 10),
(15232, 'Stelmotis', NULL, 'Raf.', 142),
(15233, 'Stemmacantha', NULL, 'Cass.', 18),
(15234, 'Stemmatella', NULL, 'Wedd. ex Benth.', 18),
(15235, 'Stemmatodaphne', NULL, 'Gamble', 91),
(15236, 'Stemmatophyllum', NULL, 'Tiegh.', 98),
(15237, 'Stemodia', NULL, 'L.', 423),
(15238, 'Stemodiopsis', NULL, 'Engl.', 150),
(15239, 'Stemonocoleus', NULL, 'Harms', 68),
(15240, 'Stemotria', NULL, 'Wettst. & Harms ex Engl.', 150),
(15241, 'Stenachaenium', NULL, 'Benth.', 18),
(15242, 'Stenadenium', NULL, 'Pax', 66),
(15243, 'Stenandriopsis', NULL, 'S.Moore', 1),
(15244, 'Stenandrium', NULL, 'Nees', 1),
(15245, 'Stenanona', NULL, 'Standl.', 8),
(15246, 'Stenanthemum', NULL, 'Reissek', 139),
(15247, 'Stenanthera', NULL, 'Engl. & Diels', 8),
(15248, 'Stenanthus', NULL, 'Oerst. ex Hanst.', 76),
(15249, 'Stenaria', NULL, 'Raf.', 142),
(15250, 'Stenocalyx', NULL, 'Turcz.(SUH)', 101),
(15251, 'Stenocarpha', NULL, 'S.F.Blake', 18),
(15252, 'Stenocarpus', NULL, 'R.Br.', 135),
(15253, 'Stenocephalum', NULL, 'Sch.Bip.', 18),
(15254, 'Stenochasma', NULL, 'Miq.', 109),
(15255, 'Stenochilus', NULL, 'R.Br.', 150),
(15256, 'Stenocline', NULL, 'DC.', 18),
(15257, 'Stenocoelium', NULL, 'Ledeb.', 9),
(15258, 'Stenodon', NULL, 'Naudin', 105),
(15259, 'Stenodraba', NULL, 'O.E.Schulz', 197),
(15260, 'Stenodrepanum', NULL, 'Harms', 68),
(15261, 'Stenogastra', NULL, 'Hanst.', 76),
(15262, 'Stenogonum', NULL, 'Nutt.', 134),
(15263, 'Stenogyne', NULL, 'Benth.', 90),
(15264, 'Stenolobium', NULL, 'D.Don', 22),
(15265, 'Stenomeria', NULL, 'Turcz.', 10),
(15266, 'Stenomeris', NULL, 'Planch.', 59),
(15267, 'Stenonema', NULL, 'Hook.', 197),
(15268, 'Stenonia', NULL, 'Baill.', 184),
(15269, 'Stenoniella', NULL, 'Kuntze', 184),
(15270, 'Stenopadus', NULL, 'S.F.Blake', 18),
(15271, 'Stenopetalum', NULL, 'R.Br. ex DC.', 197),
(15272, 'Stenophalium', NULL, 'Anderb.', 18),
(15273, 'Stenophragma', NULL, 'Celak.', 197),
(15274, 'Stenophyllus', NULL, 'Raf.', 55),
(15275, 'Stenops', NULL, 'B.Nord.', 18),
(15276, 'Stenoschista', NULL, 'Bremek.', 1),
(15277, 'Stenosiphanthus', NULL, 'A.Samp.', 22),
(15278, 'Stenosiphon', NULL, 'Spach', 121),
(15279, 'Stenosiphonium', NULL, 'Nees', 1),
(15280, 'Stenosolen', NULL, '(Mull.Arg.) Markgr.', 10),
(15281, 'Stenosolenium', NULL, 'Turcz.', 25),
(15282, 'Stenospermation', NULL, 'Schott', 12),
(15283, 'Stenospermum', NULL, 'Sweet ex Heynh.', 116),
(15284, 'Stenostelma', NULL, 'Schltr.', 10),
(15285, 'Stenostephanus', NULL, 'Nees', 1),
(15286, 'Stenostomum', NULL, 'C.F.Gaertn.', 142),
(15287, 'Stenothyrsus', NULL, 'C.B.Clarke', 1),
(15288, 'Stenotopsis', NULL, 'Rydb.', 18),
(15289, 'Stenotus', NULL, 'Nutt.', 18),
(15290, 'Stephanandra', NULL, 'Siebold & Zucc.', 141),
(15291, 'Stephania', NULL, 'Lour.', 107),
(15292, 'Stephaniscus', NULL, 'Tiegh.', 98),
(15293, 'Stephanium', NULL, 'Schreb.', 142),
(15294, 'Stephanocaryum', NULL, 'Popov', 25),
(15295, 'Stephanochilus', NULL, 'Coss. & Durieu ex Maire', 18),
(15296, 'Stephanococcus', NULL, 'Bremek.', 142),
(15297, 'Stephanodaphne', NULL, 'Baill.', 164),
(15298, 'Stephanodoria', NULL, 'Greene', 18),
(15299, 'Stephanolepis', NULL, 'S.Moore', 18),
(15300, 'Stephanoluma', NULL, 'Baill.', 148),
(15301, 'Stephanomeria', NULL, 'Nutt.', 18),
(15302, 'Stephanopholis', NULL, 'S.F.Blake', 18),
(15303, 'Stephanophysum', NULL, 'Pohl', 1),
(15304, 'Stephanorossia', NULL, 'Chiov.', 9),
(15305, 'Stephanostachys', NULL, '(Klotzsch) Klotzsch ex O.E.Schul', 15),
(15306, 'Stephanostegia', NULL, 'Baill.', 10),
(15307, 'Stephanostema', NULL, 'K.Schum.', 10),
(15308, 'Stephanotella', NULL, 'E.Fourn.', 10),
(15309, 'Stephanotis', NULL, 'Thouars', 10),
(15310, 'Stephanotrichum', NULL, 'Naudin', 105),
(15311, 'Stephegyne', NULL, 'Korth.', 142),
(15312, 'Steptorhamphus', NULL, 'Bunge', 18),
(15313, 'Stereocarpus', NULL, '(Pierre) Hallier f.', 162),
(15314, 'Stereocaryum', NULL, 'Burret', 116),
(15315, 'Stereoderma', NULL, 'Blume', 120),
(15316, 'Sterigmanthe', NULL, 'Klotzsch & Garcke', 66),
(15317, 'Sterigmapetalum', NULL, 'Kuhlm.', 140),
(15318, 'Sterigmostemum', NULL, 'M.Bieb.', 197),
(15319, 'Steriphoma', NULL, 'Spreng.', 32);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(15320, 'Sterrhymenia', NULL, 'Griseb.', 154),
(15321, 'Stethoma', NULL, 'Raf.', 1),
(15322, 'Steudelago', NULL, 'Kuntze', 142),
(15323, 'Steudnera', NULL, 'K.Koch', 12),
(15324, 'Stevenia', NULL, 'Adams ex Fisch.', 197),
(15325, 'Stevensia', NULL, 'Poit.', 142),
(15326, 'Stevensonia', NULL, 'Duncan ex Balf.f.', 15),
(15327, 'Stevia', NULL, 'Cav.', 18),
(15328, 'Steviopsis', NULL, 'R.M.King & H.Rob.', 18),
(15329, 'Stewartia', NULL, 'L.(SUO)', 162),
(15330, 'Stewartiella', NULL, 'Nasir', 9),
(15331, 'Steyermarkia', NULL, 'Standl.', 142),
(15332, 'Steyermarkina', NULL, 'R.M.King & H.Rob.', 18),
(15333, 'Stichianthus', NULL, 'Valeton', 142),
(15334, 'Stictocardia', NULL, 'Hallier f.', 46),
(15335, 'Stifftia', NULL, 'J.C.Mikan', 18),
(15336, 'Stigmanthus', NULL, 'Lour.', 142),
(15337, 'Stigmaphyllon', NULL, 'A.Juss.', 101),
(15338, 'Stigmatanthus', NULL, 'Roem. & Schult.(SUO)', 142),
(15339, 'Stigmatella', NULL, 'Eig(SUH)', 197),
(15340, 'Stigmatorhynchus', NULL, 'Schltr.', 10),
(15341, 'Stilaginella', NULL, 'Tul.', 66),
(15342, 'Stilago', NULL, 'L.(SUS)', 184),
(15343, 'Stilbanthus', NULL, 'Hook.f.', 5),
(15344, 'Stilbocarpa', NULL, '(Hook.f.) Decne. & Planch.', 13),
(15345, 'Stillingfleetia', NULL, 'Bojer', 66),
(15346, 'Stillingia', NULL, 'Garden ex L.', 66),
(15347, 'Stilpnogyne', NULL, 'DC.', 18),
(15348, 'Stilpnolepis', NULL, 'Krasch.', 18),
(15349, 'Stilpnopappus', NULL, 'Mart. ex DC.', 18),
(15350, 'Stilpnophyllum', NULL, 'Hook.f.', 142),
(15351, 'Stilpnophyton', NULL, 'Less.', 18),
(15352, 'Stilpnophytum', NULL, 'Less.(SUO)', 18),
(15353, 'Stimenes', NULL, 'Raf.', 154),
(15354, 'Stimomphis', NULL, 'Raf.', 154),
(15355, 'Stimoryne', NULL, 'Raf.', 154),
(15356, 'Stimpsonia', NULL, 'C.Wright ex A.Gray', 115),
(15357, 'Stipecoma', NULL, 'Mull.Arg.', 10),
(15358, 'Stipellaria', NULL, 'Benth.(SUS)', 66),
(15359, 'Stiptanthus', NULL, 'Briq.', 90),
(15360, 'Stirlingia', NULL, 'Endl.', 135),
(15361, 'Stironeuron', NULL, 'Radlk.', 148),
(15362, 'Stisseria', NULL, 'Scop.', 148),
(15363, 'Stixis', NULL, 'Lour.', 549),
(15364, 'Stizolobium', NULL, 'P.Browne', 68),
(15365, 'Stizophyllum', NULL, 'Miers', 22),
(15366, 'Stobaea', NULL, 'Thunb.', 18),
(15367, 'Stocksia', NULL, 'Benth.', 147),
(15368, 'Stoebe', NULL, 'L.', 18),
(15369, 'Stoibrax', NULL, 'Raf.', 9),
(15370, 'Stokesia', NULL, 'L''Her.', 18),
(15371, 'Stokoeanthus', NULL, 'E.G.H.Oliv.', 64),
(15372, 'Stollaea', NULL, 'Schltr.', 50),
(15373, 'Stomandra', NULL, 'Standl.', 142),
(15374, 'Stomatanthes', NULL, 'R.M.King & H.Rob.', 18),
(15375, 'Stomatocalyx', NULL, 'Mull.Arg.', 66),
(15376, 'Stomatochaeta', NULL, '(S.F.Blake) Maguire & Wurdack', 18),
(15377, 'Stomatostemma', NULL, 'N.E.Br.', 10),
(15378, 'Storckiella', NULL, 'Seem.', 68),
(15379, 'Stormia', NULL, 'S.Moore', 8),
(15380, 'Storthocalyx', NULL, 'Radlk.', 147),
(15381, 'Stracheya', NULL, 'Benth.', 68),
(15382, 'Strailia', NULL, 'T.Durand', 92),
(15383, 'Strakaea', NULL, 'C.Presl', 16),
(15384, 'Stramentopappus', NULL, 'H.Rob. & V.A.Funk', 18),
(15385, 'Stramonium', NULL, 'Mill.', 154),
(15386, 'Strangea', NULL, 'Meisn.', 135),
(15387, 'Stranvaesia', NULL, 'Lindl.', 141),
(15388, 'Straussia', NULL, 'A.Gray', 142),
(15389, 'Straussiella', NULL, 'Hausskn.', 197),
(15390, 'Streblacanthus', NULL, 'Kuntze', 1),
(15391, 'Streblorrhiza', NULL, 'Endl.', 68),
(15392, 'Streblosa', NULL, 'Korth.', 142),
(15393, 'Streblosiopsis', NULL, 'Valeton', 142),
(15394, 'Strelitzia', NULL, 'Aiton', 157),
(15395, 'Strempelia', NULL, 'A.Rich.', 142),
(15396, 'Strempeliopsis', NULL, 'Benth.', 10),
(15397, 'Strepsilobus', NULL, 'Raf.', 68),
(15398, 'Strepsimela', NULL, 'Raf.', 98),
(15399, 'Streptanthella', NULL, 'Rydb.', 197),
(15400, 'Streptanthus', NULL, 'Nutt.', 197),
(15401, 'Streptocarpus', NULL, 'Lindl.', 76),
(15402, 'Streptocaulon', NULL, 'Wight & Arn.', 10),
(15403, 'Streptoglossa', NULL, 'Steetz ex F.Muell.', 18),
(15404, 'Streptoloma', NULL, 'Bunge', 197),
(15405, 'Streptomanes', NULL, 'K.Schum.', 10),
(15406, 'Streptopetalum', NULL, 'Hochst.', 169),
(15407, 'Streptopus', NULL, 'Michx.', 94),
(15408, 'Streptosiphon', NULL, 'Mildbr.', 1),
(15409, 'Streptosolen', NULL, 'Miers', 154),
(15410, 'Streptostigma', NULL, 'Regel', 154),
(15411, 'Streptothamnus', NULL, 'F.Muell.', 506),
(15412, 'Streptotrachelus', NULL, 'Greenm.', 10),
(15413, 'Striga', NULL, 'Lour.', 400),
(15414, 'Strigina', NULL, 'Engl.', 150),
(15415, 'Strigosella', NULL, 'Boiss.', 197),
(15416, 'Striolaria', NULL, 'Ducke', 142),
(15417, 'Strobilacanthus', NULL, 'Griseb.', 1),
(15418, 'Strobilanthes', NULL, 'Blume', 1),
(15419, 'Strobilanthopsis', NULL, 'S.Moore', 1),
(15420, 'Strobilopanax', NULL, 'R.Vig.', 13),
(15421, 'Strobilopsis', NULL, 'Hilliard & B.L.Burtt', 150),
(15422, 'Strobilorhachis', NULL, 'Klotzsch', 1),
(15423, 'Strobopetalum', NULL, 'N.E.Br.', 10),
(15424, 'Stroganowia', NULL, 'Kar. & Kir.', 197),
(15425, 'Stromanthe', NULL, 'Sond.', 103),
(15426, 'Strombocarpa', NULL, '(Benth.) A.Gray', 68),
(15427, 'Strongylocalyx', NULL, 'Blume', 116),
(15428, 'Strongylocaryum', NULL, 'Burret', 15),
(15429, 'Strongylodon', NULL, 'Vogel', 68),
(15430, 'Strophacanthus', NULL, 'Lindau', 1),
(15431, 'Strophanthus', NULL, 'DC.', 10),
(15432, 'Strophioblachia', NULL, 'Boerl.', 66),
(15433, 'Strophiodiscus', NULL, 'Choux', 147),
(15434, 'Strophocaulos', NULL, 'Small', 46),
(15435, 'Strophostyles', NULL, 'Elliott', 68),
(15436, 'Strotheria', NULL, 'B.L.Turner', 18),
(15437, 'Struchium', NULL, 'P.Browne', 18),
(15438, 'Strukeria', NULL, 'Vell.', 175),
(15439, 'Strumpfia', NULL, 'Jacq.', 142),
(15440, 'Struthanthus', NULL, 'Mart.', 98),
(15441, 'Struthiola', NULL, 'L.', 164),
(15442, 'Struthiolopsis', NULL, 'E.Phillips', 164),
(15443, 'Strychnopsis', NULL, 'Baill.', 107),
(15444, 'Stuartia', NULL, 'L.', 162),
(15445, 'Stuartina', NULL, 'Sond.', 18),
(15446, 'Stubendorffia', NULL, 'Schrenk ex Fisch., C.A.Mey. & Av', 197),
(15447, 'Stuckertia', NULL, 'Kuntze', 10),
(15448, 'Stuckertiella', NULL, 'Beauverd', 18),
(15449, 'Stuebelia', NULL, 'Pax', 32),
(15450, 'Stuessya', NULL, 'B.L.Turner & F.G.Davies', 18),
(15451, 'Stuhlmannia', NULL, 'Taub.', 68),
(15452, 'Stultitia', NULL, 'E.Phillips', 10),
(15453, 'Sturmia', NULL, 'C.F.Gaertn.', 142),
(15454, 'Stussenia', NULL, 'C.Hansen', 105),
(15455, 'Stutzeria', NULL, 'F.Muell.(SUI)', 50),
(15456, 'Styasasia', NULL, 'S.Moore', 1),
(15457, 'Stygnanthe', NULL, 'Hanst.', 76),
(15458, 'Stylanthus', NULL, 'Rchb.f. & Zoll.', 66),
(15459, 'Stylarthropus', NULL, 'Baill.', 1),
(15460, 'Stylisma', NULL, 'Raf.', 46),
(15461, 'Styloceras', NULL, 'Kunth ex Juss.', 28),
(15462, 'Stylochaeton', NULL, 'Lepr.', 12),
(15463, 'Stylocline', NULL, 'Nutt.', 18),
(15464, 'Stylocoryna', NULL, 'Cav.(SUH)', 142),
(15465, 'Stylocoryne', NULL, 'Wight & Arn.(SUO)', 142),
(15466, 'Stylodiscus', NULL, 'Benn.', 184),
(15467, 'Stylodon', NULL, 'Raf.', 173),
(15468, 'Styloma', NULL, 'O.F.Cook', 15),
(15469, 'Stylomecon', NULL, 'G.Taylor', 126),
(15470, 'Stylophorum', NULL, 'Nutt.', 126),
(15471, 'Stylophyllum', NULL, 'Britton & Rose', 48),
(15472, 'Stylosanthes', NULL, 'Sw.', 68),
(15473, 'Stylosiphonia', NULL, 'Brandegee', 142),
(15474, 'Stylotrichium', NULL, 'Mattf.', 18),
(15475, 'Styphelia', NULL, 'Sm.', 64),
(15476, 'Styphnolobium', NULL, 'Schott ex Endl.', 68),
(15477, 'Styrophyton', NULL, 'S.Y.Hu', 105),
(15478, 'Styrosinia', NULL, 'Raf.', 76),
(15479, 'Suaeda', NULL, 'Forssk. ex Scop.', 5),
(15480, 'Suberanthus', NULL, 'Borhidi & M.Fernandez Zeq.', 142),
(15481, 'Sublimia', NULL, 'Comm. ex Mart.', 15),
(15482, 'Subularia', NULL, 'L.', 197),
(15483, 'Succowia', NULL, 'Medik.', 197),
(15484, 'Suchtelenia', NULL, 'Kar. ex Meisn.', 25),
(15485, 'Suckleya', NULL, 'A.Gray', 5),
(15486, 'Suessenguthia', NULL, 'Merxm.', 1),
(15487, 'Suitenia', NULL, 'Stokes(SUO)', 106),
(15488, 'Suitramia', NULL, 'Rchb.(SUO)', 105),
(15489, 'Suksdorfia', NULL, 'A.Gray', 149),
(15490, 'Sukunia', NULL, 'A.C.Sm.', 142),
(15491, 'Sulaimania', NULL, 'Hedge & Rech.f.', 90),
(15492, 'Sulipa', NULL, 'Blanco', 142),
(15493, 'Sulitia', NULL, 'Merr.', 142),
(15494, 'Sullivantia', NULL, 'Torr. & A.Gray', 149),
(15495, 'Sulzeria', NULL, 'Roem. & Schult.(SUI)', 142),
(15496, 'Sumatroscirpus', NULL, 'Oteng-Yeb.', 55),
(15497, 'Sumbavia', NULL, 'Baill.', 66),
(15498, 'Sunaptea', NULL, 'Griff.', 60),
(15499, 'Sundacarpus', NULL, 'C.N.Page', 132),
(15500, 'Surenus', NULL, 'Kuntze', 106),
(15501, 'Surfacea', NULL, 'Moldenke', 90),
(15502, 'Surwala', NULL, 'M.Roem.', 106),
(15503, 'Susilkumara', NULL, 'Bennet(SUS)', 90),
(15504, 'Sutera', NULL, 'Roth', 150),
(15505, 'Suteria', NULL, 'DC.', 142),
(15506, 'Sutherlandia', NULL, 'R.Br. ex W.T.Aiton', 68),
(15507, 'Suttonia', NULL, 'A.Rich.', 115),
(15508, 'Suzukia', NULL, 'Kudo', 90),
(15509, 'Svensonia', NULL, 'Moldenke', 173),
(15510, 'Sventenia', NULL, 'Font Quer', 18),
(15511, 'Svitramia', NULL, 'Cham.', 105),
(15512, 'Swainsona', NULL, 'Salisb.', 68),
(15513, 'Swartsia', NULL, 'J.F.Gmel.', 154),
(15514, 'Sweetia', NULL, 'Spreng.', 68),
(15515, 'Sweetiopsis', NULL, 'Chodat & Hassk.', 68),
(15516, 'Swertia', NULL, 'L.', 75),
(15517, 'Swertopsis', NULL, 'Makino', 75),
(15518, 'Swida', NULL, 'Opiz', 47),
(15519, 'Swinglea', NULL, 'Merr.', 143),
(15520, 'Swynnertonia', NULL, 'S.Moore', 10),
(15521, 'Syagrus', NULL, 'Mart.', 15),
(15522, 'Sychinium', NULL, 'Desv.', 109),
(15523, 'Sycios', NULL, 'Medik.(SUO)', 49),
(15524, 'Sycocarpus', NULL, 'Britton', 106),
(15525, 'Sycodendron', NULL, 'Rojas Acosta', 109),
(15526, 'Sycomorphe', NULL, 'Miq.', 109),
(15527, 'Sycomorus', NULL, 'Gasp.', 109),
(15528, 'Sycophila', NULL, 'Welw. ex Tiegh.', 98),
(15529, 'Sykesia', NULL, 'Arn.', 142),
(15530, 'Sylitra', NULL, 'E.Mey.(SUH)', 68),
(15531, 'Syllisium', NULL, 'Endl.(SUO)', 116),
(15532, 'Syllysium', NULL, 'Meyen & Schauer', 116),
(15533, 'Symbegonia', NULL, 'Warb.', 20),
(15534, 'Symbolanthus', NULL, 'G.Don', 75),
(15535, 'Symmeria', NULL, 'Benth.', 134),
(15536, 'Symonanthus', NULL, 'Haegi', 154),
(15537, 'Sympagis', NULL, '(Nees) Bremek.', 1),
(15538, 'Sympegma', NULL, 'Bunge', 5),
(15539, 'Symphiandra', NULL, 'Steud.', 30),
(15540, 'Symphionema', NULL, 'R.Br.', 135),
(15541, 'Symphorema', NULL, 'Roxb.', 90),
(15542, 'Symphoricarpos', NULL, 'Duhamel', 33),
(15543, 'Symphostemon', NULL, 'Hiern', 90),
(15544, 'Symphyandra', NULL, 'A.DC.', 30),
(15545, 'Symphyllarion', NULL, 'Gagnep.', 142),
(15546, 'Symphyllia', NULL, 'Baill.', 66),
(15547, 'Symphyllocarpus', NULL, 'Maxim.', 18),
(15548, 'Symphyllophyton', NULL, 'Gilg', 75),
(15549, 'Symphyochaeta', NULL, '(DC.) Skottsb.', 18),
(15550, 'Symphyochlamys', NULL, 'Gurke', 102),
(15551, 'Symphyogyne', NULL, 'Burret', 15),
(15552, 'Symphyoloma', NULL, 'C.A.Mey.', 9),
(15553, 'Symphyomyrtus', NULL, 'Schauer', 116),
(15554, 'Symphyopappus', NULL, 'Turcz.', 18),
(15555, 'Symphysia', NULL, 'C.Presl', 64),
(15556, 'Symphysicarpus', NULL, 'Hassk.', 10),
(15557, 'Symphytonema', NULL, 'Schltr.', 10),
(15558, 'Symphytosiphon', NULL, 'Harms', 106),
(15559, 'Symphytum', NULL, 'L.', 25),
(15560, 'Sympieza', NULL, 'Licht. ex Roem. & Schult.', 64),
(15561, 'Symplectochilus', NULL, 'Lindau', 1),
(15562, 'Symplocarpus', NULL, 'Salisb. ex Nutt.', 12),
(15563, 'Symplococarpon', NULL, 'Airy Shaw', 409),
(15564, 'Synadenium', NULL, 'Boiss.', 66),
(15565, 'Synallodia', NULL, 'Raf.', 75),
(15566, 'Synandra', NULL, 'Nutt.', 90),
(15567, 'Synandrina', NULL, 'Standl. & L.O.Williams', 145),
(15568, 'Synandrodaphne', NULL, 'Gilg', 164),
(15569, 'Synandrogyne', NULL, 'Buchet', 12),
(15570, 'Synandropus', NULL, 'A.C.Sm.', 107),
(15571, 'Synandrospadix', NULL, 'Engl.', 12),
(15572, 'Synantherias', NULL, 'Schott', 12),
(15573, 'Synaphea', NULL, 'R.Br.', 135),
(15574, 'Synapsis', NULL, 'Griseb.', 540),
(15575, 'Synaptantha', NULL, 'Hook.f.', 142),
(15576, 'Synaptea', NULL, 'Kurz(SUO)', 60),
(15577, 'Synaptolepis', NULL, 'Oliv.', 164),
(15578, 'Synardisia', NULL, '(Mez) Lundell', 115),
(15579, 'Synarrhena', NULL, 'Fisch. & C.A.Mey.', 148),
(15580, 'Synaspisma', NULL, 'Endl.', 66),
(15581, 'Synastemon', NULL, 'F.Muell.', 184),
(15582, 'Syncalathium', NULL, 'Lipsch.', 18),
(15583, 'Syncarpha', NULL, 'DC.', 18),
(15584, 'Syncarpia', NULL, 'Ten.', 116),
(15585, 'Syncephalum', NULL, 'DC.', 18),
(15586, 'Synchoriste', NULL, 'Baill.', 1),
(15587, 'Synclisia', NULL, 'Benth.', 107),
(15588, 'Syncolostemon', NULL, 'E.Mey.', 90),
(15589, 'Syncretocarpus', NULL, 'S.F.Blake', 18),
(15590, 'Syndesmanthus', NULL, 'Klotzsch', 64),
(15591, 'Syndesmis', NULL, 'Wall.', 6),
(15592, 'Syndiclis', NULL, 'Hook.f.', 91),
(15593, 'Syndyophyllum', NULL, 'K.Schum. & Lauterb.', 66),
(15594, 'Synedrella', NULL, 'Gaertn.', 18),
(15595, 'Synedrellopsis', NULL, 'Hieron. & Kuntze', 18),
(15596, 'Syneilesis', NULL, 'Maxim.', 18),
(15597, 'Synelcosciadium', NULL, 'Boiss.', 9),
(15598, 'Synema', NULL, 'Dulac', 66),
(15599, 'Synepilaena', NULL, 'Baill.', 76),
(15600, 'Synexemia', NULL, 'Raf.', 184),
(15601, 'Syngonium', NULL, 'Schott', 12),
(15602, 'Synima', NULL, 'Radlk.', 147),
(15603, 'Synisoon', NULL, 'Baill.', 142),
(15604, 'Synnema', NULL, 'Benth.', 1),
(15605, 'Synoecia', NULL, 'Miq.', 109),
(15606, 'Synosma', NULL, 'Raf. ex Britton & A.Br.(SUS)', 18),
(15607, 'Synostemon', NULL, 'F.Muell.', 184),
(15608, 'Synotis', NULL, '(C.B.Clarke) C.Jeffrey & Y.L.Che', 18),
(15609, 'Synotoma', NULL, '(G.Don) Rich.Schulz', 30),
(15610, 'Synoum', NULL, 'A.Juss.', 106),
(15611, 'Synstemon', NULL, 'Botsch.', 197),
(15612, 'Synstemonanthus', NULL, 'Botsch.(SUS)', 197),
(15613, 'Synthlipsis', NULL, 'A.Gray', 197),
(15614, 'Synthyris', NULL, 'Benth.', 423),
(15615, 'Syntriandrium', NULL, 'Engl.', 107),
(15616, 'Syntrichopappus', NULL, 'A.Gray', 18),
(15617, 'Syntrinema', NULL, 'H.Pfeiff.', 55),
(15618, 'Synurus', NULL, 'Iljin', 18),
(15619, 'Syreitschikovia', NULL, 'Pavlov', 18),
(15620, 'Syrenia', NULL, 'Andrz. ex Besser', 197),
(15621, 'Syrenopsis', NULL, 'Jaub. & Spach', 197),
(15622, 'Syringa', NULL, 'L.', 120),
(15623, 'Syringantha', NULL, 'Standl.', 142),
(15624, 'Syringidium', NULL, 'Lindau(SUH)', 1),
(15625, 'Syrrheonema', NULL, 'Miers', 107),
(15626, 'Systenotheca', NULL, 'Reveal & Hardham', 134),
(15627, 'Syzygiopsis', NULL, 'Ducke', 148),
(15628, 'Szovitsia', NULL, 'Fisch. & C.A.Mey.', 9),
(15629, 'Tabacum', NULL, 'Gilib.', 154),
(15630, 'Tabacus', NULL, 'Moench', 154),
(15631, 'Tabascina', NULL, 'Baill.', 1),
(15632, 'Taberna', NULL, 'Miers', 10),
(15633, 'Tabernanthe', NULL, 'Baill.', 10),
(15634, 'Tacarcuna', NULL, 'Huft', 66),
(15635, 'Tacazzea', NULL, 'Decne.', 10),
(15636, 'Tacca', NULL, 'J.R.Forst. & G.Forst.', 59),
(15637, 'Taccarum', NULL, 'Brongn. ex Schott', 12),
(15638, 'Tachia', NULL, 'Aubl.', 75),
(15639, 'Tachiadenus', NULL, 'Griseb.', 75),
(15640, 'Tachibota', NULL, 'Aubl.', 40),
(15641, 'Tacitus', NULL, 'Moran', 48),
(15642, 'Tacoanthus', NULL, 'Baill.', 1),
(15643, 'Tacsonia', NULL, 'Juss.', 127),
(15644, 'Tadehagi', NULL, 'H.Ohashi', 68),
(15645, 'Taeckholmia', NULL, 'Boulos', 18),
(15646, 'Taeniandra', NULL, 'Bremek.', 1),
(15647, 'Taenianthera', NULL, 'Burret', 15),
(15648, 'Taenidia', NULL, '(Torr. & A.Gray) Drude', 9),
(15649, 'Taeniochlaena', NULL, 'Hook.f.', 45),
(15650, 'Taeniopleurum', NULL, 'J.M.Coult. & Rose', 9),
(15651, 'Taeniosapium', NULL, 'Mull.Arg.', 66),
(15652, 'Taetsia', NULL, 'Medik.', 3),
(15653, 'Tagetes', NULL, 'L.', 18),
(15654, 'Taguaria', NULL, 'Raf.', 98),
(15655, 'Tahitia', NULL, 'Burret', 102),
(15656, 'Taihangia', NULL, 'T.T.Yu & C.L.Li', 141),
(15657, 'Tainionema', NULL, 'Schltr.', 10),
(15658, 'Taitonia', NULL, 'Yamam.', 90),
(15659, 'Taiwania', NULL, 'Hayata', 51),
(15660, 'Takeikadzuchia', NULL, 'Kitag. & Kitam.', 18),
(15661, 'Takhtajania', NULL, 'Baranova & J.-F.Leroy', 176),
(15662, 'Takhtajanianthus', NULL, 'A.B.De', 18),
(15663, 'Talassia', NULL, 'Korovin', 9),
(15664, 'Talbotia', NULL, 'S.Moore(SUH)', 172),
(15665, 'Talbotiopsis', NULL, 'L.B.Sm.(SUS)', 172),
(15666, 'Talguenea', NULL, 'Miers ex Endl.', 139),
(15667, 'Taliera', NULL, 'Mart.', 15),
(15668, 'Talisiopsis', NULL, 'Radlk.', 147),
(15669, 'Tamamschjania', NULL, 'Pimenov & Kljuykov', 9),
(15670, 'Tamananthus', NULL, 'V.M.Badillo', 18),
(15671, 'Tamania', NULL, 'Cuatrec.', 18),
(15672, 'Tamaricaria', NULL, 'Qaiser & Ali(SUS)', 160),
(15673, 'Tamarindus', NULL, 'L.', 68),
(15674, 'Tamarix', NULL, 'L.', 160),
(15675, 'Tamatavia', NULL, 'Hook.f.', 142),
(15676, 'Tamaulipa', NULL, 'R.M.King & H.Rob.', 18),
(15677, 'Tambourissa', NULL, 'Sonn.', 108),
(15678, 'Tamilnadia', NULL, 'Tirveng. & Sastre', 142),
(15679, 'Tammsia', NULL, 'H.Karst.', 142),
(15680, 'Tamonea', NULL, 'Aubl.', 173),
(15681, 'Tamus', NULL, 'L.', 59),
(15682, 'Tanacetum', NULL, 'L.', 18),
(15683, 'Tanaecium', NULL, 'Sw.', 22),
(15684, 'Tanakea', NULL, 'Franch. & Sav.', 149),
(15685, 'Tanarius', NULL, 'Kuntze', 66),
(15686, 'Tangaraca', NULL, 'Adans.', 142),
(15687, 'Tanibouca', NULL, 'Aubl.', 44),
(15688, 'Tannodia', NULL, 'Baill.', 66),
(15689, 'Tanulepis', NULL, 'Balf.f.', 10),
(15690, 'Taonabo', NULL, 'Aubl.', 162),
(15691, 'Tapeinanthus', NULL, 'Boiss. ex Benth.(SUH)', 90),
(15692, 'Tapeinosperma', NULL, 'Hook.f.', 115),
(15693, 'Tapeinostelma', NULL, 'Schltr.', 10),
(15694, 'Tapeinostemon', NULL, 'Benth.', 75),
(15695, 'Tapeinotes', NULL, 'DC.', 76),
(15696, 'Tapesia', NULL, 'C.F.Gaertn.', 142),
(15697, 'Taphrospermum', NULL, 'C.A.Mey.', 197),
(15698, 'Tapina', NULL, 'Mart.', 76),
(15699, 'Tapinanthus', NULL, '(Blume) Blume', 98),
(15700, 'Tapinopentas', NULL, 'Bremek.', 142),
(15701, 'Tapinostemma', NULL, 'Tiegh.', 98),
(15702, 'Tapiphyllum', NULL, 'Robyns', 142),
(15703, 'Tapirocarpus', NULL, 'Sagot', 27),
(15704, 'Tapiscia', NULL, 'Oliv.', 546),
(15705, 'Taplinia', NULL, 'Lander', 18),
(15706, 'Tapogomea', NULL, 'Aubl.', 142),
(15707, 'Tapoides', NULL, 'Airy Shaw', 66),
(15708, 'Tapomana', NULL, 'Adans.(SUS)', 45),
(15709, 'Tara', NULL, 'Molina', 68),
(15710, 'Taraktogenos', NULL, 'Hassk.', 73),
(15711, 'Taralea', NULL, 'Aubl.', 68),
(15712, 'Taramea', NULL, 'Raf.(SUO)', 142),
(15713, 'Tarasa', NULL, 'Phil.', 102),
(15714, 'Taraxacum', NULL, 'Weber ex F.H.Wigg.', 18),
(15715, 'Taraxia', NULL, '(Nutt.) Raim.', 121),
(15716, 'Tarchonanthus', NULL, 'L.', 18),
(15717, 'Tardavel', NULL, 'Adans.', 142),
(15718, 'Tarphochlamys', NULL, 'Bremek.', 1),
(15719, 'Tarrietia', NULL, 'Blume', 102),
(15720, 'Tartonia', NULL, 'Raf.', 164),
(15721, 'Tashiroea', NULL, 'Matsum.', 105),
(15722, 'Tasmannia', NULL, 'DC.', 176),
(15723, 'Tassadia', NULL, 'Decne.', 10),
(15724, 'Tatea', NULL, 'Seem.(SUH)', 142),
(15725, 'Tateanthus', NULL, 'Gleason', 105),
(15726, 'Tatina', NULL, 'Raf.', 148),
(15727, 'Taubertia', NULL, 'K.Schum. ex Taub.', 107),
(15728, 'Tauroceras', NULL, 'Britton & Rose', 68),
(15729, 'Tauscheria', NULL, 'Fisch. ex DC.', 197),
(15730, 'Tauschia', NULL, 'Schltdl.', 9),
(15731, 'Tavaresia', NULL, 'Welw. ex N.E.Br.', 10),
(15732, 'Taverniera', NULL, 'DC.', 68),
(15733, 'Taveunia', NULL, 'Burret', 15),
(15734, 'Taxillus', NULL, 'Tiegh.', 98),
(15735, 'Taxodium', NULL, 'Rich.', 51),
(15736, 'Taxotrophis', NULL, 'Blume', 109),
(15737, 'Tayloriophyton', NULL, 'M.P.Nayar', 105),
(15738, 'Tchihatchewia', NULL, 'Boiss.', 197),
(15739, 'Teclea', NULL, 'Delile', 143),
(15740, 'Tecleopsis', NULL, 'Hoyle & Leakey', 143),
(15741, 'Tecomanthe', NULL, 'Baill.', 22),
(15742, 'Tecomaria', NULL, '(Endl.) Spach', 22),
(15743, 'Tecomella', NULL, 'Seem.', 22),
(15744, 'Tecticornia', NULL, 'Hook.f.', 5),
(15745, 'Tectiphiala', NULL, 'H.E.Moore', 15),
(15746, 'Tecunumania', NULL, 'Standl. & Steyerm.', 49),
(15747, 'Teedia', NULL, 'Rudolphi', 150),
(15748, 'Teesdalia', NULL, 'R.Br.', 197),
(15749, 'Teesdaliopsis', NULL, '(Willk.) Rothm.', 197),
(15750, 'Teganium', NULL, 'Schmidel', 154),
(15751, 'Tegicornia', NULL, 'Paul G.Wilson', 5),
(15752, 'Teichmeyeria', NULL, 'Scop.', 92),
(15753, 'Teinosolen', NULL, 'Hook.f.', 142),
(15754, 'Teixeiranthus', NULL, 'R.M.King & H.Rob.', 18),
(15755, 'Telanthera', NULL, 'R.Br.', 5),
(15756, 'Telanthophora', NULL, 'H.Rob. & Brettell', 18),
(15757, 'Telectadium', NULL, 'Baill.', 10),
(15758, 'Telekia', NULL, 'Baumg.', 18),
(15759, 'Telemachia', NULL, 'Urb.', 38),
(15760, 'Telesilla', NULL, 'Klotzsch', 10),
(15761, 'Telesonix', NULL, 'Raf.', 149),
(15762, 'Telfairia', NULL, 'Hook.', 49),
(15763, 'Teline', NULL, 'Medik.', 68),
(15764, 'Teliostachya', NULL, 'Nees', 1),
(15765, 'Telitoxicum', NULL, 'Moldenke', 107),
(15766, 'Tellima', NULL, 'R.Br.', 149),
(15767, 'Telmatophila', NULL, 'Mart. ex Baker', 18),
(15768, 'Telminostelma', NULL, 'E.Fourn.', 10),
(15769, 'Telmissa', NULL, 'Fenzl', 48),
(15770, 'Telogyne', NULL, 'Baill.', 66),
(15771, 'Telopea', NULL, 'R.Br.', 135),
(15772, 'Telosma', NULL, 'Coville', 10),
(15773, 'Teloxys', NULL, 'Moq.', 5),
(15774, 'Temmodaphne', NULL, 'Kosterm.', 91),
(15775, 'Temnadenia', NULL, 'Miers', 10),
(15776, 'Temnocalyx', NULL, 'Robyns', 142),
(15777, 'Temnopteryx', NULL, 'Hook.f.', 142),
(15778, 'Templetonia', NULL, 'R.Br. ex W.T.Aiton', 68),
(15779, 'Temu', NULL, 'O.Berg', 116),
(15780, 'Tenaris', NULL, 'E.Mey.', 10),
(15781, 'Tengia', NULL, 'Chun', 76),
(15782, 'Tennantia', NULL, 'Verdc.', 142),
(15783, 'Tenorea', NULL, 'Gasp.(SUH)', 109),
(15784, 'Tenrhynea', NULL, 'Hilliard & B.L.Burtt', 18),
(15785, 'Teonongia', NULL, 'Stapf', 109),
(15786, 'Tepesia', NULL, 'C.F.Gaertn.', 142),
(15787, 'Tephroseris', NULL, '(Rchb.) Rchb.', 18),
(15788, 'Tephrosia', NULL, 'Pers.', 68),
(15789, 'Tepualia', NULL, 'Griseb.', 116),
(15790, 'Tepuia', NULL, 'Camp', 64),
(15791, 'Tepuianthus', NULL, 'Maguire & Steyerm.', 164),
(15792, 'Teramnus', NULL, 'P.Browne', 68),
(15793, 'Terana', NULL, 'La Llave', 18),
(15794, 'Terebraria', NULL, 'Sesse ex Kunth', 142),
(15795, 'Teremis', NULL, 'Raf.', 154),
(15796, 'Terminaliopsis', NULL, 'Danguy', 44),
(15797, 'Terminthia', NULL, 'Bernh.', 6),
(15798, 'Terminthodia', NULL, 'Ridl.', 143),
(15799, 'Ternstroemiopsis', NULL, 'Urb.', 409),
(15800, 'Tertrea', NULL, 'DC.', 142),
(15801, 'Terua', NULL, 'Standl. & F.J.Herm.', 68),
(15802, 'Tessarandra', NULL, 'Miers', 120),
(15803, 'Tessaria', NULL, 'Ruiz & Pav.', 18),
(15804, 'Tessiera', NULL, 'DC.', 142),
(15805, 'Tessmanniacanthus', NULL, 'Mildbr.', 1),
(15806, 'Tessmanniodoxa', NULL, 'Burret', 15),
(15807, 'Tessmanniophoenix', NULL, 'Burret', 15),
(15808, 'Testudipes', NULL, 'Markgr.', 10),
(15809, 'Testulea', NULL, 'Pellegr.', 118),
(15810, 'Tetilla', NULL, 'DC.', 149),
(15811, 'Tetracarpaea', NULL, 'Benth.(SUH)', 547),
(15812, 'Tetracarpidium', NULL, 'Pax', 66),
(15813, 'Tetracera', NULL, 'L.', 58),
(15814, 'Tetrachyron', NULL, 'Schltdl.', 18),
(15815, 'Tetraclea', NULL, 'A.Gray', 90),
(15816, 'Tetraclinis', NULL, 'Mast.', 51),
(15817, 'Tetraclis', NULL, 'Hiern', 61),
(15818, 'Tetracme', NULL, 'Bunge', 197),
(15819, 'Tetracmidion', NULL, 'Korsh.', 197),
(15820, 'Tetracoccus', NULL, 'Engelm. ex Parry', 534),
(15821, 'Tetractinostigma', NULL, 'Hassk.', 184),
(15822, 'Tetractomia', NULL, 'Hook.f.', 143),
(15823, 'Tetracustelma', NULL, 'Baill.', 10),
(15824, 'Tetradapa', NULL, 'Osbeck', 68),
(15825, 'Tetradema', NULL, 'Schltr.', 76),
(15826, 'Tetradenia', NULL, 'Benth.', 90),
(15827, 'Tetradia', NULL, 'R.Br.', 102),
(15828, 'Tetradiclis', NULL, 'Steven ex M.Bieb.', 526),
(15829, 'Tetradoa', NULL, 'Pichon', 10),
(15830, 'Tetradyas', NULL, 'Danser', 98),
(15831, 'Tetradymia', NULL, 'DC.', 18),
(15832, 'Tetraedrocarpus', NULL, 'O.Schwarz', 25),
(15833, 'Tetraena', NULL, 'Maxim.', 177),
(15834, 'Tetraeugenia', NULL, 'Merr.', 116),
(15835, 'Tetraglochidion', NULL, 'K.Schum.', 184),
(15836, 'Tetraglochidium', NULL, 'Bremek.', 1),
(15837, 'Tetraglochin', NULL, 'Poepp.', 141),
(15838, 'Tetraglossa', NULL, 'Bedd.', 66),
(15839, 'Tetragoga', NULL, 'Bremek.', 1),
(15840, 'Tetragompha', NULL, 'Bremek.', 1),
(15841, 'Tetragonolobus', NULL, 'Scop.', 68),
(15842, 'Tetragonotheca', NULL, 'L.', 18),
(15843, 'Tetragyne', NULL, 'Miq.', 180),
(15844, 'Tetralix', NULL, 'Griseb.', 102),
(15845, 'Tetralocularia', NULL, 'O''Donell', 46),
(15846, 'Tetralopha', NULL, 'Hook.f.', 142),
(15847, 'Tetrameranthus', NULL, 'R.E.Fr.', 8),
(15848, 'Tetramerium', NULL, 'Nees', 1),
(15849, 'Tetramolopium', NULL, 'Nees', 18),
(15850, 'Tetranema', NULL, 'Benth.', 423),
(15851, 'Tetraneuris', NULL, 'Greene', 18),
(15852, 'Tetranthera', NULL, 'Jacq.', 91),
(15853, 'Tetranthus', NULL, 'Sw.', 18),
(15854, 'Tetrapanax', NULL, '(K.Koch) K.Koch', 13),
(15855, 'Tetrapathaea', NULL, 'Rchb.', 127),
(15856, 'Tetraperone', NULL, 'Urb.', 18),
(15857, 'Tetrapetalum', NULL, 'Miq.', 8),
(15858, 'Tetraphyllaster', NULL, 'Gilg', 105),
(15859, 'Tetraphyllum', NULL, 'Griff. ex C.B.Clarke', 76),
(15860, 'Tetraphysa', NULL, 'Schltr.', 10),
(15861, 'Tetrapilus', NULL, 'Lour.', 120),
(15862, 'Tetraplandra', NULL, 'Baill.', 66),
(15863, 'Tetraplasandra', NULL, 'A.Gray', 13),
(15864, 'Tetraplasia', NULL, 'Rehder', 142),
(15865, 'Tetrapodenia', NULL, 'Gleason', 101),
(15866, 'Tetrapollinia', NULL, 'Maguire & B.M.Boom', 75),
(15867, 'Tetrapoma', NULL, 'Turcz. ex Fisch. & C.A.Mey.', 197),
(15868, 'Tetrapora', NULL, 'Schauer', 116),
(15869, 'Tetraptera', NULL, 'Phil.', 102),
(15870, 'Tetrapterocarpon', NULL, 'Humbert', 68),
(15871, 'Tetrapterys', NULL, 'Cav.', 101),
(15872, 'Tetraria', NULL, 'P.Beauv.', 55),
(15873, 'Tetrariopsis', NULL, 'C.B.Clarke', 55),
(15874, 'Tetraselago', NULL, 'Junell', 150),
(15875, 'Tetrasida', NULL, 'Ulbr.', 102),
(15876, 'Tetrasiphon', NULL, 'Urb.', 38),
(15877, 'Tetraspidium', NULL, 'Baker', 400),
(15878, 'Tetraspora', NULL, 'Miq.', 116),
(15879, 'Tetrastemma', NULL, 'Diels ex H.Winkl.', 8),
(15880, 'Tetrastemon', NULL, 'Hook. & Arn.', 116),
(15881, 'Tetrastichella', NULL, 'Pichon', 22),
(15882, 'Tetrastigma', NULL, '(Miq.) Planch.', 181),
(15883, 'Tetrastylidium', NULL, 'Engl.', 514),
(15884, 'Tetrastylis', NULL, 'Barb.Rodr.', 127),
(15885, 'Tetrasynandra', NULL, 'Perkins', 108),
(15886, 'Tetrataenium', NULL, '(DC.) Manden.', 9),
(15887, 'Tetrataxis', NULL, 'Hook.f.', 99),
(15888, 'Tetrateleia', NULL, 'Arw.', 32),
(15889, 'Tetratelia', NULL, 'Sond.', 32),
(15890, 'Tetrathalamus', NULL, 'Lauterb.', 176),
(15891, 'Tetratheca', NULL, 'Sm.', 62),
(15892, 'Tetraulacium', NULL, 'Turcz.', 423),
(15893, 'Tetrazygia', NULL, 'Rich. ex DC.', 105),
(15894, 'Tetrazygiopsis', NULL, 'Borhidi', 105),
(15895, 'Tetrorchidiopsis', NULL, 'Rauschert', 66),
(15896, 'Tetrorum', NULL, 'Rose', 48),
(15897, 'Teucridium', NULL, 'Hook.f.', 90),
(15898, 'Teucrium', NULL, 'L.', 90),
(15899, 'Texiera', NULL, 'Jaub. & Spach(SUS)', 197),
(15900, 'Textoria', NULL, 'Miq.', 13),
(15901, 'Teyleria', NULL, 'Backer', 68),
(15902, 'Teysmannia', NULL, 'Rchb. & Zoll.', 15),
(15903, 'Thailentadopsis', NULL, 'Kosterm.', 68),
(15904, 'Thalestris', NULL, 'Rizzini', 1),
(15905, 'Thalia', NULL, 'L.', 103),
(15906, 'Thaminophyllum', NULL, 'Harv.', 18),
(15907, 'Thamnojusticia', NULL, 'Mildbr.', 1),
(15908, 'Thamnosciadium', NULL, 'Hartvig', 9),
(15909, 'Thamnoseris', NULL, 'F.Phil.', 18),
(15910, 'Thamnosma', NULL, 'Torr. & Frem.', 143),
(15911, 'Thamnus', NULL, 'Klotzsch', 64),
(15912, 'Thapsia', NULL, 'L.', 9),
(15913, 'Tharpia', NULL, 'Britton & Rose', 68),
(15914, 'Thaspium', NULL, 'Nutt.', 9),
(15915, 'Thaumasianthes', NULL, 'Danser', 98),
(15916, 'Thaumatocaryon', NULL, 'Baill.', 25),
(15917, 'Thaumatococcus', NULL, 'Benth.', 103),
(15918, 'Thaumatophyllum', NULL, 'Schott', 12),
(15919, 'Thea', NULL, 'L.', 162),
(15920, 'Thecagonum', NULL, 'Babu', 142),
(15921, 'Thecanthes', NULL, 'Wikstr.', 164),
(15922, 'Thecocarpus', NULL, 'Boiss.', 9),
(15923, 'Thecorchus', NULL, 'Bremek.', 142),
(15924, 'Theileamea', NULL, 'Baill.', 1),
(15925, 'Theilera', NULL, 'E.Phillips', 30),
(15926, 'Thelecarpus', NULL, 'Tiegh.', 98),
(15927, 'Thelechitonia', NULL, 'Cuatrec.', 18),
(15928, 'Theleophyton', NULL, '(Hook.f.) Moq.', 5),
(15929, 'Thelepaepale', NULL, 'Bremek.', 1),
(15930, 'Thelesperma', NULL, 'Less.', 18),
(15931, 'Theligonum', NULL, 'L.', 142),
(15932, 'Thellungiella', NULL, 'O.E.Schulz', 197),
(15933, 'Thelycrania', NULL, '(Dumort.) Fourr.', 47),
(15934, 'Thelypodiopsis', NULL, 'Rydb.', 197),
(15935, 'Thelypodium', NULL, 'Endl.', 197),
(15936, 'Thelypotzium', NULL, 'Gagnep.', 184),
(15937, 'Thelyra', NULL, 'Thouars', 40),
(15938, 'Themistoclesia', NULL, 'Klotzsch', 64),
(15939, 'Thenardia', NULL, 'Kunth', 10),
(15940, 'Theophrasta', NULL, 'L.', 163),
(15941, 'Theresa', NULL, 'Clos', 90),
(15942, 'Theresia', NULL, 'K.Koch', 94),
(15943, 'Theriophonum', NULL, 'Blume', 12),
(15944, 'Thermopsis', NULL, 'R.Br.', 68),
(15945, 'Therofon', NULL, 'Raf.(SUS)', 149),
(15946, 'Therophon', NULL, 'Rydb.(SUS)', 149),
(15947, 'Therorhodion', NULL, '(Maxim.) Small', 64),
(15948, 'Thesidium', NULL, 'Sond.', 146),
(15949, 'Thesium', NULL, 'L.', 146),
(15950, 'Thespesia', NULL, 'Sol. ex Correa', 102),
(15951, 'Thespesiopsis', NULL, 'Exell & Hillc.', 102),
(15952, 'Thespidium', NULL, 'F.Muell. ex Benth.', 18),
(15953, 'Thespis', NULL, 'DC.', 18),
(15954, 'Thevenotia', NULL, 'DC.', 18),
(15955, 'Theyodis', NULL, 'A.Rich.', 142),
(15956, 'Thibaudia', NULL, 'Ruiz & Pav.', 64),
(15957, 'Thieleodoxa', NULL, 'Cham.', 142),
(15958, 'Thiersia', NULL, 'Baill.', 142),
(15959, 'Thilachium', NULL, 'Lour.', 32),
(15960, 'Thilcum', NULL, 'Molina', 121),
(15961, 'Thiloa', NULL, 'Eichler', 44),
(15962, 'Thinogeton', NULL, 'Benth.', 154),
(15963, 'Thinouia', NULL, 'Triana & Planch.', 147),
(15964, 'Thiollierea', NULL, 'Montrouz.', 142),
(15965, 'Thiseltonia', NULL, 'Hemsl.', 18),
(15966, 'Thium', NULL, 'Steud.', 68),
(15967, 'Thladiantha', NULL, 'Bunge', 49),
(15968, 'Thlaspeocarpa', NULL, 'C.A.Sm.', 197),
(15969, 'Thlaspi', NULL, 'L.', 197),
(15970, 'Thlaspiceras', NULL, 'F.K.Mey.', 197),
(15971, 'Thogsennia', NULL, 'Aiello', 142),
(15972, 'Thollonia', NULL, 'Baill.', 85),
(15973, 'Thomandersia', NULL, 'Baill.', 1),
(15974, 'Thomasia', NULL, 'J.Gay', 102),
(15975, 'Thompsonella', NULL, 'Britton & Rose', 48),
(15976, 'Thompsonia', NULL, 'R.Br.', 127),
(15977, 'Thomsonia', NULL, 'Wall.', 12),
(15978, 'Thonnera', NULL, 'De Wild.', 8),
(15979, 'Thoracocarpus', NULL, 'Harling', 54),
(15980, 'Thoracosperma', NULL, 'Klotzsch', 64),
(15981, 'Thoracostachyum', NULL, 'Kurz', 55),
(15982, 'Thoreldora', NULL, 'Pierre', 143),
(15983, 'Thorelia', NULL, 'Gagnep.', 18),
(15984, 'Thorella', NULL, 'Briq.', 9),
(15985, 'Thornbera', NULL, 'Rydb.', 68),
(15986, 'Thorncroftia', NULL, 'N.E.Br.', 90),
(15987, 'Thornea', NULL, 'Breedlove & E.M.McClint.', 42),
(15988, 'Thorntonia', NULL, 'Rchb.', 102),
(15989, 'Thouarsiora', NULL, 'Homolle ex Arenes', 142),
(15990, 'Thouinia', NULL, 'Poit.', 147),
(15991, 'Thouinidium', NULL, 'Radlk.', 147),
(15992, 'Thouvenotia', NULL, 'Danguy', 91),
(15993, 'Thozetia', NULL, 'F.Muell. ex Benth.', 10),
(15994, 'Thraulococcus', NULL, 'Radlk.', 147),
(15995, 'Threlkeldia', NULL, 'R.Br.', 5),
(15996, 'Thrinax', NULL, 'Sw.', 15),
(15997, 'Thrincoma', NULL, 'O.F.Cook', 15),
(15998, 'Thringis', NULL, 'O.F.Cook', 15),
(15999, 'Thryallis', NULL, 'L.(SUH)', 101),
(16000, 'Thryothamnus', NULL, 'Phil.', 173),
(16001, 'Thryptomene', NULL, 'Endl.', 116),
(16002, 'Thuessinkia', NULL, 'Korth. ex Miq.', 15),
(16003, 'Thuinia', NULL, 'Raf.(SUO)', 120),
(16004, 'Thuja', NULL, 'L.', 51),
(16005, 'Thujopsis', NULL, 'Siebold & Zucc. ex Endl.', 51),
(16006, 'Thunbergia', NULL, 'Retz.', 1),
(16007, 'Thunbergianthus', NULL, 'Engl.', 150),
(16008, 'Thunbergiella', NULL, 'H.Wolff', 9),
(16009, 'Thunbgeria', NULL, 'Montin', 142),
(16010, 'Thurberia', NULL, 'A.Gray', 102),
(16011, 'Thurovia', NULL, 'Rose', 18),
(16012, 'Thuspeinanta', NULL, 'T.Durand', 90),
(16013, 'Thyella', NULL, 'Raf.', 46),
(16014, 'Thylacanthus', NULL, 'Tul.', 68),
(16015, 'Thylacodraba', NULL, '(Nabelek) O.E.Schulz', 197),
(16016, 'Thymbra', NULL, 'L.', 90),
(16017, 'Thymelaea', NULL, 'Mill.', 164),
(16018, 'Thymocarpus', NULL, 'Nicolson, Steyerm. & Sivad.', 103),
(16019, 'Thymophylla', NULL, 'Lag.', 18),
(16020, 'Thymopsis', NULL, 'Benth.', 18),
(16021, 'Thymus', NULL, 'L.', 90),
(16022, 'Thyridocalyx', NULL, 'Bremek.', 142),
(16023, 'Thyrocarpus', NULL, 'Hance', 25),
(16024, 'Thyrsacanthus', NULL, 'Nees', 1),
(16025, 'Thyrsanthella', NULL, 'Pichon', 10),
(16026, 'Thyrsanthera', NULL, 'Pierre ex Gagnep.', 66),
(16027, 'Thyrsosalacia', NULL, 'Loes.', 38),
(16028, 'Thysanella', NULL, 'A.Gray', 134),
(16029, 'Thysanobotrya', NULL, 'Alderw.', 52),
(16030, 'Thysanocarpus', NULL, 'Hook.', 197),
(16031, 'Thysanospermum', NULL, 'Champ. ex Benth.', 142),
(16032, 'Thysanostemon', NULL, 'Maguire', 42),
(16033, 'Thysanostigma', NULL, 'J.B.Imlay', 1),
(16034, 'Thysanus', NULL, 'Lour.', 45),
(16035, 'Tianschaniella', NULL, 'B.Fedtsch. ex Popov', 25),
(16036, 'Tiarella', NULL, 'L.', 149),
(16037, 'Tiarocarpus', NULL, 'Rech.f.', 18),
(16038, 'Tibestina', NULL, 'Maire', 18),
(16039, 'Tibetia', NULL, '(Ali) H.P.Tsui', 68),
(16040, 'Tibouchinopsis', NULL, 'Markgr.', 105),
(16041, 'Ticodendron', NULL, 'Gomez-Laur. & L.D.Gomez', 165),
(16042, 'Ticorea', NULL, 'Aubl.', 143),
(16043, 'Tidestromia', NULL, 'Standl.', 5),
(16044, 'Tiedemannia', NULL, 'DC.', 9),
(16045, 'Tieghemia', NULL, 'Balle', 98),
(16046, 'Tieghemopanax', NULL, 'R.Vig.', 13),
(16047, 'Tienmuia', NULL, 'Hu', 400),
(16048, 'Tietkensia', NULL, 'P.S.Short', 18),
(16049, 'Tiglium', NULL, 'Klotzsch', 66),
(16050, 'Tigridiopalma', NULL, 'C.Chen', 105),
(16051, 'Tikalia', NULL, 'Lundell', 147),
(16052, 'Tilco', NULL, 'Adans.', 121),
(16053, 'Tilia', NULL, 'L.', 102),
(16054, 'Tiliacora', NULL, 'Colebr.', 107),
(16055, 'Tilingia', NULL, 'Regel', 9),
(16056, 'Tillaea', NULL, 'L.', 48),
(16057, 'Tillaeastrum', NULL, 'Britton', 48),
(16058, 'Tillospermum', NULL, 'Griff.', 116),
(16059, 'Tilmia', NULL, 'O.F.Cook', 15),
(16060, 'Timandra', NULL, 'Klotzsch', 66),
(16061, 'Timeroya', NULL, 'Benth.(SUO)', 117),
(16062, 'Timeroyea', NULL, 'Montrouz.', 117),
(16063, 'Tina', NULL, 'Schult.', 147),
(16064, 'Tinguarra', NULL, 'Parl.', 9),
(16065, 'Tinnea', NULL, 'Kotschy & Peyr.', 90),
(16066, 'Tinomiscium', NULL, 'Miers ex Hook.f. & Thomson', 107),
(16067, 'Tinopsis', NULL, 'Radlk.', 147),
(16068, 'Tinospora', NULL, 'Miers', 107),
(16069, 'Tintinnabularia', NULL, 'Woodson', 10),
(16070, 'Tipuana', NULL, '(Benth.) Benth.', 68),
(16071, 'Tiquilia', NULL, 'Pers.', 25),
(16072, 'Tiquiliopsis', NULL, 'A.Heller', 25),
(16073, 'Tirania', NULL, 'Pierre', 32),
(16074, 'Tirpitzia', NULL, 'Hallier f.', 95),
(16075, 'Tirucalia', NULL, 'Raf.(SUH)', 66),
(16076, 'Tisonia', NULL, 'Baill.', 145),
(16077, 'Tisserantia', NULL, 'Humbert', 18),
(16078, 'Tisserantiodoxa', NULL, 'Aubrev. & Pellegr.', 148),
(16079, 'Tisserantodendron', NULL, 'Sillans', 22),
(16080, 'Titanotrichum', NULL, 'Soler.', 76),
(16081, 'Tithonia', NULL, 'Desf. ex Juss.', 18),
(16082, 'Tithymaloides', NULL, 'Ortega', 66),
(16083, 'Tithymalopsis', NULL, 'Klotzsch & Garcke', 66),
(16084, 'Tithymalus', NULL, 'Gaertn.', 66),
(16085, 'Tjongina', NULL, 'Adans.', 116),
(16086, 'Tobagoa', NULL, 'Urb.', 142),
(16087, 'Todaroa', NULL, 'Parl.', 9),
(16088, 'Toddalia', NULL, 'Juss.', 143),
(16089, 'Toddaliopsis', NULL, 'Engl.', 143),
(16090, 'Toddavaddia', NULL, 'Kuntze(SUS)', 124),
(16091, 'Toechima', NULL, 'Radlk.', 147),
(16092, 'Tolbonia', NULL, 'Kuntze', 18),
(16093, 'Tolmachevia', NULL, 'A.Love & D.Love', 48),
(16094, 'Tolmiea', NULL, 'Torr. & A.Gray', 149),
(16095, 'Tolpis', NULL, 'Adans.', 18),
(16096, 'Tolypanthus', NULL, '(Blume) Blume', 98),
(16097, 'Tommasinia', NULL, 'Bertol.', 9),
(16098, 'Tonalanthus', NULL, 'Brandegee', 18),
(16099, 'Tonduzia', NULL, 'Pittier', 10),
(16100, 'Tonella', NULL, 'Nutt. ex A.Gray', 423),
(16101, 'Tonestus', NULL, 'A.Nelson', 18),
(16102, 'Tongoloa', NULL, 'H.Wolff', 9),
(16103, 'Tontanea', NULL, 'Aubl.', 142),
(16104, 'Tontelea', NULL, 'Aubl.', 38),
(16105, 'Tordyliopsis', NULL, 'DC.', 9),
(16106, 'Tordylium', NULL, 'L.', 9),
(16107, 'Torenia', NULL, 'L.', 150),
(16108, 'Torfasadis', NULL, 'Raf.', 66),
(16109, 'Torilis', NULL, 'Adans.', 9),
(16110, 'Tornabenea', NULL, 'Parl.', 9),
(16111, 'Torpesia', NULL, '(Endl.) M.Roem.', 106),
(16112, 'Torralbasia', NULL, 'Krug & Urb.', 38),
(16113, 'Torresea', NULL, 'Allemao', 68),
(16114, 'Torrubia', NULL, 'Vell.', 117),
(16115, 'Torrukia', NULL, 'Vell.', 117),
(16116, 'Tortuella', NULL, 'Urb.', 142),
(16117, 'Torularia', NULL, 'O.E.Schulz(SUH)', 197),
(16118, 'Torulinium', NULL, 'Desv.', 55),
(16119, 'Toubaouate', NULL, 'Aubrev. & Pellegr.', 68),
(16120, 'Touchardia', NULL, 'Gaudich.', 171),
(16121, 'Touchiroa', NULL, 'Aubl.', 68),
(16122, 'Toulichiba', NULL, 'Adans.', 68),
(16123, 'Toulicia', NULL, 'Aubl.', 147),
(16124, 'Touloucouna', NULL, 'M.Roem.', 106),
(16125, 'Tounatea', NULL, 'Aubl.', 68),
(16126, 'Tournefortiopsis', NULL, 'Rusby', 142),
(16127, 'Tournesol', NULL, 'Adans.', 66),
(16128, 'Tournesolia', NULL, 'Scop.', 66),
(16129, 'Tourneuxia', NULL, 'Coss.', 18),
(16130, 'Touroulia', NULL, 'Aubl.', 137),
(16131, 'Tourrettia', NULL, 'Foug.', 22),
(16132, 'Toussaintia', NULL, 'Boutique', 8),
(16133, 'Tovara', NULL, 'Adans.', 134),
(16134, 'Tovaria', NULL, 'Ruiz & Pav.', 167),
(16135, 'Tovomitidium', NULL, 'Ducke', 42),
(16136, 'Townsendia', NULL, 'Hook.', 18),
(16137, 'Toxanthera', NULL, 'Hook.f.', 49),
(16138, 'Toxanthes', NULL, 'Turcz.', 18),
(16139, 'Toxicodendron', NULL, 'Mill.', 6),
(16140, 'Toxicodendrum', NULL, 'Thunb.(SUH)', 66),
(16141, 'Toxocarpus', NULL, 'Wight & Arn.', 10),
(16142, 'Toxophoenix', NULL, 'Schott', 15),
(16143, 'Toxostigma', NULL, 'A.Rich.', 25),
(16144, 'Tozzia', NULL, 'L.', 400),
(16145, 'Trachelanthus', NULL, 'Kunze', 25),
(16146, 'Tracheliopsis', NULL, 'Buser', 30),
(16147, 'Trachelium', NULL, 'L.', 30),
(16148, 'Trachelospermum', NULL, 'Lem.', 10),
(16149, 'Trachomitum', NULL, 'Woodson', 10),
(16150, 'Trachycalymma', NULL, '(K.Schum.) Bullock', 10),
(16151, 'Trachycarpus', NULL, 'H.Wendl.', 15),
(16152, 'Trachycaryon', NULL, 'Klotzsch', 66),
(16153, 'Trachydium', NULL, 'Lindl.', 9),
(16154, 'Trachylobium', NULL, 'Hayne', 68),
(16155, 'Trachymene', NULL, 'Rudge', 9),
(16156, 'Trachyphrynium', NULL, 'K.Schum.(SUH)', 103),
(16157, 'Trachypremnon', NULL, 'Lindig', 52),
(16158, 'Trachysciadium', NULL, 'Eckl. & Zeyh.', 9),
(16159, 'Trachyspermum', NULL, 'Link', 9),
(16160, 'Trachystemon', NULL, 'D.Don', 25),
(16161, 'Trachystigma', NULL, 'C.B.Clarke', 76),
(16162, 'Trachystoma', NULL, 'O.E.Schulz', 197),
(16163, 'Trachystylis', NULL, 'S.T.Blake', 55),
(16164, 'Tractocopevodia', NULL, 'Raizada & V.Naray.', 143),
(16165, 'Tracyina', NULL, 'S.F.Blake', 18),
(16166, 'Traganopsis', NULL, 'Maire & Wilczek', 5),
(16167, 'Traganthus', NULL, 'Klotzsch', 66),
(16168, 'Traganum', NULL, 'Delile', 5),
(16169, 'Tragia', NULL, 'L.', 66),
(16170, 'Tragiella', NULL, 'Pax & K.Hoffm.', 66),
(16171, 'Tragiola', NULL, 'Small & Pennell', 150),
(16172, 'Tragiopsis', NULL, 'H.Karst.', 66),
(16173, 'Tragium', NULL, 'Spreng.', 9),
(16174, 'Tragopogon', NULL, 'L.', 18),
(16175, 'Tragoselinum', NULL, 'Mill.', 9),
(16176, 'Trailliaedoxa', NULL, 'W.W.Sm. & Forrest', 142),
(16177, 'Trapa', NULL, 'L.', 99),
(16178, 'Traunia', NULL, 'K.Schum.', 10),
(16179, 'Traversia', NULL, 'Hook.f.', 18),
(16180, 'Traxara', NULL, 'Raf.', 25),
(16181, 'Traxilum', NULL, 'Raf.', 25),
(16182, 'Trechonaetes', NULL, 'Miers', 154),
(16183, 'Treichelia', NULL, 'Vatke', 30),
(16184, 'Treisia', NULL, 'Haw.', 66),
(16185, 'Tremacanthus', NULL, 'S.Moore', 1),
(16186, 'Tremacron', NULL, 'Craib', 76),
(16187, 'Tremandra', NULL, 'R.Br. ex DC.', 62),
(16188, 'Trematocarpus', NULL, 'Zahlbr.', 30),
(16189, 'Trematolobelia', NULL, 'Zahlbr.', 30),
(16190, 'Trematosperma', NULL, 'Urb.', 85),
(16191, 'Trembleya', NULL, 'DC.', 105),
(16192, 'Tremotis', NULL, 'Raf.', 109),
(16193, 'Trepocarpus', NULL, 'Nutt. ex DC.', 9),
(16194, 'Tresanthera', NULL, 'H.Karst.', 142),
(16195, 'Tretorhiza', NULL, 'Adans.', 75),
(16196, 'Treubania', NULL, 'Tiegh.', 98),
(16197, 'Treubella', NULL, 'Tiegh.(SUH)', 98),
(16198, 'Treutlera', NULL, 'Hook.f.', 10),
(16199, 'Trevauxia', NULL, 'Steud.(SUO)', 49),
(16200, 'Trevesia', NULL, 'Vis.', 13),
(16201, 'Trevia', NULL, 'L.(SUO)', 66),
(16202, 'Trevirana', NULL, 'Willd.', 76),
(16203, 'Trevirania', NULL, 'Heynh.', 142),
(16204, 'Trevoa', NULL, 'Miers ex Hook.', 139),
(16205, 'Trevouxia', NULL, 'Scop.', 49),
(16206, 'Triactina', NULL, 'Hook.f. & Thomson', 48),
(16207, 'Triadenum', NULL, 'Raf.', 42),
(16208, 'Triadica', NULL, 'Lour.', 66),
(16209, 'Triadodaphne', NULL, 'Kosterm.', 91),
(16210, 'Triaenacanthus', NULL, 'Nees', 1),
(16211, 'Triaenophora', NULL, '(Hook.f.) Soler.', 150),
(16212, 'Triainolepis', NULL, 'Hook.f.', 142),
(16213, 'Trianaea', NULL, 'Planch. & Linden', 154),
(16214, 'Trianaeopiper', NULL, 'Trel.', 130),
(16215, 'Trianoptiles', NULL, 'Fenzl ex Endl.', 55),
(16216, 'Trianosperma', NULL, '(Torr. & A.Gray) Mart.', 49),
(16217, 'Trianthera', NULL, 'Wettst.(SUH)', 150),
(16218, 'Triarthron', NULL, 'Baill.', 98),
(16219, 'Triaspis', NULL, 'Burch.', 101),
(16220, 'Tribrachya', NULL, 'Korth.', 142),
(16221, 'Tribroma', NULL, 'O.F.Cook', 102),
(16222, 'Tribulopis', NULL, 'R.Br.', 177),
(16223, 'Tribulopsis', NULL, 'R.Br.(SUO)', 177),
(16224, 'Tribulus', NULL, 'L.', 177),
(16225, 'Tricardia', NULL, 'Torr.', 25),
(16226, 'Tricarium', NULL, 'Lour.', 184),
(16227, 'Tricera', NULL, 'Schreb.', 28),
(16228, 'Triceratia', NULL, 'A.Rich.', 49),
(16229, 'Tricerma', NULL, 'Liebm.', 38),
(16230, 'Triceros', NULL, 'Griff.', 49),
(16231, 'Trichacanthus', NULL, 'Zoll. & Moritzi', 1),
(16232, 'Trichantha', NULL, 'H.Karst. & Triana(SUH)', 46),
(16233, 'Trichanthemis', NULL, 'Regel & Schmalh.', 18),
(16234, 'Trichanthodium', NULL, 'Sond. & F.Muell.', 18),
(16235, 'Tricherostigma', NULL, 'Boiss.', 66),
(16236, 'Trichinium', NULL, 'R.Br.', 5),
(16237, 'Trichipteris', NULL, 'C.Presl', 52),
(16238, 'Trichobasis', NULL, 'Turcz.', 116),
(16239, 'Trichocalyx', NULL, 'Balf.f.', 1),
(16240, 'Trichocarya', NULL, 'Miq.', 40),
(16241, 'Trichocaulon', NULL, 'N.E.Br.', 10),
(16242, 'Trichochiton', NULL, 'Kom.', 197),
(16243, 'Trichocline', NULL, 'Cass.', 18),
(16244, 'Trichocoronis', NULL, 'A.Gray', 18),
(16245, 'Trichocoryne', NULL, 'S.F.Blake', 18),
(16246, 'Trichocyamos', NULL, 'Yakovlev', 68),
(16247, 'Trichodesma', NULL, 'R.Br.', 25),
(16248, 'Trichodrymonia', NULL, 'Oerst.', 76),
(16249, 'Trichodypsis', NULL, 'Baill.', 15),
(16250, 'Trichogalium', NULL, 'Fourr.', 142),
(16251, 'Trichogonia', NULL, '(DC.) Gardner', 18),
(16252, 'Trichogoniopsis', NULL, 'R.M.King & H.Rob.', 18),
(16253, 'Trichogyne', NULL, 'Less.', 18),
(16254, 'Tricholaser', NULL, 'Gilli', 9),
(16255, 'Tricholepis', NULL, 'DC.', 18),
(16256, 'Tricholobus', NULL, 'Blume', 45),
(16257, 'Trichophorum', NULL, 'Pers.', 55),
(16258, 'Trichopodium', NULL, 'C.Presl(SUH)', 68),
(16259, 'Trichoptilium', NULL, 'A.Gray', 18),
(16260, 'Trichopus', NULL, 'Gaertn.', 59),
(16261, 'Trichosacme', NULL, 'Zucc.', 10),
(16262, 'Trichosanchezia', NULL, 'Mildbr.', 1),
(16263, 'Trichosandra', NULL, 'Decne.', 10),
(16264, 'Trichosanthes', NULL, 'L.', 49),
(16265, 'Trichoschoenus', NULL, 'J.Raynal', 55),
(16266, 'Trichospira', NULL, 'Kunth', 18),
(16267, 'Trichosporum', NULL, 'D.Don', 76),
(16268, 'Trichostema', NULL, 'L.', 90),
(16269, 'Trichostephania', NULL, 'Tardieu', 45),
(16270, 'Trichostephanus', NULL, 'Gilg', 73),
(16271, 'Trichosterigma', NULL, 'Klotzsch & Garcke', 66),
(16272, 'Trichostigma', NULL, 'A.Rich.', 128),
(16273, 'Trichostomantherium', NULL, 'Domin', 10),
(16274, 'Trichothalamus', NULL, 'Spreng.', 141),
(16275, 'Trichotolinum', NULL, 'O.E.Schulz', 197),
(16276, 'Trichovaselia', NULL, 'Tiegh.', 118),
(16277, 'Trichuriella', NULL, 'Bennet', 5),
(16278, 'Trichurus', NULL, 'C.C.Towns.(SUH)', 5),
(16279, 'Tricliceras', NULL, 'Thonn. ex DC.', 169),
(16280, 'Triclisia', NULL, 'Benth.', 107),
(16281, 'Tricomaria', NULL, 'Gillies ex Hook. & Arn.', 101),
(16282, 'Tricomariopsis', NULL, 'Dubard', 101),
(16283, 'Tricostularia', NULL, 'Nees ex Lehm.', 55),
(16284, 'Tricuspidaria', NULL, 'Ruiz & Pav.', 62),
(16285, 'Tricycla', NULL, 'Cav.', 117),
(16286, 'Tricyclandra', NULL, 'Keraudren', 49),
(16287, 'Tricyrtis', NULL, 'Wall.', 94),
(16288, 'Tridactylina', NULL, '(DC.) Sch.Bip.', 18),
(16289, 'Tridax', NULL, 'L.', 18),
(16290, 'Tridentea', NULL, 'Haw.', 10),
(16291, 'Tridesmis', NULL, 'Lour.', 66),
(16292, 'Tridianisia', NULL, 'Baill.', 85),
(16293, 'Tridimeris', NULL, 'Baill.', 8),
(16294, 'Tridynamia', NULL, 'Gagnep.', 46),
(16295, 'Trieenea', NULL, 'Hilliard', 150),
(16296, 'Trientalis', NULL, 'L.', 115),
(16297, 'Trifidacanthus', NULL, 'Merr.', 68),
(16298, 'Trifolium', NULL, 'L.', 68),
(16299, 'Trigonella', NULL, 'L.', 68),
(16300, 'Trigonia', NULL, 'Aubl.', 168),
(16301, 'Trigoniodendron', NULL, 'E.F.Guim. & Miguel', 168),
(16302, 'Trigonobalanus', NULL, 'Forman', 72),
(16303, 'Trigonocapnos', NULL, 'Schltr.', 126),
(16304, 'Trigonocaryum', NULL, 'Trautv.', 25),
(16305, 'Trigonochlamys', NULL, 'Hook.f.', 27),
(16306, 'Trigonopyren', NULL, 'Bremek.', 142),
(16307, 'Trigonosciadium', NULL, 'Boiss.', 9),
(16308, 'Trigonospermum', NULL, 'Less.', 18),
(16309, 'Trigonotis', NULL, 'Steven', 25),
(16310, 'Triguera', NULL, 'Cav.', 154),
(16311, 'Trigyneia', NULL, 'Rchb.(SUO)', 8),
(16312, 'Trigynia', NULL, 'Jacq.-Fel.', 105),
(16313, 'Trilepidea', NULL, 'Tiegh.', 98),
(16314, 'Trilepis', NULL, 'Nees', 55),
(16315, 'Triliena', NULL, 'Raf.', 154),
(16316, 'Trilisa', NULL, '(Cass.) Cass.', 18),
(16317, 'Trimeranthus', NULL, 'H.Karst.', 105),
(16318, 'Trimeria', NULL, 'Harv.', 145),
(16319, 'Trimeris', NULL, 'C.Presl', 30),
(16320, 'Trimerisma', NULL, 'C.Presl(SUS)', 50),
(16321, 'Trimeriza', NULL, 'Lindl.', 16),
(16322, 'Trimerocalyx', NULL, '(Murb.) Murb.', 150),
(16323, 'Trimorphandra', NULL, 'Brongn. & Gris', 58),
(16324, 'Trinia', NULL, 'Hoffm.', 9),
(16325, 'Triniella', NULL, 'Calest.', 9),
(16326, 'Triodanis', NULL, 'Raf.', 30),
(16327, 'Triodoglossum', NULL, 'Bullock', 10),
(16328, 'Triodon', NULL, 'DC.', 142),
(16329, 'Triolena', NULL, 'Naudin', 105),
(16330, 'Trioncinia', NULL, '(F.Muell.) Veldkamp', 18),
(16331, 'Triopterys', NULL, 'L.', 101),
(16332, 'Triosteum', NULL, 'L.', 33),
(16333, 'Tripetalanthus', NULL, 'A.Chev.', 68),
(16334, 'Tripetaleia', NULL, 'Siebold & Zucc.', 64),
(16335, 'Tripetalum', NULL, 'K.Schum.', 42),
(16336, 'Triphasia', NULL, 'Lour.', 143),
(16337, 'Triphelia', NULL, 'R.Br. ex Endl.', 116),
(16338, 'Triphylleion', NULL, 'Suess.', 9),
(16339, 'Triplandra', NULL, 'Raf.', 66),
(16340, 'Triplarina', NULL, 'Raf.', 116),
(16341, 'Triplasandra', NULL, 'Seem.', 13),
(16342, 'Triplectrum', NULL, 'Wight & Arn.', 105),
(16343, 'Tripleurospermum', NULL, 'Sch.Bip.', 18),
(16344, 'Triplisomeris', NULL, '(Baill.) Aubrev. & Pellegr.', 68),
(16345, 'Triplocephalum', NULL, 'O.Hoffm.', 18),
(16346, 'Triplochiton', NULL, 'K.Schum.', 102),
(16347, 'Triplochlamys', NULL, 'Ulbr.', 102),
(16348, 'Triplolepis', NULL, 'Turcz.', 10),
(16349, 'Triplopetalum', NULL, 'Nyar.', 197),
(16350, 'Triplotaxis', NULL, 'Hutch.', 18),
(16351, 'Tripodandra', NULL, 'Baill.', 107),
(16352, 'Tripodanthera', NULL, 'M.Roem.', 49),
(16353, 'Tripodanthus', NULL, '(Eichler) Tiegh.', 98),
(16354, 'Tripodion', NULL, 'Medik.', 68),
(16355, 'Tripteris', NULL, 'Less.', 18),
(16356, 'Tripterocalyx', NULL, '(Torr.) Hook.', 117),
(16357, 'Tripterococcus', NULL, 'Endl.', 38),
(16358, 'Tripterodendron', NULL, 'Radlk.', 147),
(16359, 'Tripterospermum', NULL, 'Blume', 75),
(16360, 'Tripterygium', NULL, 'Hook.f.', 38),
(16361, 'Triptilion', NULL, 'Ruiz & Pav.', 18),
(16362, 'Triptilodiscus', NULL, 'Turcz.', 18),
(16363, 'Trirostellum', NULL, 'Z.P.Wang & Q.Z.Xie', 49),
(16364, 'Trisanthus', NULL, 'Lour.', 9),
(16365, 'Trisciadia', NULL, 'Hook.f.', 142),
(16366, 'Trisciadium', NULL, 'Phil.', 9),
(16367, 'Trisema', NULL, 'Hook.f.', 58),
(16368, 'Trisepalum', NULL, 'C.B.Clarke', 76),
(16369, 'Tristania', NULL, 'R.Br.', 116),
(16370, 'Tristellateia', NULL, 'Thouars', 101),
(16371, 'Tristemma', NULL, 'Juss.', 105),
(16372, 'Tristemon', NULL, 'Scheele', 49),
(16373, 'Tristemonanthus', NULL, 'Loes.', 38),
(16374, 'Tristerix', NULL, 'Mart.', 98),
(16375, 'Tristira', NULL, 'Radlk.', 147),
(16376, 'Tristiropsis', NULL, 'Radlk.', 147),
(16377, 'Tristylium', NULL, 'Turcz.', 162),
(16378, 'Trisynsyne', NULL, 'Baill.', 72),
(16379, 'Tritaxis', NULL, 'Baill.', 66),
(16380, 'Trithecanthera', NULL, 'Tiegh.', 98),
(16381, 'Trithrinax', NULL, 'Mart.', 15),
(16382, 'Tritomopterys', NULL, '(A.Juss. ex Endl.) Nied.', 101),
(16383, 'Triumfettoides', NULL, 'Rauschert', 102),
(16384, 'Triuranthera', NULL, 'Backer', 105),
(16385, 'Trixis', NULL, 'P.Browne', 18),
(16386, 'Trochetia', NULL, 'DC.', 102),
(16387, 'Trochetiopsis', NULL, 'Marais', 102),
(16388, 'Trochisandra', NULL, 'Bedd.', 38),
(16389, 'Trochiscanthes', NULL, 'W.D.J.Koch', 9),
(16390, 'Trochiscus', NULL, 'O.E.Schulz', 197),
(16391, 'Trochocarpa', NULL, 'R.Br.', 64),
(16392, 'Trochomeria', NULL, 'Hook.f.', 49),
(16393, 'Trochomeriopsis', NULL, 'Cogn.', 49),
(16394, 'Troglophyton', NULL, 'Hilliard & B.L.Burtt', 18),
(16395, 'Tromotriche', NULL, 'Haw.', 10),
(16396, 'Tromsdorffia', NULL, 'Blume', 76),
(16397, 'Troostwykia', NULL, 'Miq.', 45),
(16398, 'Tropalanthe', NULL, 'S.Moore', 148),
(16399, 'Trophisomia', NULL, 'Rojas Acosta', 109),
(16400, 'Tropidocarpum', NULL, 'Hook.', 197),
(16401, 'Tropidopetalum', NULL, 'Turcz.', 6),
(16402, 'Trouettia', NULL, 'Pierre ex Baill.', 148),
(16403, 'Trozelia', NULL, 'Raf.', 154),
(16404, 'Trujanoa', NULL, 'La Llave', 6),
(16405, 'Trukia', NULL, 'Kaneh.', 142),
(16406, 'Trungboa', NULL, 'Rauschert', 150),
(16407, 'Trybliocalyx', NULL, 'Lindau', 1),
(16408, 'Trychinolepis', NULL, 'B.L.Rob.', 18),
(16409, 'Trymalium', NULL, 'Fenzl', 139),
(16410, 'Tryphostemma', NULL, 'Harv.', 127),
(16411, 'Tryptomene', NULL, 'Walp.', 116),
(16412, 'Tryssophyton', NULL, 'Wurdack', 105),
(16413, 'Tsebona', NULL, 'Capuron', 148),
(16414, 'Tsiangia', NULL, 'But, H.H.Hsue & P.T.Li', 142),
(16415, 'Tsimatimia', NULL, 'Jum. & H.Perrier', 42),
(16416, 'Tsingya', NULL, 'Capuron', 147),
(16417, 'Tsoongia', NULL, 'Merr.', 90),
(16418, 'Tsoongiodendron', NULL, 'Chun', 100),
(16419, 'Tsuga', NULL, 'Carriere', 129),
(16420, 'Tsusiophyllum', NULL, 'Maxim.', 64),
(16421, 'Tuberostyles', NULL, 'Benth.(SUO)', 18),
(16422, 'Tuberostylis', NULL, 'Steetz', 18),
(16423, 'Tubiflora', NULL, 'J.F.Gmel.', 1),
(16424, 'Tubocapsicum', NULL, 'Makino', 154),
(16425, 'Tuckermannia', NULL, 'Nutt.', 18),
(16426, 'Tuerckheimocharis', NULL, 'Urb.', 150),
(16427, 'Tugarinovia', NULL, 'Iljin', 18),
(16428, 'Tula', NULL, 'Adans.', 154),
(16429, 'Tulasnea', NULL, 'Naudin', 105),
(16430, 'Tulestea', NULL, 'Aubrev. & Pellegr.', 148),
(16431, 'Tulipa', NULL, 'L.', 94),
(16432, 'Tulisma', NULL, 'Raf.', 76),
(16433, 'Tumalis', NULL, 'Raf.', 66),
(16434, 'Tumamoca', NULL, 'Rose', 49),
(16435, 'Tumidinodus', NULL, 'H.W.Li', 76),
(16436, 'Tupa', NULL, 'G.Don', 30),
(16437, 'Tupeia', NULL, 'Cham. & Schltdl.', 98),
(16438, 'Tupeianthus', NULL, 'Takht.(SUO)', 164),
(16439, 'Tupidanthus', NULL, 'Hook.f. & Thomson', 13),
(16440, 'Turaniphytum', NULL, 'Poljakov', 18),
(16441, 'Turbina', NULL, 'Raf.', 46),
(16442, 'Turgenia', NULL, 'Hoffm.', 9),
(16443, 'Turgeniopsis', NULL, 'Boiss.', 9),
(16444, 'Turia', NULL, 'Forssk. ex J.F.Gmel.', 49),
(16445, 'Turraea', NULL, 'L.', 106),
(16446, 'Turricula', NULL, 'J.F.Macbr.', 25),
(16447, 'Turrigera', NULL, 'Decne.', 10),
(16448, 'Turrillia', NULL, 'A.C.Sm.(SUS)', 135),
(16449, 'Turrita', NULL, 'Wallr.', 197),
(16450, 'Turritis', NULL, 'L.', 197),
(16451, 'Turukhania', NULL, 'Vassilcz.', 68),
(16452, 'Tussacia', NULL, 'Benth.', 76),
(16453, 'Tussilago', NULL, 'L.', 18),
(16454, 'Tutcheria', NULL, 'Dunn', 162),
(16455, 'Tuxtla', NULL, 'Villasenor & Strother', 18),
(16456, 'Tuyamaea', NULL, 'T.Yamaz.', 150),
(16457, 'Tweedia', NULL, 'Hook. & Arn.', 10),
(16458, 'Tydaea', NULL, 'Decne.', 76),
(16459, 'Tylanthera', NULL, 'C.Hansen', 105),
(16460, 'Tylecarpus', NULL, 'Engl.', 85),
(16461, 'Tylecodon', NULL, 'Toelken', 48),
(16462, 'Tyleria', NULL, 'Gleason', 118),
(16463, 'Tyleropappus', NULL, 'Greenm.', 18),
(16464, 'Tylocarya', NULL, 'Nelmes', 55),
(16465, 'Tylodontia', NULL, 'Griseb.', 10),
(16466, 'Tyloglossa', NULL, 'Hochst.', 1),
(16467, 'Tylopetalum', NULL, 'Barneby & Krukoff', 107),
(16468, 'Tylophora', NULL, 'R.Br.', 10),
(16469, 'Tylophoropsis', NULL, 'N.E.Br.', 10),
(16470, 'Tylopsacas', NULL, 'Leeuwenb.', 76);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(16471, 'Tylosema', NULL, '(Schweinf.) Torre & Hillc.', 68),
(16472, 'Tylosepalum', NULL, 'Kurz ex Teijsm. & Binn.', 66),
(16473, 'Tylosperma', NULL, 'Leeuwenb.(SUH)', 76),
(16474, 'Tylostemon', NULL, 'Engl.', 91),
(16475, 'Tynanthus', NULL, 'Miers(SUO)', 22),
(16476, 'Tynnanthus', NULL, 'Miers', 22),
(16477, 'Typhonium', NULL, 'Schott', 12),
(16478, 'Typhonodorum', NULL, 'Schott', 12),
(16479, 'Tyria', NULL, 'Klotzsch ex Endl.', 66),
(16480, 'Tyrimnus', NULL, '(Cass.) Cass.', 18),
(16481, 'Tysonia', NULL, 'Bolus(SUH)', 25),
(16482, 'Tzellemtinia', NULL, 'Chiov.', 184),
(16483, 'Ubochea', NULL, 'Baill.', 173),
(16484, 'Udani', NULL, 'Adans.', 44),
(16485, 'Uechtritzia', NULL, 'Freyn', 18),
(16486, 'Ugamia', NULL, 'Pavlov', 18),
(16487, 'Ugni', NULL, 'Turcz.', 116),
(16488, 'Uittienia', NULL, 'Steenis', 68),
(16489, 'Ulbrichia', NULL, 'Urb.', 102),
(16490, 'Uldinia', NULL, 'J.M.Black', 9),
(16491, 'Uleanthus', NULL, 'Harms', 68),
(16492, 'Ulearum', NULL, 'Engl.', 12),
(16493, 'Uleodendron', NULL, 'Rauschert', 109),
(16494, 'Uleophytum', NULL, 'Hieron.', 18),
(16495, 'Ulex', NULL, 'L.', 68),
(16496, 'Ulleria', NULL, 'Bremek.', 1),
(16497, 'Ulloa', NULL, 'Pers.', 154),
(16498, 'Ulostoma', NULL, 'G.Don', 75),
(16499, 'Ulticona', NULL, 'Raf.', 154),
(16500, 'Ultragossypium', NULL, 'Roberty', 102),
(16501, 'Ulugbekia', NULL, 'Zakirov', 25),
(16502, 'Umbellularia', NULL, '(Nees) Nutt.', 91),
(16503, 'Umbilicus', NULL, 'DC.', 48),
(16504, 'Umtiza', NULL, 'Sim', 68),
(16505, 'Uncariopsis', NULL, 'H.Karst.', 142),
(16506, 'Uncinaria', NULL, 'Rchb.(SUO)', 142),
(16507, 'Uncinia', NULL, 'Pers.', 55),
(16508, 'Ungeria', NULL, 'Schott & Endl.', 102),
(16509, 'Ungnadia', NULL, 'Endl.', 147),
(16510, 'Ungula', NULL, 'Barlow', 98),
(16511, 'Ungulipetalum', NULL, 'Moldenke', 107),
(16512, 'Unigenes', NULL, 'E.Wimm.', 30),
(16513, 'Unona', NULL, 'L.f.', 8),
(16514, 'Unxia', NULL, 'L.f.', 18),
(16515, 'Upuna', NULL, 'Symington', 60),
(16516, 'Uragoga', NULL, 'Baill.', 142),
(16517, 'Uranodactylus', NULL, 'Gilli', 197),
(16518, 'Uranthera', NULL, 'Pax & K.Hoffm.(SUH)', 184),
(16519, 'Uraria', NULL, 'Desv.', 68),
(16520, 'Urariopsis', NULL, 'Schindl.', 68),
(16521, 'Urbananthus', NULL, 'R.M.King & H.Rob.', 18),
(16522, 'Urbanella', NULL, 'Pierre', 148),
(16523, 'Urbania', NULL, 'Phil.', 173),
(16524, 'Urbanodendron', NULL, 'Mez', 91),
(16525, 'Urbanodoxa', NULL, 'Muschl.', 197),
(16526, 'Urbanoguarea', NULL, 'Harms', 106),
(16527, 'Urbanolophium', NULL, 'Melch.', 22),
(16528, 'Urbanosciadium', NULL, 'H.Wolff', 9),
(16529, 'Urbinella', NULL, 'Greenm.', 18),
(16530, 'Urbinia', NULL, 'Rose', 48),
(16531, 'Urceola', NULL, 'Roxb.', 10),
(16532, 'Urceolaria', NULL, 'Willd. ex Cothen.', 142),
(16533, 'Urechites', NULL, 'Mull.Arg.', 10),
(16534, 'Urena', NULL, 'L.', 102),
(16535, 'Uribea', NULL, 'Dugand & Romero', 68),
(16536, 'Urinaria', NULL, 'Medik.', 184),
(16537, 'Urmenetea', NULL, 'Phil.', 18),
(16538, 'Urnularia', NULL, 'Stapf', 10),
(16539, 'Urocarpidium', NULL, 'Ulbr.', 102),
(16540, 'Urocarpus', NULL, 'J.Drumm. ex Harv.', 143),
(16541, 'Urodesmium', NULL, 'Naudin', 105),
(16542, 'Urodon', NULL, 'Turcz.', 68),
(16543, 'Urogentias', NULL, 'Gilg & Gilg-Ben.', 75),
(16544, 'Urolepis', NULL, '(DC.) R.M.King & H.Rob.', 18),
(16545, 'Uromorus', NULL, 'Bureau', 109),
(16546, 'Uromyrtus', NULL, 'Burret', 116),
(16547, 'Uropappus', NULL, 'Nutt.', 18),
(16548, 'Uroskinnera', NULL, 'Lindl.', 423),
(16549, 'Urospatha', NULL, 'Schott', 12),
(16550, 'Urospathella', NULL, 'Bunting', 12),
(16551, 'Urospermum', NULL, 'Scop.', 18),
(16552, 'Urostemon', NULL, 'B.Nord.', 18),
(16553, 'Urostephanus', NULL, 'B.L.Rob. & Greenm.', 10),
(16554, 'Urostigma', NULL, 'Gasp.', 109),
(16555, 'Urotheca', NULL, 'Gilg', 105),
(16556, 'Ursia', NULL, 'Vassilcz.', 68),
(16557, 'Ursinia', NULL, 'Gaertn.', 18),
(16558, 'Ursiniopsis', NULL, 'E.Phillips', 18),
(16559, 'Urtica', NULL, 'L.', 171),
(16560, 'Uruparia', NULL, 'Raf.', 142),
(16561, 'Urvillea', NULL, 'Kunth', 147),
(16562, 'Usoricum', NULL, 'Lunell(SUS)', 121),
(16563, 'Usteria', NULL, 'Willd.', 97),
(16564, 'Utleria', NULL, 'Bedd. ex Benth.', 10),
(16565, 'Utleya', NULL, 'Wilbur & Luteyn', 64),
(16566, 'Utsetela', NULL, 'Pellegr.', 109),
(16567, 'Uva', NULL, 'Kuntze', 8),
(16568, 'Uvaria', NULL, 'L.', 8),
(16569, 'Uvariella', NULL, 'Ridl.', 8),
(16570, 'Vacciniopsis', NULL, 'Rusby', 64),
(16571, 'Vachellia', NULL, 'Wight & Arn.', 68),
(16572, 'Vahadenia', NULL, 'Stapf', 10),
(16573, 'Vailia', NULL, 'Rusby', 10),
(16574, 'Vaillantia', NULL, 'Hoffm.(SUO)', 142),
(16575, 'Valantia', NULL, 'L.', 142),
(16576, 'Valentina', NULL, 'Speg.', 25),
(16577, 'Valentiniella', NULL, 'Speg.', 25),
(16578, 'Valenzuelia', NULL, 'Bertero ex Cambess.', 147),
(16579, 'Valerioa', NULL, 'Standl. & Steyerm.', 76),
(16580, 'Valerioanthus', NULL, 'Lundell', 115),
(16581, 'Valetonia', NULL, 'T.Durand', 85),
(16582, 'Valikaha', NULL, 'Adans.', 105),
(16583, 'Vallariopsis', NULL, 'Woodson', 10),
(16584, 'Vallaris', NULL, 'Raf.(SUH)', 10),
(16585, 'Vallea', NULL, 'Mutis ex L.f.', 62),
(16586, 'Vallesia', NULL, 'Ruiz & Pav.', 10),
(16587, 'Valteta', NULL, 'Raf.', 154),
(16588, 'Valvanthera', NULL, 'C.T.White', 79),
(16589, 'Van-Royena', NULL, 'Aubrev.', 148),
(16590, 'Vanasushava', NULL, 'P.K.Mukh. & Constance', 9),
(16591, 'Vanclevea', NULL, 'Greene', 18),
(16592, 'Vandasia', NULL, 'Domin', 68),
(16593, 'Vandasina', NULL, 'Rauschert', 68),
(16594, 'Vandellia', NULL, 'P.Browne ex L.', 150),
(16595, 'Vandera', NULL, 'Raf.', 66),
(16596, 'Vanderystia', NULL, 'De Wild.', 148),
(16597, 'Vanessa', NULL, 'Raf.', 142),
(16598, 'Vangueria', NULL, 'Comm. ex Juss.', 142),
(16599, 'Vangueriopsis', NULL, 'Robyns', 142),
(16600, 'Vanhouttea', NULL, 'Lem.', 76),
(16601, 'Vania', NULL, 'F.K.Mey.', 197),
(16602, 'Vanieria', NULL, 'Lour.', 109),
(16603, 'Vanillosmopsis', NULL, 'Sch.Bip.', 18),
(16604, 'Vaniotia', NULL, 'H.Lev.', 76),
(16605, 'Vanwykia', NULL, 'Wiens', 98),
(16606, 'Varennea', NULL, 'DC.', 68),
(16607, 'Varilla', NULL, 'A.Gray', 18),
(16608, 'Varinga', NULL, 'Raf.', 109),
(16609, 'Varnera', NULL, 'L.', 142),
(16610, 'Varthemia', NULL, 'DC.', 18),
(16611, 'Vaselia', NULL, 'Tiegh.', 118),
(16612, 'Vaseyanthus', NULL, 'Cogn.', 49),
(16613, 'Vasivaea', NULL, 'Baill.', 102),
(16614, 'Vassobia', NULL, 'Rusby', 154),
(16615, 'Vataireopsis', NULL, 'Ducke', 68),
(16616, 'Vateria', NULL, 'L.', 60),
(16617, 'Vateriopsis', NULL, 'F.Heim', 60),
(16618, 'Vatovaea', NULL, 'Chiov.', 68),
(16619, 'Vauanthes', NULL, 'Haw.', 48),
(16620, 'Vaughania', NULL, 'S.Moore', 68),
(16621, 'Vaupelia', NULL, 'Brand', 25),
(16622, 'Vaupesia', NULL, 'R.E.Schult.', 66),
(16623, 'Vauquelinia', NULL, 'Correa ex Humb. & Bonpl.', 141),
(16624, 'Vausagesia', NULL, 'Baill.', 118),
(16625, 'Vavaea', NULL, 'Benth.', 106),
(16626, 'Vavanga', NULL, 'Rohr(SUI)', 142),
(16627, 'Vavilovia', NULL, 'Fed.', 68),
(16628, 'Veatchia', NULL, 'A.Gray', 6),
(16629, 'Veconcibea', NULL, '(Mull.Arg.) Pax & K.Hoffm.', 66),
(16630, 'Veeresia', NULL, 'Monach. & Moldenke', 102),
(16631, 'Vegaea', NULL, 'Urb.', 115),
(16632, 'Veillonia', NULL, 'H.E.Moore', 15),
(16633, 'Veitchia', NULL, 'H.Wendl.', 15),
(16634, 'Velaea', NULL, 'D.Dietr.', 9),
(16635, 'Vella', NULL, 'DC.', 197),
(16636, 'Vellereophyton', NULL, 'Hilliard & B.L.Burtt', 18),
(16637, 'Vellosiella', NULL, 'Baill.', 150),
(16638, 'Vellozia', NULL, 'Vand.', 172),
(16639, 'Velpeaulia', NULL, 'Gaudich.', 154),
(16640, 'Velvetia', NULL, 'Tiegh.', 98),
(16641, 'Velvitsia', NULL, 'Hiern', 150),
(16642, 'Vendredia', NULL, 'Baill.', 18),
(16643, 'Venegasia', NULL, 'DC.', 18),
(16644, 'Venidium', NULL, 'Less.', 18),
(16645, 'Ventenatia', NULL, 'Tratt.', 66),
(16646, 'Ventilago', NULL, 'Gaertn.', 139),
(16647, 'Veprecella', NULL, 'Naudin', 105),
(16648, 'Veratrilla', NULL, '(Baill.) Franch.', 75),
(16649, 'Verbascum', NULL, 'L.', 150),
(16650, 'Verbena', NULL, 'L.', 173),
(16651, 'Verbenoxylum', NULL, 'Tronc.', 173),
(16652, 'Verdcourtia', NULL, 'R.Wilczek', 68),
(16653, 'Verhuellia', NULL, 'Miq.', 130),
(16654, 'Verlotia', NULL, 'E.Fourn.', 10),
(16655, 'Vermifrux', NULL, 'J.B.Gillett', 68),
(16656, 'Vernicia', NULL, 'Lour.', 66),
(16657, 'Vernoniopsis', NULL, 'Humbert', 18),
(16658, 'Veronica', NULL, 'L.', 423),
(16659, 'Veronicastrum', NULL, 'Heist. ex Fabr.', 423),
(16660, 'Verrucularia', NULL, 'A.Juss.', 101),
(16661, 'Verrucularina', NULL, 'Rauschert', 101),
(16662, 'Verschaffeltia', NULL, 'H.Wendl.', 15),
(16663, 'Versteegia', NULL, 'Valeton', 142),
(16664, 'Verticordia', NULL, 'DC.', 116),
(16665, 'Verulamia', NULL, 'DC. ex Poir.', 142),
(16666, 'Veselskya', NULL, 'Opiz', 197),
(16667, 'Vesicarex', NULL, 'Steyerm.', 55),
(16668, 'Vesicaria', NULL, 'Adans.', 197),
(16669, 'Vesselowskya', NULL, 'Pamp.', 50),
(16670, 'Vestia', NULL, 'Willd.', 154),
(16671, 'Vexatorella', NULL, 'Rourke', 135),
(16672, 'Vexibia', NULL, 'Raf.', 68),
(16673, 'Vexillifera', NULL, 'Ducke', 68),
(16674, 'Vicarya', NULL, 'Wall. ex Voigt', 10),
(16675, 'Vicatia', NULL, 'DC.', 9),
(16676, 'Vicentia', NULL, 'Allemao', 44),
(16677, 'Vicia', NULL, 'L.', 68),
(16678, 'Vicilla', NULL, 'Schur', 68),
(16679, 'Vicioides', NULL, 'Moench', 68),
(16680, 'Vicoa', NULL, 'Cass.', 18),
(16681, 'Victorinia', NULL, 'Leon', 66),
(16682, 'Vidalia', NULL, 'Fern.-Vill.', 42),
(16683, 'Vidoricum', NULL, 'Kuntze', 148),
(16684, 'Vieraea', NULL, 'Sch.Bip.', 18),
(16685, 'Viereckia', NULL, 'R.M.King & H.Rob.', 18),
(16686, 'Vietsenia', NULL, 'C.Hansen', 105),
(16687, 'Vigethia', NULL, 'W.A.Weber', 18),
(16688, 'Vigia', NULL, 'Vell.', 66),
(16689, 'Vigna', NULL, 'Savi', 68),
(16690, 'Vignaldia', NULL, 'A.Rich.', 142),
(16691, 'Vignaudia', NULL, 'Schweinf.(SUO)', 142),
(16692, 'Vignopsis', NULL, 'De Wild.', 68),
(16693, 'Viguiera', NULL, 'Kunth', 18),
(16694, 'Villadia', NULL, 'Rose', 48),
(16695, 'Villamilla', NULL, 'Ruiz & Pav.', 128),
(16696, 'Villanova', NULL, 'Lag.', 18),
(16697, 'Villaresia', NULL, 'Ruiz & Pav.', 85),
(16698, 'Villaresiopsis', NULL, 'Sleumer', 85),
(16699, 'Villebrunea', NULL, 'Gaudich.', 171),
(16700, 'Villocuspis', NULL, '(A.DC.) Aubrev. & Pellegr.', 148),
(16701, 'Vilmorinia', NULL, 'DC.', 68),
(16702, 'Vilobia', NULL, 'Strother', 18),
(16703, 'Viminaria', NULL, 'Sm.', 68),
(16704, 'Vinca', NULL, 'L.', 10),
(16705, 'Vincentella', NULL, 'Pierre', 148),
(16706, 'Vincentia', NULL, 'Gaudich.', 55),
(16707, 'Vincetoxicopsis', NULL, 'Costantin', 10),
(16708, 'Vincetoxicum', NULL, 'Wolf', 10),
(16709, 'Vindasia', NULL, 'Benoist', 1),
(16710, 'Vinticena', NULL, 'Steud.', 102),
(16711, 'Viola', NULL, 'L.', 174),
(16712, 'Viposia', NULL, 'Lundell', 38),
(16713, 'Virecta', NULL, 'Afzel. ex Sm.(SUH)', 142),
(16714, 'Virectaria', NULL, 'Bremek.', 142),
(16715, 'Vireya', NULL, 'Raf.', 76),
(16716, 'Virgilia', NULL, 'Poir.', 68),
(16717, 'Virginia', NULL, '(DC.) Nicoli', 18),
(16718, 'Virgulaster', NULL, 'Semple', 18),
(16719, 'Viridivia', NULL, 'J.H.Hemsl. & Verdc.', 127),
(16720, 'Viscainoa', NULL, 'Greene', 177),
(16721, 'Viscoides', NULL, 'Jacq.', 142),
(16722, 'Viscum', NULL, 'L.', 146),
(16723, 'Visiania', NULL, 'Gasp.(SUH)', 109),
(16724, 'Vismianthus', NULL, 'Mildbr.', 45),
(16725, 'Visnea', NULL, 'L.f.', 409),
(16726, 'Vissadali', NULL, 'Adans.', 142),
(16727, 'Vitellaria', NULL, 'C.F.Gaertn.', 148),
(16728, 'Vitellariopsis', NULL, 'Baill. ex Dubard', 148),
(16729, 'Viticella', NULL, 'Mitch.', 84),
(16730, 'Vitiphoenix', NULL, 'Becc.', 15),
(16731, 'Vitis', NULL, 'L.', 181),
(16732, 'Vittadinia', NULL, 'A.Rich.', 18),
(16733, 'Vittetia', NULL, 'R.M.King & H.Rob.', 18),
(16734, 'Viviana', NULL, 'Colla', 142),
(16735, 'Vladimiria', NULL, 'Iljin', 18),
(16736, 'Voandzeia', NULL, 'Thouars', 68),
(16737, 'Voanioala', NULL, 'J.Dransf.', 15),
(16738, 'Voatamalo', NULL, 'Capuron ex Bosser', 534),
(16739, 'Vochy', NULL, 'Aubl.', 175),
(16740, 'Voelckeria', NULL, 'Klotzsch & H.Karst. ex Endl.', 162),
(16741, 'Vogelia', NULL, 'Medik.(SUH)', 197),
(16742, 'Vogelocassia', NULL, 'Britton', 68),
(16743, 'Voharanga', NULL, 'Costantin & Bois', 10),
(16744, 'Vohemaria', NULL, 'Buchenau', 10),
(16745, 'Voigtia', NULL, 'Klotzsch', 142),
(16746, 'Voladeria', NULL, 'Benoist', 55),
(16747, 'Volkensia', NULL, 'O.Hoffm.', 18),
(16748, 'Volkensiella', NULL, 'H.Wolff', 9),
(16749, 'Volkensinia', NULL, 'Schinz', 5),
(16750, 'Volkensiophyton', NULL, 'Lindau', 1),
(16751, 'Volkiella', NULL, 'Merxm. & Czech', 55),
(16752, 'Volutaria', NULL, 'Cass.', 18),
(16753, 'Volvulopsis', NULL, 'Roberty', 46),
(16754, 'Volvulus', NULL, 'Medik.', 46),
(16755, 'Vonitra', NULL, 'Becc.', 15),
(16756, 'Vossianthus', NULL, 'Kuntze', 102),
(16757, 'Votomita', NULL, 'Aubl.', 105),
(16758, 'Vouacapoua', NULL, 'Aubl.', 68),
(16759, 'Vouay', NULL, 'Aubl.', 15),
(16760, 'Voyria', NULL, 'Aubl.', 75),
(16761, 'Voyriella', NULL, 'Miq.', 75),
(16762, 'Vvedenskya', NULL, 'Korovin', 9),
(16763, 'Vvedenskyella', NULL, 'Botsch.', 197),
(16764, 'Waddingtonia', NULL, 'Phil.', 154),
(16765, 'Wadea', NULL, 'Raf.', 154),
(16766, 'Wagatea', NULL, 'Dalzell', 68),
(16767, 'Wagenitzia', NULL, 'Dostal', 18),
(16768, 'Wahlenbergia', NULL, 'Blume(SUH)', 30),
(16769, 'Waitzia', NULL, 'J.C.Wendl.', 18),
(16770, 'Wajira', NULL, 'Thulin', 68),
(16771, 'Wakilia', NULL, 'Gilli', 197),
(16772, 'Walafrida', NULL, 'E.Mey.', 150),
(16773, 'Walberia', NULL, 'Mill. ex Ehret', 154),
(16774, 'Waldheimia', NULL, 'Kar. & Kir.', 18),
(16775, 'Waldsteinia', NULL, 'Willd.', 141),
(16776, 'Walidda', NULL, '(A.DC.) Pichon', 10),
(16777, 'Walkeria', NULL, 'A.Chev.', 148),
(16778, 'Wallacea', NULL, 'Spruce ex Hook.', 118),
(16779, 'Wallaceodendron', NULL, 'Koord.', 68),
(16780, 'Walleniella', NULL, 'P.Wilson', 115),
(16781, 'Wallichia', NULL, 'Reinw. ex Blume(SUH)', 15),
(16782, 'Wallrothia', NULL, 'Spreng.', 9),
(16783, 'Walpersia', NULL, 'Harv.', 68),
(16784, 'Wamalchitamia', NULL, 'Strother', 18),
(16785, 'Warburgia', NULL, 'Engl.', 31),
(16786, 'Warburgina', NULL, 'Eig', 142),
(16787, 'Wardenia', NULL, 'King', 13),
(16788, 'Warea', NULL, 'Nutt.', 197),
(16789, 'Waria', NULL, 'Aubl.(SUO)', 8),
(16790, 'Warionia', NULL, 'Benth. & Coss.', 18),
(16791, 'Warneria', NULL, 'Ellis(SUO)', 142),
(16792, 'Warpuria', NULL, 'Stapf', 1),
(16793, 'Wartmannia', NULL, 'Mull.Arg.', 66),
(16794, 'Wasabia', NULL, 'Matsum.', 197),
(16795, 'Washingtonia', NULL, 'Raf.(SUI)', 15),
(16796, 'Waterhousea', NULL, 'B.Hyland', 116),
(16797, 'Watsonamra', NULL, 'Kuntze', 142),
(16798, 'Wattakaka', NULL, 'Hassk.', 10),
(16799, 'Webera', NULL, 'J.F.Gmel.(SUH)', 105),
(16800, 'Weberaster', NULL, 'A.Love & D.Love', 18),
(16801, 'Weberbauera', NULL, 'Gilg & Muschl.', 197),
(16802, 'Weberbauerella', NULL, 'Ulbr.', 68),
(16803, 'Websteria', NULL, 'S.H.Wright', 55),
(16804, 'Wedelia', NULL, 'Loefl.(SUH)', 18),
(16805, 'Wedeliella', NULL, 'Cockerell', 117),
(16806, 'Wehlia', NULL, 'F.Muell.', 116),
(16807, 'Weigela', NULL, 'Thunb.', 513),
(16808, 'Weigeltia', NULL, 'A.DC.', 115),
(16809, 'Weihea', NULL, 'Spreng.', 140),
(16810, 'Welchiodendron', NULL, 'Peter G.Wilson & J.T.Waterh.', 116),
(16811, 'Wellstedia', NULL, 'Balf.f.', 25),
(16812, 'Welwitschiella', NULL, 'O.Hoffm.', 18),
(16813, 'Wenchengia', NULL, 'C.Y.Wu & S.Chow', 90),
(16814, 'Wendelboa', NULL, 'Soest', 18),
(16815, 'Wenderothia', NULL, 'Schltdl.', 68),
(16816, 'Wendlandiella', NULL, 'Dammer', 15),
(16817, 'Wenzelia', NULL, 'Merr.', 143),
(16818, 'Werdermannia', NULL, 'O.E.Schulz', 197),
(16819, 'Werneria', NULL, 'Kunth', 18),
(16820, 'Wernhamia', NULL, 'S.Moore', 142),
(16821, 'Westia', NULL, 'Vahl', 68),
(16822, 'Westoniella', NULL, 'Cuatrec.', 18),
(16823, 'Westphalina', NULL, 'A.Robyns & Bamps', 102),
(16824, 'Westringia', NULL, 'Sm.', 90),
(16825, 'Wetria', NULL, 'Baill.', 66),
(16826, 'Wetriaria', NULL, 'Pax', 66),
(16827, 'Wettinella', NULL, 'O.F.Cook & Doyle', 15),
(16828, 'Wettiniicarpus', NULL, 'Burret', 15),
(16829, 'Wettsteinia', NULL, 'Petr.', 18),
(16830, 'Wheelerella', NULL, 'G.B.Grant(SUS)', 25),
(16831, 'White-Sloanea', NULL, 'Chiov.', 10),
(16832, 'Whitfieldia', NULL, 'Hook.', 1),
(16833, 'Whitfordia', NULL, 'Elmer', 68),
(16834, 'Whitfordiodendron', NULL, 'Elmer', 68),
(16835, 'Whitia', NULL, 'Blume', 76),
(16836, 'Whitmorea', NULL, 'Sleumer', 545),
(16837, 'Whitneya', NULL, 'A.Gray', 18),
(16838, 'Whyanbeelia', NULL, 'Airy Shaw & B.Hyland', 534),
(16839, 'Whytockia', NULL, 'W.W.Sm.', 76),
(16840, 'Wiborgia', NULL, 'Thunb.', 68),
(16841, 'Widdringtonia', NULL, 'Endl.', 51),
(16842, 'Widgrenia', NULL, 'Malme', 10),
(16843, 'Wiedemannia', NULL, 'Fisch. & C.A.Mey.', 90),
(16844, 'Wiegmannia', NULL, 'Meyen', 142),
(16845, 'Wielandia', NULL, 'Baill.', 184),
(16846, 'Wiestia', NULL, 'Sch.Bip.', 18),
(16847, 'Wigandia', NULL, 'Kunth', 25),
(16848, 'Wightia', NULL, 'Wall.', 150),
(16849, 'Wigmannia', NULL, 'Walp.(SUO)', 142),
(16850, 'Wikstroemia', NULL, 'Schrad.(SUH)', 164),
(16851, 'Wilbrandia', NULL, 'Silva Manso', 49),
(16852, 'Wildemaniodoxa', NULL, 'Aubrev. & Pellegr.', 148),
(16853, 'Wilhelminia', NULL, 'Hochr.', 102),
(16854, 'Wilkesia', NULL, 'A.Gray', 18),
(16855, 'Wilkiea', NULL, 'F.Muell.', 108),
(16856, 'Willardia', NULL, 'Rose', 68),
(16857, 'Willdenovia', NULL, 'J.F.Gmel.', 142),
(16858, 'Williamia', NULL, 'Baill.', 184),
(16859, 'Williamodendron', NULL, 'Kubitzki & H.G.Richt.', 91),
(16860, 'Williamsia', NULL, 'Merr.', 142),
(16861, 'Willughbeia', NULL, 'Roxb.', 10),
(16862, 'Willughbeiopsis', NULL, 'Rauschert', 10),
(16863, 'Wilsonia', NULL, 'R.Br.', 46),
(16864, 'Wimmeria', NULL, 'Schltdl. & Cham.', 38),
(16865, 'Winchia', NULL, 'A.DC.', 10),
(16866, 'Windmannia', NULL, 'P.Browne', 50),
(16867, 'Winklera', NULL, 'Regel', 197),
(16868, 'Wintera', NULL, 'Murray(SUS)', 176),
(16869, 'Wislizenia', NULL, 'Engelm.', 509),
(16870, 'Wissadula', NULL, 'Medik.', 102),
(16871, 'Wissmannia', NULL, 'Burret', 15),
(16872, 'Wisteria', NULL, 'Nutt.', 68),
(16873, 'Withania', NULL, 'Pauquy', 154),
(16874, 'Wittea', NULL, 'Kunth', 30),
(16875, 'Wittmannia', NULL, 'Vahl', 142),
(16876, 'Wodyetia', NULL, 'Irvine', 15),
(16877, 'Woehleria', NULL, 'Griseb.', 5),
(16878, 'Woikoia', NULL, 'Baehni', 148),
(16879, 'Wolffia', NULL, 'Horkel ex Schleid.', 12),
(16880, 'Wolffiella', NULL, '(Hegelm.) Hegelm.', 12),
(16881, 'Wolffiopsis', NULL, 'Hartog & Plas', 12),
(16882, 'Wollastonia', NULL, 'DC. ex Decne.', 18),
(16883, 'Woodburnia', NULL, 'Prain', 13),
(16884, 'Woodfordia', NULL, 'Salisb.', 99),
(16885, 'Woodia', NULL, 'Schltr.', 10),
(16886, 'Woodiella', NULL, 'Merr.', 8),
(16887, 'Woodiellantha', NULL, 'Rauschert', 8),
(16888, 'Woodsonia', NULL, 'L.H.Bailey', 15),
(16889, 'Woollsia', NULL, 'F.Muell.', 64),
(16890, 'Wootonella', NULL, 'Standl.', 18),
(16891, 'Wootonia', NULL, 'Greene', 18),
(16892, 'Wormskioldia', NULL, 'Schumach. & Thonn.', 169),
(16893, 'Woytkowskia', NULL, 'Woodson', 10),
(16894, 'Wrightea', NULL, 'Roxb.', 15),
(16895, 'Wrixonia', NULL, 'F.Muell.', 90),
(16896, 'Wulfenia', NULL, 'Jacq.', 423),
(16897, 'Wulfeniopsis', NULL, 'D.Y.Hong', 423),
(16898, 'Wulffia', NULL, 'Neck. ex Cass.', 18),
(16899, 'Wulfhorstia', NULL, 'C.E.C.Fisch.', 106),
(16900, 'Wunderlichia', NULL, 'Riedel ex Benth.', 18),
(16901, 'Wunschmannia', NULL, 'Urb.', 22),
(16902, 'Wurdackanthus', NULL, 'Maguire', 75),
(16903, 'Wurtzia', NULL, 'Baill.', 184),
(16904, 'Wyethia', NULL, 'Nutt.', 18),
(16905, 'X Anthrichaerophyllum', NULL, 'P.Fourn.', 9),
(16906, 'X Asperugalium', NULL, 'E.Fourn.', 142),
(16907, 'X Attabignya', NULL, 'Balick, A.B.Anderson & Med.-Cost', 15),
(16908, 'X Cratae-Mespilus', NULL, 'E.G.Camus', 141),
(16909, 'X Cupressocyparis', NULL, 'Dallim.', 51),
(16910, 'X Fatshedera', NULL, 'Guillaumin', 13),
(16911, 'X Galiasperula', NULL, 'Ronniger', 142),
(16912, 'X Gaulnettya', NULL, 'Marchant', 64),
(16913, 'X Gaulthettya', NULL, 'Camp', 64),
(16914, 'X Gloxinera', NULL, 'Weathers', 76),
(16915, 'X Graptoveria', NULL, 'G.D.Rowley', 48),
(16916, 'X Hesperotsuga', NULL, 'C.N.Page', 129),
(16917, 'X Heucherella', NULL, 'Wehrh.', 149),
(16918, 'X Hoodiapelia', NULL, 'G.D.Rowley', 10),
(16919, 'X Hoodiopsis', NULL, 'C.A.Luckh.', 10),
(16920, 'X Kalmiothamnus', NULL, 'Starling', 64),
(16921, 'X Majoranamaracus', NULL, 'Rech.f.', 90),
(16922, 'X Margyracaena', NULL, 'Bitter', 141),
(16923, 'X Origanomajorana', NULL, 'Domin', 90),
(16924, 'X Osmarea', NULL, 'Burkwood & Skipwith', 120),
(16925, 'X Phyllothamnus', NULL, 'C.K.Schneid.', 64),
(16926, 'X Pyronia', NULL, 'Veitch ex Trab.', 141),
(16927, 'X Sedeveria', NULL, 'E.Walther', 48),
(16928, 'X Sorbaronia', NULL, 'C.K.Schneid.', 141),
(16929, 'X Sorbopyrus', NULL, 'C.K.Schneid.', 141),
(16930, 'Xamesike', NULL, 'Raf.', 66),
(16931, 'Xantheranthemum', NULL, 'Lindau', 1),
(16932, 'Xanthisma', NULL, 'DC.', 18),
(16933, 'Xanthium', NULL, 'L.', 18),
(16934, 'Xanthobrychis', NULL, 'Galushko', 68),
(16935, 'Xanthocephalum', NULL, 'Willd.', 18),
(16936, 'Xanthoceras', NULL, 'Bunge', 147),
(16937, 'Xanthocercis', NULL, 'Baill.', 68),
(16938, 'Xanthochymus', NULL, 'Roxb.', 42),
(16939, 'Xanthogalum', NULL, 'Ave-Lall.', 9),
(16940, 'Xanthomyrtus', NULL, 'Diels', 116),
(16941, 'Xanthopappus', NULL, 'C.Winkl.', 18),
(16942, 'Xanthophytopsis', NULL, 'Pit.', 142),
(16943, 'Xanthophytum', NULL, 'Reinw. ex Blume', 142),
(16944, 'Xanthosia', NULL, 'Rudge', 9),
(16945, 'Xanthostachya', NULL, 'Bremek.', 1),
(16946, 'Xanthostemon', NULL, 'F.Muell.', 116),
(16947, 'Xanthoxalis', NULL, 'Small', 124),
(16948, 'Xantonnea', NULL, 'Pierre ex Pit.', 142),
(16949, 'Xantonneopsis', NULL, 'Pit.', 142),
(16950, 'Xatardia', NULL, 'Meisn. & Zeyh.', 9),
(16951, 'Xenacanthus', NULL, 'Bremek.', 1),
(16952, 'Xenodendron', NULL, 'K.Schum. & Lauterb.', 116),
(16953, 'Xenophya', NULL, 'Schott', 12),
(16954, 'Xenostegia', NULL, 'D.F.Austin & Staples', 46),
(16955, 'Xeranthemum', NULL, 'L.', 18),
(16956, 'Xeroaloysia', NULL, 'Tronc.', 173),
(16957, 'Xerocarpa', NULL, 'Lam.', 90),
(16958, 'Xerocarpus', NULL, 'Guill. & Perr.', 68),
(16959, 'Xerocassia', NULL, 'Britton & Rose', 68),
(16960, 'Xerocladia', NULL, 'Harv.', 68),
(16961, 'Xerococcus', NULL, 'Oerst.', 142),
(16962, 'Xeroderris', NULL, 'Roberty', 68),
(16963, 'Xerodraba', NULL, 'Skottsb.', 197),
(16964, 'Xerolekia', NULL, 'Anderb.', 18),
(16965, 'Xerophyta', NULL, 'Juss.', 172),
(16966, 'Xerosicyos', NULL, 'Humbert', 49),
(16967, 'Xerosphaera', NULL, 'Sojak', 68),
(16968, 'Xerospiraea', NULL, 'Henr.', 141),
(16969, 'Xerothamnella', NULL, 'C.T.White', 1),
(16970, 'Ximeniopsis', NULL, 'Alain', 119),
(16971, 'Xizangia', NULL, 'D.Y.Hong', 150),
(16972, 'Xolisma', NULL, 'Raf.', 64),
(16973, 'Xolocotzia', NULL, 'Miranda', 173),
(16974, 'Xylanche', NULL, 'Beck', 400),
(16975, 'Xylanthemum', NULL, 'Tzvelev', 18),
(16976, 'Xylia', NULL, 'Benth.', 68),
(16977, 'Xylinabaria', NULL, 'Pierre', 10),
(16978, 'Xylinabariopsis', NULL, 'Pit.', 10),
(16979, 'Xylocalyx', NULL, 'Balf.f.', 400),
(16980, 'Xylocarpus', NULL, 'J.Konig', 106),
(16981, 'Xylochlamys', NULL, 'Domin', 98),
(16982, 'Xylococcus', NULL, 'Nutt.', 64),
(16983, 'Xylolobus', NULL, 'Kuntze', 68),
(16984, 'Xylomelum', NULL, 'Sm.', 135),
(16985, 'Xylonagra', NULL, 'Donn.Sm. & Rose', 121),
(16986, 'Xylonymus', NULL, 'Kalkman ex Ding Hou', 38),
(16987, 'Xylophacos', NULL, 'Rydb.', 68),
(16988, 'Xylophragma', NULL, 'Sprague', 22),
(16989, 'Xylophylla', NULL, 'L.', 184),
(16990, 'Xylopiastrum', NULL, 'Roberty', 8),
(16991, 'Xylopicron', NULL, 'Adans.(SUO)', 8),
(16992, 'Xylopicrum', NULL, 'P.Browne', 8),
(16993, 'Xylopleurum', NULL, 'Spach', 121),
(16994, 'Xylosterculia', NULL, 'Kosterm.', 102),
(16995, 'Xylothamia', NULL, 'G.L.Nesom, Y.B.Suh, D.R.Morgan &', 18),
(16996, 'Xylotheca', NULL, 'Hochst.', 198),
(16997, 'Xylothermia', NULL, 'Greene', 68),
(16998, 'Xymalos', NULL, 'Baill.', 108),
(16999, 'Xyridopsis', NULL, 'Welw. ex B.Nord.', 18),
(17000, 'Xysmalobium', NULL, 'R.Br.', 10),
(17001, 'Yabea', NULL, 'Koso-Pol.', 9),
(17002, 'Yangapa', NULL, 'Raf.', 142),
(17003, 'Yarina', NULL, 'O.F.Cook', 15),
(17004, 'Yeatesia', NULL, 'Small', 1),
(17005, 'Yermo', NULL, 'Dorn', 18),
(17006, 'Yinquania', NULL, 'Z.Y.Zhu', 47),
(17007, 'Ynesa', NULL, 'O.F.Cook', 15),
(17008, 'Youngia', NULL, 'Cass.', 18),
(17009, 'Yua', NULL, 'C.L.Li', 181),
(17010, 'Yucaratonia', NULL, 'Burkart', 68),
(17011, 'Yucca', NULL, 'L.', 3),
(17012, 'Yunckeria', NULL, 'Lundell', 115),
(17013, 'Yunnanea', NULL, 'Hu', 162),
(17014, 'Yunquea', NULL, 'Skottsb.', 18),
(17015, 'Yutajea', NULL, 'Steyerm.', 142),
(17016, 'Yuyba', NULL, '(Barb.Rodr.) L.H.Bailey', 15),
(17017, 'Zaa', NULL, 'Baill.', 22),
(17018, 'Zabelia', NULL, '(Rehder) Makino', 33),
(17019, 'Zacateza', NULL, 'Bullock', 10),
(17020, 'Zacintha', NULL, 'Mill.', 18),
(17021, 'Zaczatea', NULL, 'Baill.', 10),
(17022, 'Zahlbrucknera', NULL, 'Rchb.', 149),
(17023, 'Zalaccella', NULL, 'Becc.', 15),
(17024, 'Zalitea', NULL, 'Raf.', 66),
(17025, 'Zalmaria', NULL, 'B.D.Jacks.', 142),
(17026, 'Zaluzania', NULL, 'Pers.', 18),
(17027, 'Zaluzianskya', NULL, 'F.W.Schmidt', 150),
(17028, 'Zamaria', NULL, 'Raf.', 142),
(17029, 'Zamioculcas', NULL, 'Schott', 12),
(17030, 'Zamzela', NULL, 'Raf.', 40),
(17031, 'Zandera', NULL, 'D.L.Schulz', 18),
(17032, 'Zanonia', NULL, 'L.', 49),
(17033, 'Zantedeschia', NULL, 'Spreng.', 12),
(17034, 'Zapoteca', NULL, 'H.M.Hern.', 68),
(17035, 'Zappania', NULL, 'Scop.', 90),
(17036, 'Zarcoa', NULL, 'Llanos', 184),
(17037, 'Zataria', NULL, 'Boiss.', 90),
(17038, 'Zauschneria', NULL, 'C.Presl', 121),
(17039, 'Zederachia', NULL, 'Heist. ex Fabr.', 106),
(17040, 'Zehneria', NULL, 'Endl.', 49),
(17041, 'Zelkova', NULL, 'Spach', 170),
(17042, 'Zelonops', NULL, 'Raf.', 15),
(17043, 'Zenia', NULL, 'Chun', 68),
(17044, 'Zenkerella', NULL, 'Taub.', 68),
(17045, 'Zenkerina', NULL, 'Engl.', 1),
(17046, 'Zenkerodendron', NULL, 'Gilg ex Jabl.', 184),
(17047, 'Zenkerophytum', NULL, 'Engl. ex Diels', 107),
(17048, 'Zenobia', NULL, 'D.Don', 64),
(17049, 'Zeravschania', NULL, 'Korovin', 9),
(17050, 'Zerdana', NULL, 'Boiss.', 197),
(17051, 'Zeugandra', NULL, 'P.H.Davis', 30),
(17052, 'Zeuxanthe', NULL, 'Ridl.', 142),
(17053, 'Zexmenia', NULL, 'La Llave', 18),
(17054, 'Zeydora', NULL, 'Lour. ex Gomes', 68),
(17055, 'Zeyhera', NULL, 'Mart.(SUO)', 22),
(17056, 'Zeyheria', NULL, 'Mart.', 22),
(17057, 'Zhumeria', NULL, 'Rech.f. & Wendelbo', 90),
(17058, 'Zieria', NULL, 'Sm.', 143),
(17059, 'Zieridium', NULL, 'Baill.', 143),
(17060, 'Zilla', NULL, 'Forssk.', 197),
(17061, 'Zimapania', NULL, 'Engl. & Pax', 66),
(17062, 'Zimmermannia', NULL, 'Pax', 184),
(17063, 'Zimmermanniopsis', NULL, 'Radcl.-Sm.', 184),
(17064, 'Zingania', NULL, 'A.Chev.', 68),
(17065, 'Zinnia', NULL, 'L.', 18),
(17066, 'Zinowiewia', NULL, 'Turcz.', 38),
(17067, 'Zippelia', NULL, 'Blume', 130),
(17068, 'Zizia', NULL, 'W.D.J.Koch', 9),
(17069, 'Ziziphora', NULL, 'L.', 90),
(17070, 'Zoegea', NULL, 'L.', 18),
(17071, 'Zollernia', NULL, 'Wied-Neuw. & Nees', 68),
(17072, 'Zombia', NULL, 'L.H.Bailey', 15),
(17073, 'Zombitsia', NULL, 'Keraudren', 49),
(17074, 'Zomicarpa', NULL, 'Schott', 12),
(17075, 'Zomicarpella', NULL, 'N.E.Br.', 12),
(17076, 'Zonanthemis', NULL, 'Greene', 18),
(17077, 'Zonanthus', NULL, 'Griseb.', 75),
(17078, 'Zornia', NULL, 'J.F.Gmel.', 68),
(17079, 'Zosima', NULL, 'Hoffm.', 9),
(17080, 'Zschokkea', NULL, 'Mull.Arg.', 10),
(17081, 'Zucca', NULL, 'Comm. ex Juss.', 49),
(17082, 'Zuccagnia', NULL, 'Cav.', 68),
(17083, 'Zuccarinia', NULL, 'Blume', 142),
(17084, 'Zucchellia', NULL, 'Decne.', 10),
(17085, 'Zuckertia', NULL, 'Baill.', 66),
(17086, 'Zuckia', NULL, 'Standl.', 5),
(17087, 'Zunilia', NULL, 'Lundell', 115),
(17088, 'Zurloa', NULL, 'Ten.', 106),
(17089, 'Zwaardekronia', NULL, 'Korth.', 142),
(17090, 'Zwackhia', NULL, 'Sendtn. ex Rchb.(SUH)', 25),
(17091, 'Zwingera', NULL, 'Hofer', 154),
(17092, 'Zygalchemilla', NULL, 'Rydb.', 141),
(17093, 'Zygodia', NULL, 'Benth.', 10),
(17094, 'Zygogynum', NULL, 'Baill.', 176),
(17095, 'Zygonerion', NULL, 'Baill.', 10),
(17096, 'Zygoon', NULL, 'Hiern', 142),
(17097, 'Zygophyllidium', NULL, '(Boiss.) Small', 66),
(17098, 'Zygophyllum', NULL, 'L.', 177),
(17099, 'Zygoruellia', NULL, 'Baill.', 1),
(17100, 'Zygosicyos', NULL, 'Humbert', 49),
(17101, 'Zygospermum', NULL, 'Thwaites ex Baill.', 184),
(17102, 'Zygostelma', NULL, 'Benth.', 10),
(17103, 'Zygostigma', NULL, 'Griseb.', 75),
(17104, 'Zymum', NULL, 'Thouars', 101),
(17105, 'Zyzyxia', NULL, 'Strother', 18),
(17106, 'Mangenotia', NULL, 'Pichon', 10),
(17107, 'Aa', NULL, 'Rchb.f.', 123),
(17108, 'Abdominea', NULL, 'J.J.Sm.', 123),
(17109, 'Abolboda', NULL, 'Bonpl.', 498),
(17110, 'Abromeitiella', NULL, 'Mez', 244),
(17111, 'Abrophyllum', NULL, 'Hook.f. ex Benth.', 449),
(17112, 'Acampe', NULL, 'Lindl.', 123),
(17113, 'Acanthephippium', NULL, 'Blume', 123),
(17114, 'Acanthocalycium', NULL, 'Backeb.', 29),
(17115, 'Acanthocarpus', NULL, 'Lehm.', 368),
(17116, 'Acanthogilia', NULL, 'A.G.Day & Moran', 428),
(17117, 'Acantholimon', NULL, 'Boiss.', 426),
(17118, 'Acanthophyllum', NULL, 'C.A.Mey.', 257),
(17119, 'Acanthostachys', NULL, 'Klotzsch', 244),
(17120, 'Acarpha', NULL, 'Griseb.', 251),
(17121, 'Aceranthus', NULL, 'C.Morren & Decne.', 237),
(17122, 'Aceras', NULL, 'R.Br.', 123),
(17123, 'Aceratorchis', NULL, 'Schltr.', 123),
(17124, 'Acharia', NULL, 'Thunb.', 198),
(17125, 'Achatocarpus', NULL, 'Triana', 199),
(17126, 'Achlyphila', NULL, 'Maguire & Wurdack', 498),
(17127, 'Achlys', NULL, 'DC.', 237),
(17128, 'Achyronychia', NULL, 'Torr. & A.Gray', 257),
(17129, 'Aciachne', NULL, 'Benth.', 131),
(17130, 'Acianthus', NULL, 'R.Br.', 123),
(17131, 'Acicarpha', NULL, 'Juss.', 251),
(17132, 'Acidosasa', NULL, 'C.D.Chu & C.S.Chao', 131),
(17133, 'Acineta', NULL, 'Lindl.', 123),
(17134, 'Aconitum', NULL, 'L.', 441),
(17135, 'Acoridium', NULL, 'Nees & Meyen', 123),
(17136, 'Acorus', NULL, 'L.', 200),
(17137, 'Acostaea', NULL, 'Schltr.', 123),
(17138, 'Acostia', NULL, 'Swallen', 131),
(17139, 'Acrachne', NULL, 'Wight & Arn. ex Chiov.', 131),
(17140, 'Acriopsis', NULL, 'Blume', 123),
(17141, 'Acritochaete', NULL, 'Pilg.', 131),
(17142, 'Acroceras', NULL, 'Stapf', 131),
(17143, 'Acrodon', NULL, 'N.E.Br.', 207),
(17144, 'Acrolophia', NULL, 'Pfitzer', 123),
(17145, 'Acropelta', NULL, 'Nakai', 296),
(17146, 'Acrophorus', NULL, 'C.Presl', 296),
(17147, 'Acrorchis', NULL, 'Dressler', 123),
(17148, 'Acrosanthes', NULL, 'Eckl. & Zeyh.', 207),
(17149, 'Acrosorus', NULL, 'Copel.', 321),
(17150, 'Acrostichum', NULL, 'L.', 437),
(17151, 'Actaea', NULL, 'L.', 441),
(17152, 'Actiniopteris', NULL, 'Link', 201),
(17153, 'Actinocladum', NULL, 'McClure ex Soderstr.', 131),
(17154, 'Acystopteris', NULL, 'Nakai', 495),
(17155, 'Ada', NULL, 'Lindl.', 123),
(17156, 'Adenochilus', NULL, 'Hook.f.', 123),
(17157, 'Adenoderris', NULL, 'J.Sm.', 495),
(17158, 'Adenogramma', NULL, 'Rchb.', 387),
(17159, 'Adenoncos', NULL, 'Blume', 123),
(17160, 'Adenophorus', NULL, 'Gaudich.', 321),
(17161, 'Adiantopsis', NULL, 'Fee', 202),
(17162, 'Adiantum', NULL, 'L.', 202),
(17163, 'Adonis', NULL, 'L.', 441),
(17164, 'Adoxa', NULL, 'L.', 203),
(17165, 'Adrorhizon', NULL, 'Hook.f.', 123),
(17166, 'Aechmea', NULL, 'Ruiz & Pav.', 244),
(17167, 'Aegialitis', NULL, 'R.Br.', 426),
(17168, 'Aegilops', NULL, 'L.', 131),
(17169, 'Aegopogon', NULL, 'Humb. & Bonpl. ex Willd.', 131),
(17170, 'Aeluropus', NULL, 'Trin.', 131),
(17171, 'Aenigmopteris', NULL, 'Holttum', 296),
(17172, 'Aerangis', NULL, 'Rchb.f.', 123),
(17173, 'Aeranthes', NULL, 'Lindl.', 123),
(17174, 'Aerides', NULL, 'Lour.', 123),
(17175, 'Aetheolirion', NULL, 'Forman', 268),
(17176, 'Aethephyllum', NULL, 'N.E.Br.', 207),
(17177, 'Aextoxicon', NULL, 'Ruiz & Pav.', 204),
(17178, 'Aframomum', NULL, 'K.Schum.', 501),
(17179, 'Afropteris', NULL, 'Alston', 437),
(17180, 'Afrothismia', NULL, '(Engl.) Schltr.', 246),
(17181, 'Afrotrichloris', NULL, 'Chiov.', 131),
(17182, 'Aganisia', NULL, 'Lindl.', 123),
(17183, 'Agapanthus', NULL, 'L''Her.', 205),
(17184, 'Agdestis', NULL, 'Moc. & Sesse ex DC.', 206),
(17185, 'Agenium', NULL, 'Nees', 131),
(17186, 'Aglaomorpha', NULL, 'Schott', 429),
(17187, 'Aglossorhyncha', NULL, 'Schltr.', 123),
(17188, 'Agropyron', NULL, 'Gaertn.', 131),
(17189, 'Agropyropsis', NULL, '(Batt. & Trab.) A.Camus', 131),
(17190, 'Agrostemma', NULL, 'L.', 257),
(17191, 'Agrostis', NULL, 'L.', 131),
(17192, 'Agrostocrinum', NULL, 'F.Muell.', 335),
(17193, 'Agrostophyllum', NULL, 'Blume', 123),
(17194, 'Ainea', NULL, 'Ravenna', 349),
(17195, 'Aira', NULL, 'L.', 131),
(17196, 'Airopsis', NULL, 'Desv.', 131),
(17197, 'Aizoanthemum', NULL, 'Dinter ex Friedrich', 207),
(17198, 'Aizoon', NULL, 'L.', 207),
(17199, 'Akania', NULL, 'Hook.f.', 208),
(17200, 'Akebia', NULL, 'Decne.', 359),
(17201, 'Alamania', NULL, 'Lex.', 123),
(17202, 'Alania', NULL, 'Endl.', 242),
(17203, 'Albuca', NULL, 'L.', 338),
(17204, 'Aldrovanda', NULL, 'L.', 294),
(17205, 'Aletris', NULL, 'L.', 391),
(17206, 'Alexgeorgea', NULL, 'Carlquist', 444),
(17207, 'Aligera', NULL, 'Suksd.', 491),
(17208, 'Alisma', NULL, 'L.', 209),
(17209, 'Allium', NULL, 'L.', 210),
(17210, 'Allochrusa', NULL, 'Bunge ex Boiss.', 257),
(17211, 'Alloeochaete', NULL, 'C.E.Hubb.', 131),
(17212, 'Allolepis', NULL, 'Soderstr. & H.F.Decker', 131),
(17213, 'Allophyllum', NULL, '(Nutt.) A.D.Grant & V.E.Grant', 428),
(17214, 'Alloteropsis', NULL, 'C.Presl', 131),
(17215, 'Alluaudia', NULL, '(Drake) Drake', 284),
(17216, 'Alluaudiopsis', NULL, 'Humbert & Choux', 284),
(17217, 'Aloe', NULL, 'L.', 211),
(17218, 'Aloinopsis', NULL, 'Schwantes', 207),
(17219, 'Alopecurus', NULL, 'L.', 131),
(17220, 'Alophia', NULL, 'Herb.', 349),
(17221, 'Alpinia', NULL, 'Roxb.', 501),
(17222, 'Alrawia', NULL, '(Wendelbo) K.M.Perss. & Wendelbo', 338),
(17223, 'Alseuosmia', NULL, 'A.Cunn.', 212),
(17224, 'Alsinidendron', NULL, 'H.Mann', 257),
(17225, 'Alstroemeria', NULL, 'L.', 213),
(17226, 'Altensteinia', NULL, 'Kunth', 123),
(17227, 'Althenia', NULL, 'F.Petit', 500),
(17228, 'Altingia', NULL, 'Noronha', 214),
(17229, 'Alvimia', NULL, 'Calderon ex Soderstr. & Londono', 131),
(17230, 'Amaryllis', NULL, 'L.', 215),
(17231, 'Amauropelta', NULL, 'Kunze', 480),
(17232, 'Amblostoma', NULL, 'Scheidw.', 123),
(17233, 'Amborella', NULL, 'Baill.', 216),
(17234, 'Ambrella', NULL, 'H.Perrier', 123),
(17235, 'Amentotaxus', NULL, 'Pilg.', 476),
(17236, 'Amerorchis', NULL, 'Hulten', 123),
(17237, 'Amesiella', NULL, 'Schltr. ex Garay', 123),
(17238, 'Amianthium', NULL, 'A.Gray', 382),
(17239, 'Amischotolype', NULL, 'Hassk.', 268),
(17240, 'Amitostigma', NULL, 'Schltr.', 123),
(17241, 'Ammobroma', NULL, 'Torr.', 362),
(17242, 'Ammocharis', NULL, 'Herb.', 215),
(17243, 'Ammochloa', NULL, 'Boiss.', 131),
(17244, 'Ammophila', NULL, 'Host', 131),
(17245, 'Amomum', NULL, 'Roxb.', 501),
(17246, 'Amparoa', NULL, 'Schltr.', 123),
(17247, 'Ampelodesmos', NULL, 'Link', 131),
(17248, 'Ampelopteris', NULL, 'Kunze', 480),
(17249, 'Amphiblestra', NULL, 'C.Presl', 296),
(17250, 'Amphibolia', NULL, 'L.Bolus ex A.G.J.Herre', 207),
(17251, 'Amphibolis', NULL, 'C.Agardh', 275),
(17252, 'Amphicarpum', NULL, 'Kunth', 131),
(17253, 'Amphigena', NULL, 'Rolfe', 123),
(17254, 'Amphineuron', NULL, 'Holttum', 480),
(17255, 'Amphipetalum', NULL, 'Bacigalupo', 431),
(17256, 'Amphiphyllum', NULL, 'Gleason', 442),
(17257, 'Amphipogon', NULL, 'R.Br.', 131),
(17258, 'Amphisiphon', NULL, 'W.F.Barker', 338),
(17259, 'Anacampseros', NULL, 'L.', 431),
(17260, 'Anacamptis', NULL, 'Rich.', 123),
(17261, 'Anadelphia', NULL, 'Hack.', 131),
(17262, 'Ananas', NULL, 'Mill.', 244),
(17263, 'Ananthacorus', NULL, 'Underw. & Maxon', 492),
(17264, 'Anapalina', NULL, 'N.E.Br.', 349),
(17265, 'Anarthria', NULL, 'R.Br.', 217),
(17266, 'Anarthropteris', NULL, 'Copel.', 429),
(17267, 'Ancistrachne', NULL, 'S.T.Blake', 131),
(17268, 'Ancistragrostis', NULL, 'S.T.Blake', 131),
(17269, 'Ancistrochilus', NULL, 'Rolfe', 123),
(17270, 'Ancistrocladus', NULL, 'Wall.', 218),
(17271, 'Ancistrorhynchus', NULL, 'Finet', 123),
(17272, 'Ancrumia', NULL, 'Harv. ex Baker', 210),
(17273, 'Andrea', NULL, 'Mez', 244),
(17274, 'Androchilus', NULL, 'Liebm. ex Hartm.', 123),
(17275, 'Androcorys', NULL, 'Schltr.', 123),
(17276, 'Androcymbium', NULL, 'Willd.', 266),
(17277, 'Androlepis', NULL, 'Brongn. ex Houllet', 244),
(17278, 'Andropogon', NULL, 'L.', 131),
(17279, 'Andropterum', NULL, 'Stapf', 131),
(17280, 'Androsace', NULL, 'L.', 434),
(17281, 'Androsiphon', NULL, 'Schltr.', 338),
(17282, 'Androstephium', NULL, 'Torr.', 481),
(17283, 'Andruris', NULL, 'Schltr.', 486),
(17284, 'Aneilema', NULL, 'R.Br.', 268),
(17285, 'Anemarrhena', NULL, 'Bunge', 219),
(17286, 'Anemia', NULL, 'Sw.', 460),
(17287, 'Anemoclema', NULL, '(Franch.) W.T.Wang', 441),
(17288, 'Anemone', NULL, 'L.', 441),
(17289, 'Anemonella', NULL, 'Spach', 441),
(17290, 'Anemonopsis', NULL, 'Siebold & Zucc.', 441),
(17291, 'Anemopsis', NULL, 'Hook. & Arn.', 457),
(17292, 'Anetium', NULL, 'Splitg.', 492),
(17293, 'Angiopteris', NULL, 'Hoffm.', 376),
(17294, 'Angolaea', NULL, 'Wedd.', 427),
(17295, 'Angraecopsis', NULL, 'Kraenzl.', 123),
(17296, 'Angraecum', NULL, 'Bory', 123),
(17297, 'Anguloa', NULL, 'Ruiz & Pav.', 123),
(17298, 'Ania', NULL, 'Lindl.', 123),
(17299, 'Anigozanthos', NULL, 'Labill.', 327),
(17300, 'Anisocampium', NULL, 'C.Presl', 495),
(17301, 'Anisopogon', NULL, 'R.Br.', 131),
(17302, 'Ankyropetalum', NULL, 'Fenzl', 257),
(17303, 'Anneliesia', NULL, 'Brieger & Luckel', 123),
(17304, 'Anochilus', NULL, 'Rolfe', 123),
(17305, 'Anoectochilus', NULL, 'Blume', 123),
(17306, 'Anogramma', NULL, 'Link', 202),
(17307, 'Anomatheca', NULL, 'Ker Gawl.', 349),
(17308, 'Anomochloa', NULL, 'Brongn.', 131),
(17309, 'Anopteris', NULL, 'Prantl ex Diels', 437),
(17310, 'Anopterus', NULL, 'Labill.', 306),
(17311, 'Anredera', NULL, 'Juss.', 236),
(17312, 'Ansellia', NULL, 'Lindl.', 123),
(17313, 'Antegibbaeum', NULL, 'Schwantes ex C.Weber', 207),
(17314, 'Anthaenantiopsis', NULL, 'Mez ex Pilg.', 131),
(17315, 'Anthenantia', NULL, 'P.Beauv.', 131),
(17316, 'Anthephora', NULL, 'Schreb.', 131),
(17317, 'Anthericopsis', NULL, 'Engl.', 268),
(17318, 'Anthobryum', NULL, 'Phil.', 312),
(17319, 'Anthochloa', NULL, 'Nees & Meyen', 131),
(17320, 'Anthochortus', NULL, 'Nees', 444),
(17321, 'Anthogonium', NULL, 'Wall. ex Lindl.', 123),
(17322, 'Antholyza', NULL, 'L.', 349),
(17323, 'Anthosiphon', NULL, 'Schltr.', 123),
(17324, 'Anthotium', NULL, 'R.Br.', 319),
(17325, 'Anthoxanthum', NULL, 'L.', 131),
(17326, 'Antigramma', NULL, 'C.Presl', 226),
(17327, 'Antillanorchis', NULL, 'Garay', 123),
(17328, 'Antimima', NULL, 'N.E.Br.', 207),
(17329, 'Antinoria', NULL, 'Parl.', 131),
(17330, 'Antrophyum', NULL, 'Kaulf.', 492),
(17331, 'Anychia', NULL, 'Michx.', 257),
(17332, 'Apacheria', NULL, 'C.T.Mason', 274),
(17333, 'Apalanthe', NULL, 'Planch.', 342),
(17334, 'Apatesia', NULL, 'N.E.Br.', 207),
(17335, 'Apera', NULL, 'Adans.', 131),
(17336, 'Aphanelytrum', NULL, 'Hack.', 131),
(17337, 'Aphelia', NULL, 'R.Br.', 258),
(17338, 'Aphyllanthes', NULL, 'L.', 220),
(17339, 'Aphyllorchis', NULL, 'Blume', 123),
(17340, 'Apinagia', NULL, 'Tul.', 427),
(17341, 'Aplectrum', NULL, '(Nutt.) Torr.', 123),
(17342, 'Apluda', NULL, 'L.', 131),
(17343, 'Apochiton', NULL, 'C.E.Hubb.', 131),
(17344, 'Apoclada', NULL, 'McClure', 131),
(17345, 'Apocopis', NULL, 'Nees', 131),
(17346, 'Apodanthes', NULL, 'Poit.', 221),
(17347, 'Apodolirion', NULL, 'Baker', 215),
(17348, 'Aponogeton', NULL, 'L.f.', 222),
(17349, 'Aporostylis', NULL, 'Rupp & Hatch', 123),
(17350, 'Apostasia', NULL, 'Blume', 123),
(17351, 'Appendicula', NULL, 'Blume', 123),
(17352, 'Appertiella', NULL, 'C.D.K.Cook & Triest', 342),
(17353, 'Aptenia', NULL, 'N.E.Br.', 207),
(17354, 'Apteria', NULL, 'Nutt.', 246),
(17355, 'Aquilegia', NULL, 'L.', 441),
(17356, 'Aracamunia', NULL, 'Carnevali & I.Ramirez', 123),
(17357, 'Arachniodes', NULL, 'Blume', 296),
(17358, 'Arachnis', NULL, 'Blume', 123),
(17359, 'Arachnitis', NULL, 'Phil.', 271),
(17360, 'Araeococcus', NULL, 'Brongn.', 244),
(17361, 'Araiostegia', NULL, 'Copel.', 279),
(17362, 'Aratitiyopea', NULL, 'Steyerm.', 498),
(17363, 'Arberella', NULL, 'Soderstr. & Calderon', 131),
(17364, 'Archineottia', NULL, 'S.C.Chen', 123),
(17365, 'Archytaea', NULL, 'Mart.', 241),
(17366, 'Arctagrostis', NULL, 'Griseb.', 131),
(17367, 'Arctophila', NULL, '(Rupr.) Andersson', 131),
(17368, 'Arenaria', NULL, 'L.', 257),
(17369, 'Arenifera', NULL, 'A.G.J.Herre', 207),
(17370, 'Arethusa', NULL, 'L.', 123),
(17371, 'Aretiastrum', NULL, '(DC.) Spach', 491),
(17372, 'Argophyllum', NULL, 'J.R.Forst. & G.Forst.', 223),
(17373, 'Argyroderma', NULL, 'N.E.Br.', 207),
(17374, 'Ariocarpus', NULL, 'Scheidw.', 29),
(17375, 'Aristea', NULL, 'Sol. ex Aiton', 349),
(17376, 'Aristida', NULL, 'L.', 131),
(17377, 'Armatocereus', NULL, 'Backeb.', 29),
(17378, 'Armeria', NULL, 'Willd.', 426),
(17379, 'Armodorum', NULL, 'Breda', 123),
(17380, 'Arnocrinum', NULL, 'Endl. & Lehm.', 219),
(17381, 'Arnottia', NULL, 'A.Rich.', 123),
(17382, 'Arpophyllum', NULL, 'Lex.', 123),
(17383, 'Arrhenatherum', NULL, 'P.Beauv.', 131),
(17384, 'Arrojadoa', NULL, 'Britton & Rose', 29),
(17385, 'Arthragrostis', NULL, 'Lazarides', 131),
(17386, 'Arthrocereus', NULL, 'A.Berger & F.M.Knuth', 29),
(17387, 'Arthrochilus', NULL, 'F.Muell.', 123),
(17388, 'Arthromeris', NULL, '(T.Moore) J.Sm.', 429),
(17389, 'Arthropodium', NULL, 'R.Br.', 219),
(17390, 'Arthropogon', NULL, 'Nees', 131),
(17391, 'Arthropteris', NULL, 'J.Sm.', 396),
(17392, 'Arthrostylidium', NULL, 'Rupr.', 131),
(17393, 'Artorima', NULL, 'Dressler & G.E.Pollard', 123),
(17394, 'Arundina', NULL, 'Blume', 123),
(17395, 'Arundinaria', NULL, 'Michx.', 131),
(17396, 'Arundinella', NULL, 'Raddi', 131),
(17397, 'Arundo', NULL, 'L.', 131),
(17398, 'Arundoclaytonia', NULL, 'Davidse & R.P.Ellis', 131),
(17399, 'Ascidieria', NULL, 'Seidenf.', 123),
(17400, 'Ascocentrum', NULL, 'Schltr. ex J.J.Sm.', 123),
(17401, 'Ascochilopsis', NULL, 'Carr', 123),
(17402, 'Ascochilus', NULL, 'Ridl.', 123),
(17403, 'Ascoglossum', NULL, 'Schltr.', 123),
(17404, 'Asepalum', NULL, 'Marais', 400),
(17405, 'Askidiosperma', NULL, 'Steud.', 444),
(17406, 'Asparagus', NULL, 'L.', 224),
(17407, 'Aspasia', NULL, 'Lindl.', 123),
(17408, 'Aspazoma', NULL, 'N.E.Br.', 207),
(17409, 'Asphodeline', NULL, 'Rchb.', 225),
(17410, 'Asphodelus', NULL, 'L.', 225),
(17411, 'Aspidistra', NULL, 'Ker Gawl.', 269),
(17412, 'Aspidogyne', NULL, 'Garay', 123),
(17413, 'Aspidotis', NULL, '(Nutt. ex Hook.) Copel.', 202),
(17414, 'Asplenium', NULL, 'L.', 226),
(17415, 'Astelia', NULL, 'Banks & Sol. ex R.Br.', 227),
(17416, 'Asteropeia', NULL, 'Thouars', 228),
(17417, 'Asteropyrum', NULL, 'J.R.Drumm. & Hutch.', 441),
(17418, 'Asthenochloa', NULL, 'Buse', 131),
(17419, 'Astrebla', NULL, 'F.Muell.', 131),
(17420, 'Astrephia', NULL, 'Dufr.', 491),
(17421, 'Astridia', NULL, 'Dinter', 207),
(17422, 'Astrophytum', NULL, 'Lem.', 29),
(17423, 'Atalopteris', NULL, 'Maxon & C.Chr.', 296),
(17424, 'Ataxipteris', NULL, 'Holttum', 296),
(17425, 'Athroostachys', NULL, 'Benth.', 131),
(17426, 'Athyrium', NULL, 'Roth', 495),
(17427, 'Atractantha', NULL, 'McClure', 131),
(17428, 'Audouinia', NULL, 'Brongn.', 245),
(17429, 'Aulonemia', NULL, 'Goudot', 131),
(17430, 'Aulosepalum', NULL, 'Garay', 123),
(17431, 'Aulotandra', NULL, 'Gagnep.', 501),
(17432, 'Austrobaileya', NULL, 'C.T.White', 229),
(17433, 'Austrocactus', NULL, 'Britton & Rose', 29),
(17434, 'Austrochloris', NULL, 'Lazarides', 131),
(17435, 'Austrofestuca', NULL, '(Tzvelev) E.B.Alexeev', 131),
(17436, 'Austrogramme', NULL, 'E.Fourn.', 202),
(17437, 'Austrotaxus', NULL, 'Compton', 476),
(17438, 'Auxopus', NULL, 'Schltr.', 123),
(17439, 'Avena', NULL, 'L.', 131),
(17440, 'Axonopus', NULL, 'P.Beauv.', 131),
(17441, 'Ayensua', NULL, 'L.B.Sm.', 244),
(17442, 'Azima', NULL, 'Lam.', 452),
(17443, 'Azolla', NULL, 'Lam.', 230),
(17444, 'Aztekium', NULL, 'Boed.', 29),
(17445, 'Babiana', NULL, 'Ker Gawl. ex Sims', 349),
(17446, 'Baeometra', NULL, 'Salisb. ex Endl.', 266),
(17447, 'Balanophora', NULL, 'J.R.Forst. & G.Forst.', 232),
(17448, 'Balanops', NULL, 'Baill.', 231),
(17449, 'Balbisia', NULL, 'Cav.', 361),
(17450, 'Baldellia', NULL, 'Parl.', 209),
(17451, 'Bambusa', NULL, 'Schreb.', 131),
(17452, 'Bamiania', NULL, 'Lincz.', 426),
(17453, 'Baptistonia', NULL, 'Barb.Rodr.', 123),
(17454, 'Baptorhachis', NULL, 'Clayton & Renvoize', 131),
(17455, 'Barberetta', NULL, 'Harv.', 327),
(17456, 'Barbeuia', NULL, 'Thouars', 234),
(17457, 'Barbeya', NULL, 'Schweinf.', 235),
(17458, 'Barbosella', NULL, 'Schltr.', 123),
(17459, 'Barbrodria', NULL, 'Luer', 123),
(17460, 'Barclaya', NULL, 'Wall.', 395),
(17461, 'Barkeria', NULL, 'Knowles & Westc.', 123),
(17462, 'Barlia', NULL, 'Parl.', 123),
(17463, 'Barnardiella', NULL, 'Goldblatt', 349),
(17464, 'Barneoudia', NULL, 'Gay', 441),
(17465, 'Barombia', NULL, 'Schltr.', 123),
(17466, 'Bartholina', NULL, 'R.Br.', 123),
(17467, 'Basella', NULL, 'L.', 236),
(17468, 'Basiphyllaea', NULL, 'Schltr.', 123),
(17469, 'Baskervillea', NULL, 'Lindl.', 123),
(17470, 'Batemannia', NULL, 'Lindl.', 123),
(17471, 'Baxteria', NULL, 'R.Br. ex Hook.', 278),
(17472, 'Bdallophyton', NULL, 'Eichler', 277),
(17473, 'Beaucarnea', NULL, 'Lem.', 293),
(17474, 'Beckmannia', NULL, 'Host', 131),
(17475, 'Beclardia', NULL, 'A.Rich.', 123),
(17476, 'Beesia', NULL, 'Balf.f. & W.W.Sm.', 441),
(17477, 'Belamcanda', NULL, 'Adans.', 349),
(17478, 'Belonanthus', NULL, 'Graebn.', 491),
(17479, 'Belosynapsis', NULL, 'Hassk.', 268),
(17480, 'Belvisia', NULL, 'Mirb.', 429),
(17481, 'Bentleya', NULL, 'E.M.Benn.', 421),
(17482, 'Benzingia', NULL, 'Dodson', 123),
(17483, 'Berberis', NULL, 'L.', 237),
(17484, 'Bergeranthus', NULL, 'Schwantes', 207),
(17485, 'Bergerocactus', NULL, 'Britton & Rose', 29),
(17486, 'Bergia', NULL, 'L.', 299),
(17487, 'Berlinianche', NULL, '(Harms) Vattimo', 221),
(17488, 'Berneuxia', NULL, 'Decne.', 282),
(17489, 'Berrisfordia', NULL, 'L.Bolus', 207),
(17490, 'Berzelia', NULL, 'Brongn.', 245),
(17491, 'Bewsia', NULL, 'Gooss.', 131),
(17492, 'Bhidea', NULL, 'Stapf ex Bor', 131),
(17493, 'Biebersteinia', NULL, 'Stephan', 238),
(17494, 'Biermannia', NULL, 'King & Pantl.', 123),
(17495, 'Bifrenaria', NULL, 'Lindl.', 123),
(17496, 'Bijlia', NULL, 'N.E.Br.', 207),
(17497, 'Billbergia', NULL, 'Thunb.', 244),
(17498, 'Binotia', NULL, 'Rolfe', 123),
(17499, 'Bipinnula', NULL, 'Comm. ex Juss.', 123),
(17500, 'Blancoa', NULL, 'Lindl.', 327),
(17501, 'Blandfordia', NULL, 'Sm.', 239),
(17502, 'Blastocaulon', NULL, 'Ruhland', 304),
(17503, 'Blechnum', NULL, 'L.', 240),
(17504, 'Blepharidachne', NULL, 'Hack.', 131),
(17505, 'Blepharoneuron', NULL, 'Nash', 131),
(17506, 'Bletia', NULL, 'Ruiz & Pav.', 123),
(17507, 'Bletilla', NULL, 'Rchb.f.', 123),
(17508, 'Bloomeria', NULL, 'Kellogg', 481),
(17509, 'Blossfeldia', NULL, 'Werderm.', 29),
(17510, 'Blotiella', NULL, 'R.M.Tryon', 281),
(17511, 'Blumenbachia', NULL, 'Schrad.', 367),
(17512, 'Blyxa', NULL, 'Noronha ex Thouars', 342),
(17513, 'Bobartia', NULL, 'L.', 349),
(17514, 'Boesenbergia', NULL, 'Kuntze', 501),
(17515, 'Bogoria', NULL, 'J.J.Sm.', 123),
(17516, 'Boissiera', NULL, 'Hochst. ex Steud.', 131),
(17517, 'Bokkeveldia', NULL, 'D.Mull.-Doblies & U.Mull.-Doblie', 215),
(17518, 'Bolanthus', NULL, '(Ser.) Rchb.', 257),
(17519, 'Bolbitis', NULL, 'Schott', 369),
(17520, 'Bollea', NULL, 'Rchb.f.', 123),
(17521, 'Bolusiella', NULL, 'Schltr.', 123),
(17522, 'Bomarea', NULL, 'Mirb.', 213),
(17523, 'Bommeria', NULL, 'E.Fourn.', 202),
(17524, 'Bonatea', NULL, 'Willd.', 123),
(17525, 'Bongardia', NULL, 'C.A.Mey.', 237),
(17526, 'Bonnetia', NULL, 'Mart.', 241),
(17527, 'Bonniera', NULL, 'Cordem.', 123),
(17528, 'Bonplandia', NULL, 'Cav.', 428),
(17529, 'Boophone', NULL, 'Herb.', 215),
(17530, 'Boopis', NULL, 'Juss.', 251),
(17531, 'Boquila', NULL, 'Decne.', 359),
(17532, 'Borya', NULL, 'Labill.', 242),
(17533, 'Bothriochilus', NULL, 'Lem.', 123),
(17534, 'Bothriochloa', NULL, 'Kuntze', 131),
(17535, 'Botrychium', NULL, 'Sw.', 399),
(17536, 'Bougueria', NULL, 'Decne.', 423),
(17537, 'Boussingaultia', NULL, 'Kunth', 236),
(17538, 'Bouteloua', NULL, 'Lag.', 131),
(17539, 'Bowenia', NULL, 'Hook.', 243),
(17540, 'Bowiea', NULL, 'Harv. ex Hook.f.', 338),
(17541, 'Brachiaria', NULL, '(Trin.) Griseb.', 131),
(17542, 'Brachionidium', NULL, 'Lindl.', 123),
(17543, 'Brachtia', NULL, 'Rchb.f.', 123),
(17544, 'Brachyachne', NULL, '(Benth.) Stapf', 131),
(17545, 'Brachycereus', NULL, 'Britton & Rose', 29),
(17546, 'Brachychloa', NULL, 'S.M.Phillips', 131),
(17547, 'Brachycorythis', NULL, 'Lindl.', 123),
(17548, 'Brachyelytrum', NULL, 'P.Beauv.', 131),
(17549, 'Brachypeza', NULL, 'Garay', 123),
(17550, 'Brachypodium', NULL, 'P.Beauv.', 131),
(17551, 'Brachysiphon', NULL, 'A.Juss.', 407),
(17552, 'Brachystele', NULL, 'Schltr.', 123),
(17553, 'Brachystemma', NULL, 'D.Don', 257),
(17554, 'Bracisepalum', NULL, 'J.J.Sm.', 123),
(17555, 'Brainea', NULL, 'J.Sm.', 240),
(17556, 'Brasenia', NULL, 'Schreb.', 249),
(17557, 'Brasilicereus', NULL, 'Backeb.', 29),
(17558, 'Brassavola', NULL, 'R.Br.', 123),
(17559, 'Brassia', NULL, 'R.Br.', 123),
(17560, 'Braunsia', NULL, 'Schwantes', 207),
(17561, 'Braxireon', NULL, 'Raf.', 215),
(17562, 'Bretschneidera', NULL, 'Hemsl.', 208),
(17563, 'Brewcaria', NULL, 'L.B.Sm., Steyerm. & H.Rob.', 244),
(17564, 'Brewerina', NULL, 'A.Gray', 257),
(17565, 'Brexia', NULL, 'Noronha ex Thouars', 306),
(17566, 'Briegeria', NULL, 'Senghas', 123),
(17567, 'Brimeura', NULL, 'Salisb.', 338),
(17568, 'Briza', NULL, 'L.', 131),
(17569, 'Brizula', NULL, 'Hieron.', 258),
(17570, 'Brocchinia', NULL, 'Schult.f.', 244),
(17571, 'Brodiaea', NULL, 'Sm.', 481),
(17572, 'Bromelia', NULL, 'L.', 244),
(17573, 'Bromheadia', NULL, 'Lindl.', 123),
(17574, 'Bromuniola', NULL, 'Stapf & C.E.Hubb.', 131),
(17575, 'Bromus', NULL, 'L.', 131),
(17576, 'Broughtonia', NULL, 'R.Br.', 123),
(17577, 'Broussaisia', NULL, 'Gaudich.', 341),
(17578, 'Brownanthus', NULL, 'Schwantes', 207),
(17579, 'Browningia', NULL, 'Britton & Rose', 29),
(17580, 'Brownleea', NULL, 'Harv. ex Lindl.', 123),
(17581, 'Brunia', NULL, 'Lam.', 245),
(17582, 'Brunonia', NULL, 'Sm.', 319),
(17583, 'Brunsvigia', NULL, 'Heist.', 215),
(17584, 'Brylkinia', NULL, 'F.Schmidt', 131),
(17585, 'Bryocarpum', NULL, 'Hook.f. & Thomson', 434),
(17586, 'Bubania', NULL, 'Girard', 426),
(17587, 'Buchloe', NULL, 'Engelm.', 131),
(17588, 'Buchlomimus', NULL, 'Reeder, C.Reeder & Rzed.', 131),
(17589, 'Buchtienia', NULL, 'Schltr.', 123),
(17590, 'Buergersiochloa', NULL, 'Pilg.', 131),
(17591, 'Bufonia', NULL, 'L.', 257),
(17592, 'Buforrestia', NULL, 'C.B.Clarke', 268),
(17593, 'Bukiniczia', NULL, 'Lincz.', 426),
(17594, 'Bulbine', NULL, 'Wolf', 225),
(17595, 'Bulbinella', NULL, 'Kunth', 225),
(17596, 'Bulbocodium', NULL, 'L.', 266),
(17597, 'Bulbophyllum', NULL, 'Thouars', 123),
(17598, 'Bulleyia', NULL, 'Schltr.', 123),
(17599, 'Burbidgea', NULL, 'Hook.f.', 501),
(17600, 'Burchardia', NULL, 'R.Br.', 266),
(17601, 'Burmannia', NULL, 'L.', 246),
(17602, 'Burnatia', NULL, 'Micheli', 209),
(17603, 'Burnettia', NULL, 'Lindl.', 123),
(17604, 'Bursaria', NULL, 'Cav.', 421),
(17605, 'Butomopsis', NULL, 'Kunth', 366),
(17606, 'Butomus', NULL, 'L.', 247),
(17607, 'Butumia', NULL, 'G.Taylor', 427),
(17608, 'Byblis', NULL, 'Salisb.', 248),
(17609, 'Cabomba', NULL, 'Aubl.', 249),
(17610, 'Cadellia', NULL, 'F.Muell.', 475),
(17611, 'Cadetia', NULL, 'Gaudich.', 123),
(17612, 'Caesia', NULL, 'R.Br.', 219),
(17613, 'Caiophora', NULL, 'C.Presl', 367),
(17614, 'Caladenia', NULL, 'R.Br.', 123),
(17615, 'Calamagrostis', NULL, 'Adans.', 131),
(17616, 'Calamovilfa', NULL, '(A.Gray) Hack.', 131),
(17617, 'Calandrinia', NULL, 'Kunth', 431),
(17618, 'Calanthe', NULL, 'Ker Gawl.', 123),
(17619, 'Calathodes', NULL, 'Hook.f. & Thomson', 441),
(17620, 'Calderonella', NULL, 'Soderstr. & H.F.Decker', 131),
(17621, 'Caldesia', NULL, 'Parl.', 209),
(17622, 'Caleana', NULL, 'R.Br.', 123),
(17623, 'Calectasia', NULL, 'R.Br.', 278),
(17624, 'Calibanus', NULL, 'Rose', 293),
(17625, 'Caliphruria', NULL, 'Herb.', 215),
(17626, 'Callianthemum', NULL, 'C.A.Mey.', 441),
(17627, 'Callisia', NULL, 'Loefl.', 268),
(17628, 'Callitriche', NULL, 'L.', 423),
(17629, 'Calochilus', NULL, 'R.Br.', 123),
(17630, 'Calochlaena', NULL, '(Maxon) R.A.White & M.D.Turner', 283),
(17631, 'Calopogon', NULL, 'R.Br.', 123),
(17632, 'Calopsis', NULL, 'P.Beauv. ex Desv.', 444),
(17633, 'Calorophus', NULL, 'Labill.', 444),
(17634, 'Caloscordum', NULL, 'Herb.', 210),
(17635, 'Calostemma', NULL, 'R.Br.', 215),
(17636, 'Caltha', NULL, 'L.', 441);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(17637, 'Caluera', NULL, 'Dodson & Determann', 123),
(17638, 'Calycanthus', NULL, 'L.', 250),
(17639, 'Calycera', NULL, 'Cav.', 251),
(17640, 'Calydorea', NULL, 'Herb.', 349),
(17641, 'Calymmanthera', NULL, 'Schltr.', 123),
(17642, 'Calymmanthium', NULL, 'F.Ritter', 29),
(17643, 'Calymmodon', NULL, 'C.Presl', 321),
(17644, 'Calypso', NULL, 'Salisb.', 123),
(17645, 'Calyptochloa', NULL, 'C.E.Hubb.', 131),
(17646, 'Calyptridium', NULL, 'Nutt.', 431),
(17647, 'Calyptrochilum', NULL, 'Kraenzl.', 123),
(17648, 'Calyptrotheca', NULL, 'Gilg', 284),
(17649, 'Camassia', NULL, 'Lindl.', 338),
(17650, 'Camptandra', NULL, 'Ridl.', 501),
(17651, 'Camptodium', NULL, 'Fee', 296),
(17652, 'Camptorrhiza', NULL, 'Hutch.', 266),
(17653, 'Camptosorus', NULL, 'Link', 226),
(17654, 'Campylocentrum', NULL, 'Benth.', 123),
(17655, 'Campyloneurum', NULL, 'C.Presl', 429),
(17656, 'Campylosiphon', NULL, 'Benth.', 246),
(17657, 'Campylostachys', NULL, 'Kunth', 471),
(17658, 'Campynema', NULL, 'Labill.', 252),
(17659, 'Campynemanthe', NULL, 'Baill.', 252),
(17660, 'Canistrum', NULL, 'E.Morren', 244),
(17661, 'Canna', NULL, 'L.', 254),
(17662, 'Cannabis', NULL, 'L.', 253),
(17663, 'Cannomois', NULL, 'P.Beauv. ex Desv.', 444),
(17664, 'Cantua', NULL, 'Juss. ex Lam.', 428),
(17665, 'Capanemia', NULL, 'Barb.Rodr.', 123),
(17666, 'Capillipedium', NULL, 'Stapf', 131),
(17667, 'Cardenanthus', NULL, 'R.C.Foster', 349),
(17668, 'Cardiandra', NULL, 'Siebold & Zucc.', 341),
(17669, 'Cardiochilos', NULL, 'P.J.Cribb', 123),
(17670, 'Cardiomanes', NULL, 'C.Presl', 344),
(17671, 'Cardionema', NULL, 'DC.', 257),
(17672, 'Cardiopteris', NULL, 'Wall. ex Royle', 255),
(17673, 'Carlemannia', NULL, 'Benth.', 256),
(17674, 'Carnegiea', NULL, 'Britton & Rose', 29),
(17675, 'Carpanthea', NULL, 'N.E.Br.', 207),
(17676, 'Carpenteria', NULL, 'Torr.', 341),
(17677, 'Carpobrotus', NULL, 'N.E.Br.', 207),
(17678, 'Carpodetus', NULL, 'J.R.Forst. & G.Forst.', 449),
(17679, 'Carpolyza', NULL, 'Salisb.', 215),
(17680, 'Carruanthus', NULL, '(Schwantes) Schwantes', 207),
(17681, 'Cartonema', NULL, 'R.Br.', 268),
(17682, 'Caryotophora', NULL, 'Leistner', 207),
(17683, 'Cassebeera', NULL, 'Kaulf.', 202),
(17684, 'Castellanoa', NULL, 'Traub', 215),
(17685, 'Castellia', NULL, 'Tineo', 131),
(17686, 'Castelnavia', NULL, 'Tul. & Wedd.', 427),
(17687, 'Catabrosa', NULL, 'P.Beauv.', 131),
(17688, 'Catalepis', NULL, 'Stapf & Stent', 131),
(17689, 'Catapodium', NULL, 'Link', 131),
(17690, 'Catasetum', NULL, 'Rich. ex Kunth', 123),
(17691, 'Cathestecum', NULL, 'C.Presl', 131),
(17692, 'Catopsis', NULL, 'Griseb.', 244),
(17693, 'Cattleya', NULL, 'Lindl.', 123),
(17694, 'Cattleyopsis', NULL, 'Lem.', 123),
(17695, 'Caucaea', NULL, 'Schltr.', 123),
(17696, 'Caularthron', NULL, 'Raf.', 123),
(17697, 'Caulokaempferia', NULL, 'K.Larsen', 501),
(17698, 'Caulophyllum', NULL, 'Michx.', 237),
(17699, 'Cautleya', NULL, '(Benth.) Hook.f.', 501),
(17700, 'Caylusea', NULL, 'A.St.-Hil.', 443),
(17701, 'Cedrelopsis', NULL, 'Baill.', 436),
(17702, 'Cenchrus', NULL, 'L.', 131),
(17703, 'Centotheca', NULL, 'Desv.', 131),
(17704, 'Centranthera', NULL, 'R.Br.', 400),
(17705, 'Centranthus', NULL, 'Lam. & DC.', 491),
(17706, 'Centrochloa', NULL, 'Swallen', 131),
(17707, 'Centroglossa', NULL, 'Barb.Rodr.', 123),
(17708, 'Centrolepis', NULL, 'Labill.', 258),
(17709, 'Centropodia', NULL, 'Rchb.', 131),
(17710, 'Centrostigma', NULL, 'Schltr.', 123),
(17711, 'Cephalanthera', NULL, 'Rich.', 123),
(17712, 'Cephalantheropsis', NULL, 'Guillaumin', 123),
(17713, 'Cephalaria', NULL, 'Schrad. ex Roem. & Schult.', 289),
(17714, 'Cephalocereus', NULL, 'Pfeiff.', 29),
(17715, 'Cephalomanes', NULL, 'C.Presl', 344),
(17716, 'Cephalophyllum', NULL, '(Haw.) N.E.Br.', 207),
(17717, 'Cephalorhizum', NULL, 'Popov & Korovin', 426),
(17718, 'Cephalostemon', NULL, 'R.H.Schomb.', 442),
(17719, 'Cephalotaxus', NULL, 'Siebold & Zucc.', 260),
(17720, 'Cephalotus', NULL, 'Labill.', 259),
(17721, 'Ceradenia', NULL, 'L.E.Bishop', 321),
(17722, 'Ceraria', NULL, 'H.Pearson & Stephens', 284),
(17723, 'Cerastium', NULL, 'L.', 257),
(17724, 'Ceratandra', NULL, 'Eckl. ex F.A.Bauer', 123),
(17725, 'Ceratiosicyos', NULL, 'Nees', 198),
(17726, 'Ceratocaryum', NULL, 'Nees', 444),
(17727, 'Ceratocentron', NULL, 'Senghas', 123),
(17728, 'Ceratocephala', NULL, 'Moench', 441),
(17729, 'Ceratochilus', NULL, 'Blume', 123),
(17730, 'Ceratolacis', NULL, '(Tul.) Wedd.', 427),
(17731, 'Ceratophyllum', NULL, 'L.', 261),
(17732, 'Ceratopteris', NULL, 'Brongn.', 404),
(17733, 'Ceratostigma', NULL, 'Bunge', 426),
(17734, 'Ceratostylis', NULL, 'Blume', 123),
(17735, 'Ceratotheca', NULL, 'Endl.', 406),
(17736, 'Ceratozamia', NULL, 'Brongn.', 499),
(17737, 'Cercidiphyllum', NULL, 'Siebold & Zucc.', 262),
(17738, 'Cerdia', NULL, 'Moc. & Sesse', 257),
(17739, 'Cereus', NULL, 'Mill.', 29),
(17740, 'Cerochlamys', NULL, 'N.E.Br.', 207),
(17741, 'Cerosora', NULL, '(Baker) Domin', 202),
(17742, 'Ceterach', NULL, 'Willd.', 226),
(17743, 'Cevallia', NULL, 'Lag.', 367),
(17744, 'Chaenanthe', NULL, 'Lindl.', 123),
(17745, 'Chaetanthus', NULL, 'R.Br.', 444),
(17746, 'Chaetium', NULL, 'Nees', 131),
(17747, 'Chaetobromus', NULL, 'Nees', 131),
(17748, 'Chaetolimon', NULL, '(Bunge) Lincz.', 426),
(17749, 'Chaetonychia', NULL, '(DC.) Sweet', 257),
(17750, 'Chaetopoa', NULL, 'C.E.Hubb.', 131),
(17751, 'Chaetopogon', NULL, 'Janch.', 131),
(17752, 'Chamaeangis', NULL, 'Schltr.', 123),
(17753, 'Chamaeanthus', NULL, 'Schltr. ex J.J.Sm.', 123),
(17754, 'Chamaegastrodia', NULL, 'Makino & F.Maek.', 123),
(17755, 'Chamaelirium', NULL, 'Willd.', 382),
(17756, 'Chamaeraphis', NULL, 'R.Br.', 131),
(17757, 'Chamaescilla', NULL, 'F.Muell. ex Benth.', 219),
(17758, 'Chamaexeros', NULL, 'Benth.', 368),
(17759, 'Chamelophyton', NULL, 'Garay', 123),
(17760, 'Chamorchis', NULL, 'Rich.', 123),
(17761, 'Chandrasekharania', NULL, 'V.J.Nair, V.S.Ramach. & Sreek.', 131),
(17762, 'Changnienia', NULL, 'S.S.Chien', 123),
(17763, 'Chapmanolirion', NULL, 'Dinter', 215),
(17764, 'Chaseella', NULL, 'Summerh.', 123),
(17765, 'Chasmanthe', NULL, 'N.E.Br.', 349),
(17766, 'Chasmanthium', NULL, 'Link', 131),
(17767, 'Chasmatophyllum', NULL, '(Schwantes) Dinter & Schwantes', 207),
(17768, 'Chasmopodium', NULL, 'Stapf', 131),
(17769, 'Chaubardia', NULL, 'Rchb.f.', 123),
(17770, 'Chaubardiella', NULL, 'Garay', 123),
(17771, 'Chauliodon', NULL, 'Summerh.', 123),
(17772, 'Cheilanthes', NULL, 'Sw.', 202),
(17773, 'Cheilanthopsis', NULL, 'Hieron.', 495),
(17774, 'Cheiloplecton', NULL, 'Fee', 202),
(17775, 'Cheiradenia', NULL, 'Lindl.', 123),
(17776, 'Cheiranthera', NULL, 'A.Cunn. ex Brongn.', 421),
(17777, 'Cheiridopsis', NULL, 'N.E.Br.', 207),
(17778, 'Cheiropleuria', NULL, 'C.Presl', 263),
(17779, 'Cheirostylis', NULL, 'Blume', 123),
(17780, 'Chelonistele', NULL, 'Pfitzer', 123),
(17781, 'Chevalierella', NULL, 'A.Camus', 131),
(17782, 'Chigua', NULL, 'D.W.Stev.', 499),
(17783, 'Chikusichloa', NULL, 'Koidz.', 131),
(17784, 'Chiloglottis', NULL, 'R.Br.', 123),
(17785, 'Chiloschista', NULL, 'Lindl.', 123),
(17786, 'Chimonanthus', NULL, 'Lindl.', 250),
(17787, 'Chimonobambusa', NULL, 'Makino', 131),
(17788, 'Chingia', NULL, 'Holttum', 480),
(17789, 'Chionachne', NULL, 'R.Br.', 131),
(17790, 'Chionochloa', NULL, 'Zotov', 131),
(17791, 'Chionodoxa', NULL, 'Boiss.', 338),
(17792, 'Chionographis', NULL, 'Maxim.', 382),
(17793, 'Chitonanthera', NULL, 'Schltr.', 123),
(17794, 'Chitonochilus', NULL, 'Schltr.', 123),
(17795, 'Chlamydogramme', NULL, 'Holttum', 296),
(17796, 'Chlamydophytum', NULL, 'Mildbr.', 232),
(17797, 'Chlidanthus', NULL, 'Herb.', 215),
(17798, 'Chloraea', NULL, 'Lindl.', 123),
(17799, 'Chloris', NULL, 'Sw.', 131),
(17800, 'Chlorocalymma', NULL, 'Clayton', 131),
(17801, 'Chlorogalum', NULL, '(Lindl.) Kunth', 338),
(17802, 'Chlorosa', NULL, 'Blume', 123),
(17803, 'Chondropetalum', NULL, 'Rottb.', 444),
(17804, 'Chondrorhyncha', NULL, 'Lindl.', 123),
(17805, 'Chondrosum', NULL, 'Desv.', 131),
(17806, 'Choristylis', NULL, 'Harv.', 351),
(17807, 'Christella', NULL, 'H.Lev.', 480),
(17808, 'Christensenia', NULL, 'Maxon', 376),
(17809, 'Christopteris', NULL, 'Copel.', 429),
(17810, 'Chroniochilus', NULL, 'J.J.Sm.', 123),
(17811, 'Chrysochloa', NULL, 'Swallen', 131),
(17812, 'Chrysocycnis', NULL, 'Linden & Rchb.f.', 123),
(17813, 'Chrysoglossum', NULL, 'Blume', 123),
(17814, 'Chrysopogon', NULL, 'Trin.', 131),
(17815, 'Chunia', NULL, 'H.T.Chang', 330),
(17816, 'Chusquea', NULL, 'Kunth', 131),
(17817, 'Chusua', NULL, 'Nevski', 123),
(17818, 'Chysis', NULL, 'Lindl.', 123),
(17819, 'Chytroglossa', NULL, 'Rchb.f.', 123),
(17820, 'Cibotium', NULL, 'Kaulf.', 283),
(17821, 'Cimicifuga', NULL, 'Wernisch.', 441),
(17822, 'Cinna', NULL, 'L.', 131),
(17823, 'Cipocereus', NULL, 'F.Ritter', 29),
(17824, 'Cipura', NULL, 'Aubl.', 349),
(17825, 'Circaeaster', NULL, 'Maxim.', 264),
(17826, 'Circaeocarpus', NULL, 'C.Y.Wu', 457),
(17827, 'Circandra', NULL, 'N.E.Br.', 207),
(17828, 'Cirrhaea', NULL, 'Lindl.', 123),
(17829, 'Cischweinfia', NULL, 'Dressler & N.H.Williams', 123),
(17830, 'Cistus', NULL, 'L.', 265),
(17831, 'Citriobatus', NULL, 'A.Cunn. ex Putt.', 421),
(17832, 'Claderia', NULL, 'Hook.f.', 123),
(17833, 'Cladopus', NULL, 'H.Moeller', 427),
(17834, 'Cladoraphis', NULL, 'Franch.', 131),
(17835, 'Clausospicula', NULL, 'Lazarides', 131),
(17836, 'Claytonia', NULL, 'L.', 431),
(17837, 'Cleisocentron', NULL, 'Bruhl', 123),
(17838, 'Cleisomeria', NULL, 'Lindl. ex G.Don', 123),
(17839, 'Cleisostoma', NULL, 'Blume', 123),
(17840, 'Cleistachne', NULL, 'Benth.', 131),
(17841, 'Cleistes', NULL, 'Rich. ex Lindl.', 123),
(17842, 'Cleistocactus', NULL, 'Lem.', 29),
(17843, 'Cleistochloa', NULL, 'C.E.Hubb.', 131),
(17844, 'Clematepistephium', NULL, 'N.Halle', 123),
(17845, 'Clematis', NULL, 'L.', 441),
(17846, 'Cleretum', NULL, 'N.E.Br.', 207),
(17847, 'Clivia', NULL, 'Lindl.', 215),
(17848, 'Clowesia', NULL, 'Lindl.', 123),
(17849, 'Cobaea', NULL, 'Cav.', 428),
(17850, 'Cobana', NULL, 'Ravenna', 349),
(17851, 'Cochleanthes', NULL, 'Raf.', 123),
(17852, 'Cochlidium', NULL, 'Kaulf.', 321),
(17853, 'Cochlioda', NULL, 'Lindl.', 123),
(17854, 'Cochliostema', NULL, 'Lem.', 268),
(17855, 'Codonocarpus', NULL, 'A.Cunn. ex Endl.', 326),
(17856, 'Codonorchis', NULL, 'Lindl.', 123),
(17857, 'Codonosiphon', NULL, 'Schltr.', 123),
(17858, 'Coelachne', NULL, 'R.Br.', 131),
(17859, 'Coelachyrum', NULL, 'Hochst. & Nees', 131),
(17860, 'Coelanthum', NULL, 'E.Mey. ex Fenzl', 387),
(17861, 'Coelia', NULL, 'Lindl.', 123),
(17862, 'Coeliopsis', NULL, 'Rchb.f.', 123),
(17863, 'Coeloglossum', NULL, 'Hartm.', 123),
(17864, 'Coelogyne', NULL, 'Lindl.', 123),
(17865, 'Coelorachis', NULL, 'Brongn.', 131),
(17866, 'Cohniella', NULL, 'Pfitzer', 123),
(17867, 'Coilochilus', NULL, 'Schltr.', 123),
(17868, 'Coix', NULL, 'L.', 131),
(17869, 'Colanthelia', NULL, 'McClure & E.W.Sm.', 131),
(17870, 'Colchicum', NULL, 'L.', 266),
(17871, 'Coleanthus', NULL, 'Seidel', 131),
(17872, 'Coleocarya', NULL, 'S.T.Blake', 444),
(17873, 'Coleocephalocereus', NULL, 'Backeb.', 29),
(17874, 'Coleotrype', NULL, 'C.B.Clarke', 268),
(17875, 'Collabium', NULL, 'Blume', 123),
(17876, 'Collomia', NULL, 'Nutt.', 428),
(17877, 'Collospermum', NULL, 'Skottsb.', 227),
(17878, 'Colobanthus', NULL, 'Bartl.', 257),
(17879, 'Colpodium', NULL, 'Trin.', 131),
(17880, 'Columellia', NULL, 'Ruiz & Pav.', 267),
(17881, 'Colysis', NULL, 'C.Presl', 429),
(17882, 'Cometes', NULL, 'L.', 257),
(17883, 'Commelina', NULL, 'L.', 268),
(17884, 'Comospermum', NULL, 'Rauschert', 219),
(17885, 'Comparettia', NULL, 'Poepp. & Endl.', 123),
(17886, 'Comperia', NULL, 'K.Koch', 123),
(17887, 'Conanthera', NULL, 'Ruiz & Pav.', 477),
(17888, 'Condylago', NULL, 'Luer', 123),
(17889, 'Conicosia', NULL, 'N.E.Br.', 207),
(17890, 'Coniogramme', NULL, 'Fee', 202),
(17891, 'Connellia', NULL, 'N.E.Br.', 244),
(17892, 'Conophytum', NULL, 'N.E.Br.', 207),
(17893, 'Conostylis', NULL, 'R.Br.', 327),
(17894, 'Consolida', NULL, 'Gray', 441),
(17895, 'Constantia', NULL, 'Barb.Rodr.', 123),
(17896, 'Convallaria', NULL, 'L.', 269),
(17897, 'Coopernookia', NULL, 'Carolin', 319),
(17898, 'Copiapoa', NULL, 'Britton & Rose', 29),
(17899, 'Coptis', NULL, 'Salisb.', 441),
(17900, 'Coptophyllum', NULL, 'Korth.', 142),
(17901, 'Corallorrhiza', NULL, 'Gagnebin', 123),
(17902, 'Corbichonia', NULL, 'Scop.', 387),
(17903, 'Cordiglottis', NULL, 'J.J.Sm.', 123),
(17904, 'Coriaria', NULL, 'L.', 270),
(17905, 'Cornopteris', NULL, 'Nakai', 495),
(17906, 'Cornucopiae', NULL, 'L.', 131),
(17907, 'Corokia', NULL, 'A.Cunn.', 223),
(17908, 'Corpuscularia', NULL, 'Schwantes', 207),
(17909, 'Corrigiola', NULL, 'L.', 387),
(17910, 'Corryocactus', NULL, 'Britton & Rose', 29),
(17911, 'Corsia', NULL, 'Becc.', 271),
(17912, 'Cortaderia', NULL, 'Stapf', 131),
(17913, 'Cortusa', NULL, 'L.', 434),
(17914, 'Coryanthes', NULL, 'Hook.', 123),
(17915, 'Corybas', NULL, 'Salisb.', 123),
(17916, 'Corycium', NULL, 'Sw.', 123),
(17917, 'Corylopsis', NULL, 'Siebold & Zucc.', 330),
(17918, 'Corymborkis', NULL, 'Thouars', 123),
(17919, 'Corynaea', NULL, 'Hook.f.', 232),
(17920, 'Corynephorus', NULL, 'P.Beauv.', 131),
(17921, 'Corynocarpus', NULL, 'J.R.Forst. & G.Forst.', 272),
(17922, 'Corynotheca', NULL, 'F.Muell. ex Benth.', 219),
(17923, 'Coryphantha', NULL, '(Engelm.) Lem.', 29),
(17924, 'Coryphopteris', NULL, 'Holttum', 480),
(17925, 'Costus', NULL, 'L.', 273),
(17926, 'Cottea', NULL, 'Kunth', 131),
(17927, 'Cottendorfia', NULL, 'Schult.f.', 244),
(17928, 'Cottonia', NULL, 'Wight', 123),
(17929, 'Coveniella', NULL, 'Tindale', 296),
(17930, 'Cranichis', NULL, 'Sw.', 123),
(17931, 'Craniolaria', NULL, 'L.', 378),
(17932, 'Craspedorhachis', NULL, 'Benth.', 131),
(17933, 'Cremastra', NULL, 'Lindl.', 123),
(17934, 'Crepidomanes', NULL, '(C.Presl) C.Presl', 344),
(17935, 'Cribbia', NULL, 'Senghas', 123),
(17936, 'Criciuma', NULL, 'Soderstr. & Londono', 131),
(17937, 'Crinipes', NULL, 'Hochst.', 131),
(17938, 'Crinum', NULL, 'L.', 215),
(17939, 'Crispiloba', NULL, 'Steenis', 212),
(17940, 'Crithopsis', NULL, 'Jaub. & Spach', 131),
(17941, 'Crocosmia', NULL, 'Planch.', 349),
(17942, 'Crocus', NULL, 'L.', 349),
(17943, 'Croomia', NULL, 'Torr.', 470),
(17944, 'Crossosoma', NULL, 'Nutt.', 274),
(17945, 'Crybe', NULL, 'Lindl.', 123),
(17946, 'Crypsinus', NULL, 'C.Presl', 429),
(17947, 'Crypsis', NULL, 'Aiton', 131),
(17948, 'Cryptanthus', NULL, 'Otto & A.Dietr.', 244),
(17949, 'Cryptarrhena', NULL, 'R.Br.', 123),
(17950, 'Cryptocentrum', NULL, 'Benth.', 123),
(17951, 'Cryptochilus', NULL, 'Wall.', 123),
(17952, 'Cryptochloa', NULL, 'Swallen', 131),
(17953, 'Cryptogramma', NULL, 'R.Br.', 202),
(17954, 'Cryptophoranthus', NULL, 'Barb.Rodr.', 123),
(17955, 'Cryptopus', NULL, 'Lindl.', 123),
(17956, 'Cryptopylos', NULL, 'Garay', 123),
(17957, 'Cryptostephanus', NULL, 'Welw. ex Baker', 215),
(17958, 'Cryptostylis', NULL, 'R.Br.', 123),
(17959, 'Ctenitis', NULL, '(C.Chr.) C.Chr.', 296),
(17960, 'Ctenium', NULL, 'Panz.', 131),
(17961, 'Ctenopteris', NULL, 'Blume ex Kunze', 321),
(17962, 'Cucubalus', NULL, 'L.', 257),
(17963, 'Cuitlauzina', NULL, 'La Llave & Lex.', 123),
(17964, 'Culcita', NULL, 'C.Presl', 283),
(17965, 'Curculigo', NULL, 'Gaertn.', 347),
(17966, 'Curcuma', NULL, 'L.', 501),
(17967, 'Curcumorpha', NULL, 'A.S.Rao & D.M.Verma', 501),
(17968, 'Cuspidaria', NULL, 'DC.', 22),
(17969, 'Cutandia', NULL, 'Willk.', 131),
(17970, 'Cuttsia', NULL, 'F.Muell.', 449),
(17971, 'Cyanaeorchis', NULL, 'Barb.Rodr.', 123),
(17972, 'Cyanastrum', NULL, 'Oliv.', 477),
(17973, 'Cyanella', NULL, 'Royen ex L.', 477),
(17974, 'Cyanotis', NULL, 'D.Don', 268),
(17975, 'Cyathophylla', NULL, 'Bocquet & Strid', 257),
(17976, 'Cyathopus', NULL, 'Stapf', 131),
(17977, 'Cybebus', NULL, 'Garay', 123),
(17978, 'Cybistetes', NULL, 'Milne-Redh. & Schweick.', 215),
(17979, 'Cyclocheilon', NULL, 'Oliv.', 400),
(17980, 'Cyclodium', NULL, 'C.Presl', 296),
(17981, 'Cyclogramma', NULL, 'Tagawa', 480),
(17982, 'Cyclopeltis', NULL, 'J.Sm.', 296),
(17983, 'Cyclopogon', NULL, 'C.Presl', 123),
(17984, 'Cyclosorus', NULL, 'Link', 480),
(17985, 'Cyclostachya', NULL, 'Reeder & C.Reeder', 131),
(17986, 'Cycnoches', NULL, 'Lindl.', 123),
(17987, 'Cylindrophyllum', NULL, 'Schwantes', 207),
(17988, 'Cymbidiella', NULL, 'Rolfe', 123),
(17989, 'Cymbidium', NULL, 'Sw.', 123),
(17990, 'Cymbocarpa', NULL, 'Miers', 246),
(17991, 'Cymbopogon', NULL, 'Spreng.', 131),
(17992, 'Cymodocea', NULL, 'K.Koenig', 275),
(17993, 'Cynodon', NULL, 'Rich.', 131),
(17994, 'Cynomorium', NULL, 'L.', 276),
(17995, 'Cynorkis', NULL, 'Thouars', 123),
(17996, 'Cynosurus', NULL, 'L.', 131),
(17997, 'Cypella', NULL, 'Herb.', 349),
(17998, 'Cyperochloa', NULL, 'Lazarides & L.Watson', 131),
(17999, 'Cyphochilus', NULL, 'Schltr.', 123),
(18000, 'Cyphochlaena', NULL, 'Hack.', 131),
(18001, 'Cypholoron', NULL, 'Dodson & Dressler', 123),
(18002, 'Cyphostigma', NULL, 'Benth.', 501),
(18003, 'Cypripedium', NULL, 'L.', 123),
(18004, 'Cypselea', NULL, 'Turpin', 207),
(18005, 'Cypselocarpus', NULL, 'F.Muell.', 326),
(18006, 'Cyrtidiorchis', NULL, 'Rauschert', 123),
(18007, 'Cyrtococcum', NULL, 'Stapf', 131),
(18008, 'Cyrtomium', NULL, 'C.Presl', 296),
(18009, 'Cyrtopodium', NULL, 'R.Br.', 123),
(18010, 'Cyrtorchis', NULL, 'Schltr.', 123),
(18011, 'Cyrtosia', NULL, 'Blume', 123),
(18012, 'Cyrtostylis', NULL, 'R.Br.', 123),
(18013, 'Cystoathyrium', NULL, 'Ching', 495),
(18014, 'Cystodium', NULL, 'J.Sm.', 283),
(18015, 'Cystopteris', NULL, 'Bernh.', 495),
(18016, 'Cystorchis', NULL, 'Blume', 123),
(18017, 'Cytinus', NULL, 'L.', 277),
(18018, 'Dactylanthus', NULL, 'Hook.f.', 232),
(18019, 'Dactylis', NULL, 'L.', 131),
(18020, 'Dactyloctenium', NULL, 'Willd.', 131),
(18021, 'Dactylopsis', NULL, 'N.E.Br.', 207),
(18022, 'Dactylorhiza', NULL, 'Neck. ex Nevski', 123),
(18023, 'Dactylorhynchus', NULL, 'Schltr.', 123),
(18024, 'Dactylostalix', NULL, 'Rchb.f.', 123),
(18025, 'Daiswa', NULL, 'Raf.', 382),
(18026, 'Daknopholis', NULL, 'Clayton', 131),
(18027, 'Dalzellia', NULL, 'Wight', 427),
(18028, 'Damasonium', NULL, 'Mill.', 209),
(18029, 'Dampiera', NULL, 'R.Br.', 319),
(18030, 'Danae', NULL, 'Medik.', 451),
(18031, 'Danaea', NULL, 'Sm.', 376),
(18032, 'Dandya', NULL, 'H.E.Moore', 481),
(18033, 'Danthonia', NULL, 'DC.', 131),
(18034, 'Danthonidium', NULL, 'C.E.Hubb.', 131),
(18035, 'Danthoniopsis', NULL, 'Stapf', 131),
(18036, 'Darlingtonia', NULL, 'Torr.', 456),
(18037, 'Darwiniera', NULL, 'Braas & Luckel', 123),
(18038, 'Dasylirion', NULL, 'Zucc.', 293),
(18039, 'Dasypogon', NULL, 'R.Br.', 278),
(18040, 'Dasypyrum', NULL, '(Coss. & Durieu) T.Durand', 131),
(18041, 'Daubenya', NULL, 'Lindl.', 338),
(18042, 'Davallia', NULL, 'Sm.', 279),
(18043, 'Davallodes', NULL, '(Copel.) Copel.', 279),
(18044, 'Decaisnea', NULL, 'Hook.f. & Thomson', 359),
(18045, 'Decarya', NULL, 'Choux', 284),
(18046, 'Decaryella', NULL, 'A.Camus', 131),
(18047, 'Decaryochloa', NULL, 'A.Camus', 131),
(18048, 'Decumaria', NULL, 'L.', 341),
(18049, 'Degeneria', NULL, 'I.W.Bailey & A.C.Sm.', 280),
(18050, 'Degranvillea', NULL, 'Determann', 123),
(18051, 'Deinanthe', NULL, 'Maxim.', 341),
(18052, 'Deiregyne', NULL, 'Schltr.', 123),
(18053, 'Delosperma', NULL, 'N.E.Br.', 207),
(18054, 'Delphinium', NULL, 'L.', 441),
(18055, 'Dendrobium', NULL, 'Sw.', 123),
(18056, 'Dendrocalamus', NULL, 'Nees', 131),
(18057, 'Dendrochilum', NULL, 'Blume', 123),
(18058, 'Dendrophylax', NULL, 'Rchb.f.', 123),
(18059, 'Denmoza', NULL, 'Britton & Rose', 29),
(18060, 'Dennstaedtia', NULL, 'Bernh.', 281),
(18061, 'Deschampsia', NULL, 'P.Beauv.', 131),
(18062, 'Desmazeria', NULL, 'Dumort.', 131),
(18063, 'Desmostachya', NULL, '(Stapf) Stapf', 131),
(18064, 'Deuterocohnia', NULL, 'Mez', 244),
(18065, 'Deutzia', NULL, 'Thunb.', 341),
(18066, 'Devia', NULL, 'Goldblatt & J.C.Manning', 349),
(18067, 'Devillea', NULL, 'Tul. & Wedd.', 427),
(18068, 'Diacalpe', NULL, 'Blume', 296),
(18069, 'Diadenium', NULL, 'Poepp. & Endl.', 123),
(18070, 'Dialyceras', NULL, 'Capuron', 465),
(18071, 'Diandrolyra', NULL, 'Stapf', 131),
(18072, 'Dianella', NULL, 'Lam.', 335),
(18073, 'Dianthus', NULL, 'L.', 257),
(18074, 'Diapensia', NULL, 'L.', 282),
(18075, 'Diaphananthe', NULL, 'Schltr.', 123),
(18076, 'Diaphanoptera', NULL, 'Rech.f.', 257),
(18077, 'Diarrhena', NULL, 'P.Beauv.', 131),
(18078, 'Diaspasis', NULL, 'R.Br.', 319),
(18079, 'Diblemma', NULL, 'J.Sm.', 429),
(18080, 'Diceratostele', NULL, 'Summerh.', 123),
(18081, 'Dicerocaryum', NULL, 'Bojer', 406),
(18082, 'Dicerostylis', NULL, 'Blume', 123),
(18083, 'Dichaea', NULL, 'Lindl.', 123),
(18084, 'Dichaetaria', NULL, 'Nees ex Steud.', 131),
(18085, 'Dichanthium', NULL, 'Willemet', 131),
(18086, 'Dichelachne', NULL, 'Endl.', 131),
(18087, 'Dichelostemma', NULL, 'Kunth', 481),
(18088, 'Dicheranthus', NULL, 'Webb', 257),
(18089, 'Dichocarpum', NULL, 'W.T.Wang & P.K.Hsiao', 441),
(18090, 'Dichopogon', NULL, 'Kunth', 219),
(18091, 'Dichorisandra', NULL, 'J.C.Mikan', 268),
(18092, 'Dichroa', NULL, 'Lour.', 341),
(18093, 'Dichromanthus', NULL, 'Garay', 123),
(18094, 'Dickasonia', NULL, 'L.O.Williams', 123),
(18095, 'Dicoryphe', NULL, 'Thouars', 330),
(18096, 'Dicraeanthus', NULL, 'Engl.', 427),
(18097, 'Dicraeia', NULL, 'Thouars', 427),
(18098, 'Dicranoglossum', NULL, 'J.Sm.', 429),
(18099, 'Dicranopteris', NULL, 'Bernh.', 317),
(18100, 'Dicrocaulon', NULL, 'N.E.Br.', 207),
(18101, 'Dictymia', NULL, 'J.Sm.', 429),
(18102, 'Dictyolimon', NULL, 'Rech.f.', 426),
(18103, 'Dictyophyllaria', NULL, 'Garay', 123),
(18104, 'Dictyospermum', NULL, 'Wight', 268),
(18105, 'Dictyostega', NULL, 'Miers', 246),
(18106, 'Didiciea', NULL, 'King & Prain', 123),
(18107, 'Didierea', NULL, 'Baill.', 284),
(18108, 'Didymaotus', NULL, 'N.E.Br.', 207),
(18109, 'Didymeles', NULL, 'Thouars', 285),
(18110, 'Didymochlaena', NULL, 'Desv.', 296),
(18111, 'Didymoplexiella', NULL, 'Garay', 123),
(18112, 'Didymoplexis', NULL, 'Griff.', 123),
(18113, 'Diegodendron', NULL, 'Capuron', 286),
(18114, 'Diellia', NULL, 'Brack.', 226),
(18115, 'Dielsia', NULL, 'Gilg', 444),
(18116, 'Dielsiochloa', NULL, 'Pilg.', 131),
(18117, 'Dierama', NULL, 'K.Koch', 349),
(18118, 'Dietes', NULL, 'Salisb. ex Klatt', 349),
(18119, 'Digitaria', NULL, 'Haller', 131),
(18120, 'Diglyphosa', NULL, 'Blume', 123),
(18121, 'Dignathe', NULL, 'Lindl.', 123),
(18122, 'Dignathia', NULL, 'Stapf', 131),
(18123, 'Diheteropogon', NULL, '(Hack.) Stapf', 131),
(18124, 'Dilatris', NULL, 'Bergius', 327),
(18125, 'Dilochia', NULL, 'Lindl.', 123),
(18126, 'Dilomilis', NULL, 'Raf.', 123),
(18127, 'Dilophotriche', NULL, '(C.E.Hubb.) Jacq.-Fel.', 131),
(18128, 'Dimerandra', NULL, 'Schltr.', 123),
(18129, 'Dimeria', NULL, 'R.Br.', 131),
(18130, 'Dimerocostus', NULL, 'Kuntze', 273),
(18131, 'Dimorphorchis', NULL, 'Rolfe', 123),
(18132, 'Dinebra', NULL, 'Jacq.', 131),
(18133, 'Dinema', NULL, 'Lindl.', 123),
(18134, 'Dinklageella', NULL, 'Mansf.', 123),
(18135, 'Dinochloa', NULL, 'Buse', 131),
(18136, 'Dinteranthus', NULL, 'Schwantes', 207),
(18137, 'Dionaea', NULL, 'Ellis', 294),
(18138, 'Dioncophyllum', NULL, 'Baill.', 287),
(18139, 'Dionysia', NULL, 'Fenzl', 434),
(18140, 'Dioon', NULL, 'Lindl.', 499),
(18141, 'Diora', NULL, 'Ravenna', 219),
(18142, 'Diothonea', NULL, 'Lindl.', 123),
(18143, 'Dipcadi', NULL, 'Medik.', 338),
(18144, 'Dipentodon', NULL, 'Dunn', 288),
(18145, 'Diphylax', NULL, 'Hook.f.', 123),
(18146, 'Diphylleia', NULL, 'Michx.', 237),
(18147, 'Diplandrorchis', NULL, 'S.C.Chen', 123),
(18148, 'Diplarche', NULL, 'Hook.f. & Thomson', 282),
(18149, 'Diplarrhena', NULL, 'Labill.', 349),
(18150, 'Diplaziopsis', NULL, 'C.Chr.', 495),
(18151, 'Diplazium', NULL, 'Sw.', 495),
(18152, 'Diplobryum', NULL, 'C.Cusset', 427),
(18153, 'Diplocaulobium', NULL, '(Rchb.f.) Kraenzl.', 123),
(18154, 'Diplocentrum', NULL, 'Lindl.', 123),
(18155, 'Diplolabellum', NULL, 'F.Maek.', 123),
(18156, 'Diplomeris', NULL, 'D.Don', 123),
(18157, 'Diplopogon', NULL, 'R.Br.', 131),
(18158, 'Diploprora', NULL, 'Hook.f.', 123),
(18159, 'Diplopterygium', NULL, '(Diels) Nakai', 317),
(18160, 'Diplora', NULL, 'Baker', 226),
(18161, 'Diplosoma', NULL, 'Schwantes', 207),
(18162, 'Dipodium', NULL, 'R.Br.', 123),
(18163, 'Dipogon', NULL, 'Liebm.', 68),
(18164, 'Dipsacus', NULL, 'L.', 289),
(18165, 'Dipteranthus', NULL, 'Barb.Rodr.', 123),
(18166, 'Dipteris', NULL, 'Reinw.', 290),
(18167, 'Dipterostele', NULL, 'Schltr.', 123),
(18168, 'Dirachma', NULL, 'Schweinf. ex Balf.f.', 291),
(18169, 'Disa', NULL, 'Bergius', 123),
(18170, 'Disanthus', NULL, 'Maxim.', 330),
(18171, 'Discocactus', NULL, 'Pfeiff.', 29),
(18172, 'Discyphus', NULL, 'Schltr.', 123),
(18173, 'Disocactus', NULL, 'Lindl.', 29),
(18174, 'Disperis', NULL, 'Sw.', 123),
(18175, 'Disphyma', NULL, 'N.E.Br.', 207),
(18176, 'Disporopsis', NULL, 'Hance', 269),
(18177, 'Disporum', NULL, 'Salisb. ex D.Don', 266),
(18178, 'Dissanthelium', NULL, 'Trin.', 131),
(18179, 'Dissochondrus', NULL, '(W.F.Hillebr.) Kuntze', 131),
(18180, 'Disteganthus', NULL, 'Lem.', 244),
(18181, 'Distichia', NULL, 'Nees & Meyen', 355),
(18182, 'Distichlis', NULL, 'Raf.', 131),
(18183, 'Distyliopsis', NULL, 'P.K.Endress', 330),
(18184, 'Distylium', NULL, 'Siebold & Zucc.', 330),
(18185, 'Distylodon', NULL, 'Summerh.', 123),
(18186, 'Ditepalanthus', NULL, 'Fagerl.', 232),
(18187, 'Dithrix', NULL, 'Schltr.', 123),
(18188, 'Diuris', NULL, 'Sm.', 123),
(18189, 'Djinga', NULL, 'C.Cusset', 427),
(18190, 'Dobera', NULL, 'Juss.', 452),
(18191, 'Dodecatheon', NULL, 'L.', 434),
(18192, 'Dodsonia', NULL, 'Ackerman', 123),
(18193, 'Domingoa', NULL, 'Schltr.', 123),
(18194, 'Donatia', NULL, 'J.R.Forst. & G.Forst.', 474),
(18195, 'Doodia', NULL, 'R.Br.', 240),
(18196, 'Doritis', NULL, 'Lindl.', 123),
(18197, 'Dorotheanthus', NULL, 'Schwantes', 207),
(18198, 'Doryanthes', NULL, 'Correa', 292),
(18199, 'Doryopteris', NULL, 'J.Sm.', 202),
(18200, 'Dossinia', NULL, 'C.Morren', 123),
(18201, 'Dovea', NULL, 'Kunth', 444),
(18202, 'Dracophilus', NULL, '(Schwantes) Dinter & Schwantes', 207),
(18203, 'Dracula', NULL, 'Luer', 123),
(18204, 'Drakaea', NULL, 'Lindl.', 123),
(18205, 'Drake-Brockmania', NULL, 'Stapf', 131),
(18206, 'Dregeochloa', NULL, 'Conert', 131),
(18207, 'Dresslerella', NULL, 'Luer', 123),
(18208, 'Dressleria', NULL, 'Dodson', 123),
(18209, 'Drimia', NULL, 'Jacq. ex Willd.', 338),
(18210, 'Drimiopsis', NULL, 'Lindl. & Paxton', 338),
(18211, 'Drosanthemopsis', NULL, 'Rauschert', 207),
(18212, 'Drosanthemum', NULL, 'Schwantes', 207),
(18213, 'Drosera', NULL, 'L.', 294),
(18214, 'Drosophyllum', NULL, 'Link', 295),
(18215, 'Dryadella', NULL, 'Luer', 123),
(18216, 'Dryadorchis', NULL, 'Schltr.', 123),
(18217, 'Drymaria', NULL, 'Willd. ex Schult.', 257),
(18218, 'Drymoanthus', NULL, 'Nicholls', 123),
(18219, 'Drymoda', NULL, 'Lindl.', 123),
(18220, 'Drymophila', NULL, 'R.Br.', 269),
(18221, 'Drymotaenium', NULL, 'Makino', 429),
(18222, 'Drynaria', NULL, '(Bory) J.Sm.', 429),
(18223, 'Dryopoa', NULL, 'Vickery', 131),
(18224, 'Dryopolystichum', NULL, 'Copel.', 296),
(18225, 'Dryopsis', NULL, 'Holttum & P.J.Edwards', 296),
(18226, 'Dryopteris', NULL, 'Adans.', 296),
(18227, 'Drypis', NULL, 'L.', 257),
(18228, 'Duboisia', NULL, 'R.Br.', 154),
(18229, 'Duckea', NULL, 'Maguire', 442),
(18230, 'Duckeella', NULL, 'Porto', 123),
(18231, 'Dunstervillea', NULL, 'Garay', 123),
(18232, 'Dupontia', NULL, 'R.Br.', 131),
(18233, 'Duthiastrum', NULL, 'M.P.de Vos', 349),
(18234, 'Duthiea', NULL, 'Hack.', 131),
(18235, 'Dyakia', NULL, 'Christenson', 123),
(18236, 'Dyckia', NULL, 'Schult.f.', 244),
(18237, 'Dyerophytum', NULL, 'Kuntze', 426),
(18238, 'Dysosma', NULL, 'Woodson', 237),
(18239, 'Earina', NULL, 'Lindl.', 123),
(18240, 'Eberlanzia', NULL, 'Schwantes', 207),
(18241, 'Ebracteola', NULL, 'Dinter & Schwantes', 207),
(18242, 'Eccoptocarpha', NULL, 'Launert', 131),
(18243, 'Eccremis', NULL, 'Baker', 335),
(18244, 'Ecdeiocolea', NULL, 'F.Muell.', 297),
(18245, 'Echinaria', NULL, 'Desf.', 131),
(18246, 'Echinocactus', NULL, 'Link & Otto', 29),
(18247, 'Echinocereus', NULL, 'Engelm.', 29),
(18248, 'Echinochloa', NULL, 'P.Beauv.', 131),
(18249, 'Echinodorus', NULL, 'Rich. ex Engelm.', 209),
(18250, 'Echinolaena', NULL, 'Desv.', 131),
(18251, 'Echinopogon', NULL, 'P.Beauv.', 131),
(18252, 'Echinopsis', NULL, 'Zucc.', 29),
(18253, 'Ectrosia', NULL, 'R.Br.', 131),
(18254, 'Ectrosiopsis', NULL, '(Ohwi) Jansen', 131),
(18255, 'Egeria', NULL, 'Planch.', 342),
(18256, 'Eggelingia', NULL, 'Summerh.', 123),
(18257, 'Ehrharta', NULL, 'Thunb.', 131),
(18258, 'Eichhornia', NULL, 'Kunth', 430),
(18259, 'Ekmanochloa', NULL, 'Hitchc.', 131),
(18260, 'Elaeagnus', NULL, 'L.', 298),
(18261, 'Elaphoglossum', NULL, 'Schott ex J.Sm.', 369),
(18262, 'Elasis', NULL, 'D.R.Hunt', 268),
(18263, 'Elatine', NULL, 'L.', 299),
(18264, 'Elegia', NULL, 'L.', 444),
(18265, 'Eleorchis', NULL, 'F.Maek.', 123),
(18266, 'Elettaria', NULL, 'Maton', 501),
(18267, 'Elettariopsis', NULL, 'Baker', 501),
(18268, 'Eleusine', NULL, 'Gaertn.', 131),
(18269, 'Eleutherine', NULL, 'Herb.', 349),
(18270, 'Elionurus', NULL, 'Humb. & Bonpl. ex Willd.', 131),
(18271, 'Elisena', NULL, 'Herb.', 215),
(18272, 'Elleanthus', NULL, 'C.Presl', 123),
(18273, 'Elodea', NULL, 'Michx.', 342),
(18274, 'Elymandra', NULL, 'Stapf', 131),
(18275, 'Elymus', NULL, 'L.', 131),
(18276, 'Elythranthera', NULL, '(Endl.) A.S.George', 123),
(18277, 'Elytrophorus', NULL, 'P.Beauv.', 131),
(18278, 'Elytrostachys', NULL, 'McClure', 131),
(18279, 'Emblingia', NULL, 'F.Muell.', 300),
(18280, 'Embolanthera', NULL, 'Merr.', 330),
(18281, 'Embreea', NULL, 'Dodson', 123),
(18282, 'Empodisma', NULL, 'L.A.S.Johnson & D.F.Cutler', 444),
(18283, 'Empodium', NULL, 'Salisb.', 347),
(18284, 'Enarganthe', NULL, 'N.E.Br.', 207),
(18285, 'Encephalartos', NULL, 'Lehm.', 499),
(18286, 'Encholirium', NULL, 'Mart. ex Schult.f.', 244),
(18287, 'Encyclia', NULL, 'Hook.', 123),
(18288, 'Endocaulos', NULL, 'C.Cusset', 427),
(18289, 'Endonema', NULL, 'A.Juss.', 407),
(18290, 'Endresiella', NULL, 'Schltr.', 123),
(18291, 'Enemion', NULL, 'Raf.', 441),
(18292, 'Enhalus', NULL, 'Rich.', 342),
(18293, 'Enhydrias', NULL, 'Ridl.', 342),
(18294, 'Ennealophus', NULL, 'N.E.Br.', 349),
(18295, 'Enneapogon', NULL, 'Desv. ex P.Beauv.', 131),
(18296, 'Enteropogon', NULL, 'Nees', 131),
(18297, 'Entolasia', NULL, 'Stapf', 131),
(18298, 'Entomophobia', NULL, 'de Vogel', 123),
(18299, 'Entoplocamia', NULL, 'Stapf', 131),
(18300, 'Eparmatostigma', NULL, 'Garay', 123),
(18301, 'Ephedra', NULL, 'L.', 301),
(18302, 'Ephippianthus', NULL, 'Rchb.f.', 123),
(18303, 'Epiblastus', NULL, 'Schltr.', 123),
(18304, 'Epiblema', NULL, 'R.Br.', 123),
(18305, 'Epidanthus', NULL, 'L.O.Williams', 123),
(18306, 'Epidendropsis', NULL, 'Garay & Dunst.', 123),
(18307, 'Epidendrum', NULL, 'L.', 123),
(18308, 'Epidryos', NULL, 'Maguire', 442),
(18309, 'Epigeneium', NULL, 'Gagnep.', 123),
(18310, 'Epimedium', NULL, 'L.', 237),
(18311, 'Epipactis', NULL, 'Zinn', 123),
(18312, 'Epiphyllum', NULL, 'Haw.', 29),
(18313, 'Epipogium', NULL, 'Borkh.', 123),
(18314, 'Epistephium', NULL, 'Kunth', 123),
(18315, 'Epithelantha', NULL, 'F.A.C.Weber ex Britton & Rose', 29),
(18316, 'Equisetum', NULL, 'L.', 302),
(18317, 'Eragrostiella', NULL, 'Bor', 131),
(18318, 'Eragrostis', NULL, 'Wolf', 131),
(18319, 'Eranthis', NULL, 'Salisb.', 441),
(18320, 'Eremitis', NULL, 'Doll', 131),
(18321, 'Eremocaulon', NULL, 'Soderstr. & Londono', 131),
(18322, 'Eremochloa', NULL, 'Buse', 131),
(18323, 'Eremocrinum', NULL, 'M.E.Jones', 219),
(18324, 'Eremolaena', NULL, 'Baill.', 455),
(18325, 'Eremopoa', NULL, 'Roshev.', 131),
(18326, 'Eremopyrum', NULL, '(Ledeb.) Jaub. & Spach', 131),
(18327, 'Eremosyne', NULL, 'Endl.', 303),
(18328, 'Eremurus', NULL, 'M.Bieb.', 225),
(18329, 'Erepsia', NULL, 'N.E.Br.', 207),
(18330, 'Eria', NULL, 'Lindl.', 123),
(18331, 'Eriachne', NULL, 'R.Br.', 131),
(18332, 'Erianthecium', NULL, 'Parodi', 131),
(18333, 'Eriastrum', NULL, 'Wooton & Standl.', 428),
(18334, 'Eriaxis', NULL, 'Rchb.f.', 123),
(18335, 'Erinna', NULL, 'Phil.', 210),
(18336, 'Eriocaulon', NULL, 'L.', 304),
(18337, 'Eriochilus', NULL, 'R.Br.', 123),
(18338, 'Eriochloa', NULL, 'Kunth', 131),
(18339, 'Eriochrysis', NULL, 'P.Beauv.', 131),
(18340, 'Eriodes', NULL, 'Rolfe', 123),
(18341, 'Erioneuron', NULL, 'Nash', 131),
(18342, 'Eriopsis', NULL, 'Lindl.', 123),
(18343, 'Eriosorus', NULL, 'Fee', 202),
(18344, 'Eriospermum', NULL, 'Jacq. ex Willd.', 305),
(18345, 'Eriosyce', NULL, 'Phil.', 29),
(18346, 'Erodium', NULL, 'L''Her. ex Aiton', 314),
(18347, 'Erucaria', NULL, 'Gaertn.', 197),
(18348, 'Erycina', NULL, 'Lindl.', 123),
(18349, 'Erythrodes', NULL, 'Blume', 123),
(18350, 'Erythrorchis', NULL, 'Blume', 123),
(18351, 'Escallonia', NULL, 'Mutis ex L.f.', 306),
(18352, 'Escobaria', NULL, 'Britton & Rose', 29),
(18353, 'Escontria', NULL, 'Rose', 29),
(18354, 'Esmeralda', NULL, 'Rchb.f.', 123),
(18355, 'Espostoa', NULL, 'Britton & Rose', 29),
(18356, 'Espostoopsis', NULL, 'Buxb.', 29),
(18357, 'Esterhuysenia', NULL, 'L.Bolus', 207),
(18358, 'Etlingera', NULL, 'Giseke', 501),
(18359, 'Euanthe', NULL, 'Schltr.', 123),
(18360, 'Eucharis', NULL, 'Planch. & Linden', 215),
(18361, 'Euclasta', NULL, 'Franch.', 131),
(18362, 'Eucnide', NULL, 'Zucc.', 367),
(18363, 'Eucomis', NULL, 'L''Her.', 338),
(18364, 'Eucommia', NULL, 'Oliv.', 307),
(18365, 'Eucosia', NULL, 'Blume', 123),
(18366, 'Eucrosia', NULL, 'Ker Gawl.', 215),
(18367, 'Eulalia', NULL, 'Kunth', 131),
(18368, 'Eulaliopsis', NULL, 'Honda', 131),
(18369, 'Eulophia', NULL, 'R.Br. ex Lindl.', 123),
(18370, 'Eulophiella', NULL, 'Rolfe', 123),
(18371, 'Eulychnia', NULL, 'Phil.', 29),
(18372, 'Eupomatia', NULL, 'R.Br.', 308),
(18373, 'Euptelea', NULL, 'Siebold & Zucc.', 309),
(18374, 'Euryale', NULL, 'Salisb.', 395),
(18375, 'Eurycentrum', NULL, 'Schltr.', 123),
(18376, 'Eurychone', NULL, 'Schltr.', 123),
(18377, 'Eurylobium', NULL, 'Hochst.', 471),
(18378, 'Eurynotia', NULL, 'R.C.Foster', 349),
(18379, 'Eurystemon', NULL, 'Alexander', 430),
(18380, 'Eurystyles', NULL, 'Wawra', 123),
(18381, 'Eustachys', NULL, 'Desv.', 131),
(18382, 'Eustephia', NULL, 'Cav.', 215),
(18383, 'Eustigma', NULL, 'Gardner & Champ.', 330),
(18384, 'Eustrephus', NULL, 'R.Br.', 360),
(18385, 'Euthryptochloa', NULL, 'Cope', 131),
(18386, 'Euthystachys', NULL, 'A.DC.', 471),
(18387, 'Evrardianthe', NULL, 'Rauschert', 123),
(18388, 'Exbucklandia', NULL, 'R.W.Br.', 330),
(18389, 'Exorhopala', NULL, 'Steenis', 232),
(18390, 'Exotheca', NULL, 'Andersson', 131),
(18391, 'Facheiroa', NULL, 'Britton & Rose', 29),
(18392, 'Fadyenia', NULL, 'Hook.', 296),
(18393, 'Famatina', NULL, 'Ravenna', 215),
(18394, 'Farmeria', NULL, 'Willis ex Trimen', 427),
(18395, 'Farrago', NULL, 'Clayton', 131),
(18396, 'Fascicularia', NULL, 'Mez', 244),
(18397, 'Faucaria', NULL, 'Schwantes', 207),
(18398, 'Fedia', NULL, 'Gaertn.', 491),
(18399, 'Fendlera', NULL, 'Engelm. & A.Gray', 341),
(18400, 'Fendlerella', NULL, 'A.Heller', 341),
(18401, 'Fenestraria', NULL, 'N.E.Br.', 207),
(18402, 'Fernandezia', NULL, 'Ruiz & Pav.', 123),
(18403, 'Fernseea', NULL, 'Baker', 244),
(18404, 'Ferocactus', NULL, 'Britton & Rose', 29),
(18405, 'Ferraria', NULL, 'Burm. ex Mill.', 349),
(18406, 'Festuca', NULL, 'L.', 131),
(18407, 'Fieldia', NULL, 'A.Cunn.', 76),
(18408, 'Fingerhuthia', NULL, 'Nees', 131),
(18409, 'Flagellaria', NULL, 'L.', 310),
(18410, 'Flickingeria', NULL, 'A.D.Hawkes', 123),
(18411, 'Floerkea', NULL, 'Willd.', 365),
(18412, 'Floscopa', NULL, 'Lour.', 268),
(18413, 'Forficaria', NULL, 'Lindl.', 123),
(18414, 'Forgesia', NULL, 'Comm. ex Juss.', 306),
(18415, 'Forstera', NULL, 'L.f.', 474),
(18416, 'Fortunatia', NULL, 'J.F.Macbr.', 338),
(18417, 'Fortunearia', NULL, 'Rehder & E.H.Wilson', 330),
(18418, 'Fosterella', NULL, 'L.B.Sm.', 244),
(18419, 'Fosteria', NULL, 'Molseed', 349),
(18420, 'Fothergilla', NULL, 'L.', 330),
(18421, 'Fouquieria', NULL, 'Kunth', 311),
(18422, 'Frailea', NULL, 'Britton & Rose', 29),
(18423, 'Frankenia', NULL, 'L.', 312),
(18424, 'Freesia', NULL, 'Eckl. ex Klatt', 349),
(18425, 'Fregea', NULL, 'Rchb.f.', 123),
(18426, 'Frithia', NULL, 'N.E.Br.', 207),
(18427, 'Froesiochloa', NULL, 'G.A.Black', 131),
(18428, 'Frondaria', NULL, 'Luer', 123),
(18429, 'Fuertesia', NULL, 'Urb.', 367),
(18430, 'Fuertesiella', NULL, 'Schltr.', 123),
(18431, 'Fumana', NULL, '(Dunal) Spach', 265),
(18432, 'Gagnepainia', NULL, 'K.Schum.', 501),
(18433, 'Gaimardia', NULL, 'Gaudich.', 258),
(18434, 'Galanthus', NULL, 'L.', 215),
(18435, 'Galax', NULL, 'Sims', 282),
(18436, 'Galaxia', NULL, 'Thunb.', 349),
(18437, 'Galbulimima', NULL, 'F.M.Bailey', 337),
(18438, 'Galeandra', NULL, 'Lindl.', 123),
(18439, 'Galearis', NULL, 'Raf.', 123),
(18440, 'Galenia', NULL, 'L.', 207),
(18441, 'Galeola', NULL, 'Lour.', 123),
(18442, 'Galtonia', NULL, 'Decne.', 338),
(18443, 'Gamocarpha', NULL, 'DC.', 251),
(18444, 'Garaventia', NULL, 'Looser', 210),
(18445, 'Garnotia', NULL, 'Brongn.', 131),
(18446, 'Gasteria', NULL, 'Duval', 211),
(18447, 'Gastridium', NULL, 'P.Beauv.', 131),
(18448, 'Gastrochilus', NULL, 'D.Don', 123),
(18449, 'Gastrodia', NULL, 'R.Br.', 123),
(18450, 'Gaudinia', NULL, 'P.Beauv.', 131),
(18451, 'Gavilea', NULL, 'Poepp.', 123),
(18452, 'Geesinkorchis', NULL, 'de Vogel', 123),
(18453, 'Geissoloma', NULL, 'Lindl. ex Kunth', 313),
(18454, 'Geissorhiza', NULL, 'Ker Gawl.', 349),
(18455, 'Geitonoplesium', NULL, 'A.Cunn. ex R.Br.', 335),
(18456, 'Gelasine', NULL, 'Herb.', 349),
(18457, 'Gemmaria', NULL, 'Salisb.', 215),
(18458, 'Genlisea', NULL, 'A.St.-Hil.', 363),
(18459, 'Gennaria', NULL, 'Parl.', 123),
(18460, 'Genoplesium', NULL, 'R.Br.', 123),
(18461, 'Genyorchis', NULL, 'Schltr.', 123),
(18462, 'Geoblasta', NULL, 'Barb.Rodr.', 123),
(18463, 'Geocarpon', NULL, 'Mack.', 257),
(18464, 'Geocharis', NULL, '(K.Schum.) Ridl.', 501),
(18465, 'Geodorum', NULL, 'Jacks.', 123),
(18466, 'Geogenanthus', NULL, 'Ule', 268),
(18467, 'Geomitra', NULL, 'Becc.', 246),
(18468, 'Geosiris', NULL, 'Baill.', 349),
(18469, 'Geostachys', NULL, '(Baker) Ridl.', 501),
(18470, 'Geranium', NULL, 'L.', 314),
(18471, 'Germainia', NULL, 'Balansa & Poitr.', 131),
(18472, 'Gethyllis', NULL, 'L.', 215),
(18473, 'Gethyum', NULL, 'Phil.', 210),
(18474, 'Ghaznianthus', NULL, 'Lincz.', 426),
(18475, 'Gibasis', NULL, 'Raf.', 268),
(18476, 'Gibasoides', NULL, 'D.R.Hunt', 268),
(18477, 'Gibbaeum', NULL, 'Haw.', 207),
(18478, 'Gigantochloa', NULL, 'Kurz ex Munro', 131),
(18479, 'Gilgiochloa', NULL, 'Pilg.', 131),
(18480, 'Gilia', NULL, 'Ruiz & Pav.', 428),
(18481, 'Gilliesia', NULL, 'Lindl.', 210),
(18482, 'Ginkgo', NULL, 'L.', 315),
(18483, 'Gisekia', NULL, 'L.', 316),
(18484, 'Gladiolimon', NULL, 'Mobayen', 426),
(18485, 'Gladiolus', NULL, 'L.', 349),
(18486, 'Glaphyropteridopsis', NULL, 'Ching', 480),
(18487, 'Glaphyropteris', NULL, '(Fee) C.Presl ex Fee', 480),
(18488, 'Glaucidium', NULL, 'Siebold & Zucc.', 441),
(18489, 'Glaziophyton', NULL, 'Franch.', 131),
(18490, 'Gleichenia', NULL, 'Sm.', 317),
(18491, 'Glinus', NULL, 'L.', 387),
(18492, 'Glischrocaryon', NULL, 'Endl.', 329),
(18493, 'Glischrocolla', NULL, '(Endl.) A.DC.', 407),
(18494, 'Glischrothamnus', NULL, 'Pilg.', 387),
(18495, 'Globba', NULL, 'L.', 501),
(18496, 'Globularia', NULL, 'L.', 423),
(18497, 'Glomera', NULL, 'Blume', 123),
(18498, 'Glomeropitcairnia', NULL, 'Mez', 244),
(18499, 'Gloriosa', NULL, 'L.', 266),
(18500, 'Glossodia', NULL, 'R.Br.', 123),
(18501, 'Glossopetalon', NULL, 'A.Gray', 274),
(18502, 'Glossorhyncha', NULL, 'Ridl.', 123),
(18503, 'Glottiphyllum', NULL, 'Haw.', 207),
(18504, 'Glyceria', NULL, 'R.Br.', 131),
(18505, 'Glyphochloa', NULL, 'Clayton', 131),
(18506, 'Glyphotaenium', NULL, 'J.Sm.', 321),
(18507, 'Gomesa', NULL, 'R.Br.', 123),
(18508, 'Gomortega', NULL, 'Ruiz & Pav.', 318),
(18509, 'Gomphichis', NULL, 'Lindl.', 123),
(18510, 'Gonatostylis', NULL, 'Schltr.', 123),
(18511, 'Gongora', NULL, 'Ruiz & Pav.', 123),
(18512, 'Goniochilus', NULL, 'M.W.Chase', 123),
(18513, 'Goniolimon', NULL, 'Boiss.', 426),
(18514, 'Goniophlebium', NULL, 'C.Presl', 429),
(18515, 'Goniopteris', NULL, 'C.Presl', 480),
(18516, 'Gonioscypha', NULL, 'Baker', 269),
(18517, 'Gonocarpus', NULL, 'Thunb.', 329),
(18518, 'Goodenia', NULL, 'Sm.', 319),
(18519, 'Goodyera', NULL, 'R.Br.', 123),
(18520, 'Gouinia', NULL, 'E.Fourn.', 131),
(18521, 'Goupia', NULL, 'Aubl.', 320),
(18522, 'Govenia', NULL, 'Lindl.', 123),
(18523, 'Grafia', NULL, 'Rchb.', 9),
(18524, 'Grahamia', NULL, 'Gillies ex Hook. & Arn.', 431),
(18525, 'Grammangis', NULL, 'Rchb.f.', 123),
(18526, 'Grammatophyllum', NULL, 'Blume', 123),
(18527, 'Grammatopteridium', NULL, 'Alderw.', 429),
(18528, 'Grammitis', NULL, 'Sw.', 321),
(18529, 'Graphephorum', NULL, 'Desv.', 131),
(18530, 'Graphorkis', NULL, 'Thouars', 123),
(18531, 'Greenwoodia', NULL, 'Burns-Bal.', 123),
(18532, 'Greigia', NULL, 'Regel', 244),
(18533, 'Greslania', NULL, 'Balansa', 131),
(18534, 'Grevea', NULL, 'Baill.', 388),
(18535, 'Grielum', NULL, 'L.', 394),
(18536, 'Griffinia', NULL, 'Ker Gawl.', 215),
(18537, 'Griffithella', NULL, '(Tul.) Warm.', 427),
(18538, 'Griffithsochloa', NULL, 'G.J.Pierce', 131),
(18539, 'Griselinia', NULL, 'J.R.Forst. & G.Forst.', 322),
(18540, 'Grobya', NULL, 'Lindl.', 123),
(18541, 'Groenlandia', NULL, 'J.Gay', 433),
(18542, 'Gronovia', NULL, 'L.', 367),
(18543, 'Grosourdya', NULL, 'Rchb.f.', 123),
(18544, 'Grubbia', NULL, 'Bergius', 324),
(18545, 'Guacamaya', NULL, 'Maguire', 442),
(18546, 'Guaduella', NULL, 'Franch.', 131),
(18547, 'Guilfoylia', NULL, 'F.Muell.', 475),
(18548, 'Gunnarella', NULL, 'Senghas', 123),
(18549, 'Gunnera', NULL, 'L.', 325),
(18550, 'Gunniopsis', NULL, 'Pax', 207),
(18551, 'Guthriea', NULL, 'Bolus', 198),
(18552, 'Guzmania', NULL, 'Ruiz & Pav.', 244),
(18553, 'Gymnadenia', NULL, 'R.Br.', 123),
(18554, 'Gymnocalycium', NULL, 'Pfeiff.', 29),
(18555, 'Gymnocarpium', NULL, 'Newman', 495),
(18556, 'Gymnocarpos', NULL, 'Forssk.', 257),
(18557, 'Gymnochilus', NULL, 'Blume', 123),
(18558, 'Gymnogrammitis', NULL, 'Griff.', 279),
(18559, 'Gymnopogon', NULL, 'P.Beauv.', 131),
(18560, 'Gymnopteris', NULL, 'Bernh.', 202),
(18561, 'Gymnosiphon', NULL, 'Blume', 246),
(18562, 'Gymnospermium', NULL, 'Spach', 237),
(18563, 'Gymnosteris', NULL, 'Greene', 428),
(18564, 'Gymnotheca', NULL, 'Decne.', 457),
(18565, 'Gynandriris', NULL, 'Parl.', 349),
(18566, 'Gynerium', NULL, 'P.Beauv.', 131),
(18567, 'Gynoglottis', NULL, 'J.J.Sm.', 123),
(18568, 'Gypsophila', NULL, 'L.', 257),
(18569, 'Gyrostemon', NULL, 'Desf.', 326),
(18570, 'Haageocereus', NULL, 'Backeb.', 29),
(18571, 'Habenaria', NULL, 'Willd.', 123),
(18572, 'Habranthus', NULL, 'Herb.', 215),
(18573, 'Habrochloa', NULL, 'C.E.Hubb.', 131),
(18574, 'Habropetalum', NULL, 'Airy Shaw', 287),
(18575, 'Habrosia', NULL, 'Fenzl', 257),
(18576, 'Hachettea', NULL, 'Baill.', 232),
(18577, 'Hackelochloa', NULL, 'Kuntze', 131),
(18578, 'Haemanthus', NULL, 'L.', 215),
(18579, 'Haemodorum', NULL, 'Sm.', 327),
(18580, 'Hagenbachia', NULL, 'Nees & Mart.', 219),
(18581, 'Hagsatera', NULL, 'Tamayo', 123),
(18582, 'Hainardia', NULL, 'Greuter', 131),
(18583, 'Hakonechloa', NULL, 'Makino ex Honda', 131),
(18584, 'Halerpestes', NULL, 'Greene', 441),
(18585, 'Halimium', NULL, '(Dunal) Spach', 265),
(18586, 'Hallianthus', NULL, 'H.E.K.Hartmann', 207),
(18587, 'Halodule', NULL, 'Endl.', 275),
(18588, 'Halophila', NULL, 'Thouars', 342),
(18589, 'Halophytum', NULL, 'Speg.', 328),
(18590, 'Halopyrum', NULL, 'Stapf', 131),
(18591, 'Haloragis', NULL, 'J.R.Forst. & G.Forst.', 329),
(18592, 'Haloragodendron', NULL, 'Orchard', 329),
(18593, 'Hamadryas', NULL, 'Comm. ex Juss.', 441),
(18594, 'Hamamelis', NULL, 'L.', 330),
(18595, 'Hammarbya', NULL, 'Kuntze', 123),
(18596, 'Hancockia', NULL, 'Rolfe', 123),
(18597, 'Hanguana', NULL, 'Blume', 331),
(18598, 'Haniffia', NULL, 'Holttum', 501),
(18599, 'Hannonia', NULL, 'Braun-Blanq. & Maire', 215),
(18600, 'Hapalorchis', NULL, 'Schltr.', 123),
(18601, 'Haplochorema', NULL, 'K.Schum.', 501),
(18602, 'Haplothismia', NULL, 'Airy Shaw', 246),
(18603, 'Haptanthus', NULL, 'Goldberg & C. Nelson', 332),
(18604, 'Haraella', NULL, 'Kudo', 123),
(18605, 'Harpachne', NULL, 'Hochst. ex A.Rich.', 131),
(18606, 'Harpagophytum', NULL, 'DC. ex Meisn.', 406),
(18607, 'Harperia', NULL, 'W.Fitzg.', 444),
(18608, 'Harperocallis', NULL, 'McDaniel', 483),
(18609, 'Harpochloa', NULL, 'Kunth', 131),
(18610, 'Harrisella', NULL, 'Fawc. & Rendle', 123),
(18611, 'Harrisia', NULL, 'Britton', 29),
(18612, 'Hastingsia', NULL, 'S.Watson', 338),
(18613, 'Hatiora', NULL, 'Britton & Rose', 29),
(18614, 'Haworthia', NULL, 'Duval', 211),
(18615, 'Haya', NULL, 'Balf.f.', 257),
(18616, 'Haylockia', NULL, 'Herb.', 215),
(18617, 'Hechtia', NULL, 'Klotzsch', 244),
(18618, 'Hecistopteris', NULL, 'J.Sm.', 492),
(18619, 'Hectorella', NULL, 'Hook.f.', 333),
(18620, 'Hederorkis', NULL, 'Thouars', 123),
(18621, 'Hedychium', NULL, 'J.Konig', 501),
(18622, 'Helcia', NULL, 'Lindl.', 123),
(18623, 'Heliamphora', NULL, 'Benth.', 456),
(18624, 'Helianthemum', NULL, 'Mill.', 265),
(18625, 'Helictotrichon', NULL, 'Besser', 131),
(18626, 'Helleborus', NULL, 'L.', 441),
(18627, 'Helleriella', NULL, 'A.D.Hawkes', 123),
(18628, 'Helmholtzia', NULL, 'F.Muell.', 416),
(18629, 'Helminthostachys', NULL, 'Kaulf.', 399),
(18630, 'Helonias', NULL, 'L.', 382),
(18631, 'Heloniopsis', NULL, 'A.Gray', 382),
(18632, 'Helonoma', NULL, 'Garay', 123),
(18633, 'Helosis', NULL, 'Rich.', 232),
(18634, 'Helwingia', NULL, 'Willd.', 334),
(18635, 'Hemarthria', NULL, 'R.Br.', 131),
(18636, 'Hemerocallis', NULL, 'L.', 335),
(18637, 'Hemidictyum', NULL, 'C.Presl', 495),
(18638, 'Hemionitis', NULL, 'L.', 202),
(18639, 'Hemiorchis', NULL, 'Kurz', 501),
(18640, 'Hemiphylacus', NULL, 'S.Watson', 224),
(18641, 'Hemipilia', NULL, 'Lindl.', 123),
(18642, 'Hemiscleria', NULL, 'Lindl.', 123),
(18643, 'Hemisorghum', NULL, 'C.E.Hubb. ex Bor', 131),
(18644, 'Henrardia', NULL, 'C.E.Hubb.', 131),
(18645, 'Hensmania', NULL, 'W.Fitzg.', 219),
(18646, 'Hepatica', NULL, 'Mill.', 441),
(18647, 'Herbertia', NULL, 'Sweet', 349),
(18648, 'Hereroa', NULL, '(Schwantes) Dinter & Schwantes', 207),
(18649, 'Herminium', NULL, 'L.', 123),
(18650, 'Hermodactylus', NULL, 'Mill.', 349),
(18651, 'Herniaria', NULL, 'L.', 257),
(18652, 'Herpolirion', NULL, 'Hook.f.', 219),
(18653, 'Herpysma', NULL, 'Lindl.', 123),
(18654, 'Herreanthus', NULL, 'Schwantes', 207),
(18655, 'Herschelianthe', NULL, 'Rauschert', 123),
(18656, 'Hesperantha', NULL, 'Ker Gawl.', 349),
(18657, 'Hesperocallis', NULL, 'A.Gray', 336),
(18658, 'Hesperoxiphion', NULL, 'Baker', 349),
(18659, 'Hessea', NULL, 'Herb.', 215),
(18660, 'Hetaeria', NULL, 'Blume', 123),
(18661, 'Heterachne', NULL, 'Benth.', 131),
(18662, 'Heteranthelium', NULL, 'Jaub. & Spach', 131),
(18663, 'Heteranthera', NULL, 'Ruiz & Pav.', 430),
(18664, 'Heteranthoecia', NULL, 'Stapf', 131),
(18665, 'Heterogonium', NULL, 'C.Presl', 296),
(18666, 'Heteropholis', NULL, 'C.E.Hubb.', 131),
(18667, 'Heteropogon', NULL, 'Pers.', 131),
(18668, 'Heterotristicha', NULL, 'Tobler', 427),
(18669, 'Heterozostera', NULL, '(Setch.) Hartog', 502),
(18670, 'Hexacyrtis', NULL, 'Dinter', 266),
(18671, 'Hexadesmia', NULL, 'Brongn.', 123),
(18672, 'Hexaglottis', NULL, 'Vent.', 349),
(18673, 'Hexalectris', NULL, 'Raf.', 123),
(18674, 'Hexapterella', NULL, 'Urb.', 246),
(18675, 'Hexisea', NULL, 'Lindl.', 123),
(18676, 'Hickelia', NULL, 'A.Camus', 131),
(18677, 'Hierochloe', NULL, 'R.Br.', 131),
(18678, 'Hieronymiella', NULL, 'Pax', 215),
(18679, 'Hilaria', NULL, 'Kunth', 131),
(18680, 'Himantoglossum', NULL, 'K.Koch', 123),
(18681, 'Hintonella', NULL, 'Ames', 123),
(18682, 'Hippeastrum', NULL, 'Herb.', 215),
(18683, 'Hippeophyllum', NULL, 'Schltr.', 123),
(18684, 'Hippophae', NULL, 'L.', 298),
(18685, 'Hippuris', NULL, 'L.', 423),
(18686, 'Hirtzia', NULL, 'Dodson', 123),
(18687, 'Hispaniella', NULL, 'Braem', 123),
(18688, 'Histiopteris', NULL, '(J.Agardh) J.Sm.', 281),
(18689, 'Hitchcockella', NULL, 'A.Camus', 131),
(18690, 'Hitchenia', NULL, 'Wall.', 501),
(18691, 'Hodgsoniola', NULL, 'F.Muell.', 219),
(18692, 'Hoehneella', NULL, 'Ruschi', 123),
(18693, 'Hoffmannia', NULL, 'Sw.', 142),
(18694, 'Hofmeisterella', NULL, 'Rchb.f.', 123),
(18695, 'Hohenbergia', NULL, 'Schult.f.', 244),
(18696, 'Hohenbergiopsis', NULL, 'L.B.Sm. & Read', 244),
(18697, 'Holboellia', NULL, 'Wall.', 359),
(18698, 'Holcoglossum', NULL, 'Schltr.', 123),
(18699, 'Holcolemma', NULL, 'Stapf & C.E.Hubb.', 131),
(18700, 'Holcosorus', NULL, 'T.Moore', 429),
(18701, 'Holcus', NULL, 'L.', 131),
(18702, 'Holodictyum', NULL, 'Maxon', 226),
(18703, 'Holopogon', NULL, 'Kom. & Nevski', 123),
(18704, 'Holosteum', NULL, 'L.', 257),
(18705, 'Holothrix', NULL, 'Rich. ex Lindl.', 123),
(18706, 'Holubia', NULL, 'Oliv.', 406),
(18707, 'Homalodiscus', NULL, 'Bunge ex Boiss.', 443),
(18708, 'Homalopetalum', NULL, 'Rolfe', 123),
(18709, 'Homeria', NULL, 'Vent.', 349),
(18710, 'Homolepis', NULL, 'Chase', 131),
(18711, 'Homopholis', NULL, 'C.E.Hubb.', 131),
(18712, 'Homozeugos', NULL, 'Stapf', 131),
(18713, 'Hopkinsia', NULL, 'W.Fitzg.', 217),
(18714, 'Hordelymus', NULL, '(Jess.) Jess. ex Harz', 131),
(18715, 'Hordeum', NULL, 'L.', 131),
(18716, 'Horichia', NULL, 'Jenny', 123),
(18717, 'Hormidium', NULL, '(Lindl.) Heynh.', 123),
(18718, 'Hornstedtia', NULL, 'Retz.', 501),
(18719, 'Horvatia', NULL, 'Garay', 123),
(18720, 'Hottonia', NULL, 'L.', 434),
(18721, 'Houlletia', NULL, 'Brongn.', 123),
(18722, 'Houttuynia', NULL, 'Thunb.', 457),
(18723, 'Hubbardia', NULL, 'Bor', 131),
(18724, 'Hubbardochloa', NULL, 'Auquier', 131),
(18725, 'Hudsonia', NULL, 'L.', 265),
(18726, 'Humata', NULL, 'Cav.', 279),
(18727, 'Humbertochloa', NULL, 'A.Camus & Stapf', 131),
(18728, 'Humulus', NULL, 'L.', 253),
(18729, 'Huntleya', NULL, 'Bateman ex Lindl.', 123),
(18730, 'Huthia', NULL, 'Brand', 428),
(18731, 'Huttonaea', NULL, 'Harv.', 123),
(18732, 'Hyacinthella', NULL, 'Schur', 338),
(18733, 'Hyacinthoides', NULL, 'Heist. ex Fabr.', 338),
(18734, 'Hyacinthus', NULL, 'L.', 338),
(18735, 'Hyalotrichopteris', NULL, 'W.H.Wagner', 429),
(18736, 'Hybochilus', NULL, 'Schltr.', 123),
(18737, 'Hydatella', NULL, 'Diels', 339),
(18738, 'Hydnora', NULL, 'Thunb.', 340),
(18739, 'Hydrastis', NULL, 'L.', 441),
(18740, 'Hydrilla', NULL, 'Rich.', 342),
(18741, 'Hydrobryum', NULL, 'Endl.', 427),
(18742, 'Hydrocera', NULL, 'Blume', 233),
(18743, 'Hydrocharis', NULL, 'L.', 342),
(18744, 'Hydrocleys', NULL, 'Rich.', 366),
(18745, 'Hydrophilus', NULL, 'Linder', 444),
(18746, 'Hydrostachys', NULL, 'Thouars', 343),
(18747, 'Hydrothauma', NULL, 'C.E.Hubb.', 131),
(18748, 'Hydrothrix', NULL, 'Hook.f.', 430),
(18749, 'Hygrochilus', NULL, 'Pfitzer', 123),
(18750, 'Hygrochloa', NULL, 'Lazarides', 131),
(18751, 'Hygroryza', NULL, 'Nees', 131),
(18752, 'Hylebates', NULL, 'Chippind.', 131),
(18753, 'Hyline', NULL, 'Herb.', 215),
(18754, 'Hylocereus', NULL, '(A.Berger) Britton & Rose', 29),
(18755, 'Hylophila', NULL, 'Lindl.', 123),
(18756, 'Hymenachne', NULL, 'P.Beauv.', 131),
(18757, 'Hymenocallis', NULL, 'Salisb.', 215),
(18758, 'Hymenoglossum', NULL, 'C.Presl', 344),
(18759, 'Hymenogyne', NULL, 'Haw.', 207),
(18760, 'Hymenolepis', NULL, 'Cass.', 18),
(18761, 'Hymenophyllopsis', NULL, 'K.I.Goebel', 345),
(18762, 'Hymenophyllum', NULL, 'Sm.', 344),
(18763, 'Hymenorchis', NULL, 'Schltr.', 123),
(18764, 'Hymenosporum', NULL, 'R.Br. ex F.Muell.', 421),
(18765, 'Hyparrhenia', NULL, 'E.Fourn.', 131),
(18766, 'Hypericopsis', NULL, 'Boiss.', 312),
(18767, 'Hypericum', NULL, 'L.', 346),
(18768, 'Hypertelis', NULL, 'E.Mey. ex Fenzl', 387),
(18769, 'Hyperthelia', NULL, 'Clayton', 131),
(18770, 'Hypodematium', NULL, 'Kunze', 495),
(18771, 'Hypoderris', NULL, 'R.Br. ex Hook.', 296),
(18772, 'Hypodiscus', NULL, 'Nees', 444),
(18773, 'Hypolaena', NULL, 'R.Br.', 444),
(18774, 'Hypolepis', NULL, 'Bernh.', 281),
(18775, 'Hypoxidia', NULL, 'Friedmann', 347),
(18776, 'Hypoxis', NULL, 'L.', 347),
(18777, 'Hypseochloa', NULL, 'C.E.Hubb.', 131),
(18778, 'Hystrix', NULL, 'Moench', 131),
(18779, 'Ibicella', NULL, 'Van Eselt.', 378),
(18780, 'Ichnanthus', NULL, 'P.Beauv.', 131),
(18781, 'Idiospermum', NULL, 'S.T.Blake', 250),
(18782, 'Ikonnikovia', NULL, 'Lincz.', 426),
(18783, 'Illecebrum', NULL, 'L.', 257),
(18784, 'Illicium', NULL, 'L.', 348),
(18785, 'Imerinaea', NULL, 'Schltr.', 123),
(18786, 'Imitaria', NULL, 'N.E.Br.', 207),
(18787, 'Impatiens', NULL, 'L.', 233),
(18788, 'Imperata', NULL, 'Cirillo', 131);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(18789, 'Indocalamus', NULL, 'Nakai', 131),
(18790, 'Indopoa', NULL, 'Bor', 131),
(18791, 'Indosasa', NULL, 'McClure', 131),
(18792, 'Indotristicha', NULL, 'P.Royen', 427),
(18793, 'Ionopsis', NULL, 'Kunth', 123),
(18794, 'Ipheion', NULL, 'Raf.', 210),
(18795, 'Iphigenia', NULL, 'Kunth', 266),
(18796, 'Ipomopsis', NULL, 'Michx.', 428),
(18797, 'Ipsea', NULL, 'Lindl.', 123),
(18798, 'Iris', NULL, 'L.', 349),
(18799, 'Isabelia', NULL, 'Barb.Rodr.', 123),
(18800, 'Isachne', NULL, 'R.Br.', 131),
(18801, 'Ischaemum', NULL, 'L.', 131),
(18802, 'Ischnocentrum', NULL, 'Schltr.', 123),
(18803, 'Ischnogyne', NULL, 'Schltr.', 123),
(18804, 'Ischyrolepis', NULL, 'Steud.', 444),
(18805, 'Iseilema', NULL, 'Andersson', 131),
(18806, 'Isochilus', NULL, 'R.Br.', 123),
(18807, 'Isoetes', NULL, 'L.', 350),
(18808, 'Isophysis', NULL, 'T.Moore', 349),
(18809, 'Isopyrum', NULL, 'L.', 441),
(18810, 'Isotria', NULL, 'Raf.', 123),
(18811, 'Ixerba', NULL, 'A.Cunn.', 352),
(18812, 'Ixia', NULL, 'L.', 349),
(18813, 'Ixiolirion', NULL, 'Herb.', 353),
(18814, 'Ixophorus', NULL, 'Schltdl.', 131),
(18815, 'Jacobsenia', NULL, 'L.Bolus & Schwantes', 207),
(18816, 'Jacquiniella', NULL, 'Schltr.', 123),
(18817, 'Jamesia', NULL, 'Torr. & A.Gray', 341),
(18818, 'Jamesonia', NULL, 'Hook. & Grev.', 202),
(18819, 'Jansenella', NULL, 'Bor', 131),
(18820, 'Japonolirion', NULL, 'Nakai', 413),
(18821, 'Jasminocereus', NULL, 'Britton & Rose', 29),
(18822, 'Jeffersonia', NULL, 'Barton', 237),
(18823, 'Jejosephia', NULL, 'A.N.Rao & Mani', 123),
(18824, 'Jenmaniella', NULL, 'Engl.', 427),
(18825, 'Jensenobotrya', NULL, 'A.G.J.Herre', 207),
(18826, 'Jodrellia', NULL, 'Baijnath', 225),
(18827, 'Johnsonia', NULL, 'R.Br.', 219),
(18828, 'Joinvillea', NULL, 'Gaudich. ex Brongn. & Gris', 354),
(18829, 'Jordaaniella', NULL, 'H.E.K.Hartmann', 207),
(18830, 'Josephinia', NULL, 'Vent.', 406),
(18831, 'Jouvea', NULL, 'E.Fourn.', 131),
(18832, 'Jumellea', NULL, 'Schltr.', 123),
(18833, 'Juncus', NULL, 'L.', 355),
(18834, 'Juttadinteria', NULL, 'Schwantes', 207),
(18835, 'Kabulia', NULL, 'Bor & C.E.C.Fisch.', 257),
(18836, 'Kadsura', NULL, 'Juss.', 459),
(18837, 'Kaempferia', NULL, 'L.', 501),
(18838, 'Kaliphora', NULL, 'Hook.f.', 388),
(18839, 'Kalopternix', NULL, 'Garay & Dunst.', 123),
(18840, 'Kamiesbergia', NULL, 'Snijman', 215),
(18841, 'Kampochloa', NULL, 'Clayton', 131),
(18842, 'Kaokochloa', NULL, 'De Winter', 131),
(18843, 'Kaufmannia', NULL, 'Regel', 434),
(18844, 'Kefersteinia', NULL, 'Rchb.f.', 123),
(18845, 'Kegeliella', NULL, 'Mansf.', 123),
(18846, 'Kelissa', NULL, 'Ravenna', 349),
(18847, 'Kengia', NULL, 'Packer', 131),
(18848, 'Kerriochloa', NULL, 'C.E.Hubb.', 131),
(18849, 'Khadia', NULL, 'N.E.Br.', 207),
(18850, 'Kingdonia', NULL, 'Balf.f. & W.W.Sm.', 264),
(18851, 'Kingia', NULL, 'R.Br.', 278),
(18852, 'Kingidium', NULL, 'P.F.Hunt', 123),
(18853, 'Kinugasa', NULL, 'Tatew. & Suto', 382),
(18854, 'Kirengeshoma', NULL, 'Yatabe', 341),
(18855, 'Kissenia', NULL, 'R.Br. ex Endl.', 367),
(18856, 'Klaprothia', NULL, 'Kunth', 367),
(18857, 'Klattia', NULL, 'Baker', 349),
(18858, 'Knautia', NULL, 'L.', 289),
(18859, 'Knowltonia', NULL, 'Salisb.', 441),
(18860, 'Koeleria', NULL, 'Pers.', 131),
(18861, 'Koellensteinia', NULL, 'Rchb.f.', 123),
(18862, 'Konantzia', NULL, 'Dodson & N.H.Williams', 123),
(18863, 'Krauseola', NULL, 'Pax & K.Hoffm.', 257),
(18864, 'Kreodanthus', NULL, 'Garay', 123),
(18865, 'Kuhlhasseltia', NULL, 'J.J.Sm.', 123),
(18866, 'Kunhardtia', NULL, 'Maguire', 442),
(18867, 'Kuniwatsukia', NULL, 'Pic.Serm.', 495),
(18868, 'Kuntheria', NULL, 'Conran & Clifford', 266),
(18869, 'Lacaena', NULL, 'Lindl.', 123),
(18870, 'Laccopetalum', NULL, 'Ulbr.', 441),
(18871, 'Lachenalia', NULL, 'J.Jacq. ex Murray', 338),
(18872, 'Lachnanthes', NULL, 'Elliott', 327),
(18873, 'Lachnocaulon', NULL, 'Kunth', 304),
(18874, 'Lactoris', NULL, 'Phil.', 357),
(18875, 'Laelia', NULL, 'Lindl.', 123),
(18876, 'Laeliopsis', NULL, 'Lindl. & Paxton', 123),
(18877, 'Lagarosiphon', NULL, 'Harv.', 342),
(18878, 'Lagurus', NULL, 'L.', 131),
(18879, 'Lamarckia', NULL, 'Moench', 131),
(18880, 'Lampranthus', NULL, 'N.E.Br.', 207),
(18881, 'Lamprothyrsus', NULL, 'Pilg.', 131),
(18882, 'Lanaria', NULL, 'Aiton', 358),
(18883, 'Langloisia', NULL, 'Greene', 428),
(18884, 'Langsdorffia', NULL, 'Mart.', 232),
(18885, 'Lanium', NULL, '(Lindl.) Benth.', 123),
(18886, 'Lapageria', NULL, 'Ruiz & Pav.', 415),
(18887, 'Lapeirousia', NULL, 'Pourr.', 349),
(18888, 'Lapidaria', NULL, '(Dinter & Schwantes) N.E.Br.', 207),
(18889, 'Lapiedra', NULL, 'Lag.', 215),
(18890, 'Lardizabala', NULL, 'Ruiz & Pav.', 359),
(18891, 'Larentia', NULL, 'Klatt', 349),
(18892, 'Lasiacis', NULL, '(Griseb.) Hitchc.', 131),
(18893, 'Lasiurus', NULL, 'Boiss.', 131),
(18894, 'Lastreopsis', NULL, 'Ching', 296),
(18895, 'Latace', NULL, 'Phil.', 210),
(18896, 'Lathrophytum', NULL, 'Eichler', 232),
(18897, 'Laurembergia', NULL, 'Bergius', 329),
(18898, 'Laxmannia', NULL, 'R.Br.', 219),
(18899, 'Lecanopteris', NULL, 'Reinw.', 123),
(18900, 'Lecanorchis', NULL, 'Blume', 123),
(18901, 'Lechea', NULL, 'L.', 265),
(18902, 'Lecomtella', NULL, 'A.Camus', 131),
(18903, 'Ledebouria', NULL, 'Roth', 338),
(18904, 'Ledermanniella', NULL, 'Engl.', 427),
(18905, 'Leersia', NULL, 'Sw.', 131),
(18906, 'Leiothrix', NULL, 'Ruhland', 304),
(18907, 'Leiothylax', NULL, 'Warm.', 427),
(18908, 'Leipoldtia', NULL, 'L.Bolus', 207),
(18909, 'Lellingeria', NULL, 'A.R.Sm. & R.C.Moran', 321),
(18910, 'Lemboglossum', NULL, 'Halb.', 123),
(18911, 'Lemmaphyllum', NULL, 'C.Presl', 429),
(18912, 'Lemurella', NULL, 'Schltr.', 123),
(18913, 'Lemurorchis', NULL, 'Kraenzl.', 123),
(18914, 'Lenzia', NULL, 'Phil.', 431),
(18915, 'Leocereus', NULL, 'Britton & Rose', 29),
(18916, 'Leochilus', NULL, 'Knowles & Westc.', 123),
(18917, 'Leontice', NULL, 'L.', 237),
(18918, 'Leontochir', NULL, 'Phil.', 213),
(18919, 'Leopoldia', NULL, 'Parl.', 338),
(18920, 'Lepanthes', NULL, 'Sw.', 123),
(18921, 'Lepanthopsis', NULL, 'Ames', 123),
(18922, 'Lepidobolus', NULL, 'Nees', 444),
(18923, 'Lepidogyne', NULL, 'Blume', 123),
(18924, 'Lepidozamia', NULL, 'Regel', 499),
(18925, 'Lepilaena', NULL, 'J.L.Drumm. ex Harv.', 500),
(18926, 'Lepismium', NULL, 'Pfeiff.', 29),
(18927, 'Lepisorus', NULL, '(J.Sm.) Ching', 429),
(18928, 'Leporella', NULL, 'A.S.George', 123),
(18929, 'Leptagrostis', NULL, 'C.E.Hubb.', 131),
(18930, 'Leptaspis', NULL, 'R.Br.', 131),
(18931, 'Leptocarpus', NULL, 'R.Br.', 444),
(18932, 'Leptocarydion', NULL, 'Stapf', 131),
(18933, 'Leptocereus', NULL, '(A.Berger) Britton & Rose', 29),
(18934, 'Leptochilus', NULL, 'Kaulf.', 429),
(18935, 'Leptochloa', NULL, 'P.Beauv.', 131),
(18936, 'Leptocoryphium', NULL, 'Nees', 131),
(18937, 'Leptodactylon', NULL, 'Hook. & Arn.', 428),
(18938, 'Leptolaena', NULL, 'Thouars', 455),
(18939, 'Leptolepia', NULL, 'Prantl', 281),
(18940, 'Leptopteris', NULL, 'C.Presl', 401),
(18941, 'Leptopyrum', NULL, 'Rchb.', 441),
(18942, 'Leptorumohra', NULL, '(H.Ito) H.Ito', 296),
(18943, 'Leptosolena', NULL, 'C.Presl', 501),
(18944, 'Leptotes', NULL, 'Lindl.', 123),
(18945, 'Leptothrium', NULL, 'Kunth', 131),
(18946, 'Lepturidium', NULL, 'Hitchc. & Ekman', 131),
(18947, 'Lepturopetium', NULL, 'Morat', 131),
(18948, 'Lepturus', NULL, 'R.Br.', 131),
(18949, 'Lepuropetalon', NULL, 'Elliott', 405),
(18950, 'Lepyrodia', NULL, 'R.Br.', 444),
(18951, 'Lepyrodiclis', NULL, 'Fenzl', 257),
(18952, 'Leschenaultia', NULL, 'R.Br.', 319),
(18953, 'Lesliea', NULL, 'Seidenf.', 123),
(18954, 'Letestuella', NULL, 'G.Taylor', 427),
(18955, 'Lethia', NULL, 'Ravenna', 349),
(18956, 'Leuchtenbergia', NULL, 'Hook.', 29),
(18957, 'Leucocoryne', NULL, 'Lindl.', 210),
(18958, 'Leucohyle', NULL, 'Klotzsch', 123),
(18959, 'Leucojum', NULL, 'L.', 215),
(18960, 'Leucostegia', NULL, 'C.Presl', 279),
(18961, 'Levenhookia', NULL, 'R.Br.', 474),
(18962, 'Lewisia', NULL, 'Pursh', 431),
(18963, 'Leymus', NULL, 'Hochst.', 131),
(18964, 'Libertia', NULL, 'Spreng.', 349),
(18965, 'Libyella', NULL, 'Pamp.', 131),
(18966, 'Ligeophila', NULL, 'Garay', 123),
(18967, 'Lilaea', NULL, 'Bonpl.', 356),
(18968, 'Limeum', NULL, 'L.', 364),
(18969, 'Limnanthes', NULL, 'R.Br.', 365),
(18970, 'Limnas', NULL, 'Trin.', 131),
(18971, 'Limnobium', NULL, 'Rich.', 342),
(18972, 'Limnocharis', NULL, 'Bonpl.', 366),
(18973, 'Limnodea', NULL, 'L.H.Dewey', 131),
(18974, 'Limnophyton', NULL, 'Miq.', 209),
(18975, 'Limnopoa', NULL, 'C.E.Hubb.', 131),
(18976, 'Limodorum', NULL, 'Boehm.', 123),
(18977, 'Limoniastrum', NULL, 'Fabr.', 426),
(18978, 'Limoniopsis', NULL, 'Lincz.', 426),
(18979, 'Limonium', NULL, 'Mill.', 426),
(18980, 'Linanthus', NULL, 'Benth.', 428),
(18981, 'Linariopsis', NULL, 'Welw.', 406),
(18982, 'Linconia', NULL, 'L.', 245),
(18983, 'Lindbergella', NULL, 'Bor', 131),
(18984, 'Lindmania', NULL, 'Mez', 244),
(18985, 'Lindsaea', NULL, 'Dryand. ex Sm.', 281),
(18986, 'Lindsayella', NULL, 'Ames & C.Schweinf.', 123),
(18987, 'Lintonia', NULL, 'Stapf', 131),
(18988, 'Liparis', NULL, 'Rich.', 123),
(18989, 'Liparophyllum', NULL, 'Hook.f.', 383),
(18990, 'Liquidambar', NULL, 'L.', 214),
(18991, 'Liriope', NULL, 'Lour.', 269),
(18992, 'Listera', NULL, 'R.Br.', 123),
(18993, 'Listrostachys', NULL, 'Rchb.', 123),
(18994, 'Litanthus', NULL, 'Harv.', 338),
(18995, 'Lithachne', NULL, 'P.Beauv.', 131),
(18996, 'Lithops', NULL, 'N.E.Br.', 207),
(18997, 'Lithostegia', NULL, 'Ching', 296),
(18998, 'Littledalea', NULL, 'Hemsl.', 131),
(18999, 'Littonia', NULL, 'Hook.', 266),
(19000, 'Littorella', NULL, 'Bergius', 423),
(19001, 'Loasa', NULL, 'Adans.', 367),
(19002, 'Lochia', NULL, 'Balf.f.', 257),
(19003, 'Lockhartia', NULL, 'Hook.', 123),
(19004, 'Loefgrenianthus', NULL, 'Hoehne', 123),
(19005, 'Loeflingia', NULL, 'L.', 257),
(19006, 'Loeselia', NULL, 'L.', 428),
(19007, 'Loeseliastrum', NULL, '(Brand) Timbrook', 428),
(19008, 'Loliolum', NULL, 'Krecz. & Bobrov', 131),
(19009, 'Lolium', NULL, 'L.', 131),
(19010, 'Lomagramma', NULL, 'J.Sm.', 369),
(19011, 'Lomandra', NULL, 'Labill.', 368),
(19012, 'Lomariopsis', NULL, 'Fee', 369),
(19013, 'Lomatophyllum', NULL, 'Willd.', 211),
(19014, 'Lonchitis', NULL, 'L.', 281),
(19015, 'Lonchostephus', NULL, 'Tul.', 427),
(19016, 'Lonchostoma', NULL, 'Wikstr.', 245),
(19017, 'Lophacme', NULL, 'Stapf', 131),
(19018, 'Lophatherum', NULL, 'Brongn.', 131),
(19019, 'Lophiola', NULL, 'Ker Gawl.', 391),
(19020, 'Lophogyne', NULL, 'Tul.', 427),
(19021, 'Lopholepis', NULL, 'Decne.', 131),
(19022, 'Lophophora', NULL, 'J.M.Coult.', 29),
(19023, 'Lophophytum', NULL, 'Schott & Endl.', 232),
(19024, 'Lophopogon', NULL, 'Hack.', 131),
(19025, 'Lophopyxis', NULL, 'Hook.f.', 370),
(19026, 'Lophosoria', NULL, 'C.Presl', 283),
(19027, 'Loropetalum', NULL, 'R.Br. ex Rchb.', 330),
(19028, 'Loudetia', NULL, 'Hochst. ex Steud.', 131),
(19029, 'Loudetiopsis', NULL, 'Conert', 131),
(19030, 'Louisiella', NULL, 'C.E.Hubb. & J.Leonard', 131),
(19031, 'Loxocarya', NULL, 'R.Br.', 444),
(19032, 'Loxodera', NULL, 'Launert', 131),
(19033, 'Loxogramme', NULL, '(Blume) C.Presl', 429),
(19034, 'Loxsoma', NULL, 'R.Br. ex A.Cunn.', 372),
(19035, 'Loxsomopsis', NULL, 'H.Christ', 372),
(19036, 'Ludisia', NULL, 'A.Rich.', 123),
(19037, 'Lueddemannia', NULL, 'Rchb.f.', 123),
(19038, 'Luisia', NULL, 'Gaudich.', 123),
(19039, 'Lunathyrium', NULL, 'Koidz.', 495),
(19040, 'Luronium', NULL, 'Raf.', 209),
(19041, 'Luziola', NULL, 'Juss.', 131),
(19042, 'Luzula', NULL, 'DC.', 355),
(19043, 'Luzuriaga', NULL, 'Ruiz & Pav.', 373),
(19044, 'Lyallia', NULL, 'Hook.f.', 333),
(19045, 'Lycaste', NULL, 'Lindl.', 123),
(19046, 'Lychnis', NULL, 'L.', 257),
(19047, 'Lycochloa', NULL, 'Sam.', 131),
(19048, 'Lycomormium', NULL, 'Rchb.f.', 123),
(19049, 'Lycopodiella', NULL, 'Holub', 374),
(19050, 'Lycopodium', NULL, 'L.', 374),
(19051, 'Lycoris', NULL, 'Herb.', 215),
(19052, 'Lycurus', NULL, 'Kunth', 131),
(19053, 'Lygeum', NULL, 'L.', 131),
(19054, 'Lyginia', NULL, 'R.Br.', 217),
(19055, 'Lygodium', NULL, 'Sw.', 460),
(19056, 'Lymania', NULL, 'Read', 244),
(19057, 'Lyperanthus', NULL, 'R.Br.', 123),
(19058, 'Macarenia', NULL, 'P.Royen', 427),
(19059, 'Macarthuria', NULL, 'Hugel ex Endl.', 364),
(19060, 'Machaerocarpus', NULL, 'Small', 209),
(19061, 'Machairophyllum', NULL, 'Schwantes', 207),
(19062, 'Maclurolyra', NULL, 'Calderon & Soderstr.', 131),
(19063, 'Macodes', NULL, '(Blume) Lindl.', 123),
(19064, 'Macradenia', NULL, 'R.Br.', 123),
(19065, 'Macropidia', NULL, 'J.L.Drumm. ex Harv.', 327),
(19066, 'Macropodanthus', NULL, 'L.O.Williams', 123),
(19067, 'Macropodiella', NULL, 'Engl.', 427),
(19068, 'Macrothelypteris', NULL, '(H.Ito) Ching', 480),
(19069, 'Macrozamia', NULL, 'Miq.', 499),
(19070, 'Mahonia', NULL, 'Nutt.', 237),
(19071, 'Maianthemum', NULL, 'Weber', 269),
(19072, 'Maidenia', NULL, 'Rendle', 342),
(19073, 'Maihuenia', NULL, '(F.A.C.Weber) K.Schum.', 29),
(19074, 'Maingaya', NULL, 'Oliv.', 330),
(19075, 'Malaccotristicha', NULL, 'C.Cusset & G.Cusset', 427),
(19076, 'Malaxis', NULL, 'Sol. ex Sw.', 123),
(19077, 'Malephora', NULL, 'N.E.Br.', 207),
(19078, 'Malesherbia', NULL, 'Ruiz & Pav.', 375),
(19079, 'Malleola', NULL, 'J.J.Sm. & Schltr.', 123),
(19080, 'Maltebrunia', NULL, 'Kunth', 131),
(19081, 'Mammillaria', NULL, 'Haw.', 29),
(19082, 'Mammilloydia', NULL, 'Buxb.', 29),
(19083, 'Manisuris', NULL, 'L.', 131),
(19084, 'Manniella', NULL, 'Rchb.f.', 123),
(19085, 'Mantisia', NULL, 'Sims', 501),
(19086, 'Marahuacaea', NULL, 'Maguire', 442),
(19087, 'Marathrum', NULL, 'Bonpl.', 427),
(19088, 'Marattia', NULL, 'Sw.', 376),
(19089, 'Margelliantha', NULL, 'P.J.Cribb', 123),
(19090, 'Marginariopsis', NULL, 'C.Chr.', 429),
(19091, 'Marsilea', NULL, 'L.', 377),
(19092, 'Marsippospermum', NULL, 'Desv.', 355),
(19093, 'Marthella', NULL, 'Urb.', 246),
(19094, 'Martynia', NULL, 'L.', 378),
(19095, 'Maschalocephalus', NULL, 'Gilg & K.Schum.', 442),
(19096, 'Masdevallia', NULL, 'Ruiz & Pav.', 123),
(19097, 'Massonia', NULL, 'Thunb. ex L.f.', 338),
(19098, 'Mastersiella', NULL, 'Gilg-Ben.', 444),
(19099, 'Mastigostyla', NULL, 'I.M.Johnst.', 349),
(19100, 'Mathieua', NULL, 'Klotzsch', 215),
(19101, 'Matonia', NULL, 'R.Br. ex Wall.', 379),
(19102, 'Matteuccia', NULL, 'Tod.', 495),
(19103, 'Matudaea', NULL, 'Lundell', 330),
(19104, 'Matudanthus', NULL, 'D.R.Hunt', 268),
(19105, 'Maundia', NULL, 'F.Muell.', 356),
(19106, 'Maxillaria', NULL, 'Ruiz & Pav.', 123),
(19107, 'Maxonia', NULL, 'C.Chr.', 296),
(19108, 'Mayaca', NULL, 'Aubl.', 380),
(19109, 'Medeola', NULL, 'L.', 269),
(19110, 'Mediocalcar', NULL, 'J.J.Sm.', 123),
(19111, 'Mediusella', NULL, '(Cavaco) Dorr', 455),
(19112, 'Medusagyne', NULL, 'Baker', 381),
(19113, 'Meeboldina', NULL, 'Suess.', 444),
(19114, 'Megalachne', NULL, 'Steud.', 131),
(19115, 'Megalastrum', NULL, 'Holttum', 296),
(19116, 'Megaloprotachne', NULL, 'C.E.Hubb.', 131),
(19117, 'Megalorchis', NULL, 'H.Perrier', 123),
(19118, 'Megalotheca', NULL, 'F.Muell.', 444),
(19119, 'Megalotus', NULL, 'Garay', 123),
(19120, 'Megastachya', NULL, 'P.Beauv.', 131),
(19121, 'Megastylis', NULL, 'Schltr.', 123),
(19122, 'Meiracyllium', NULL, 'Rchb.f.', 123),
(19123, 'Melanocenchris', NULL, 'Nees', 131),
(19124, 'Melanophylla', NULL, 'Baker', 484),
(19125, 'Melanthium', NULL, 'L.', 382),
(19126, 'Melasphaerula', NULL, 'Ker Gawl.', 349),
(19127, 'Melica', NULL, 'L.', 131),
(19128, 'Melinis', NULL, 'P.Beauv.', 131),
(19129, 'Melocactus', NULL, 'Link & Otto', 29),
(19130, 'Melocalamus', NULL, 'Benth.', 131),
(19131, 'Melocanna', NULL, 'Trin.', 131),
(19132, 'Mendoncella', NULL, 'A.D.Hawkes', 123),
(19133, 'Meniscium', NULL, 'Schreb.', 480),
(19134, 'Menisorus', NULL, 'Alston', 480),
(19135, 'Mentzelia', NULL, 'L.', 367),
(19136, 'Menyanthes', NULL, 'L.', 383),
(19137, 'Merendera', NULL, 'Ramond', 266),
(19138, 'Merostachys', NULL, 'Spreng.', 131),
(19139, 'Mesanthemum', NULL, 'Korn.', 304),
(19140, 'Mesembryanthemum', NULL, 'L.', 207),
(19141, 'Mesoglossum', NULL, 'Halb.', 123),
(19142, 'Mesophlebion', NULL, 'Holttum', 480),
(19143, 'Mesosetum', NULL, 'Steud.', 131),
(19144, 'Mesospinidium', NULL, 'Rchb.f.', 123),
(19145, 'Mesostemma', NULL, 'Vved.', 257),
(19146, 'Mestoklema', NULL, 'N.E.Br. ex Glen', 207),
(19147, 'Metanarthecium', NULL, 'Maxim.', 391),
(19148, 'Metanemone', NULL, 'W.T.Wang', 441),
(19149, 'Metathelypteris', NULL, '(H.Ito) Ching', 480),
(19150, 'Metaxya', NULL, 'C.Presl', 384),
(19151, 'Metcalfia', NULL, 'Conert', 131),
(19152, 'Mexicoa', NULL, 'Garay', 123),
(19153, 'Meyerophytum', NULL, 'Schwantes', 207),
(19154, 'Meziella', NULL, 'Schindl.', 329),
(19155, 'Mezobromelia', NULL, 'L.B.Sm.', 244),
(19156, 'Mibora', NULL, 'Adans.', 131),
(19157, 'Micraira', NULL, 'F.Muell.', 131),
(19158, 'Micranthocereus', NULL, 'Backeb.', 29),
(19159, 'Micranthus', NULL, '(Pers.) Eckl.', 349),
(19160, 'Microbriza', NULL, 'Nicora & Rugolo', 131),
(19161, 'Microcalamus', NULL, 'Franch.', 131),
(19162, 'Microchloa', NULL, 'R.Br.', 131),
(19163, 'Microcoelia', NULL, 'Lindl.', 123),
(19164, 'Microcycas', NULL, '(Miq.) A.DC.', 499),
(19165, 'Microgramma', NULL, 'C.Presl', 429),
(19166, 'Microlepia', NULL, 'C.Presl', 281),
(19167, 'Micropera', NULL, 'Lindl.', 123),
(19168, 'Microphyes', NULL, 'Phil.', 257),
(19169, 'Micropyropsis', NULL, 'Romero Zarco & Cabezudo', 131),
(19170, 'Micropyrum', NULL, '(Gaudin) Link', 131),
(19171, 'Microsaccus', NULL, 'Blume', 123),
(19172, 'Microsorum', NULL, 'Link', 429),
(19173, 'Microstegium', NULL, 'Nees', 131),
(19174, 'Microsteris', NULL, 'Greene', 428),
(19175, 'Microtatorchis', NULL, 'Schltr.', 123),
(19176, 'Microterangis', NULL, 'Senghas', 123),
(19177, 'Microtis', NULL, 'R.Br.', 123),
(19178, 'Miersia', NULL, 'Lindl.', 210),
(19179, 'Miersiella', NULL, 'Urb.', 246),
(19180, 'Mila', NULL, 'Britton & Rose', 29),
(19181, 'Mildella', NULL, 'Trevis.', 202),
(19182, 'Milium', NULL, 'L.', 131),
(19183, 'Milla', NULL, 'Cav.', 481),
(19184, 'Milligania', NULL, 'Hook.f.', 227),
(19185, 'Miltonia', NULL, 'Lindl.', 123),
(19186, 'Miltonioides', NULL, 'Brieger & Luckel', 123),
(19187, 'Miltoniopsis', NULL, 'God.-Leb.', 123),
(19188, 'Milula', NULL, 'Prain', 210),
(19189, 'Minuartia', NULL, 'L.', 257),
(19190, 'Miscanthus', NULL, 'Andersson', 131),
(19191, 'Mischobulbum', NULL, 'Schltr.', 123),
(19192, 'Misodendrum', NULL, 'Banks ex DC.', 385),
(19193, 'Mitrastemon', NULL, 'Makino', 386),
(19194, 'Mitrophyllum', NULL, 'Schwantes', 207),
(19195, 'Miyakea', NULL, 'Miyabe & Tatew.', 441),
(19196, 'Mnesithea', NULL, 'Kunth', 131),
(19197, 'Mniochloa', NULL, 'Chase', 131),
(19198, 'Mniopsis', NULL, 'Mart. & Zucc.', 427),
(19199, 'Mniothamnea', NULL, '(Oliv.) Nied.', 245),
(19200, 'Mobilabium', NULL, 'Rupp', 123),
(19201, 'Moehringia', NULL, 'L.', 257),
(19202, 'Moenchia', NULL, 'Ehrh.', 257),
(19203, 'Moerenhoutia', NULL, 'Blume', 123),
(19204, 'Mohria', NULL, 'Sw.', 460),
(19205, 'Molinadendron', NULL, 'P.K.Endress', 330),
(19206, 'Molineria', NULL, 'Colla', 347),
(19207, 'Molinia', NULL, 'Schrank', 131),
(19208, 'Mollugo', NULL, 'L.', 387),
(19209, 'Mona', NULL, 'O.Nilsson', 431),
(19210, 'Monachather', NULL, 'Steud.', 131),
(19211, 'Monachosorum', NULL, 'Kunze', 202),
(19212, 'Monadenia', NULL, 'Lindl.', 123),
(19213, 'Monanthochloe', NULL, 'Engelm.', 131),
(19214, 'Monelytrum', NULL, 'Hack. ex Schinz', 131),
(19215, 'Monilaria', NULL, 'Schwantes', 207),
(19216, 'Monochoria', NULL, 'C.Presl', 430),
(19217, 'Monocosmia', NULL, 'Fenzl', 431),
(19218, 'Monocostus', NULL, 'K.Schum.', 273),
(19219, 'Monocymbium', NULL, 'Stapf', 131),
(19220, 'Monodia', NULL, 'S.W.L.Jacobs', 131),
(19221, 'Monogramma', NULL, 'Comm. ex Schkuhr', 492),
(19222, 'Monomeria', NULL, 'Lindl.', 123),
(19223, 'Monophyllorchis', NULL, 'Schltr.', 123),
(19224, 'Monosepalum', NULL, 'Schltr.', 123),
(19225, 'Monostylis', NULL, 'Tul.', 427),
(19226, 'Monotrema', NULL, 'Korn.', 442),
(19227, 'Monsonia', NULL, 'L.', 314),
(19228, 'Montia', NULL, 'L.', 431),
(19229, 'Montinia', NULL, 'Thunb.', 388),
(19230, 'Montiopsis', NULL, 'Kuntze', 431),
(19231, 'Moraea', NULL, 'Mill.', 349),
(19232, 'Morina', NULL, 'L.', 389),
(19233, 'Mormodes', NULL, 'Lindl.', 123),
(19234, 'Mormolyca', NULL, 'Fenzl', 123),
(19235, 'Moschopsis', NULL, 'Phil.', 251),
(19236, 'Mosdenia', NULL, 'Stent', 131),
(19237, 'Mossia', NULL, 'N.E.Br.', 207),
(19238, 'Mourera', NULL, 'Aubl.', 427),
(19239, 'Muellerolimon', NULL, 'Lincz.', 426),
(19240, 'Muhlenbergia', NULL, 'Schreb.', 131),
(19241, 'Muilla', NULL, 'S.Watson ex Benth.', 210),
(19242, 'Muiria', NULL, 'N.E.Br.', 207),
(19243, 'Munroa', NULL, 'Torr.', 131),
(19244, 'Murchisonia', NULL, 'Brittan', 219),
(19245, 'Murdannia', NULL, 'Royle', 268),
(19246, 'Muscari', NULL, 'Mill.', 338),
(19247, 'Muscarimia', NULL, 'Kostel.', 338),
(19248, 'Myosoton', NULL, 'Moench', 257),
(19249, 'Myosurus', NULL, 'L.', 441),
(19250, 'Myoxanthus', NULL, 'Poepp. & Endl.', 123),
(19251, 'Myriocladus', NULL, 'Swallen', 131),
(19252, 'Myriophyllum', NULL, 'L.', 329),
(19253, 'Myriostachya', NULL, '(Benth.) Hook.f.', 131),
(19254, 'Myrmechis', NULL, '(Lindl.) Blume', 123),
(19255, 'Myrmecophila', NULL, 'Rolfe', 123),
(19256, 'Myrosmodes', NULL, 'Rchb.f.', 123),
(19257, 'Myrothamnus', NULL, 'Welw.', 390),
(19258, 'Myrtillocactus', NULL, 'Console', 29),
(19259, 'Mystacidium', NULL, 'Lindl.', 123),
(19260, 'Mystropetalon', NULL, 'Harv.', 232),
(19261, 'Mytilaria', NULL, 'Lecomte', 330),
(19262, 'Myuropteris', NULL, 'C.Chr.', 429),
(19263, 'Nabaluia', NULL, 'Ames', 123),
(19264, 'Nageliella', NULL, 'L.O.Williams', 123),
(19265, 'Najas', NULL, 'L.', 342),
(19266, 'Namaquanthus', NULL, 'L.Bolus', 207),
(19267, 'Namaquanula', NULL, 'D.Mull.-Doblies & U.Mull.-Doblie', 215),
(19268, 'Namibia', NULL, '(Schwantes) Dinter & Schwantes', 207),
(19269, 'Nananthus', NULL, 'N.E.Br.', 207),
(19270, 'Nandina', NULL, 'Thunb.', 237),
(19271, 'Nannothelypteris', NULL, 'Holttum', 480),
(19272, 'Nanochilus', NULL, 'K.Schum.', 501),
(19273, 'Nanodes', NULL, 'Lindl.', 123),
(19274, 'Naravelia', NULL, 'Adans.', 441),
(19275, 'Narcissus', NULL, 'L.', 215),
(19276, 'Nardostachys', NULL, 'DC.', 491),
(19277, 'Narduroides', NULL, 'Rouy', 131),
(19278, 'Nardus', NULL, 'L.', 131),
(19279, 'Narthecium', NULL, 'Huds.', 391),
(19280, 'Nassella', NULL, '(Trin.) E.Desv.', 131),
(19281, 'Nastus', NULL, 'Juss.', 131),
(19282, 'Navarretia', NULL, 'Ruiz & Pav.', 428),
(19283, 'Navia', NULL, 'Schult.f.', 244),
(19284, 'Nebelia', NULL, 'Neck. ex Sweet', 245),
(19285, 'Nechamandra', NULL, 'Planch.', 342),
(19286, 'Nectaroscordum', NULL, 'Lindl.', 210),
(19287, 'Neesiochloa', NULL, 'Pilg.', 131),
(19288, 'Negripteris', NULL, 'Pic.Serm.', 202),
(19289, 'Nelia', NULL, 'Schwantes', 207),
(19290, 'Nelumbo', NULL, 'Adans.', 392),
(19291, 'Nemastylis', NULL, 'Nutt.', 349),
(19292, 'Nematopoa', NULL, 'C.E.Hubb.', 131),
(19293, 'Neo-urbania', NULL, 'Fawc. & Rendle', 123),
(19294, 'Neoastelia', NULL, 'J.B.Williams', 227),
(19295, 'Neobartlettia', NULL, 'Schltr.', 123),
(19296, 'Neobathiea', NULL, 'Schltr.', 123),
(19297, 'Neobenthamia', NULL, 'Rolfe', 123),
(19298, 'Neobolusia', NULL, 'Schltr.', 123),
(19299, 'Neobouteloua', NULL, 'Gould', 131),
(19300, 'Neobuxbaumia', NULL, 'Backeb.', 29),
(19301, 'Neocheiropteris', NULL, 'H.Christ', 429),
(19302, 'Neoclemensia', NULL, 'Carr', 123),
(19303, 'Neocogniauxia', NULL, 'Schltr.', 123),
(19304, 'Neodregea', NULL, 'C.H.Wright', 266),
(19305, 'Neodryas', NULL, 'Rchb.f.', 123),
(19306, 'Neofinetia', NULL, 'Hu', 123),
(19307, 'Neogardneria', NULL, 'Schltr. ex Garay', 123),
(19308, 'Neoglaziovia', NULL, 'Mez', 244),
(19309, 'Neogontscharovia', NULL, 'Lincz.', 426),
(19310, 'Neogyna', NULL, 'Rchb.f.', 123),
(19311, 'Neohenricia', NULL, 'L.Bolus', 207),
(19312, 'Neokoehleria', NULL, 'Schltr.', 123),
(19313, 'Neolehmannia', NULL, 'Kraenzl.', 123),
(19314, 'Neolloydia', NULL, 'Britton & Rose', 29),
(19315, 'Neomarica', NULL, 'Sprague', 349),
(19316, 'Neomoorea', NULL, 'Rolfe', 123),
(19317, 'Neopatersonia', NULL, 'Schonl.', 338),
(19318, 'Neopaxia', NULL, 'O.Nilsson', 431),
(19319, 'Neoporteria', NULL, 'Britton & Rose', 29),
(19320, 'Neoraimondia', NULL, 'Britton & Rose', 29),
(19321, 'Neoregelia', NULL, 'L.B.Sm.', 244),
(19322, 'Neostapfia', NULL, 'Burtt Davy', 131),
(19323, 'Neostapfiella', NULL, 'A.Camus', 131),
(19324, 'Neostrearia', NULL, 'L.S.Sm.', 330),
(19325, 'Neotinea', NULL, 'Rchb.f.', 123),
(19326, 'Neottia', NULL, 'Guett.', 123),
(19327, 'Neottianthe', NULL, '(Rchb.) Schltr.', 123),
(19328, 'Neowerdermannia', NULL, 'Fric', 29),
(19329, 'Neowilliamsia', NULL, 'Garay', 123),
(19330, 'Nepenthes', NULL, 'L.', 393),
(19331, 'Nephelaphyllum', NULL, 'Blume', 123),
(19332, 'Nephelochloa', NULL, 'Boiss.', 131),
(19333, 'Nephopteris', NULL, 'Lellinger', 202),
(19334, 'Nephrangis', NULL, '(Schltr.) Summerh.', 123),
(19335, 'Nephrolepis', NULL, 'Schott', 396),
(19336, 'Nephrophyllidium', NULL, 'Gilg', 383),
(19337, 'Nerine', NULL, 'Herb.', 215),
(19338, 'Nervilia', NULL, 'Comm. ex Gaudich.', 123),
(19339, 'Nesogenes', NULL, 'A.DC.', 400),
(19340, 'Neurachne', NULL, 'R.Br.', 131),
(19341, 'Neurada', NULL, 'L.', 394),
(19342, 'Neuradopsis', NULL, 'Bremek. & Oberm.', 394),
(19343, 'Neurodium', NULL, 'Fee', 429),
(19344, 'Neurolepis', NULL, 'Meisn.', 131),
(19345, 'Neuropoa', NULL, 'Clayton', 131),
(19346, 'Neuwiedia', NULL, 'Blume', 123),
(19347, 'Nevillea', NULL, 'Esterh. & H.P.Linder', 444),
(19348, 'Nevrocallis', NULL, 'Fee', 437),
(19349, 'Neyraudia', NULL, 'Hook.f.', 131),
(19350, 'Nidema', NULL, 'Britton & Millsp.', 123),
(19351, 'Nidularium', NULL, 'Lem.', 244),
(19352, 'Niederleinia', NULL, 'Hieron.', 312),
(19353, 'Niemeyera', NULL, 'F.Muell.', 148),
(19354, 'Nietneria', NULL, 'Klotzsch ex Benth.', 391),
(19355, 'Nigella', NULL, 'L.', 441),
(19356, 'Nigritella', NULL, 'Rich.', 123),
(19357, 'Niphidium', NULL, 'J.Sm.', 429),
(19358, 'Nivenia', NULL, 'Vent.', 349),
(19359, 'Noahdendron', NULL, 'Endress, B.Hyland & Tracey', 330),
(19360, 'Nolina', NULL, 'Michx.', 293),
(19361, 'Nothodoritis', NULL, 'Z.H.Tsi', 123),
(19362, 'Nothoperanema', NULL, '(Tagawa) Ching', 296),
(19363, 'Nothoscordum', NULL, 'Kunth', 210),
(19364, 'Nothostele', NULL, 'Garay', 123),
(19365, 'Notochloe', NULL, 'Domin', 131),
(19366, 'Notylia', NULL, 'Lindl.', 123),
(19367, 'Nuphar', NULL, 'Sm.', 395),
(19368, 'Nuxia', NULL, 'Comm. ex Lam.', 471),
(19369, 'Nymphaea', NULL, 'L.', 395),
(19370, 'Nymphoides', NULL, 'Seg.', 383),
(19371, 'Oakes-Amesia', NULL, 'C.Schweinf. & P.H.Allen', 123),
(19372, 'Oberonia', NULL, 'Lindl.', 123),
(19373, 'Obregonia', NULL, 'Fric', 29),
(19374, 'Ochagavia', NULL, 'Phil.', 244),
(19375, 'Ochlandra', NULL, 'Thwaites', 131),
(19376, 'Ochotonophila', NULL, 'Gilli', 257),
(19377, 'Ochradenus', NULL, 'Delile', 443),
(19378, 'Ochropteris', NULL, 'J.Sm.', 437),
(19379, 'Ochthochloa', NULL, 'Edgew.', 131),
(19380, 'Octarrhena', NULL, 'Thwaites', 123),
(19381, 'Octopoma', NULL, 'N.E.Br.', 207),
(19382, 'Odontelytrum', NULL, 'Hack.', 131),
(19383, 'Odontoglossum', NULL, 'Kunth', 123),
(19384, 'Odontophorus', NULL, 'N.E.Br.', 207),
(19385, 'Odontorrhynchus', NULL, 'M.N.Correa', 123),
(19386, 'Odontosoria', NULL, 'Fee', 281),
(19387, 'Odontostomum', NULL, 'Torr.', 477),
(19388, 'Odyssea', NULL, 'Stapf', 131),
(19389, 'Oeceoclades', NULL, 'Lindl.', 123),
(19390, 'Oenotrichia', NULL, 'Copel.', 281),
(19391, 'Oeonia', NULL, 'Lindl.', 123),
(19392, 'Oeoniella', NULL, 'Schltr.', 123),
(19393, 'Oerstedella', NULL, 'Rchb.f.', 123),
(19394, 'Oleandra', NULL, 'Cav.', 396),
(19395, 'Oleandropsis', NULL, 'Copel.', 429),
(19396, 'Olfersia', NULL, 'Raddi', 296),
(19397, 'Oligolobos', NULL, 'Gagnep.', 342),
(19398, 'Oligomeris', NULL, 'Cambess.', 443),
(19399, 'Oligophyton', NULL, 'Linder', 123),
(19400, 'Olinia', NULL, 'Thunb.', 397),
(19401, 'Oliveriana', NULL, 'Rchb.f.', 123),
(19402, 'Olmeca', NULL, 'Soderstr.', 131),
(19403, 'Olsynium', NULL, 'Raf.', 349),
(19404, 'Olyra', NULL, 'L.', 131),
(19405, 'Ombrophytum', NULL, 'Poepp. ex Endl.', 232),
(19406, 'Omoea', NULL, 'Blume', 123),
(19407, 'Omphalogramma', NULL, '(Franch.) Franch.', 434),
(19408, 'Oncidium', NULL, 'Sw.', 123),
(19409, 'Oncotheca', NULL, 'Baill.', 398),
(19410, 'Ondinea', NULL, 'Hartog', 395),
(19411, 'Onira', NULL, 'Ravenna', 349),
(19412, 'Onixotis', NULL, 'Raf.', 266),
(19413, 'Onoclea', NULL, 'L.', 495),
(19414, 'Onocleopsis', NULL, 'Ballard', 495),
(19415, 'Onychium', NULL, 'Kaulf.', 202),
(19416, 'Onychosepalum', NULL, 'Steud.', 444),
(19417, 'Oophytum', NULL, 'N.E.Br.', 207),
(19418, 'Ophidion', NULL, 'Luer', 123),
(19419, 'Ophioglossum', NULL, 'L.', 399),
(19420, 'Ophiopogon', NULL, 'Ker Gawl.', 269),
(19421, 'Ophiuros', NULL, 'C.F.Gaertn.', 131),
(19422, 'Ophrys', NULL, 'L.', 123),
(19423, 'Ophthalmophyllum', NULL, 'Dinter & Schwantes', 207),
(19424, 'Opizia', NULL, 'C.Presl', 131),
(19425, 'Oplismenopsis', NULL, 'Parodi', 131),
(19426, 'Oplismenus', NULL, 'P.Beauv.', 131),
(19427, 'Orchidantha', NULL, 'N.E.Br.', 371),
(19428, 'Orchipedum', NULL, 'Breda', 123),
(19429, 'Orchis', NULL, 'L.', 123),
(19430, 'Orcuttia', NULL, 'Vasey', 131),
(19431, 'Orectanthe', NULL, 'Maguire', 498),
(19432, 'Oreithales', NULL, 'Schltdl.', 441),
(19433, 'Oreobambos', NULL, 'K.Schum.', 131),
(19434, 'Oreocereus', NULL, '(A.Berger) Riccob.', 29),
(19435, 'Oreochloa', NULL, 'Link', 131),
(19436, 'Oreopteris', NULL, 'Holub', 480),
(19437, 'Oreorchis', NULL, 'Lindl.', 123),
(19438, 'Oreostylidium', NULL, 'Berggr.', 474),
(19439, 'Orestias', NULL, 'Ridl.', 123),
(19440, 'Orinus', NULL, 'Hitchc.', 131),
(19441, 'Orleanesia', NULL, 'Barb.Rodr.', 123),
(19442, 'Ormoloma', NULL, 'Maxon', 281),
(19443, 'Ornithocephalus', NULL, 'Hook.', 123),
(19444, 'Ornithochilus', NULL, '(Lindl.) Benth.', 123),
(19445, 'Ornithogalum', NULL, 'L.', 338),
(19446, 'Ornithoglossum', NULL, 'Salisb.', 266),
(19447, 'Ornithophora', NULL, 'Barb.Rodr.', 123),
(19448, 'Oropetium', NULL, 'Trin.', 131),
(19449, 'Ortachne', NULL, 'Nees ex Steud.', 131),
(19450, 'Ortegia', NULL, 'L.', 257),
(19451, 'Ortegocactus', NULL, 'Alexander', 29),
(19452, 'Orthiopteris', NULL, 'Copel.', 281),
(19453, 'Orthoceras', NULL, 'R.Br.', 123),
(19454, 'Orthoclada', NULL, 'P.Beauv.', 131),
(19455, 'Orthophytum', NULL, 'Beer', 244),
(19456, 'Orthopterum', NULL, 'L.Bolus', 207),
(19457, 'Orthrosanthus', NULL, 'Sweet', 349),
(19458, 'Oryza', NULL, 'L.', 131),
(19459, 'Oryzidium', NULL, 'C.E.Hubb. & Schweick.', 131),
(19460, 'Oryzopsis', NULL, 'Michx.', 131),
(19461, 'Oscularia', NULL, 'Schwantes', 207),
(19462, 'Oserya', NULL, 'Tul. & Wedd.', 427),
(19463, 'Osmoglossum', NULL, '(Schltr.) Schltr.', 123),
(19464, 'Osmunda', NULL, 'L.', 401),
(19465, 'Ossiculum', NULL, 'P.J.Cribb & Laan', 123),
(19466, 'Ostrearia', NULL, 'Baill.', 330),
(19467, 'Otachyrium', NULL, 'Nees', 131),
(19468, 'Otochilus', NULL, 'Lindl.', 123),
(19469, 'Otoglossum', NULL, '(Schltr.) Garay & Dunst.', 123),
(19470, 'Otostylis', NULL, 'Schltr.', 123),
(19471, 'Ottelia', NULL, 'Pers.', 342),
(19472, 'Ottochloa', NULL, 'Dandy', 131),
(19473, 'Ottosonderia', NULL, 'L.Bolus', 207),
(19474, 'Oxychloe', NULL, 'Phil.', 355),
(19475, 'Oxychloris', NULL, 'Lazarides', 131),
(19476, 'Oxygraphis', NULL, 'Bunge', 441),
(19477, 'Oxygyne', NULL, 'Schltr.', 246),
(19478, 'Oxyrhachis', NULL, 'Pilg.', 131),
(19479, 'Oxytenanthera', NULL, 'Munro', 131),
(19480, 'Pabstia', NULL, 'Garay', 123),
(19481, 'Pachites', NULL, 'Lindl.', 123),
(19482, 'Pachycereus', NULL, '(A.Berger) Britton & Rose', 29),
(19483, 'Pachyphyllum', NULL, 'Kunth', 123),
(19484, 'Pachyplectron', NULL, 'Schltr.', 123),
(19485, 'Pachystele', NULL, 'Schltr.', 123),
(19486, 'Pachystoma', NULL, 'Blume', 123),
(19487, 'Paeonia', NULL, 'L.', 402),
(19488, 'Paepalanthus', NULL, 'Kunth', 304),
(19489, 'Paesia', NULL, 'A.St.-Hil.', 281),
(19490, 'Paleodicraeia', NULL, 'C.Cusset', 427),
(19491, 'Palisota', NULL, 'Rchb. ex Endl.', 268),
(19492, 'Palmorchis', NULL, 'Barb.Rodr.', 123),
(19493, 'Palumbina', NULL, 'Rchb.f.', 123),
(19494, 'Pamianthe', NULL, 'Stapf', 215),
(19495, 'Pancratium', NULL, 'L.', 215),
(19496, 'Panicum', NULL, 'L.', 131),
(19497, 'Panisea', NULL, '(Lindl.) Lindl.', 123),
(19498, 'Pantlingia', NULL, 'Prain', 123),
(19499, 'Paphinia', NULL, 'Lindl.', 123),
(19500, 'Paphiopedilum', NULL, 'Pfitzer', 123),
(19501, 'Papilionanthe', NULL, 'Schltr.', 123),
(19502, 'Papillilabium', NULL, 'Dockrill', 123),
(19503, 'Papperitzia', NULL, 'Rchb.f.', 123),
(19504, 'Pappophorum', NULL, 'Schreb.', 131),
(19505, 'Papuaea', NULL, 'Schltr.', 123),
(19506, 'Papuapteris', NULL, 'C.Chr.', 296),
(19507, 'Paracaleana', NULL, 'Blaxell', 123),
(19508, 'Paracautleya', NULL, 'R.M.Sm.', 501),
(19509, 'Paracryphia', NULL, 'Baker f.', 403),
(19510, 'Paractaenum', NULL, 'P.Beauv.', 131),
(19511, 'Paradisanthus', NULL, 'Rchb.f.', 123),
(19512, 'Paradisea', NULL, 'Mazzuc.', 224),
(19513, 'Parafestuca', NULL, 'E.B.Alexeev', 131),
(19514, 'Paragramma', NULL, '(Blume) T.Moore', 429),
(19515, 'Parahyparrhenia', NULL, 'A.Camus', 131),
(19516, 'Parakaempferia', NULL, 'A.S.Rao & D.M.Verma', 501),
(19517, 'Paramongaia', NULL, 'Velarde', 215),
(19518, 'Paraneurachne', NULL, 'S.T.Blake', 131),
(19519, 'Paraphalaenopsis', NULL, 'A.D.Hawkes', 123),
(19520, 'Parapholis', NULL, 'C.E.Hubb.', 131),
(19521, 'Parapteroceras', NULL, 'Aver.', 123),
(19522, 'Paraquilegia', NULL, 'J.R.Drumm. & Hutch.', 441),
(19523, 'Parasorus', NULL, 'Alderw.', 279),
(19524, 'Parathelypteris', NULL, '(H.Ito) Ching', 480),
(19525, 'Paratheria', NULL, 'Griseb.', 131),
(19526, 'Pardanthopsis', NULL, '(Hance) Lenz', 349),
(19527, 'Parhabenaria', NULL, 'Gagnep.', 123),
(19528, 'Pariana', NULL, 'Aubl.', 131),
(19529, 'Paris', NULL, 'L.', 382),
(19530, 'Parnassia', NULL, 'L.', 405),
(19531, 'Parodia', NULL, 'Speg.', 29),
(19532, 'Parodiolyra', NULL, 'Soderstr. & Zuloaga', 131),
(19533, 'Paronychia', NULL, 'Mill.', 257),
(19534, 'Paroxygraphis', NULL, 'W.W.Sm.', 441),
(19535, 'Parrotia', NULL, 'C.A.Mey.', 330),
(19536, 'Parrotiopsis', NULL, '(Nied.) C.K.Schneid.', 330),
(19537, 'Parvatia', NULL, 'Decne.', 359),
(19538, 'Pasithea', NULL, 'D.Don', 219),
(19539, 'Paspalidium', NULL, 'Stapf', 131),
(19540, 'Paspalum', NULL, 'L.', 131),
(19541, 'Patersonia', NULL, 'R.Br.', 349),
(19542, 'Patrinia', NULL, 'Juss.', 491),
(19543, 'Pauridia', NULL, 'Harv.', 347),
(19544, 'Pecluma', NULL, 'M.G.Price', 429),
(19545, 'Pecteilis', NULL, 'Raf.', 123),
(19546, 'Pedalium', NULL, 'L.', 406),
(19547, 'Pedilochilus', NULL, 'Schltr.', 123),
(19548, 'Pediocactus', NULL, 'Britton & Rose', 29),
(19549, 'Pelargonium', NULL, 'L''Her. ex Aiton', 314),
(19550, 'Pelatantheria', NULL, 'Ridl.', 123),
(19551, 'Pelecyphora', NULL, 'Ehrenb.', 29),
(19552, 'Pelexia', NULL, 'Poit. ex Lindl.', 123),
(19553, 'Peliosanthes', NULL, 'Andrews', 269),
(19554, 'Pellaea', NULL, 'Link', 202),
(19555, 'Peltapteris', NULL, 'Link', 369),
(19556, 'Peltophyllum', NULL, 'Gardner', 486),
(19557, 'Penaea', NULL, 'L.', 407),
(19558, 'Peniocereus', NULL, '(A.Berger) Britton & Rose', 29),
(19559, 'Pennilabium', NULL, 'J.J.Sm.', 123),
(19560, 'Pennisetum', NULL, 'Rich.', 131),
(19561, 'Pentachlaena', NULL, 'H.Perrier', 455),
(19562, 'Pentagramma', NULL, 'Yatsk., Windham & E.Wollenw.', 202),
(19563, 'Pentameris', NULL, 'P.Beauv.', 131),
(19564, 'Pentaphragma', NULL, 'Wall. ex G.Don', 408),
(19565, 'Pentaphylax', NULL, 'Gardner & Champ.', 409),
(19566, 'Pentapogon', NULL, 'R.Br.', 131),
(19567, 'Pentaptilon', NULL, 'E.Pritz.', 319),
(19568, 'Pentarrhaphis', NULL, 'Kunth', 131),
(19569, 'Pentaschistis', NULL, '(Nees) Spach', 131),
(19570, 'Pentastemona', NULL, 'Steenis', 470),
(19571, 'Pentastemonodiscus', NULL, 'Rech.f.', 257),
(19572, 'Penthorum', NULL, 'L.', 410),
(19573, 'Peranema', NULL, 'D.Don', 296),
(19574, 'Pereilema', NULL, 'C.Presl', 131),
(19575, 'Pereskiopsis', NULL, 'Britton & Rose', 29),
(19576, 'Periballia', NULL, 'Trin.', 131),
(19577, 'Peridiscus', NULL, 'Benth.', 411),
(19578, 'Peristeranthus', NULL, 'T.E.Hunt', 123),
(19579, 'Peristeria', NULL, 'Hook.', 123),
(19580, 'Peristylus', NULL, 'Blume', 123),
(19581, 'Perotis', NULL, 'Aiton', 131),
(19582, 'Perrierbambus', NULL, 'A.Camus', 131),
(19583, 'Perrieriella', NULL, 'Schltr.', 123),
(19584, 'Perrierodendron', NULL, 'Cavaco', 455),
(19585, 'Pescatoria', NULL, 'Rchb.f.', 123),
(19586, 'Petalocentrum', NULL, 'Schltr.', 123),
(19587, 'Petalonyx', NULL, 'A.Gray', 367),
(19588, 'Petermannia', NULL, 'F.Muell.', 412),
(19589, 'Petrocoptis', NULL, 'A.Braun ex Endl.', 257),
(19590, 'Petronymphe', NULL, 'H.E.Moore', 481),
(19591, 'Petrorhagia', NULL, '(Ser.) Link', 257),
(19592, 'Petrosavia', NULL, 'Becc.', 413),
(19593, 'Peyritschia', NULL, 'E.Fourn.', 131),
(19594, 'Phacelurus', NULL, 'Griseb.', 131),
(19595, 'Phaedranassa', NULL, 'Herb.', 215),
(19596, 'Phaenanthoecium', NULL, 'C.E.Hubb.', 131),
(19597, 'Phaenosperma', NULL, 'Munro ex Benth.', 131),
(19598, 'Phaius', NULL, 'Lour.', 123),
(19599, 'Phalaenopsis', NULL, 'Blume', 123),
(19600, 'Phalaris', NULL, 'L.', 131),
(19601, 'Phalocallis', NULL, 'Herb.', 349),
(19602, 'Phanerophlebia', NULL, 'C.Presl', 296),
(19603, 'Phanerophlebiopsis', NULL, 'Ching', 296),
(19604, 'Phanerosorus', NULL, 'Copel.', 379),
(19605, 'Pharnaceum', NULL, 'L.', 387),
(19606, 'Pharus', NULL, 'P.Browne', 131),
(19607, 'Phaulothamnus', NULL, 'A.Gray', 199),
(19608, 'Phegopteris', NULL, 'Fee', 480),
(19609, 'Pheidochloa', NULL, 'S.T.Blake', 131),
(19610, 'Phelline', NULL, 'Labill.', 414),
(19611, 'Phelpsiella', NULL, 'Maguire', 442),
(19612, 'Philadelphus', NULL, 'L.', 341),
(19613, 'Philesia', NULL, 'Comm. ex Juss.', 415),
(19614, 'Philippiella', NULL, 'Speg.', 257),
(19615, 'Philippinaea', NULL, 'Schltr. & Ames', 123),
(19616, 'Philodice', NULL, 'Mart.', 304),
(19617, 'Philydrella', NULL, 'Caruel', 416),
(19618, 'Philydrum', NULL, 'Banks ex Gaertn.', 416),
(19619, 'Phippsia', NULL, '(Trin.) R.Br.', 131),
(19620, 'Phlebocarya', NULL, 'R.Br.', 327),
(19621, 'Phlebodium', NULL, '(R.Br.) J.Sm.', 429),
(19622, 'Phleum', NULL, 'L.', 131),
(19623, 'Phlox', NULL, 'L.', 428),
(19624, 'Pholidota', NULL, 'Lindl. ex Hook.', 123),
(19625, 'Pholiurus', NULL, 'Trin.', 131),
(19626, 'Phormium', NULL, 'J.R.Forst. & G.Forst.', 335),
(19627, 'Phragmipedium', NULL, 'Rolfe', 123),
(19628, 'Phragmites', NULL, 'Adans.', 131),
(19629, 'Phragmorchis', NULL, 'L.O.Williams', 123),
(19630, 'Phreatia', NULL, 'Lindl.', 123),
(19631, 'Phryma', NULL, 'L.', 417),
(19632, 'Phryna', NULL, '(Boiss.) Pax & K.Hoffm.', 257),
(19633, 'Phuodendron', NULL, '(Graebn.) Dalla Torre & Harms', 491),
(19634, 'Phyllachne', NULL, 'J.R.Forst. & G.Forst.', 474),
(19635, 'Phyllactis', NULL, 'Pers.', 491),
(19636, 'Phyllobolus', NULL, 'N.E.Br.', 207),
(19637, 'Phyllocladus', NULL, 'Rich. ex Mirb.', 418),
(19638, 'Phyllocomos', NULL, 'Mast.', 444),
(19639, 'Phylloglossum', NULL, 'Kunze', 374),
(19640, 'Phyllonoma', NULL, 'Willd. ex Schult.', 419),
(19641, 'Phyllorachis', NULL, 'Trimen', 131),
(19642, 'Phyllospadix', NULL, 'Hook.', 502),
(19643, 'Phyllostachys', NULL, 'Siebold & Zucc.', 131),
(19644, 'Phymatidium', NULL, 'Lindl.', 123),
(19645, 'Phymatopteris', NULL, 'Pic.Serm.', 429),
(19646, 'Phymatosorus', NULL, 'Pic.Serm.', 429),
(19647, 'Physena', NULL, 'Noronha ex Thouars', 420),
(19648, 'Physinga', NULL, 'Lindl.', 123),
(19649, 'Physoceras', NULL, 'Schltr.', 123),
(19650, 'Pillansia', NULL, 'L.Bolus', 349),
(19651, 'Pilophyllum', NULL, 'Schltr.', 123),
(19652, 'Pilosocereus', NULL, 'Byles & Rowley', 29),
(19653, 'Pilostyles', NULL, 'Guill.', 221),
(19654, 'Pilularia', NULL, 'L.', 377),
(19655, 'Pinelia', NULL, 'Lindl.', 123),
(19656, 'Pinguicula', NULL, 'L.', 363),
(19657, 'Pinosia', NULL, 'Urb.', 257),
(19658, 'Piptochaetium', NULL, 'J.Presl', 131),
(19659, 'Piptophyllum', NULL, 'C.E.Hubb.', 131),
(19660, 'Piresia', NULL, 'Swallen', 131),
(19661, 'Pirinia', NULL, 'Kral', 257),
(19662, 'Pitcairnia', NULL, 'L''Her.', 244),
(19663, 'Pittosporum', NULL, 'Banks ex Sol.', 421),
(19664, 'Pityphyllum', NULL, 'Schltr.', 123),
(19665, 'Pityrogramma', NULL, 'Link', 202),
(19666, 'Placea', NULL, 'Miers', 215),
(19667, 'Plagiantha', NULL, 'Renvoize', 131),
(19668, 'Plagiogyria', NULL, '(Kunze) Mett.', 422),
(19669, 'Plagiolirion', NULL, 'Baker', 215),
(19670, 'Plagiorhegma', NULL, 'Maxim.', 237),
(19671, 'Plagiosetum', NULL, 'Benth.', 131),
(19672, 'Plagiostachys', NULL, 'Ridl.', 501),
(19673, 'Plakothira', NULL, 'Florence', 367),
(19674, 'Plantago', NULL, 'L.', 423),
(19675, 'Platanthera', NULL, 'Rich.', 123),
(19676, 'Platanus', NULL, 'L.', 424),
(19677, 'Platycaulos', NULL, 'Linder', 444),
(19678, 'Platycerium', NULL, 'Desv.', 429),
(19679, 'Platycoryne', NULL, 'Rchb.f.', 123),
(19680, 'Platycrater', NULL, 'Siebold & Zucc.', 341),
(19681, 'Platyglottis', NULL, 'L.O.Williams', 123),
(19682, 'Platylepis', NULL, 'A.Rich.', 123),
(19683, 'Platyrhiza', NULL, 'Barb.Rodr.', 123),
(19684, 'Platyspermation', NULL, 'Guillaumin', 306),
(19685, 'Platystele', NULL, 'Schltr.', 123),
(19686, 'Platythelys', NULL, 'Garay', 123),
(19687, 'Platyzoma', NULL, 'R.Br.', 425),
(19688, 'Plecosorus', NULL, 'Fee', 296),
(19689, 'Plectorrhiza', NULL, 'Dockrill', 123),
(19690, 'Plectrachne', NULL, 'Henrard', 131),
(19691, 'Plectrelminthus', NULL, 'Raf.', 123),
(19692, 'Plectritis', NULL, '(Lindl.) DC.', 491),
(19693, 'Plectrophora', NULL, 'H.Focke', 123),
(19694, 'Pleea', NULL, 'Michx.', 483),
(19695, 'Pleione', NULL, 'D.Don', 123),
(19696, 'Pleioneura', NULL, 'Rech.f.', 257),
(19697, 'Pleiospilos', NULL, 'N.E.Br.', 207),
(19698, 'Pleocnemia', NULL, 'C.Presl', 296),
(19699, 'Pleopeltis', NULL, 'Humb. & Bonpl. ex Willd.', 429),
(19700, 'Plesioneuron', NULL, '(Holttum) Holttum', 480),
(19701, 'Plettkea', NULL, 'Mattf.', 257),
(19702, 'Pleuranthodium', NULL, '(K.Schum.) R.M.Sm.', 501),
(19703, 'Pleuroderris', NULL, 'Maxon', 296),
(19704, 'Pleuropogon', NULL, 'R.Br.', 131),
(19705, 'Pleurosorus', NULL, 'Fee', 226),
(19706, 'Pleurothallis', NULL, 'R.Br.', 123),
(19707, 'Pleurothallopsis', NULL, 'Porto', 123),
(19708, 'Plinthanthesis', NULL, 'Steud.', 131),
(19709, 'Plinthus', NULL, 'Fenzl', 207),
(19710, 'Plocoglottis', NULL, 'Blume', 123),
(19711, 'Plumbagella', NULL, 'Spach', 426),
(19712, 'Plumbago', NULL, 'L.', 426),
(19713, 'Pneumatopteris', NULL, 'Nakai', 480),
(19714, 'Poa', NULL, 'L.', 131),
(19715, 'Poaephyllum', NULL, 'Ridl.', 123),
(19716, 'Poagrostis', NULL, 'Stapf', 131),
(19717, 'Podangis', NULL, 'Schltr.', 123),
(19718, 'Podochilus', NULL, 'Blume', 123),
(19719, 'Podophorus', NULL, 'Phil.', 131),
(19720, 'Podophyllum', NULL, 'L.', 237),
(19721, 'Podosorus', NULL, 'Holttum', 429),
(19722, 'Podostemum', NULL, 'Michx.', 427),
(19723, 'Poecilostachys', NULL, 'Hack.', 131),
(19724, 'Poellnitzia', NULL, 'Uitewaal', 211),
(19725, 'Pogonachne', NULL, 'Bor', 131),
(19726, 'Pogonarthria', NULL, 'Stapf', 131),
(19727, 'Pogonatherum', NULL, 'P.Beauv.', 131),
(19728, 'Pogonia', NULL, 'Juss.', 123),
(19729, 'Pogoniopsis', NULL, 'Rchb.f.', 123),
(19730, 'Pogonochloa', NULL, 'C.E.Hubb.', 131),
(19731, 'Pogononeura', NULL, 'Napper', 131),
(19732, 'Pohlidium', NULL, 'Davidse, Soderstr. & R.P.Ellis', 131),
(19733, 'Pohliella', NULL, 'Engl.', 427),
(19734, 'Polaskia', NULL, 'Backeb.', 29),
(19735, 'Polemonium', NULL, 'L.', 428),
(19736, 'Polevansia', NULL, 'De Winter', 131),
(19737, 'Pollia', NULL, 'Thunb.', 268),
(19738, 'Pollichia', NULL, 'Aiton', 257),
(19739, 'Polpoda', NULL, 'C.Presl', 387),
(19740, 'Polybotrya', NULL, 'Humb. & Bonpl. ex Willd.', 296),
(19741, 'Polycarpaea', NULL, 'Lam.', 257),
(19742, 'Polycarpon', NULL, 'L.', 257),
(19743, 'Polycycnis', NULL, 'Rchb.f.', 123),
(19744, 'Polygonatum', NULL, 'Mill.', 269),
(19745, 'Polymita', NULL, 'N.E.Br.', 207),
(19746, 'Polyotidium', NULL, 'Garay', 123),
(19747, 'Polyphlebium', NULL, 'Copel.', 344),
(19748, 'Polypleurella', NULL, 'Engl.', 427),
(19749, 'Polypleurum', NULL, '(Tul.) Warm.', 427),
(19750, 'Polypodiopteris', NULL, 'C.F.Reed', 429),
(19751, 'Polypodium', NULL, 'L.', 429),
(19752, 'Polypogon', NULL, 'Desf.', 131),
(19753, 'Polypremum', NULL, 'L.', 479),
(19754, 'Polyradicion', NULL, 'Garay', 123),
(19755, 'Polyspatha', NULL, 'Benth.', 268),
(19756, 'Polystachya', NULL, 'Hook.', 123),
(19757, 'Polystichopsis', NULL, '(J.Sm.) Holttum', 296),
(19758, 'Polystichum', NULL, 'Roth', 296),
(19759, 'Polytepalum', NULL, 'Suess. & Beyerle', 257),
(19760, 'Polytoca', NULL, 'R.Br.', 131),
(19761, 'Polytrias', NULL, 'Hack.', 131),
(19762, 'Polyxena', NULL, 'Kunth', 338),
(19763, 'Pomatocalpa', NULL, 'Breda, Kuhl & Hasselt', 123),
(19764, 'Pomatosace', NULL, 'Maxim.', 434),
(19765, 'Pommereschea', NULL, 'Wittm.', 501),
(19766, 'Pommereulla', NULL, 'L.f.', 131),
(19767, 'Ponera', NULL, 'Lindl.', 123),
(19768, 'Ponerorchis', NULL, 'Rchb.f.', 123),
(19769, 'Pontederia', NULL, 'L.', 430),
(19770, 'Ponthieva', NULL, 'R.Br.', 123),
(19771, 'Popoviolimon', NULL, 'Lincz.', 426),
(19772, 'Porolabium', NULL, 'T.Tang & F.T.Wang', 123),
(19773, 'Porpax', NULL, 'Lindl.', 123),
(19774, 'Porphyrodesme', NULL, 'Schltr.', 123),
(19775, 'Porphyroglottis', NULL, 'Ridl.', 123),
(19776, 'Porphyrostachys', NULL, 'Rchb.f.', 123),
(19777, 'Porroglossum', NULL, 'Schltr.', 123),
(19778, 'Porrorhachis', NULL, 'Garay', 123),
(19779, 'Portea', NULL, 'K.Koch', 244),
(19780, 'Porteresia', NULL, 'Tateoka', 131),
(19781, 'Portulaca', NULL, 'L.', 431),
(19782, 'Portulacaria', NULL, 'Jacq.', 284),
(19783, 'Posidonia', NULL, 'K.Koenig', 432),
(19784, 'Poskea', NULL, 'Vatke', 423),
(19785, 'Potamogeton', NULL, 'L.', 433),
(19786, 'Potamophila', NULL, 'R.Br.', 131),
(19787, 'Potarophytum', NULL, 'Sandwith', 442),
(19788, 'Prasophyllum', NULL, 'R.Br.', 123),
(19789, 'Prescottia', NULL, 'Lindl.', 123),
(19790, 'Primula', NULL, 'L.', 434),
(19791, 'Pringleochloa', NULL, 'Scribn.', 131),
(19792, 'Prionanthium', NULL, 'Desv.', 131),
(19793, 'Prionium', NULL, 'E.Mey.', 482),
(19794, 'Pristiglottis', NULL, 'Cretz. & J.J.Sm.', 123),
(19795, 'Proboscidea', NULL, 'Schmidel', 378),
(19796, 'Proiphys', NULL, 'Herb.', 215),
(19797, 'Promenaea', NULL, 'Lindl.', 123),
(19798, 'Pronaya', NULL, 'Hugel', 421),
(19799, 'Pronephrium', NULL, 'C.Presl', 480),
(19800, 'Prosaptia', NULL, 'C.Presl', 321),
(19801, 'Proserpinaca', NULL, 'L.', 329),
(19802, 'Prosopanche', NULL, 'de Bary', 340),
(19803, 'Prosphytochloa', NULL, 'Schweick.', 131),
(19804, 'Psammagrostis', NULL, 'C.A.Gardner & C.E.Hubb.', 131),
(19805, 'Psammiosorus', NULL, 'C.Chr.', 396),
(19806, 'Psammochloa', NULL, 'Hitchc.', 131),
(19807, 'Psammophora', NULL, 'Dinter & Schwantes', 207),
(19808, 'Psammotropha', NULL, 'Eckl. & Zeyh.', 387),
(19809, 'Psathyrostachys', NULL, 'Nevski', 131),
(19810, 'Pseudacoridium', NULL, 'Ames', 123),
(19811, 'Pseudaechmea', NULL, 'L.B.Sm. & Read', 244),
(19812, 'Pseudananas', NULL, 'Hassl. ex Harms', 244),
(19813, 'Pseudanthistiria', NULL, '(Hack.) Hook.f.', 131),
(19814, 'Pseudechinolaena', NULL, 'Stapf', 131),
(19815, 'Pseuderia', NULL, 'Schltr.', 123),
(19816, 'Pseudoacanthocereus', NULL, 'F.Ritter', 29),
(19817, 'Pseudobaeckea', NULL, 'Nied.', 245),
(19818, 'Pseudobetckea', NULL, '(Hock) Lincz.', 491),
(19819, 'Pseudobrownanthus', NULL, 'Ihlenf. & Bittrich', 207),
(19820, 'Pseudocentrum', NULL, 'Lindl.', 123),
(19821, 'Pseudochaetochloa', NULL, 'Hitchc.', 131),
(19822, 'Pseudocoix', NULL, 'A.Camus', 131),
(19823, 'Pseudocranichis', NULL, 'Garay', 123),
(19824, 'Pseudocyclosorus', NULL, 'Ching', 480),
(19825, 'Pseudodanthonia', NULL, 'Bor & C.E.Hubb.', 131),
(19826, 'Pseudodichanthium', NULL, 'Bor', 131),
(19827, 'Pseudogaltonia', NULL, '(Kuntze) Engl.', 338),
(19828, 'Pseudogoodyera', NULL, 'Schltr.', 123),
(19829, 'Pseudolaelia', NULL, 'Porto', 123),
(19830, 'Pseudoloxocarya', NULL, 'Linder', 444),
(19831, 'Pseudomaxillaria', NULL, 'Hoehne', 123),
(19832, 'Pseudomuscari', NULL, 'Garbari & Greuter', 338),
(19833, 'Pseudoparis', NULL, 'H.Perrier', 268),
(19834, 'Pseudopentameris', NULL, 'Conert', 131),
(19835, 'Pseudophegopteris', NULL, 'Ching', 480),
(19836, 'Pseudoraphis', NULL, 'Griff.', 131),
(19837, 'Pseudorchis', NULL, 'Seg.', 123),
(19838, 'Pseudorhipsalis', NULL, 'Britton & Rose', 29),
(19839, 'Pseudosasa', NULL, 'Makino ex Nakai', 131),
(19840, 'Pseudosorghum', NULL, 'A.Camus', 131),
(19841, 'Pseudostellaria', NULL, 'Pax', 257),
(19842, 'Pseudostenomesson', NULL, 'Velarde', 215),
(19843, 'Pseudotaxus', NULL, 'W.C.Cheng', 476),
(19844, 'Pseudotectaria', NULL, 'Tardieu', 296),
(19845, 'Pseudotrimezia', NULL, 'R.C.Foster', 349),
(19846, 'Pseudovanilla', NULL, 'Garay', 123),
(19847, 'Pseudozoysia', NULL, 'Chiov.', 131),
(19848, 'Psilocaulon', NULL, 'N.E.Br.', 207),
(19849, 'Psilochilus', NULL, 'Barb.Rodr.', 123),
(19850, 'Psilolemma', NULL, 'S.M.Phillips', 131),
(19851, 'Psilotum', NULL, 'Sw.', 435),
(19852, 'Psilurus', NULL, 'Trin.', 131),
(19853, 'Psomiocarpa', NULL, 'C.Presl', 296),
(19854, 'Psychilis', NULL, 'Raf.', 123),
(19855, 'Psychopsiella', NULL, 'Luckel & Braem', 123),
(19856, 'Psychrophila', NULL, '(DC.) Bercht. & J.Presl', 441),
(19857, 'Psygmorchis', NULL, 'Dodson & Dressler', 123),
(19858, 'Psylliostachys', NULL, '(Jaub. & Spach) Nevski', 426),
(19859, 'Pteranthus', NULL, 'Forssk.', 257),
(19860, 'Pterichis', NULL, 'Lindl.', 123),
(19861, 'Pteridium', NULL, 'Gled. ex Scop.', 281),
(19862, 'Pteridoblechnum', NULL, 'Hennipman', 240),
(19863, 'Pteridrys', NULL, 'C.Chr. & Ching', 296),
(19864, 'Pteris', NULL, 'L.', 437),
(19865, 'Pterocactus', NULL, 'K.Schum.', 29),
(19866, 'Pterocephalus', NULL, 'Adans.', 289),
(19867, 'Pteroceras', NULL, 'Hasselt ex Hassk.', 123),
(19868, 'Pterocereus', NULL, 'T.MacDoug. & Miranda', 29),
(19869, 'Pterodiscus', NULL, 'Hook.', 406),
(19870, 'Pteroglossaspis', NULL, 'Rchb.f.', 123),
(19871, 'Pterostemma', NULL, 'Kraenzl.', 123),
(19872, 'Pterostemon', NULL, 'Schauer', 438),
(19873, 'Pterostylis', NULL, 'R.Br.', 123),
(19874, 'Pterozonium', NULL, 'Fee', 202),
(19875, 'Pterygodium', NULL, 'Sw.', 123),
(19876, 'Ptilopteris', NULL, 'Hance', 202),
(19877, 'Puccinellia', NULL, 'Parl.', 131),
(19878, 'Puelia', NULL, 'Franch.', 131),
(19879, 'Pulsatilla', NULL, 'Mill.', 441),
(19880, 'Puschkinia', NULL, 'Adams', 338),
(19881, 'Puya', NULL, 'Molina', 244),
(19882, 'Pycnoloma', NULL, 'C.Chr.', 429),
(19883, 'Pycnophyllopsis', NULL, 'Skottsb.', 257),
(19884, 'Pycnophyllum', NULL, 'J.Remy', 257),
(19885, 'Pygmaeorchis', NULL, 'Brade', 123),
(19886, 'Pyrgophyllum', NULL, '(Gagnep.) T.L.Wu & Z.Y.Chen', 501),
(19887, 'Pyrolirion', NULL, 'Herb.', 215),
(19888, 'Pyrrhanthera', NULL, 'Zotov', 131),
(19889, 'Pyrrorhiza', NULL, 'Maguire & Wurdack', 327),
(19890, 'Pyrrosia', NULL, 'Mirb.', 429),
(19891, 'Pyxidanthera', NULL, 'Michx.', 282),
(19892, 'Quekettia', NULL, 'Lindl.', 123),
(19893, 'Quesnelia', NULL, 'Gaudich.', 244),
(19894, 'Quiabentia', NULL, 'Britton & Rose', 29),
(19895, 'Quintinia', NULL, 'A.DC.', 439),
(19896, 'Quisqueya', NULL, 'D.Don', 123),
(19897, 'Rabiea', NULL, 'N.E.Br.', 207),
(19898, 'Racemobambos', NULL, 'Holttum', 131),
(19899, 'Raddia', NULL, 'Bertol.', 131),
(19900, 'Raddiella', NULL, 'Swallen', 131),
(19901, 'Radinosiphon', NULL, 'N.E.Br.', 349),
(19902, 'Rafflesia', NULL, 'R.Br.', 440),
(19903, 'Ranalisma', NULL, 'Stapf', 209),
(19904, 'Randonia', NULL, 'Coss.', 443),
(19905, 'Rangaeris', NULL, '(Schltr.) Summerh.', 123),
(19906, 'Ranunculus', NULL, 'L.', 441),
(19907, 'Ranzania', NULL, 'T.Ito', 237),
(19908, 'Rapatea', NULL, 'Aubl.', 442),
(19909, 'Raspalia', NULL, 'Brongn.', 245),
(19910, 'Rathbunia', NULL, 'Britton & Rose', 29),
(19911, 'Ratzeburgia', NULL, 'Kunth', 131),
(19912, 'Rauhia', NULL, 'Traub', 215),
(19913, 'Rauhiella', NULL, 'Pabst & Braga', 123),
(19914, 'Raycadenco', NULL, 'Dodson', 123),
(19915, 'Rebutia', NULL, 'K.Schum.', 29),
(19916, 'Redfieldia', NULL, 'Vasey', 131),
(19917, 'Reederochloa', NULL, 'Soderstr. & H.F.Decker', 131),
(19918, 'Regnellidium', NULL, 'Lindm.', 377),
(19919, 'Rehia', NULL, 'Fijten', 131),
(19920, 'Reichenbachanthus', NULL, 'Barb.Rodr.', 123),
(19921, 'Reimarochloa', NULL, 'Hitchc.', 131),
(19922, 'Reineckea', NULL, 'Kunth', 269),
(19923, 'Reitzia', NULL, 'Swallen', 131),
(19924, 'Relchela', NULL, 'Steud.', 131),
(19925, 'Renanthera', NULL, 'Lour.', 123),
(19926, 'Renantherella', NULL, 'Ridl.', 123),
(19927, 'Renata', NULL, 'Ruschi', 123),
(19928, 'Renealmia', NULL, 'L.f.', 501),
(19929, 'Reseda', NULL, 'L.', 443),
(19930, 'Restio', NULL, 'Rottb.', 444),
(19931, 'Restrepia', NULL, 'Kunth', 123),
(19932, 'Restrepiella', NULL, 'Garay & Dunst.', 123),
(19933, 'Restrepiopsis', NULL, 'Luer', 123);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(19934, 'Retzia', NULL, 'Thunb.', 471),
(19935, 'Reussia', NULL, 'Endl.', 430),
(19936, 'Reynaudia', NULL, 'Kunth', 131),
(19937, 'Rhadamanthus', NULL, 'Salisb.', 338),
(19938, 'Rhaesteria', NULL, 'Summerh.', 123),
(19939, 'Rhamphorhynchus', NULL, 'Garay', 123),
(19940, 'Rheome', NULL, 'Goldblatt', 349),
(19941, 'Rheopteris', NULL, 'Alston', 492),
(19942, 'Rhinephyllum', NULL, 'N.E.Br.', 207),
(19943, 'Rhinerrhiza', NULL, 'Rupp', 123),
(19944, 'Rhipidocladum', NULL, 'McClure', 131),
(19945, 'Rhipogonum', NULL, 'J.R.Forst. & G.Forst.', 445),
(19946, 'Rhipsalis', NULL, 'Gaertn.', 29),
(19947, 'Rhizanthella', NULL, 'R.S.Rogers', 123),
(19948, 'Rhizanthes', NULL, 'Dumort.', 440),
(19949, 'Rhizocephalus', NULL, 'Boiss.', 131),
(19950, 'Rhodocodon', NULL, 'Baker', 338),
(19951, 'Rhodocoma', NULL, 'Nees', 444),
(19952, 'Rhodohypoxis', NULL, 'Nel', 347),
(19953, 'Rhodolaena', NULL, 'Thouars', 455),
(19954, 'Rhodoleia', NULL, 'Champ. ex Hook.', 330),
(19955, 'Rhodophiala', NULL, 'C.Presl', 215),
(19956, 'Rhoiptelea', NULL, 'Diels & Hand.-Mazz.', 446),
(19957, 'Rhombolytrum', NULL, 'Link', 131),
(19958, 'Rhombophyllum', NULL, '(Schwantes) Schwantes', 207),
(19959, 'Rhopalephora', NULL, 'Hassk.', 268),
(19960, 'Rhopalocnemis', NULL, 'Jungh.', 232),
(19961, 'Rhynchanthus', NULL, 'Hook.f.', 501),
(19962, 'Rhynchocalyx', NULL, 'Oliv.', 447),
(19963, 'Rhynchogyna', NULL, 'Seidenf. & Garay', 123),
(19964, 'Rhyncholacis', NULL, 'Tul.', 427),
(19965, 'Rhyncholaelia', NULL, 'Schltr.', 123),
(19966, 'Rhynchophreatia', NULL, 'Schltr.', 123),
(19967, 'Rhynchoryza', NULL, 'Baill.', 131),
(19968, 'Rhynchostylis', NULL, 'Blume', 123),
(19969, 'Rhynchotheca', NULL, 'Ruiz & Pav.', 361),
(19970, 'Rhytachne', NULL, 'Desv. ex Ham.', 131),
(19971, 'Ribes', NULL, 'L.', 323),
(19972, 'Richardsiella', NULL, 'Elffers & Kenn.-O''Byrne', 131),
(19973, 'Ridleyella', NULL, 'Schltr.', 123),
(19974, 'Riedelia', NULL, 'Oliv.', 501),
(19975, 'Rigidella', NULL, 'Lindl.', 349),
(19976, 'Rimacola', NULL, 'Rupp', 123),
(19977, 'Risleya', NULL, 'King & Pantl.', 123),
(19978, 'Robbairea', NULL, 'Boiss.', 257),
(19979, 'Robiquetia', NULL, 'Gaudich.', 123),
(19980, 'Rodriguezia', NULL, 'Ruiz & Pav.', 123),
(19981, 'Rodrigueziella', NULL, 'Kuntze', 123),
(19982, 'Rodrigueziopsis', NULL, 'Schltr.', 123),
(19983, 'Roeperocharis', NULL, 'Rchb.f.', 123),
(19984, 'Roezliella', NULL, 'Schltr.', 123),
(19985, 'Rogeria', NULL, 'J.Gay ex Delile', 406),
(19986, 'Roggeveldia', NULL, 'Goldblatt', 349),
(19987, 'Rohdea', NULL, 'Roth', 269),
(19988, 'Romnalda', NULL, 'P.F.Stevens', 368),
(19989, 'Romulea', NULL, 'Maratti', 349),
(19990, 'Ronnbergia', NULL, 'E.Morren & Andre', 244),
(19991, 'Roridula', NULL, 'Burm.f. ex L.', 448),
(19992, 'Roscoea', NULL, 'Sm.', 501),
(19993, 'Rosenstockia', NULL, 'Copel.', 344),
(19994, 'Rossioglossum', NULL, '(Schltr.) Garay & G.C.Kenn.', 123),
(19995, 'Rostkovia', NULL, 'Desv.', 355),
(19996, 'Rostraria', NULL, 'Trin.', 131),
(19997, 'Rothia', NULL, 'Pers.', 68),
(19998, 'Rottboellia', NULL, 'L.f.', 131),
(19999, 'Roussea', NULL, 'Sm.', 449),
(20000, 'Rudolfiella', NULL, 'Hoehne', 123),
(20001, 'Rumicastrum', NULL, 'Ulbr.', 431),
(20002, 'Rumohra', NULL, 'Raddi', 279),
(20003, 'Ruppia', NULL, 'L.', 450),
(20004, 'Rusbyella', NULL, 'Rolfe ex Rusby', 123),
(20005, 'Ruschia', NULL, 'Schwantes', 207),
(20006, 'Ruschianthemum', NULL, 'Friedrich', 207),
(20007, 'Ruschianthus', NULL, 'L.Bolus', 207),
(20008, 'Ruscus', NULL, 'L.', 451),
(20009, 'Rytidosperma', NULL, 'Steud.', 131),
(20010, 'Saccharum', NULL, 'L.', 131),
(20011, 'Sacciolepis', NULL, 'Nash', 131),
(20012, 'Saccoglossum', NULL, 'Schltr.', 123),
(20013, 'Saccolabiopsis', NULL, 'J.J.Sm.', 123),
(20014, 'Saccolabium', NULL, 'Blume', 123),
(20015, 'Saccoloma', NULL, 'Kaulf.', 281),
(20016, 'Sadleria', NULL, 'Kaulf.', 240),
(20017, 'Saffordia', NULL, 'Maxon', 202),
(20018, 'Sagina', NULL, 'L.', 257),
(20019, 'Sagittaria', NULL, 'L.', 209),
(20020, 'Salpichlaena', NULL, 'J.Sm.', 240),
(20021, 'Salpistele', NULL, 'Dressler', 123),
(20022, 'Saltera', NULL, 'Bullock', 407),
(20023, 'Salvadora', NULL, 'L.', 452),
(20024, 'Salvinia', NULL, 'Seg.', 453),
(20025, 'Samaipaticereus', NULL, 'Cardenas', 29),
(20026, 'Sanctambrosia', NULL, 'Skottsb. ex Kuschel', 257),
(20027, 'Sanderella', NULL, 'Kuntze', 123),
(20028, 'Sandersonia', NULL, 'Hook.', 266),
(20029, 'Saniella', NULL, 'Hilliard & B.L.Burtt', 347),
(20030, 'Sansevieria', NULL, 'Thunb.', 293),
(20031, 'Santomasia', NULL, 'N.Robson', 346),
(20032, 'Saphesia', NULL, 'N.E.Br.', 207),
(20033, 'Saponaria', NULL, 'L.', 257),
(20034, 'Sapria', NULL, 'Griff.', 440),
(20035, 'Sarcanthopsis', NULL, 'Garay', 123),
(20036, 'Sarcobatus', NULL, 'Nees', 454),
(20037, 'Sarcocaulon', NULL, '(DC.) Sweet', 314),
(20038, 'Sarcochilus', NULL, 'R.Br.', 123),
(20039, 'Sarcoglottis', NULL, 'C.Presl', 123),
(20040, 'Sarcoglyphis', NULL, 'Garay', 123),
(20041, 'Sarcolaena', NULL, 'Thouars', 455),
(20042, 'Sarcophyte', NULL, 'Sparrm.', 232),
(20043, 'Sarcophyton', NULL, 'Garay', 123),
(20044, 'Sarcostoma', NULL, 'Blume', 123),
(20045, 'Sargentodoxa', NULL, 'Rehder & E.H.Wilson', 359),
(20046, 'Sarracenia', NULL, 'L.', 456),
(20047, 'Sartidia', NULL, 'De Winter', 131),
(20048, 'Sasa', NULL, 'Makino & Shibata', 131),
(20049, 'Satyridium', NULL, 'Lindl.', 123),
(20050, 'Satyrium', NULL, 'Sw.', 123),
(20051, 'Saundersia', NULL, 'Rchb.f.', 123),
(20052, 'Sauroglossum', NULL, 'Lindl.', 123),
(20053, 'Saururus', NULL, 'L.', 457),
(20054, 'Sauvallea', NULL, 'W.Wright', 268),
(20055, 'Savannosiphon', NULL, 'Goldblatt & Marais', 349),
(20056, 'Saxicolella', NULL, 'Engl.', 427),
(20057, 'Saxiglossum', NULL, 'Ching', 429),
(20058, 'Saxofridericia', NULL, 'R.H.Schomb.', 442),
(20059, 'Scabiosa', NULL, 'L.', 289),
(20060, 'Scadoxus', NULL, 'Raf.', 215),
(20061, 'Scaevola', NULL, 'L.', 319),
(20062, 'Scaphiophora', NULL, 'Schltr.', 246),
(20063, 'Scaphochlamys', NULL, 'Baker', 501),
(20064, 'Scaphosepalum', NULL, 'Pfitzer', 123),
(20065, 'Scaphyglottis', NULL, 'Poepp. & Endl.', 123),
(20066, 'Scelochiloides', NULL, 'Dodson & M.W.Chase', 123),
(20067, 'Scelochilus', NULL, 'Klotzsch', 123),
(20068, 'Schaffnerella', NULL, 'Nash', 131),
(20069, 'Schaffneria', NULL, 'Fee ex T.Moore', 226),
(20070, 'Schedonnardus', NULL, 'Steud.', 131),
(20071, 'Schelhammera', NULL, 'R.Br.', 269),
(20072, 'Scheuchzeria', NULL, 'L.', 458),
(20073, 'Schickendantzia', NULL, 'Pax', 213),
(20074, 'Schiedea', NULL, 'Cham. & Schltdl.', 257),
(20075, 'Schiedeella', NULL, 'Schltr.', 123),
(20076, 'Schiekia', NULL, 'Meisn.', 327),
(20077, 'Schisandra', NULL, 'Michx.', 459),
(20078, 'Schismocarpus', NULL, 'S.F.Blake', 367),
(20079, 'Schismus', NULL, 'P.Beauv.', 131),
(20080, 'Schistotylus', NULL, 'Dockrill', 123),
(20081, 'Schizachne', NULL, 'Hack.', 131),
(20082, 'Schizachyrium', NULL, 'Nees', 131),
(20083, 'Schizaea', NULL, 'Sm.', 460),
(20084, 'Schizobasis', NULL, 'Baker', 338),
(20085, 'Schizochilus', NULL, 'Sond.', 123),
(20086, 'Schizocodon', NULL, 'Siebold & Zucc.', 282),
(20087, 'Schizodium', NULL, 'Lindl.', 123),
(20088, 'Schizolaena', NULL, 'Thouars', 455),
(20089, 'Schizophragma', NULL, 'Siebold & Zucc.', 341),
(20090, 'Schizostachyum', NULL, 'Nees', 131),
(20091, 'Schizostylis', NULL, 'Backh. & Harv.', 349),
(20092, 'Schlechteranthus', NULL, 'Schwantes', 207),
(20093, 'Schlechterella', NULL, 'K.Schum.', 10),
(20094, 'Schlimmia', NULL, 'Planch. & Linden', 123),
(20095, 'Schlumbergera', NULL, 'Lem.', 29),
(20096, 'Schmidtia', NULL, 'Steud. ex J.A.Schmidt', 131),
(20097, 'Schoenefeldia', NULL, 'Kunth', 131),
(20098, 'Schoenocaulon', NULL, 'A.Gray', 382),
(20099, 'Schoenocephalium', NULL, 'Seub.', 442),
(20100, 'Schoenolirion', NULL, 'Torr. ex Durand', 338),
(20101, 'Schoenorchis', NULL, 'Blume', 123),
(20102, 'Scholleropsis', NULL, 'H.Perrier', 430),
(20103, 'Schomburgkia', NULL, 'Lindl.', 123),
(20104, 'Schreiteria', NULL, 'Carolin', 431),
(20105, 'Schwantesia', NULL, 'Dinter', 207),
(20106, 'Schwartzkopffia', NULL, 'Kraenzl.', 123),
(20107, 'Sciadopitys', NULL, 'Siebold & Zucc.', 461),
(20108, 'Sciaphila', NULL, 'Blume', 486),
(20109, 'Scilla', NULL, 'L.', 338),
(20110, 'Sclerachne', NULL, 'R.Br.', 131),
(20111, 'Scleranthopsis', NULL, 'Rech.f.', 257),
(20112, 'Scleranthus', NULL, 'L.', 257),
(20113, 'Sclerocactus', NULL, 'Britton & Rose', 29),
(20114, 'Sclerocephalus', NULL, 'Boiss.', 257),
(20115, 'Sclerochloa', NULL, 'P.Beauv.', 131),
(20116, 'Sclerodactylon', NULL, 'Stapf', 131),
(20117, 'Scleroglossum', NULL, 'Alderw.', 321),
(20118, 'Sclerolaena', NULL, 'R.Br.', 5),
(20119, 'Scleropogon', NULL, 'Phil.', 131),
(20120, 'Sclerothrix', NULL, 'C.Presl', 367),
(20121, 'Scolochloa', NULL, 'Link', 131),
(20122, 'Scopelogena', NULL, 'L.Bolus', 207),
(20123, 'Scopulophila', NULL, 'M.E.Jones', 257),
(20124, 'Scribneria', NULL, 'Hack.', 131),
(20125, 'Scutachne', NULL, 'Hitchc. & Chase', 131),
(20126, 'Scuticaria', NULL, 'Lindl.', 123),
(20127, 'Scybalium', NULL, 'Schott & Endl.', 232),
(20128, 'Scyphanthus', NULL, 'Sweet', 367),
(20129, 'Scyphularia', NULL, 'Fee', 279),
(20130, 'Secale', NULL, 'L.', 131),
(20131, 'Sedirea', NULL, 'Garay & H.R.Sweet', 123),
(20132, 'Sehima', NULL, 'Forssk.', 131),
(20133, 'Seidenfadenia', NULL, 'Garay', 123),
(20134, 'Selaginella', NULL, 'P.Beauv.', 462),
(20135, 'Selenicereus', NULL, '(A.Berger) Britton & Rose', 29),
(20136, 'Selenipedium', NULL, 'Rchb.f.', 123),
(20137, 'Selliera', NULL, 'Cav.', 319),
(20138, 'Selliguea', NULL, 'Bory', 429),
(20139, 'Semele', NULL, 'Kunth', 451),
(20140, 'Semiaquilegia', NULL, 'Makino', 441),
(20141, 'Semiarundinaria', NULL, 'Nakai', 131),
(20142, 'Sepalosaccus', NULL, 'Schltr.', 123),
(20143, 'Sepalosiphon', NULL, 'Schltr.', 123),
(20144, 'Serapias', NULL, 'L.', 123),
(20145, 'Serpyllopsis', NULL, 'Bosch', 344),
(20146, 'Sesamoides', NULL, 'Ortega', 443),
(20147, 'Sesamothamnus', NULL, 'Welw.', 406),
(20148, 'Sesamum', NULL, 'L.', 406),
(20149, 'Sesleria', NULL, 'Scop.', 131),
(20150, 'Sessilanthera', NULL, 'Molseed & Cruden', 349),
(20151, 'Sessilistigma', NULL, 'Goldblatt', 349),
(20152, 'Sesuvium', NULL, 'L.', 207),
(20153, 'Setaria', NULL, 'P.Beauv.', 131),
(20154, 'Setariopsis', NULL, 'Scribn. ex Millsp.', 131),
(20155, 'Seychellaria', NULL, 'Hemsl.', 486),
(20156, 'Shepherdia', NULL, 'Nutt.', 298),
(20157, 'Shibataea', NULL, 'Makino ex Nakai', 131),
(20158, 'Shortia', NULL, 'Torr. & A.Gray', 282),
(20159, 'Siderasis', NULL, 'Raf.', 268),
(20160, 'Sievekingia', NULL, 'Rchb.f.', 123),
(20161, 'Sigmatostalix', NULL, 'Rchb.f.', 123),
(20162, 'Silene', NULL, 'L.', 257),
(20163, 'Silentvalleya', NULL, 'V.J.Nair, Sreek., Vajr. & Bargha', 131),
(20164, 'Siliquamomum', NULL, 'Baill.', 501),
(20165, 'Silvianthus', NULL, 'Hook.f.', 256),
(20166, 'Silvorchis', NULL, 'J.J.Sm.', 123),
(20167, 'Simethis', NULL, 'Kunth', 224),
(20168, 'Simmondsia', NULL, 'Nutt.', 463),
(20169, 'Simplicia', NULL, 'Kirk', 131),
(20170, 'Sinadoxa', NULL, 'C.Y.Wu, Z.L.Wu & R.F.Huang', 203),
(20171, 'Sinarundinaria', NULL, 'Nakai', 131),
(20172, 'Sinobambusa', NULL, 'Makino', 131),
(20173, 'Sinocalycanthus', NULL, '(W.C.Cheng & S.Y.Chang) W.C.Chen', 250),
(20174, 'Sinofranchetia', NULL, '(Diels) Hemsl.', 359),
(20175, 'Sinopodophyllum', NULL, 'T.S.Ying', 237),
(20176, 'Sinopteris', NULL, 'C.Chr. & Ching', 202),
(20177, 'Sinorchis', NULL, 'S.C.Chen', 123),
(20178, 'Sinowilsonia', NULL, 'Hemsl.', 330),
(20179, 'Siphonochilus', NULL, 'J.M.Wood & Franks', 501),
(20180, 'Siphonychia', NULL, 'Torr. & A.Gray', 257),
(20181, 'Sirhookera', NULL, 'Kuntze', 123),
(20182, 'Sisyrinchium', NULL, 'L.', 349),
(20183, 'Sitanion', NULL, 'Raf.', 131),
(20184, 'Skiatophytum', NULL, 'L.Bolus', 207),
(20185, 'Smicrostigma', NULL, 'N.E.Br.', 207),
(20186, 'Smithorchis', NULL, 'T.Tang & F.T.Wang', 123),
(20187, 'Smithsonia', NULL, 'C.J.Saldanha', 123),
(20188, 'Smitinandia', NULL, 'Holttum', 123),
(20189, 'Snowdenia', NULL, 'C.E.Hubb.', 131),
(20190, 'Sobennikoffia', NULL, 'Schltr.', 123),
(20191, 'Sobralia', NULL, 'Ruiz & Pav.', 123),
(20192, 'Soderstromia', NULL, 'C.V.Morton', 131),
(20193, 'Sohnsia', NULL, 'Airy Shaw', 131),
(20194, 'Solanopteris', NULL, 'Copel.', 429),
(20195, 'Solaria', NULL, 'Phil.', 210),
(20196, 'Soldanella', NULL, 'L.', 434),
(20197, 'Solenangis', NULL, 'Schltr.', 123),
(20198, 'Solenidiopsis', NULL, 'Senghas', 123),
(20199, 'Solenidium', NULL, 'Lindl.', 123),
(20200, 'Solenocentrum', NULL, 'Schltr.', 123),
(20201, 'Solenomelus', NULL, 'Miers', 349),
(20202, 'Sollya', NULL, 'Lindl.', 421),
(20203, 'Sonderothamnus', NULL, 'R.Dahlgren', 407),
(20204, 'Sophronitella', NULL, 'Schltr.', 123),
(20205, 'Sophronitis', NULL, 'Lindl.', 123),
(20206, 'Sorghastrum', NULL, 'Nash', 131),
(20207, 'Sorghum', NULL, 'Moench', 131),
(20208, 'Soridium', NULL, 'Miers', 486),
(20209, 'Soterosanthus', NULL, 'Lehm. ex Jenny', 123),
(20210, 'Souliea', NULL, 'Franch.', 441),
(20211, 'Sowerbaea', NULL, 'Sm.', 219),
(20212, 'Sparaxis', NULL, 'Ker Gawl.', 349),
(20213, 'Sparganium', NULL, 'L.', 464),
(20214, 'Spartina', NULL, 'Schreb.', 131),
(20215, 'Spartochloa', NULL, 'C.E.Hubb.', 131),
(20216, 'Spathanthus', NULL, 'Desv.', 442),
(20217, 'Spathia', NULL, 'Ewart', 131),
(20218, 'Spathoglottis', NULL, 'Blume', 123),
(20219, 'Spatholirion', NULL, 'Ridl.', 268),
(20220, 'Speea', NULL, 'Loes.', 210),
(20221, 'Speirantha', NULL, 'Baker', 269),
(20222, 'Spergula', NULL, 'L.', 257),
(20223, 'Spergularia', NULL, '(Pers.) J.Presl & C.Presl', 257),
(20224, 'Sphaerobambos', NULL, 'S.Dransf.', 131),
(20225, 'Sphaerocaryum', NULL, 'Nees ex Hook.f.', 131),
(20226, 'Sphaerocionium', NULL, 'C.Presl', 344),
(20227, 'Sphaerocoma', NULL, 'T.Anderson', 257),
(20228, 'Sphaerostephanos', NULL, 'J.Sm.', 480),
(20229, 'Sphaerothylax', NULL, 'Bisch. ex Krauss', 427),
(20230, 'Spheneria', NULL, 'Kuhlm.', 131),
(20231, 'Sphenomeris', NULL, 'Maxon', 281),
(20232, 'Sphenopholis', NULL, 'Scribn.', 131),
(20233, 'Sphenopus', NULL, 'Trin.', 131),
(20234, 'Sphenostemon', NULL, 'Baill.', 466),
(20235, 'Sphenostigma', NULL, 'Baker', 349),
(20236, 'Sphyrarhynchus', NULL, 'Mansf.', 123),
(20237, 'Sphyrastylis', NULL, 'Schltr.', 123),
(20238, 'Spiculaea', NULL, 'Lindl.', 123),
(20239, 'Spiloxene', NULL, 'Salisb.', 347),
(20240, 'Spinifex', NULL, 'L.', 131),
(20241, 'Spiranthes', NULL, 'Rich.', 123),
(20242, 'Spodiopogon', NULL, 'Trin.', 131),
(20243, 'Spongiola', NULL, 'J.J.Wood & A.L.Lamb', 123),
(20244, 'Sporadanthus', NULL, 'F.Muell.', 444),
(20245, 'Sporobolus', NULL, 'R.Br.', 131),
(20246, 'Spraguea', NULL, 'Torr.', 431),
(20247, 'Sprekelia', NULL, 'Heist.', 215),
(20248, 'Staavia', NULL, 'Dahl', 245),
(20249, 'Staberoha', NULL, 'Kunth', 444),
(20250, 'Stachyanthus', NULL, 'Engl.', 85),
(20251, 'Stachyurus', NULL, 'Siebold & Zucc.', 467),
(20252, 'Stadiochilus', NULL, 'R.M.Sm.', 501),
(20253, 'Stahlianthus', NULL, 'Kuntze', 501),
(20254, 'Stalkya', NULL, 'Garay', 123),
(20255, 'Stanfieldiella', NULL, 'Brenan', 268),
(20256, 'Stangea', NULL, 'Graebn.', 491),
(20257, 'Stangeria', NULL, 'T.Moore', 468),
(20258, 'Stanhopea', NULL, 'Frost ex Hook.', 123),
(20259, 'Stauntonia', NULL, 'DC.', 359),
(20260, 'Staurochilus', NULL, 'Ridl. ex Pfitzer', 123),
(20261, 'Stawellia', NULL, 'F.Muell.', 219),
(20262, 'Stayneria', NULL, 'L.Bolus', 207),
(20263, 'Steenisioblechnum', NULL, 'Hennipman', 240),
(20264, 'Stegnogramma', NULL, 'Blume', 480),
(20265, 'Stegnosperma', NULL, 'Benth.', 469),
(20266, 'Stegolepis', NULL, 'Klotzsch ex Korn.', 442),
(20267, 'Steinchisma', NULL, 'Raf.', 131),
(20268, 'Steirachne', NULL, 'Ekman', 131),
(20269, 'Steiropteris', NULL, '(C.Chr.) Pic.Serm.', 480),
(20270, 'Stelis', NULL, 'Sw.', 123),
(20271, 'Stellaria', NULL, 'L.', 257),
(20272, 'Stellilabium', NULL, 'Schltr.', 123),
(20273, 'Stemona', NULL, 'Lour.', 470),
(20274, 'Stenanthium', NULL, '(A.Gray) Kunth', 382),
(20275, 'Stenia', NULL, 'Lindl.', 123),
(20276, 'Stenocactus', NULL, '(K.Schum.) A.W.Hill', 29),
(20277, 'Stenocereus', NULL, '(A.Berger) Riccob.', 29),
(20278, 'Stenochlaena', NULL, 'J.Sm.', 240),
(20279, 'Stenoglottis', NULL, 'Lindl.', 123),
(20280, 'Stenolepia', NULL, 'Alderw.', 296),
(20281, 'Stenomesson', NULL, 'Herb.', 215),
(20282, 'Stenoptera', NULL, 'C.Presl', 123),
(20283, 'Stenorrhynchos', NULL, 'Rich. ex Spreng.', 123),
(20284, 'Stenotaphrum', NULL, 'Trin.', 131),
(20285, 'Stephanachne', NULL, 'Keng', 131),
(20286, 'Stephanocereus', NULL, 'A.Berger', 29),
(20287, 'Stephanothelys', NULL, 'Garay', 123),
(20288, 'Stereochlaena', NULL, 'Hack.', 131),
(20289, 'Stereosandra', NULL, 'Blume', 123),
(20290, 'Sternbergia', NULL, 'Waldst. & Kit.', 215),
(20291, 'Stetsonia', NULL, 'Britton & Rose', 29),
(20292, 'Steveniella', NULL, 'Schltr.', 123),
(20293, 'Steyerbromelia', NULL, 'L.B.Sm.', 244),
(20294, 'Steyermarkochloa', NULL, 'Davidse & R.P.Ellis', 131),
(20295, 'Sticherus', NULL, 'C.Presl', 317),
(20296, 'Stichoneuron', NULL, 'Hook.f.', 470),
(20297, 'Stictophyllum', NULL, 'Dodson & M.W.Chase', 123),
(20298, 'Stigmatopteris', NULL, 'C.Chr.', 296),
(20299, 'Stigmatosema', NULL, 'Garay', 123),
(20300, 'Stilbe', NULL, 'Bergius', 471),
(20301, 'Stipa', NULL, 'L.', 131),
(20302, 'Stipagrostis', NULL, 'Nees', 131),
(20303, 'Stipulicida', NULL, 'Michx.', 257),
(20304, 'Stoeberia', NULL, 'Dinter & Schwantes', 207),
(20305, 'Stolzia', NULL, 'Schltr.', 123),
(20306, 'Stomatium', NULL, 'Schwantes', 207),
(20307, 'Stonesia', NULL, 'G.Taylor', 427),
(20308, 'Strasburgeria', NULL, 'Baill.', 472),
(20309, 'Stratiotes', NULL, 'L.', 342),
(20310, 'Streblochaete', NULL, 'Pilg.', 131),
(20311, 'Streptocalyx', NULL, 'Beer', 244),
(20312, 'Streptochaeta', NULL, 'Schrad. ex Nees', 131),
(20313, 'Streptogyna', NULL, 'P.Beauv.', 131),
(20314, 'Streptolirion', NULL, 'Edgew.', 268),
(20315, 'Streptolophus', NULL, 'Hughes', 131),
(20316, 'Streptostachys', NULL, 'Desv.', 131),
(20317, 'Stromatopteris', NULL, 'Mett.', 473),
(20318, 'Strombocactus', NULL, 'Britton & Rose', 29),
(20319, 'Strumaria', NULL, 'Jacq. ex Willd.', 215),
(20320, 'Stylapterus', NULL, 'A.Juss.', 407),
(20321, 'Stylidium', NULL, 'Sw. ex Willd.', 474),
(20322, 'Stylites', NULL, 'Amstutz', 350),
(20323, 'Stylobasium', NULL, 'Desf.', 475),
(20324, 'Stypandra', NULL, 'R.Br.', 335),
(20325, 'Styppeiochloa', NULL, 'De Winter', 131),
(20326, 'Suarezia', NULL, 'Dodson', 123),
(20327, 'Succisa', NULL, 'Haller', 289),
(20328, 'Succisella', NULL, 'Beck', 289),
(20329, 'Sucrea', NULL, 'Soderstr.', 131),
(20330, 'Suddia', NULL, 'Renvoize', 131),
(20331, 'Suessenguthiella', NULL, 'Friedrich', 387),
(20332, 'Summerhayesia', NULL, 'P.J.Cribb', 123),
(20333, 'Sunipia', NULL, 'Buch.-Ham. ex Lindl.', 123),
(20334, 'Suriana', NULL, 'L.', 475),
(20335, 'Sutrina', NULL, 'Lindl.', 123),
(20336, 'Swallenia', NULL, 'Soderstr. & H.F.Decker', 131),
(20337, 'Sycopsis', NULL, 'Oliv.', 330),
(20338, 'Symphyglossum', NULL, 'Schltr.', 123),
(20339, 'Symphyosepalum', NULL, 'Hand.-Mazz.', 123),
(20340, 'Symplectrodia', NULL, 'Lazarides', 131),
(20341, 'Synammia', NULL, 'J.Sm.', 429),
(20342, 'Synanthes', NULL, 'Burns-Bal., H.Rob. & M.S.Foster', 123),
(20343, 'Synaptophyllum', NULL, 'N.E.Br.', 207),
(20344, 'Syngonanthus', NULL, 'Ruhland', 304),
(20345, 'Syngramma', NULL, 'J.Sm.', 202),
(20346, 'Sypharissa', NULL, 'Salisb.', 338),
(20347, 'Syringodea', NULL, 'Hook.f.', 349),
(20348, 'Syringodium', NULL, 'Kutz.', 275),
(20349, 'Systeloglossum', NULL, 'Schltr.', 123),
(20350, 'Tacinga', NULL, 'Britton & Rose', 29),
(20351, 'Taeniatherum', NULL, 'Nevski', 131),
(20352, 'Taeniophyllum', NULL, 'Blume', 123),
(20353, 'Taeniorrhiza', NULL, 'Summerh.', 123),
(20354, 'Taenitis', NULL, 'Willd. ex Schkuhr', 202),
(20355, 'Tainia', NULL, 'Blume', 123),
(20356, 'Talinaria', NULL, 'Brandegee', 431),
(20357, 'Talinella', NULL, 'Baill.', 431),
(20358, 'Talinopsis', NULL, 'A.Gray', 431),
(20359, 'Talinum', NULL, 'Adans.', 431),
(20360, 'Tanquana', NULL, 'H.E.K.Hartmann & Liede', 207),
(20361, 'Tapeinia', NULL, 'Comm. ex Juss.', 349),
(20362, 'Tapeinidium', NULL, '(C.Presl) C.Chr.', 281),
(20363, 'Tapeinochilos', NULL, 'Miq.', 273),
(20364, 'Tapeinoglossum', NULL, 'Schltr.', 123),
(20365, 'Tarigidia', NULL, 'Stent', 131),
(20366, 'Tatianyx', NULL, 'Zuloaga & Soderstr.', 131),
(20367, 'Taxus', NULL, 'L.', 476),
(20368, 'Tecophilaea', NULL, 'Bertero ex Colla', 477),
(20369, 'Tectaria', NULL, 'Cav.', 296),
(20370, 'Tectaridium', NULL, 'Copel.', 296),
(20371, 'Tedingea', NULL, 'D.Mull.-Doblies & U.Mull.-Doblie', 215),
(20372, 'Telephium', NULL, 'L.', 257),
(20373, 'Telipogon', NULL, 'Kunth', 123),
(20374, 'Teratophyllum', NULL, 'Mett. ex Kuhn', 369),
(20375, 'Tersonia', NULL, 'Moq.', 326),
(20376, 'Tetracentron', NULL, 'Oliv.', 478),
(20377, 'Tetrachaete', NULL, 'Chiov.', 131),
(20378, 'Tetrachne', NULL, 'Nees', 131),
(20379, 'Tetrachondra', NULL, 'Petrie ex Oliv.', 479),
(20380, 'Tetradoxa', NULL, 'C.Y.Wu', 203),
(20381, 'Tetragamestus', NULL, 'Rchb.f.', 123),
(20382, 'Tetragonia', NULL, 'L.', 207),
(20383, 'Tetramicra', NULL, 'Lindl.', 123),
(20384, 'Tetrapogon', NULL, 'Desf.', 131),
(20385, 'Tetrathyrium', NULL, 'Benth.', 330),
(20386, 'Tetroncium', NULL, 'Willd.', 356),
(20387, 'Teuscheria', NULL, 'Garay', 123),
(20388, 'Thaia', NULL, 'Seidenf.', 123),
(20389, 'Thalassia', NULL, 'Banks ex C.Koenig', 342),
(20390, 'Thalassodendron', NULL, 'Hartog', 275),
(20391, 'Thalictrum', NULL, 'L.', 441),
(20392, 'Thamnea', NULL, 'Sol. ex Brongn.', 245),
(20393, 'Thamnocalamus', NULL, 'Munro', 131),
(20394, 'Thamnochortus', NULL, 'Bergius', 444),
(20395, 'Thaumastochloa', NULL, 'C.E.Hubb.', 131),
(20396, 'Thecopus', NULL, 'Seidenf.', 123),
(20397, 'Thecostele', NULL, 'Rchb.f.', 123),
(20398, 'Thelasis', NULL, 'Blume', 123),
(20399, 'Thelepogon', NULL, 'Roth ex Roem. & Schult.', 131),
(20400, 'Thelethylax', NULL, 'C.Cusset', 427),
(20401, 'Thelionema', NULL, 'R.J.F.Hend.', 335),
(20402, 'Thelocactus', NULL, '(K.Schum.) Britton & Rose', 29),
(20403, 'Thelymitra', NULL, 'J.R.Forst. & G.Forst.', 123),
(20404, 'Thelypteris', NULL, 'Schmidel', 480),
(20405, 'Thelyschista', NULL, 'Garay', 123),
(20406, 'Themeda', NULL, 'Forssk.', 131),
(20407, 'Thereianthus', NULL, 'G.J.Lewis', 349),
(20408, 'Theropogon', NULL, 'Maxim.', 269),
(20409, 'Thismia', NULL, 'Griff.', 246),
(20410, 'Thonningia', NULL, 'Vahl', 232),
(20411, 'Thrasya', NULL, 'Kunth', 131),
(20412, 'Thrasyopsis', NULL, 'Parodi', 131),
(20413, 'Thrixspermum', NULL, 'Lour.', 123),
(20414, 'Thuarea', NULL, 'Pers.', 131),
(20415, 'Thulinia', NULL, 'P.J.Cribb', 123),
(20416, 'Thunia', NULL, 'Rchb.f.', 123),
(20417, 'Thuranthos', NULL, 'C.H.Wright', 338),
(20418, 'Thurnia', NULL, 'Hook.f.', 482),
(20419, 'Thurya', NULL, 'Boiss. & Balansa', 257),
(20420, 'Thylacopteris', NULL, 'Kunze ex J.Sm.', 429),
(20421, 'Thylacospermum', NULL, 'Fenzl', 257),
(20422, 'Thyridachne', NULL, 'C.E.Hubb.', 131),
(20423, 'Thyridolepis', NULL, 'S.T.Blake', 131),
(20424, 'Thyrsanthemum', NULL, 'Pichon', 268),
(20425, 'Thyrsopteris', NULL, 'Kunze', 283),
(20426, 'Thyrsostachys', NULL, 'Gamble', 131),
(20427, 'Thysanoglossa', NULL, 'Porto', 123),
(20428, 'Thysanolaena', NULL, 'Nees', 131),
(20429, 'Thysanosoria', NULL, 'A.Gepp', 369),
(20430, 'Thysanotus', NULL, 'R.Br.', 219),
(20431, 'Ticoglossum', NULL, 'Lucas Rodr. ex Halb.', 123),
(20432, 'Tigridia', NULL, 'Juss.', 349),
(20433, 'Tillandsia', NULL, 'L.', 244),
(20434, 'Tinantia', NULL, 'Scheidw.', 268),
(20435, 'Tipularia', NULL, 'Nutt.', 123),
(20436, 'Titanopsis', NULL, 'Schwantes', 207),
(20437, 'Tittmannia', NULL, 'Brongn.', 245),
(20438, 'Tmesipteris', NULL, 'Bernh.', 435),
(20439, 'Todea', NULL, 'Willd. ex Bernh.', 401),
(20440, 'Tofieldia', NULL, 'Huds.', 483),
(20441, 'Tonina', NULL, 'Aubl.', 304),
(20442, 'Torrenticola', NULL, 'Domin', 427),
(20443, 'Torreya', NULL, 'Arn.', 476),
(20444, 'Torreyochloa', NULL, 'Church', 131),
(20445, 'Torricellia', NULL, 'DC.', 484),
(20446, 'Tournonia', NULL, 'Moq.', 236),
(20447, 'Tovarochloa', NULL, 'Macfarl. & But', 131),
(20448, 'Townsonia', NULL, 'Cheeseman', 123),
(20449, 'Trachoma', NULL, 'Garay', 123),
(20450, 'Trachyandra', NULL, 'Kunth', 225),
(20451, 'Trachypogon', NULL, 'Nees', 131),
(20452, 'Trachypteris', NULL, 'Andre ex H.Christ', 202),
(20453, 'Trachys', NULL, 'Pers.', 131),
(20454, 'Tradescantia', NULL, 'L.', 268),
(20455, 'Tragus', NULL, 'Haller', 131),
(20456, 'Trapella', NULL, 'Oliv.', 406),
(20457, 'Traubia', NULL, 'Moldenke', 215),
(20458, 'Traunsteinera', NULL, 'Rchb.', 123),
(20459, 'Trautvetteria', NULL, 'Fisch. & C.A.Mey.', 441),
(20460, 'Trevoria', NULL, 'F.Lehm.', 123),
(20461, 'Trianthema', NULL, 'L.', 207),
(20462, 'Trias', NULL, 'Lindl.', 123),
(20463, 'Tribeles', NULL, 'Phil.', 306),
(20464, 'Tribolium', NULL, 'Desv.', 131),
(20465, 'Tribonanthes', NULL, 'Endl.', 327),
(20466, 'Tribulocarpus', NULL, 'S.Moore', 207),
(20467, 'Tricalistra', NULL, 'Ridl.', 269),
(20468, 'Tricarpelema', NULL, 'J.K.Morton', 268),
(20469, 'Triceratella', NULL, 'Brenan', 268),
(20470, 'Triceratorhynchus', NULL, 'Summerh.', 123),
(20471, 'Trichlora', NULL, 'Baker', 210),
(20472, 'Trichloris', NULL, 'E.Fourn. ex Benth.', 131),
(20473, 'Trichocentrum', NULL, 'Poepp. & Endl.', 123),
(20474, 'Trichoceros', NULL, 'Kunth', 123),
(20475, 'Trichocladus', NULL, 'Pers.', 330),
(20476, 'Trichodiadema', NULL, 'Schwantes', 207),
(20477, 'Trichoglottis', NULL, 'Blume', 123),
(20478, 'Tricholaena', NULL, 'Schrad. ex Schult. & Schult.f.', 131),
(20479, 'Trichomanes', NULL, 'L.', 344),
(20480, 'Trichoneura', NULL, 'Andersson', 131),
(20481, 'Trichoneuron', NULL, 'Ching', 495),
(20482, 'Trichopetalum', NULL, 'Lindl.', 219),
(20483, 'Trichopilia', NULL, 'Lindl.', 123),
(20484, 'Trichopteryx', NULL, 'Nees', 131),
(20485, 'Trichosalpinx', NULL, 'Luer', 123),
(20486, 'Trichotosia', NULL, 'Blume', 123),
(20487, 'Tricoryne', NULL, 'R.Br.', 219),
(20488, 'Tridactyle', NULL, 'Schltr.', 123),
(20489, 'Tridens', NULL, 'Roem. & Schult.', 131),
(20490, 'Triglochin', NULL, 'L.', 356),
(20491, 'Trigonidium', NULL, 'Lindl.', 123),
(20492, 'Trigonospora', NULL, 'Holttum', 480),
(20493, 'Trikeraia', NULL, 'Bor', 131),
(20494, 'Trillium', NULL, 'L.', 382),
(20495, 'Trilobachne', NULL, 'Schenck ex Henrard', 131),
(20496, 'Trimenia', NULL, 'Seem.', 485),
(20497, 'Trimezia', NULL, 'Salisb. ex Herb.', 349),
(20498, 'Triniochloa', NULL, 'Hitchc.', 131),
(20499, 'Triodia', NULL, 'R.Br.', 131),
(20500, 'Triphora', NULL, 'Nutt.', 123),
(20501, 'Triphyophyllum', NULL, 'Airy Shaw', 287),
(20502, 'Triplachne', NULL, 'Link', 131),
(20503, 'Tripladenia', NULL, 'D.Don', 269),
(20504, 'Triplasis', NULL, 'P.Beauv.', 131),
(20505, 'Triplophyllum', NULL, 'Holttum', 296),
(20506, 'Triplopogon', NULL, 'Bor', 131),
(20507, 'Triplostegia', NULL, 'Wall. ex DC.', 289),
(20508, 'Tripogandra', NULL, 'Raf.', 268),
(20509, 'Tripogon', NULL, 'Roem. & Schult.', 131),
(20510, 'Tripsacum', NULL, 'L.', 131),
(20511, 'Triraphis', NULL, 'R.Br.', 131),
(20512, 'Triscenia', NULL, 'Griseb.', 131),
(20513, 'Trisetaria', NULL, 'Forssk.', 131),
(20514, 'Trisetella', NULL, 'Luer', 123),
(20515, 'Trisetum', NULL, 'Pers.', 131),
(20516, 'Tristachya', NULL, 'Nees', 131),
(20517, 'Tristagma', NULL, 'Poepp.', 210),
(20518, 'Tristicha', NULL, 'Thouars', 427),
(20519, 'Triteleia', NULL, 'Douglas ex Lindl.', 481),
(20520, 'Triteleiopsis', NULL, 'Hoover', 481),
(20521, 'Trithuria', NULL, 'Hook.f.', 339),
(20522, 'Triticum', NULL, 'L.', 131),
(20523, 'Tritonia', NULL, 'Ker Gawl.', 349),
(20524, 'Tritoniopsis', NULL, 'L.Bolus', 349),
(20525, 'Triuris', NULL, 'Miers', 486),
(20526, 'Trizeuxis', NULL, 'Lindl.', 123),
(20527, 'Trochodendron', NULL, 'Siebold & Zucc.', 487),
(20528, 'Trogostolon', NULL, 'Copel.', 279),
(20529, 'Trollius', NULL, 'L.', 441),
(20530, 'Tropaeolum', NULL, 'L.', 488),
(20531, 'Trophaeastrum', NULL, 'Sparre', 488),
(20532, 'Tropidia', NULL, 'Lindl.', 123),
(20533, 'Trudelia', NULL, 'Garay', 123),
(20534, 'Tsaiorchis', NULL, 'T.Tang & F.T.Wang', 123),
(20535, 'Tuberaria', NULL, '(Dunal) Spach', 265),
(20536, 'Tuberolabium', NULL, 'Yamam.', 123),
(20537, 'Tubilabium', NULL, 'J.J.Sm.', 123),
(20538, 'Tuctoria', NULL, 'Reeder', 131),
(20539, 'Tulasneantha', NULL, 'P.Royen', 427),
(20540, 'Tulbaghia', NULL, 'L.', 210),
(20541, 'Tupistra', NULL, 'Ker Gawl.', 269),
(20542, 'Turbinicarpus', NULL, '(Backeb.) Buxb. & Backeb.', 29),
(20543, 'Tylostigma', NULL, 'Schltr.', 123),
(20544, 'Typha', NULL, 'L.', 489),
(20545, 'Uebelinia', NULL, 'Hochst.', 257),
(20546, 'Uebelmannia', NULL, 'Buining', 29),
(20547, 'Uleiorchis', NULL, 'Hoehne', 123),
(20548, 'Ullucus', NULL, 'Caldas', 236),
(20549, 'Uncaria', NULL, 'Schreb.', 142),
(20550, 'Uncarina', NULL, '(Baill.) Stapf', 406),
(20551, 'Uncifera', NULL, 'Lindl.', 123),
(20552, 'Ungernia', NULL, 'Bunge', 215),
(20553, 'Uniola', NULL, 'L.', 131),
(20554, 'Uranthoecium', NULL, 'Stapf', 131),
(20555, 'Urceolina', NULL, 'Rchb.', 215),
(20556, 'Urelytrum', NULL, 'Hack.', 131),
(20557, 'Urginea', NULL, 'Steinh.', 338),
(20558, 'Urochlaena', NULL, 'Nees', 131),
(20559, 'Urochloa', NULL, 'P.Beauv.', 131),
(20560, 'Urochondra', NULL, 'C.E.Hubb.', 131),
(20561, 'Urophysa', NULL, 'Ulbr.', 441),
(20562, 'Utricularia', NULL, 'L.', 363),
(20563, 'Uvularia', NULL, 'L.', 266),
(20564, 'Vaccaria', NULL, 'Wolf', 257),
(20565, 'Vagaria', NULL, 'Herb.', 215),
(20566, 'Vaginularia', NULL, 'Fee', 492),
(20567, 'Vahlia', NULL, 'Thunb.', 490),
(20568, 'Valdivia', NULL, 'Gay ex J.Remy', 306),
(20569, 'Valeriana', NULL, 'L.', 491),
(20570, 'Valerianella', NULL, 'Mill.', 491),
(20571, 'Vallisneria', NULL, 'L.', 342),
(20572, 'Vancouveria', NULL, 'C.Morren & Decne.', 237),
(20573, 'Vanda', NULL, 'Jones ex R.Br.', 123),
(20574, 'Vandopsis', NULL, 'Pfitzer', 123),
(20575, 'Vanheerdea', NULL, 'L.Bolus ex H.E.K.Hartmann', 207),
(20576, 'Vanilla', NULL, 'Mill.', 123),
(20577, 'Vanoverberghia', NULL, 'Merr.', 501),
(20578, 'Vanzijlia', NULL, 'L.Bolus', 207),
(20579, 'Vargasiella', NULL, 'C.Schweinf.', 123),
(20580, 'Vaseyochloa', NULL, 'Hitchc.', 131),
(20581, 'Vasqueziella', NULL, 'Dodson', 123),
(20582, 'Vassilczenkoa', NULL, 'Lincz.', 426),
(20583, 'Velezia', NULL, 'L.', 257),
(20584, 'Velleia', NULL, 'Sm.', 319),
(20585, 'Veltheimia', NULL, 'Gled.', 338),
(20586, 'Ventenata', NULL, 'Koeler', 131),
(20587, 'Ventricularia', NULL, 'Garay', 123),
(20588, 'Veratrum', NULL, 'L.', 382),
(20589, 'Verreauxia', NULL, 'Benth.', 319),
(20590, 'Vetiveria', NULL, 'Bory', 131),
(20591, 'Vexillabium', NULL, 'F.Maek.', 123),
(20592, 'Victoria', NULL, 'Lindl.', 395),
(20593, 'Vietnamosasa', NULL, 'T.Q.Nguyen', 131),
(20594, 'Viguierella', NULL, 'A.Camus', 131),
(20595, 'Villarsia', NULL, 'Vent.', 383),
(20596, 'Vinkia', NULL, 'Meijden', 329),
(20597, 'Viscaria', NULL, 'Rohl.', 257),
(20598, 'Vitaliana', NULL, 'Sesl.', 434),
(20599, 'Vittaria', NULL, 'Sm.', 492),
(20600, 'Viviania', NULL, 'Cav.', 493),
(20601, 'Vleisia', NULL, 'Toml. & Posl.', 500),
(20602, 'Vossia', NULL, 'Wall. & Griff.', 131),
(20603, 'Vriesea', NULL, 'Lindl.', 244),
(20604, 'Vrydagzynea', NULL, 'Blume', 123),
(20605, 'Vulpia', NULL, 'C.C.Gmel.', 131),
(20606, 'Vulpiella', NULL, '(Batt. & Trab.) Andr.', 131),
(20607, 'Wachendorfia', NULL, 'Burm.', 327),
(20608, 'Walleria', NULL, 'J.Kirk', 477),
(20609, 'Walteranthus', NULL, 'Keighery', 326),
(20610, 'Wangenheimia', NULL, 'Moench', 131),
(20611, 'Warmingia', NULL, 'Rchb.f.', 123),
(20612, 'Warrea', NULL, 'Lindl.', 123),
(20613, 'Warreella', NULL, 'Schltr.', 123),
(20614, 'Warreopsis', NULL, 'Garay', 123),
(20615, 'Watsonia', NULL, 'Mill.', 349),
(20616, 'Weberbauerocereus', NULL, 'Backeb.', 29),
(20617, 'Weberocereus', NULL, 'Britton & Rose', 29),
(20618, 'Weddellina', NULL, 'Tul.', 427),
(20619, 'Weldenia', NULL, 'Schult.f.', 268),
(20620, 'Welwitschia', NULL, 'Hook.f.', 494),
(20621, 'Wendtia', NULL, 'Meyen', 361),
(20622, 'Wettsteiniola', NULL, 'Suess.', 427),
(20623, 'Whipplea', NULL, 'Torr.', 341),
(20624, 'Whiteheadia', NULL, 'Harv.', 338),
(20625, 'Whiteochloa', NULL, 'C.E.Hubb.', 131),
(20626, 'Whittonia', NULL, 'Sandwith', 411),
(20627, 'Wiesneria', NULL, 'Micheli', 209),
(20628, 'Wilhelmsia', NULL, 'Rchb.', 257),
(20629, 'Willdenowia', NULL, 'Thunb.', 444),
(20630, 'Willisia', NULL, 'Warm.', 427),
(20631, 'Willkommia', NULL, 'Hack.', 131),
(20632, 'Windsorina', NULL, 'Gleason', 442),
(20633, 'Winifredia', NULL, 'L.A.S.Johnson & B.G.Briggs', 444),
(20634, 'Winklerella', NULL, 'Engl.', 427),
(20635, 'Witsenia', NULL, 'Thunb.', 349),
(20636, 'Wittrockia', NULL, 'Lindm.', 244),
(20637, 'Wittsteinia', NULL, 'F.Muell.', 212),
(20638, 'Woodsia', NULL, 'R.Br.', 495),
(20639, 'Woodwardia', NULL, 'Sm.', 240),
(20640, 'Wooleya', NULL, 'L.Bolus', 207),
(20641, 'Wullschlaegelia', NULL, 'Rchb.f.', 123),
(20642, 'Wurmbea', NULL, 'Thunb.', 266),
(20643, 'X Acinbreea', NULL, 'Hort.', 123),
(20644, 'X Adaglossum', NULL, 'Hort.', 123),
(20645, 'X Adioda', NULL, 'Hort.', 123),
(20646, 'X Aegilosecale', NULL, 'Cif. & Giacom.', 131),
(20647, 'X Aegilotricale', NULL, 'Tscherm.-Seys.', 131),
(20648, 'X Aegilotriticum', NULL, 'E.Fourn.', 131),
(20649, 'X Aerasconetia', NULL, 'Hort.', 123),
(20650, 'X Aeridachnis', NULL, 'Hort.', 123),
(20651, 'X Aeridisia', NULL, 'Hort.', 123),
(20652, 'X Aeriditis', NULL, 'Hort.', 123),
(20653, 'X Aeridocentrum', NULL, 'Hort.', 123),
(20654, 'X Aeridochilus', NULL, 'Hort.', 123),
(20655, 'X Aeridofinetia', NULL, 'Hort.', 123),
(20656, 'X Aeridoglossum', NULL, 'Hort.', 123),
(20657, 'X Aeridopsis', NULL, 'Hort.', 123),
(20658, 'X Aeridovanda', NULL, 'Hort.', 123),
(20659, 'X Aeridovanisia', NULL, 'Hort.', 123),
(20660, 'X Agrocalamagrostis', NULL, 'Asch. & Graebn.', 131),
(20661, 'X Agroelymus', NULL, 'A.Camus', 131),
(20662, 'X Agrohordeum', NULL, 'A.Camus', 131),
(20663, 'X Agropogon', NULL, 'E.Fourn.', 131),
(20664, 'X Agrositanion', NULL, 'Bowden', 131),
(20665, 'X Agrotrisecale', NULL, 'Cif. & Giacom.', 131),
(20666, 'X Agrotriticum', NULL, 'Cif. & Giacom.', 131),
(20667, 'X Aitkenara', NULL, 'Hort.', 123),
(20668, 'X Alexanderara', NULL, 'Hort.', 123),
(20669, 'X Aliceara', NULL, 'Hort.', 123),
(20670, 'X Allenara', NULL, 'Hort.', 123),
(20671, 'X Amarcrinum', NULL, 'Coutts', 215),
(20672, 'X Amarine', NULL, 'Sealy', 215),
(20673, 'X Anacamptiplatanthera', NULL, 'E.G.Camus', 123),
(20674, 'X Anacamptorchis', NULL, 'E.G.Camus', 123),
(20675, 'X Andrewara', NULL, 'Hort.', 123),
(20676, 'X Angraecentrum', NULL, 'Hort.', 123),
(20677, 'X Angraecostylis', NULL, 'Hort.', 123),
(20678, 'X Angraeorchis', NULL, 'Hort.', 123),
(20679, 'X Angrangis', NULL, 'Hort.', 123),
(20680, 'X Angranthes', NULL, 'Hort.', 123),
(20681, 'X Angulocaste', NULL, 'Hort.', 123),
(20682, 'X Anoectomaria', NULL, 'Hort.', 123),
(20683, 'X Ansidium', NULL, 'Hort.', 123),
(20684, 'X Aracampe', NULL, 'Hort.', 123),
(20685, 'X Arachnoglossum', NULL, 'Hort.', 123),
(20686, 'X Arachnoglottis', NULL, 'Hort.', 123),
(20687, 'X Arachnopsis', NULL, 'Hort.', 123),
(20688, 'X Arachnostylis', NULL, 'Hort.', 123),
(20689, 'X Aranda', NULL, 'Hort.', 123),
(20690, 'X Aranthera', NULL, 'Hort.', 123),
(20691, 'X Arctodupontia', NULL, 'Tzvelev', 131),
(20692, 'X Arizara', NULL, 'Hort.', 123),
(20693, 'X Ascandopsis', NULL, 'Hort.', 123),
(20694, 'X Ascocenda', NULL, 'Hort.', 123),
(20695, 'X Ascocleinetia', NULL, 'Hort.', 123),
(20696, 'X Ascofinetia', NULL, 'Hort.', 123),
(20697, 'X Ascogastisia', NULL, 'Hort.', 123),
(20698, 'X Ascoglottis', NULL, 'Hort.', 123),
(20699, 'X Asconopsis', NULL, 'Hort.', 123),
(20700, 'X Ascorachnis', NULL, 'Hort.', 123),
(20701, 'X Ascovandoritis', NULL, 'Hort.', 123),
(20702, 'X Aspasium', NULL, 'Hort.', 123),
(20703, 'X Asplenoceterach', NULL, 'D.E.Mey.', 226),
(20704, 'X Asplenosorus', NULL, 'Wherry', 226),
(20705, 'X Aspodonia', NULL, 'Hort.', 123),
(20706, 'X Aspoglossum', NULL, 'Hort.', 123),
(20707, 'X Ayubara', NULL, 'Hort.', 123),
(20708, 'X Bakerara', NULL, 'Hort.', 123),
(20709, 'X Baldwinara', NULL, 'Hort.', 123),
(20710, 'X Banfieldara', NULL, 'Hort.', 123),
(20711, 'X Barangis', NULL, 'Hort.', 123),
(20712, 'X Barbendrum', NULL, 'Hort.', 123),
(20713, 'X Barbosaara', NULL, 'Hort.', 123),
(20714, 'X Barlaceras', NULL, 'E.G.Camus', 123),
(20715, 'X Bateostylis', NULL, 'Hort.', 123),
(20716, 'X Baumannara', NULL, 'Hort.', 123),
(20717, 'X Beallara', NULL, 'Hort.', 123),
(20718, 'X Beardara', NULL, 'Hort.', 123),
(20719, 'X Bishopara', NULL, 'Hort.', 123),
(20720, 'X Blackara', NULL, 'Hort.', 123),
(20721, 'X Bloomara', NULL, 'Hort.', 123),
(20722, 'X Bokchoonara', NULL, 'Hort.', 123),
(20723, 'X Bovornara', NULL, 'Hort.', 123),
(20724, 'X Bradeara', NULL, 'Hort.', 123),
(20725, 'X Brapasia', NULL, 'Hort.', 123),
(20726, 'X Brassada', NULL, 'Hort.', 123),
(20727, 'X Brassidium', NULL, 'Hort.', 123),
(20728, 'X Brassocattleya', NULL, 'Hort.', 123),
(20729, 'X Brassochilus', NULL, 'Hort.', 123),
(20730, 'X Brassodiacrium', NULL, 'Hort.', 123),
(20731, 'X Brassoepidendrum', NULL, 'Hort.', 123),
(20732, 'X Brassoepilaelia', NULL, 'Hort.', 123),
(20733, 'X Brassokeria', NULL, 'Hort.', 123),
(20734, 'X Brassolaelia', NULL, 'Hort.', 123),
(20735, 'X Brassolaeliocattleya', NULL, 'Hort.', 123),
(20736, 'X Brassophronitis', NULL, 'Hort.', 123),
(20737, 'X Brassotonia', NULL, 'Hort.', 123),
(20738, 'X Brilliandeara', NULL, 'Hort.', 123),
(20739, 'X Bromofestuca', NULL, 'Prodan', 131),
(20740, 'X Brownara', NULL, 'Hort.', 123),
(20741, 'X Brummitara', NULL, 'Hort.', 123),
(20742, 'X Buiara', NULL, 'Hort.', 123),
(20743, 'X Burkillara', NULL, 'Hort.', 123),
(20744, 'X Burrageara', NULL, 'Hort.', 123),
(20745, 'X Calammophila', NULL, 'Brand', 131),
(20746, 'X Calicharis', NULL, 'Meerow', 215),
(20747, 'X Campbellara', NULL, 'Hort.', 123),
(20748, 'X Carterara', NULL, 'Hort.', 123),
(20749, 'X Casoara', NULL, 'Hort.', 123),
(20750, 'X Catamodes', NULL, 'Hort.', 123),
(20751, 'X Catanoches', NULL, 'Hort.', 123),
(20752, 'X Cattkeria', NULL, 'Hort.', 123),
(20753, 'X Cattleyopsisgoa', NULL, 'Hort.', 123),
(20754, 'X Cattleyopsistonia', NULL, 'Hort.', 123),
(20755, 'X Cattleytonia', NULL, 'Hort.', 123),
(20756, 'X Cattotes', NULL, 'Hort.', 123),
(20757, 'X Chamodenia', NULL, 'E.G.Camus', 123),
(20758, 'X Charlesworthara', NULL, 'Hort.', 123),
(20759, 'X Chewara', NULL, 'Hort.', 123),
(20760, 'X Chilocentrum', NULL, 'Hort.', 123),
(20761, 'X Chionoscilla', NULL, 'J.Allen ex G.Nicholson', 338),
(20762, 'X Chondrobollea', NULL, 'Hort.', 123),
(20763, 'X Chrismatopteris', NULL, 'Quansah & D.S.Edwards', 480),
(20764, 'X Christieara', NULL, 'Hort.', 123),
(20765, 'X Chuanyenara', NULL, 'Hort.', 123),
(20766, 'X Chyletia', NULL, 'Hort.', 123),
(20767, 'X Cirrhophyllum', NULL, 'Hort.', 123),
(20768, 'X Cleisodes', NULL, 'Hort.', 123),
(20769, 'X Cleisonopsis', NULL, 'Hort.', 123),
(20770, 'X Cleisoquetia', NULL, 'Hort.', 123),
(20771, 'X Cochella', NULL, 'Hort.', 123),
(20772, 'X Cochlecaste', NULL, 'Hort.', 123),
(20773, 'X Cochlenia', NULL, 'Hort.', 123),
(20774, 'X Cochlepetalum', NULL, 'Hort.', 123),
(20775, 'X Coeloplatanthera', NULL, 'E.G.Camus', 123),
(20776, 'X Colmanara', NULL, 'Hort.', 123),
(20777, 'X Conphronitis', NULL, 'Hort.', 123),
(20778, 'X Coryhopea', NULL, 'Hort.', 123),
(20779, 'X Crawshayara', NULL, 'Hort.', 123),
(20780, 'X Cycnodes', NULL, 'Hort.', 123),
(20781, 'X Cynochloris', NULL, 'Clifford & Everist', 131),
(20782, 'X Cyrtellia', NULL, 'Hort.', 123),
(20783, 'X Dactylella', NULL, 'E.G.Camus', 123),
(20784, 'X Dactylitella', NULL, 'E.G.Camus', 123),
(20785, 'X Dactyloglossum', NULL, 'E.G.Camus', 123),
(20786, 'X Dactylogymnadenia', NULL, 'E.G.Camus', 123),
(20787, 'X Darwinara', NULL, 'Hort.', 123),
(20788, 'X Debruyneara', NULL, 'Hort.', 123),
(20789, 'X Degarmoara', NULL, 'Hort.', 123),
(20790, 'X Dekensara', NULL, 'Hort.', 123),
(20791, 'X Devereuxara', NULL, 'Hort.', 123),
(20792, 'X Diabroughtonia', NULL, 'Hort.', 123),
(20793, 'X Diacattleya', NULL, 'Hort.', 123),
(20794, 'X Dialaelia', NULL, 'Hort.', 123),
(20795, 'X Dialaeliocattleya', NULL, 'Hort.', 123),
(20796, 'X Dialaeliopsis', NULL, 'Hort.', 123),
(20797, 'X Dillonara', NULL, 'Hort.', 123),
(20798, 'X Diplonopsis', NULL, 'Hort.', 123),
(20799, 'X Domindesmia', NULL, 'Hort.', 123),
(20800, 'X Domintonia', NULL, 'Hort.', 123),
(20801, 'X Dominyara', NULL, 'Hort.', 123),
(20802, 'X Domliopsis', NULL, 'Hort.', 123),
(20803, 'X Doncollinara', NULL, 'Hort.', 123),
(20804, 'X Dorandopsis', NULL, 'Hort.', 123),
(20805, 'X Doricentrum', NULL, 'Hort.', 123),
(20806, 'X Doriella', NULL, 'Hort.', 123),
(20807, 'X Doriellaopsis', NULL, 'Hort.', 123),
(20808, 'X Dorifinetia', NULL, 'Hort.', 123),
(20809, 'X Doriglossum', NULL, 'Hort.', 123),
(20810, 'X Doristylis', NULL, 'Hort.', 123),
(20811, 'X Doritaenopsis', NULL, 'Hort.', 123),
(20812, 'X Dorthera', NULL, 'Hort.', 123),
(20813, 'X Dossinimaria', NULL, 'Hort.', 123),
(20814, 'X Downsara', NULL, 'Hort.', 123),
(20815, 'X Dracuvallia', NULL, 'Hort.', 123),
(20816, 'X Dresslerara', NULL, 'Hort.', 123),
(20817, 'X Duggerara', NULL, 'Hort.', 123),
(20818, 'X Dunnara', NULL, 'Hort.', 123),
(20819, 'X Dunningara', NULL, 'Hort.', 123),
(20820, 'X Durutyara', NULL, 'Hort.', 123),
(20821, 'X Eastonara', NULL, 'Hort.', 123),
(20822, 'X Edeara', NULL, 'Hort.', 123),
(20823, 'X Elyhordeum', NULL, 'Tsitsin & K.A.Petrova', 131),
(20824, 'X Elyleymus', NULL, 'B.R.Baum', 131),
(20825, 'X Elymostachys', NULL, 'Tzvelev', 131),
(20826, 'X Elymotriticum', NULL, 'E.Fourn.', 131),
(20827, 'X Elysitanion', NULL, 'Bowden', 131),
(20828, 'X Epibarkiella', NULL, 'Hort.', 123),
(20829, 'X Epibrassonitis', NULL, 'Hort.', 123),
(20830, 'X Epicatonia', NULL, 'Hort.', 123),
(20831, 'X Epicattleya', NULL, 'Hort.', 123),
(20832, 'X Epidella', NULL, 'Hort.', 123),
(20833, 'X Epidiacrium', NULL, 'Hort.', 123),
(20834, 'X Epiglottis', NULL, 'Hort.', 123),
(20835, 'X Epigoa', NULL, 'Hort.', 123),
(20836, 'X Epilaelia', NULL, 'Hort.', 123),
(20837, 'X Epilaeliocattleya', NULL, 'Hort.', 123),
(20838, 'X Epilaeliopsis', NULL, 'Hort.', 123),
(20839, 'X Epiphronitis', NULL, 'Hort.', 123),
(20840, 'X Epistoma', NULL, 'Hort.', 123),
(20841, 'X Epitonia', NULL, 'Hort.', 123),
(20842, 'X Eriosonia', NULL, 'Pic.Serm.', 202),
(20843, 'X Ernestara', NULL, 'Hort.', 123),
(20844, 'X Eulocymbidiella', NULL, 'Hort.', 123),
(20845, 'X Euryangis', NULL, 'Hort.', 123),
(20846, 'X Eurynopsis', NULL, 'Hort.', 123),
(20847, 'X Fergusonaria', NULL, 'Hort.', 123),
(20848, 'X Festulolium', NULL, 'Asch. & Graebn.', 131),
(20849, 'X Festulpia', NULL, 'Stace & R.Cotton', 131),
(20850, 'X Forgetara', NULL, 'Hort.', 123),
(20851, 'X Freedara', NULL, 'Hort.', 123),
(20852, 'X Fujioara', NULL, 'Hort.', 123),
(20853, 'X Fujiwarara', NULL, 'Hort.', 123),
(20854, 'X Galeansellia', NULL, 'Hort.', 123),
(20855, 'X Gasteraloe', NULL, 'Guillaumin', 211),
(20856, 'X Gasterhaworthia', NULL, 'G.D.Rowley', 211),
(20857, 'X Gastisia', NULL, 'Hort.', 123),
(20858, 'X Gastritis', NULL, 'Hort.', 123),
(20859, 'X Gastrochiloglottis', NULL, 'Hort.', 123),
(20860, 'X Gastrosarcochilus', NULL, 'Hort.', 123),
(20861, 'X Gastrothera', NULL, 'Hort.', 123),
(20862, 'X Gauntlettara', NULL, 'Hort.', 123),
(20863, 'X Goffara', NULL, 'Hort.', 123),
(20864, 'X Gomochilus', NULL, 'Hort.', 123),
(20865, 'X Goodaleara', NULL, 'Hort.', 123),
(20866, 'X Gottererara', NULL, 'Hort.', 123),
(20867, 'X Grammatocymbidium', NULL, 'Hort.', 123),
(20868, 'X Gymnaglossum', NULL, 'E.G.Camus', 123),
(20869, 'X Gymnanacamptis', NULL, 'E.G.Camus', 123),
(20870, 'X Gymnaplatanthera', NULL, 'E.G.Camus', 123),
(20871, 'X Gymnigritella', NULL, 'E.G.Camus', 123),
(20872, 'X Hagerara', NULL, 'Hort.', 123),
(20873, 'X Hainardiopholis', NULL, 'Castrov.', 131),
(20874, 'X Halimiocistus', NULL, 'Janch.', 265),
(20875, 'X Hamelwellsara', NULL, 'Hort.', 123),
(20876, 'X Hanesara', NULL, 'Hort.', 123),
(20877, 'X Hartara', NULL, 'Hort.', 123),
(20878, 'X Hasegawaara', NULL, 'Hort.', 123),
(20879, 'X Hattoriara', NULL, 'Hort.', 123),
(20880, 'X Hausermannara', NULL, 'Hort.', 123),
(20881, 'X Hawaiiara', NULL, 'Hort.', 123),
(20882, 'X Hawkesara', NULL, 'Hort.', 123),
(20883, 'X Hawkinsara', NULL, 'Hort.', 123),
(20884, 'X Herbertara', NULL, 'Hort.', 123),
(20885, 'X Herscheliodisa', NULL, 'Linder', 123),
(20886, 'X Higashiara', NULL, 'Hort.', 123),
(20887, 'X Hildaara', NULL, 'Hort.', 123),
(20888, 'X Himoriara', NULL, 'Hort.', 123),
(20889, 'X Holttumara', NULL, 'Hort.', 123),
(20890, 'X Hookerara', NULL, 'Hort.', 123),
(20891, 'X Hordale', NULL, 'Cif. & Giacom.', 131),
(20892, 'X Howeara', NULL, 'Hort.', 123),
(20893, 'X Hueylihara', NULL, 'Hort.', 123),
(20894, 'X Hugofreedara', NULL, 'Hort.', 123),
(20895, 'X Huntleanthes', NULL, 'Hort.', 123),
(20896, 'X Ionocidium', NULL, 'Hort.', 123),
(20897, 'X Irvingara', NULL, 'Hort.', 123),
(20898, 'X Isaoara', NULL, 'Hort.', 123),
(20899, 'X Iwanagara', NULL, 'Hort.', 123),
(20900, 'X Izumiara', NULL, 'Hort.', 123),
(20901, 'X Jewellara', NULL, 'Hort.', 123),
(20902, 'X Jimenezara', NULL, 'Hort.', 123),
(20903, 'X Joannara', NULL, 'Hort.', 123),
(20904, 'X Johnkellyara', NULL, 'Hort.', 123),
(20905, 'X Jonettia', NULL, 'Hort.', 123),
(20906, 'X Jumanthes', NULL, 'Hort.', 123),
(20907, 'X Kagawara', NULL, 'Hort.', 123),
(20908, 'X Kanzerara', NULL, 'Hort.', 123),
(20909, 'X Kawamotoara', NULL, 'Hort.', 123),
(20910, 'X Keferanthes', NULL, 'Hort.', 123),
(20911, 'X Kirchara', NULL, 'Hort.', 123),
(20912, 'X Knappara', NULL, 'Hort.', 123),
(20913, 'X Knudsonara', NULL, 'Hort.', 123),
(20914, 'X Komkrisara', NULL, 'Hort.', 123),
(20915, 'X Kraussara', NULL, 'Hort.', 123),
(20916, 'X Laeliocatonia', NULL, 'Hort.', 123),
(20917, 'X Laeliocattkeria', NULL, 'Hort.', 123),
(20918, 'X Laeliocattleya', NULL, 'Hort.', 123),
(20919, 'X Laeliokeria', NULL, 'Hort.', 123),
(20920, 'X Laeliopleya', NULL, 'Hort.', 123),
(20921, 'X Laelonia', NULL, 'Hort.', 123),
(20922, 'X Lagerara', NULL, 'Hort.', 123),
(20923, 'X Lancebirkara', NULL, 'Hort.', 123),
(20924, 'X Lauara', NULL, 'Hort.', 123),
(20925, 'X Laycockara', NULL, 'Hort.', 123),
(20926, 'X Leeara', NULL, 'Hort.', 123),
(20927, 'X Lemaireara', NULL, 'Hort.', 123),
(20928, 'X Leocidium', NULL, 'Hort.', 123),
(20929, 'X Leocidmesa', NULL, 'Hort.', 123),
(20930, 'X Leptolaelia', NULL, 'Hort.', 123),
(20931, 'X Leptovola', NULL, 'Hort.', 123),
(20932, 'X Leslieara', NULL, 'Hort.', 123),
(20933, 'X Lewisara', NULL, 'Hort.', 123),
(20934, 'X Leymopyron', NULL, 'Tzvelev', 131),
(20935, 'X Leymostachys', NULL, 'Tzvelev', 131),
(20936, 'X Leymotrix', NULL, 'Khark. & Prob.', 131),
(20937, 'X Liaopsis', NULL, 'Hort.', 123),
(20938, 'X Liebmanara', NULL, 'Hort.', 123),
(20939, 'X Limara', NULL, 'Hort.', 123),
(20940, 'X Lioponia', NULL, 'Hort.', 123),
(20941, 'X Lockcidium', NULL, 'Hort.', 123),
(20942, 'X Lockochilus', NULL, 'Hort.', 123),
(20943, 'X Lowara', NULL, 'Hort.', 123),
(20944, 'X Lowsonara', NULL, 'Hort.', 123),
(20945, 'X Luascotia', NULL, 'Hort.', 123),
(20946, 'X Luicentrum', NULL, 'Hort.', 123),
(20947, 'X Luichilus', NULL, 'Hort.', 123),
(20948, 'X Luinetia', NULL, 'Hort.', 123),
(20949, 'X Luinopsis', NULL, 'Hort.', 123),
(20950, 'X Luisanda', NULL, 'Hort.', 123),
(20951, 'X Luivanetia', NULL, 'Hort.', 123),
(20952, 'X Lutherara', NULL, 'Hort.', 123),
(20953, 'X Lycasteria', NULL, 'Hort.', 123),
(20954, 'X Lymanara', NULL, 'Hort.', 123),
(20955, 'X Lyonara', NULL, 'Hort.', 123),
(20956, 'X Maccoyara', NULL, 'Hort.', 123),
(20957, 'X Maclellanara', NULL, 'Hort.', 123),
(20958, 'X Maclemoreara', NULL, 'Hort.', 123),
(20959, 'X Macomaria', NULL, 'Hort.', 123),
(20960, 'X Macradesa', NULL, 'Hort.', 123),
(20961, 'X Mailamaiara', NULL, 'Hort.', 123),
(20962, 'X Maxillacaste', NULL, 'Hort.', 123),
(20963, 'X Maymoirara', NULL, 'Hort.', 123),
(20964, 'X Micholitzara', NULL, 'Hort.', 123),
(20965, 'X Milpasia', NULL, 'Hort.', 123),
(20966, 'X Milpilia', NULL, 'Hort.', 123),
(20967, 'X Miltada', NULL, 'Hort.', 123),
(20968, 'X Miltadium', NULL, 'Hort.', 123),
(20969, 'X Miltassia', NULL, 'Hort.', 123),
(20970, 'X Miltonidium', NULL, 'Hort.', 123),
(20971, 'X Miltonioda', NULL, 'Hort.', 123),
(20972, 'X Mizutara', NULL, 'Hort.', 123),
(20973, 'X Moirara', NULL, 'Hort.', 123),
(20974, 'X Mokara', NULL, 'Hort.', 123),
(20975, 'X Moonara', NULL, 'Hort.', 123),
(20976, 'X Moscosoara', NULL, 'Hort.', 123),
(20977, 'X Nakagawaara', NULL, 'Hort.', 123),
(20978, 'X Nakamotoara', NULL, 'Hort.', 123),
(20979, 'X Nashara', NULL, 'Hort.', 123),
(20980, 'X Naugleara', NULL, 'Hort.', 123),
(20981, 'X Neobatopus', NULL, 'Hort.', 123),
(20982, 'X Neostylis', NULL, 'Hort.', 123),
(20983, 'X Ngara', NULL, 'Hort.', 123),
(20984, 'X Nobleara', NULL, 'Hort.', 123),
(20985, 'X Nonaara', NULL, 'Hort.', 123),
(20986, 'X Northenara', NULL, 'Hort.', 123),
(20987, 'X Norwoodara', NULL, 'Hort.', 123),
(20988, 'X Notylidium', NULL, 'Hort.', 123),
(20989, 'X Odontioda', NULL, 'Hort.', 123),
(20990, 'X Odontobrassia', NULL, 'Hort.', 123),
(20991, 'X Odontocidium', NULL, 'Hort.', 123),
(20992, 'X Odontonia', NULL, 'Hort.', 123),
(20993, 'X Odontorettia', NULL, 'Hort.', 123),
(20994, 'X Okaara', NULL, 'Hort.', 123),
(20995, 'X Oncidenia', NULL, 'Hort.', 123),
(20996, 'X Oncidesa', NULL, 'Hort.', 123),
(20997, 'X Oncidettia', NULL, 'Hort.', 123),
(20998, 'X Oncidiella', NULL, 'Hort.', 123),
(20999, 'X Oncidioda', NULL, 'Hort.', 123),
(21000, 'X Oncidpilia', NULL, 'Hort.', 123),
(21001, 'X Onoara', NULL, 'Hort.', 123),
(21002, 'X Opsisanda', NULL, 'Hort.', 123),
(21003, 'X Opsiscattleya', NULL, 'Hort.', 123),
(21004, 'X Opsistylis', NULL, 'Hort.', 123),
(21005, 'X Orchiaceras', NULL, 'E.G.Camus', 123),
(21006, 'X Orchidactyla', NULL, 'E.G.Camus', 123),
(21007, 'X Orchigymnadenia', NULL, 'E.G.Camus', 123),
(21008, 'X Orchimantoglossum', NULL, 'E.G.Camus', 123),
(21009, 'X Ornithocidium', NULL, 'E.G.Camus', 123),
(21010, 'X Oryticum', NULL, 'C.P.Wang & S.H.Tang', 131),
(21011, 'X Osmentara', NULL, 'Hort.', 123),
(21012, 'X Otaara', NULL, 'Hort.', 123),
(21013, 'X Otocolax', NULL, 'Hort.', 123),
(21014, 'X Otonisia', NULL, 'Hort.', 123),
(21015, 'X Otosepalum', NULL, 'Hort.', 123),
(21016, 'X Owensara', NULL, 'Hort.', 123),
(21017, 'X Pageara', NULL, 'Hort.', 123),
(21018, 'X Palmerara', NULL, 'Hort.', 123),
(21019, 'X Pantapaara', NULL, 'Hort.', 123),
(21020, 'X Parachilus', NULL, 'Hort.', 123),
(21021, 'X Parnataara', NULL, 'Hort.', 123),
(21022, 'X Paulsenara', NULL, 'Hort.', 123),
(21023, 'X Pehara', NULL, 'Hort.', 123),
(21024, 'X Pelacentrum', NULL, 'Hort.', 123),
(21025, 'X Pelachilus', NULL, 'Hort.', 123),
(21026, 'X Pelatoritis', NULL, 'Hort.', 123),
(21027, 'X Perreiraara', NULL, 'Hort.', 123),
(21028, 'X Pescatobollea', NULL, 'Hort.', 123),
(21029, 'X Pescawarrea', NULL, 'Hort.', 123),
(21030, 'X Pescoranthes', NULL, 'Hort.', 123),
(21031, 'X Pettitara', NULL, 'Hort.', 123),
(21032, 'X Phaiocalanthe', NULL, 'Hort.', 123),
(21033, 'X Phaiocymbidium', NULL, 'Hort.', 123),
(21034, 'X Phalaerianda', NULL, 'Hort.', 123),
(21035, 'X Phalandopsis', NULL, 'Hort.', 123),
(21036, 'X Phalanetia', NULL, 'Hort.', 123),
(21037, 'X Phaliella', NULL, 'Hort.', 123),
(21038, 'X Philageria', NULL, 'Mast.', 415),
(21039, 'X Phillipsara', NULL, 'Hort.', 123),
(21040, 'X Phragmipaphium', NULL, 'Hort.', 123),
(21041, 'X Plectochilus', NULL, 'Hort.', 123),
(21042, 'X Plectrelgraecum', NULL, 'Hort.', 123),
(21043, 'X Pleopodium', NULL, 'Schelpe & N.C.Anthony', 429),
(21044, 'X Pomacentrum', NULL, 'Hort.', 123),
(21045, 'X Pomatisia', NULL, 'Hort.', 123),
(21046, 'X Potinara', NULL, 'Hort.', 123),
(21047, 'X Prolax', NULL, 'Hort.', 123),
(21048, 'X Propetalum', NULL, 'Hort.', 123),
(21049, 'X Pseudadenia', NULL, 'E.G.Camus', 123),
(21050, 'X Pseudinium', NULL, 'E.G.Camus', 123),
(21051, 'X Pseuditella', NULL, 'E.G.Camus', 123),
(21052, 'X Pseudorhiza', NULL, 'E.G.Camus', 123),
(21053, 'X Pucciphippsia', NULL, 'Tzvelev', 131),
(21054, 'X Raganara', NULL, 'Hort.', 123),
(21055, 'X Ramasamyara', NULL, 'Hort.', 123),
(21056, 'X Randactyle', NULL, 'E.G.Camus', 123),
(21057, 'X Recchara', NULL, 'Hort.', 123),
(21058, 'X Renades', NULL, 'Hort.', 123),
(21059, 'X Renafinanda', NULL, 'Hort.', 123),
(21060, 'X Renaglottis', NULL, 'Hort.', 123),
(21061, 'X Renancentrum', NULL, 'Hort.', 123),
(21062, 'X Renanetia', NULL, 'Hort.', 123),
(21063, 'X Renanopsis', NULL, 'Hort.', 123),
(21064, 'X Renanstylis', NULL, 'Hort.', 123),
(21065, 'X Renantanda', NULL, 'Hort.', 123),
(21066, 'X Renanthoglossum', NULL, 'Hort.', 123);
INSERT INTO `Genus` (`GenusID`, `Genus`, `ReferenceID`, `Authority`, `FamilyID`) VALUES
(21067, 'X Renanthopsis', NULL, 'Hort.', 123),
(21068, 'X Rhinochilus', NULL, 'Hort.', 123),
(21069, 'X Rhizanthera', NULL, 'E.G.Camus', 123),
(21070, 'X Rhynchocentrum', NULL, 'Hort.', 123),
(21071, 'X Rhynchonopsis', NULL, 'Hort.', 123),
(21072, 'X Rhynchorides', NULL, 'Hort.', 123),
(21073, 'X Rhynchovanda', NULL, 'Hort.', 123),
(21074, 'X Rhyndoropsis', NULL, 'Hort.', 123),
(21075, 'X Richardmizutaara', NULL, 'Hort.', 123),
(21076, 'X Richardsonara', NULL, 'Hort.', 123),
(21077, 'X Ridleyara', NULL, 'Hort.', 123),
(21078, 'X Robifinetia', NULL, 'Hort.', 123),
(21079, 'X Robinara', NULL, 'Hort.', 123),
(21080, 'X Rodrassia', NULL, 'Hort.', 123),
(21081, 'X Rodrettia', NULL, 'Hort.', 123),
(21082, 'X Rodrettiopsis', NULL, 'Hort.', 123),
(21083, 'X Rodrichilus', NULL, 'Hort.', 123),
(21084, 'X Rodricidium', NULL, 'Hort.', 123),
(21085, 'X Rodridenia', NULL, 'Hort.', 123),
(21086, 'X Rodriglossum', NULL, 'Hort.', 123),
(21087, 'X Rodriopsis', NULL, 'Hort.', 123),
(21088, 'X Rodritonia', NULL, 'Hort.', 123),
(21089, 'X Rolfeara', NULL, 'Hort.', 123),
(21090, 'X Ronnyara', NULL, 'Hort.', 123),
(21091, 'X Rosakirschara', NULL, 'Hort.', 123),
(21092, 'X Roseara', NULL, 'Hort.', 123),
(21093, 'X Rothara', NULL, 'Hort.', 123),
(21094, 'X Rumrillara', NULL, 'Hort.', 123),
(21095, 'X Sagarikara', NULL, 'Hort.', 123),
(21096, 'X Sanderara', NULL, 'Hort.', 123),
(21097, 'X Sappanara', NULL, 'Hort.', 123),
(21098, 'X Sarcocentrum', NULL, 'Hort.', 123),
(21099, 'X Sarconopsis', NULL, 'Hort.', 123),
(21100, 'X Sarcothera', NULL, 'Hort.', 123),
(21101, 'X Sarcovanda', NULL, 'Hort.', 123),
(21102, 'X Saridestylis', NULL, 'Hort.', 123),
(21103, 'X Sartylis', NULL, 'Hort.', 123),
(21104, 'X Sauledaara', NULL, 'Hort.', 123),
(21105, 'X Schafferara', NULL, 'Hort.', 123),
(21106, 'X Schombavola', NULL, 'Hort.', 123),
(21107, 'X Schombocatonia', NULL, 'Hort.', 123),
(21108, 'X Schombocattleya', NULL, 'Hort.', 123),
(21109, 'X Schombodiacrium', NULL, 'Hort.', 123),
(21110, 'X Schomboepidendrum', NULL, 'Hort.', 123),
(21111, 'X Schombolaelia', NULL, 'Hort.', 123),
(21112, 'X Schombonia', NULL, 'Hort.', 123),
(21113, 'X Schombonitis', NULL, 'Hort.', 123),
(21114, 'X Scottara', NULL, 'Hort.', 123),
(21115, 'X Scullyara', NULL, 'Hort.', 123),
(21116, 'X Seahexa', NULL, 'Hort.', 123),
(21117, 'X Serapirhiza', NULL, 'E.G.Camus', 123),
(21118, 'X Severinara', NULL, 'Hort.', 123),
(21119, 'X Shigeuraara', NULL, 'Hort.', 123),
(21120, 'X Shipmanara', NULL, 'Hort.', 123),
(21121, 'X Sidranara', NULL, 'Hort.', 123),
(21122, 'X Silpaprasertara', NULL, 'Hort.', 123),
(21123, 'X Sitordeum', NULL, 'Bowden', 131),
(21124, 'X Sladeara', NULL, 'Hort.', 123),
(21125, 'X Sobennigraecum', NULL, 'Hort.', 123),
(21126, 'X Sophrocattleya', NULL, 'Hort.', 123),
(21127, 'X Sophrolaelia', NULL, 'Hort.', 123),
(21128, 'X Sophrolaeliocattleya', NULL, 'Hort.', 123),
(21129, 'X Staalara', NULL, 'Hort.', 123),
(21130, 'X Stacyara', NULL, 'Hort.', 123),
(21131, 'X Stamariaara', NULL, 'Hort.', 123),
(21132, 'X Stanfieldara', NULL, 'Hort.', 123),
(21133, 'X Stangora', NULL, 'Hort.', 123),
(21134, 'X Stanhocycnis', NULL, 'Hort.', 123),
(21135, 'X Stellamizutaara', NULL, 'Hort.', 123),
(21136, 'X Stewartara', NULL, 'Hort.', 123),
(21137, 'X Stiporyzopsis', NULL, 'B.L.Johnson & Rogler', 131),
(21138, 'X Sutingara', NULL, 'Hort.', 123),
(21139, 'X Teohara', NULL, 'Hort.', 123),
(21140, 'X Tetrakeria', NULL, 'Hort.', 123),
(21141, 'X Tetraliopsis', NULL, 'Hort.', 123),
(21142, 'X Tetratonia', NULL, 'Hort.', 123),
(21143, 'X Thesaera', NULL, 'Hort.', 123),
(21144, 'X Trautara', NULL, 'Hort.', 123),
(21145, 'X Trevorara', NULL, 'Hort.', 123),
(21146, 'X Trichocidium', NULL, 'Hort.', 123),
(21147, 'X Trichonopsis', NULL, 'Hort.', 123),
(21148, 'X Trichopsis', NULL, 'Hort.', 123),
(21149, 'X Trichostylois', NULL, 'Hort.', 123),
(21150, 'X Trichovanda', NULL, 'Hort.', 123),
(21151, 'X Trisetokoeleria', NULL, 'Tzvelev', 131),
(21152, 'X Triticosecale', NULL, 'Wittm. ex A.Camus', 131),
(21153, 'X Tritordeum', NULL, 'Asch. & Graebn.', 131),
(21154, 'X Tubaecum', NULL, 'Hort.', 123),
(21155, 'X Tuckerara', NULL, 'Hort.', 123),
(21156, 'X Urceocharis', NULL, 'Mast.', 215),
(21157, 'X Vanalstyneara', NULL, 'Hort.', 123),
(21158, 'X Vancampe', NULL, 'Hort.', 123),
(21159, 'X Vandachnis', NULL, 'Hort.', 123),
(21160, 'X Vandaenopsis', NULL, 'Hort.', 123),
(21161, 'X Vandaeranthes', NULL, 'Hort.', 123),
(21162, 'X Vandewegheara', NULL, 'Hort.', 123),
(21163, 'X Vandofinetia', NULL, 'Hort.', 123),
(21164, 'X Vandofinides', NULL, 'Hort.', 123),
(21165, 'X Vandopsides', NULL, 'Hort.', 123),
(21166, 'X Vandoritis', NULL, 'Hort.', 123),
(21167, 'X Vanglossum', NULL, 'Hort.', 123),
(21168, 'X Vascostylis', NULL, 'Hort.', 123),
(21169, 'X Vaughnara', NULL, 'Hort.', 123),
(21170, 'X Vuylstekeara', NULL, 'Hort.', 123),
(21171, 'X Warneara', NULL, 'Hort.', 123),
(21172, 'X Westara', NULL, 'Hort.', 123),
(21173, 'X Wilburchangara', NULL, 'Hort.', 123),
(21174, 'X Wilkinsara', NULL, 'Hort.', 123),
(21175, 'X Wilsonara', NULL, 'Hort.', 123),
(21176, 'X Wingfieldara', NULL, 'Hort.', 123),
(21177, 'X Withnerara', NULL, 'Hort.', 123),
(21178, 'X Wooara', NULL, 'Hort.', 123),
(21179, 'X Yahiroara', NULL, 'Hort.', 123),
(21180, 'X Yamadara', NULL, 'Hort.', 123),
(21181, 'X Yapara', NULL, 'Hort.', 123),
(21182, 'X Yoneoara', NULL, 'Hort.', 123),
(21183, 'X Yusofara', NULL, 'Hort.', 123),
(21184, 'X Zygobatemannia', NULL, 'Hort.', 123),
(21185, 'X Zygocaste', NULL, 'Hort.', 123),
(21186, 'X Zygocella', NULL, 'Hort.', 123),
(21187, 'X Zygocolax', NULL, 'Hort.', 123),
(21188, 'X Zygolum', NULL, 'Hort.', 123),
(21189, 'X Zygonisia', NULL, 'Hort.', 123),
(21190, 'X Zygorhyncha', NULL, 'Hort.', 123),
(21191, 'X Zygostylis', NULL, 'Hort.', 123),
(21192, 'Xanthorhiza', NULL, 'Marshall', 441),
(21193, 'Xanthorrhoea', NULL, 'Sm.', 496),
(21194, 'Xenikophyton', NULL, 'Garay', 123),
(21195, 'Xerochloa', NULL, 'R.Br.', 131),
(21196, 'Xerolirion', NULL, 'A.S.George', 368),
(21197, 'Xeronema', NULL, 'Brongn. & Gris', 497),
(21198, 'Xerophyllum', NULL, 'Michx.', 382),
(21199, 'Xeroplana', NULL, 'Briq.', 471),
(21200, 'Xerorchis', NULL, 'Schltr.', 123),
(21201, 'Xerotia', NULL, 'Oliv.', 257),
(21202, 'Xiphidium', NULL, 'Aubl.', 327),
(21203, 'Xiphopteris', NULL, 'Kaulf.', 321),
(21204, 'Xylobium', NULL, 'Lindl.', 123),
(21205, 'Xyloolaena', NULL, 'Baill.', 455),
(21206, 'Xyris', NULL, 'L.', 498),
(21207, 'Xyropteris', NULL, 'K.U.Kramer', 281),
(21208, 'Yakirra', NULL, 'Lazarides & R.D.Webster', 131),
(21209, 'Yoania', NULL, 'Maxim.', 123),
(21210, 'Ypsilandra', NULL, 'Franch.', 382),
(21211, 'Ypsilopus', NULL, 'Summerh.', 123),
(21212, 'Yvesia', NULL, 'A.Camus', 131),
(21213, 'Zaleya', NULL, 'Burm.f.', 207),
(21214, 'Zannichellia', NULL, 'L.', 500),
(21215, 'Zea', NULL, 'L.', 131),
(21216, 'Zehnderia', NULL, 'C.Cusset', 427),
(21217, 'Zenkeria', NULL, 'Trin.', 131),
(21218, 'Zephyra', NULL, 'D.Don', 477),
(21219, 'Zephyranthes', NULL, 'Herb.', 215),
(21220, 'Zetagyne', NULL, 'Ridl.', 123),
(21221, 'Zeugites', NULL, 'P.Browne', 131),
(21222, 'Zeuktophyllum', NULL, 'N.E.Br.', 207),
(21223, 'Zeuxine', NULL, 'Lindl.', 123),
(21224, 'Zigadenus', NULL, 'Michx.', 382),
(21225, 'Zingeria', NULL, 'P.A.Smirn.', 131),
(21226, 'Zingiber', NULL, 'Boehm.', 501),
(21227, 'Zizania', NULL, 'L.', 131),
(21228, 'Zizaniopsis', NULL, 'Doll & Asch.', 131),
(21229, 'Zonotriche', NULL, '(C.E.Hubb.) J.B.Phipps', 131),
(21230, 'Zootrophion', NULL, 'Luer', 123),
(21231, 'Zostera', NULL, 'L.', 502),
(21232, 'Zosterella', NULL, 'Small', 430),
(21233, 'Zoysia', NULL, 'Willd.', 131),
(21234, 'Zygadenia', NULL, 'L.E.Bishop', 321),
(21235, 'Zygochloa', NULL, 'S.T.Blake', 131),
(21236, 'Zygopetalum', NULL, 'Hook.', 123),
(21237, 'Zygophlebia', NULL, 'L.E.Bishop', 321),
(21238, 'Zygosepalum', NULL, 'Rchb.f.', 123),
(21239, 'Zygostates', NULL, 'Lindl.', 123),
(21240, 'Zygotritonia', NULL, 'Mildbr.', 349),
(21241, 'Agouticarpa', NULL, 'C.Persson', 142),
(21242, 'Pleomele', NULL, 'Salisb.', 293),
(21243, 'Leptecophylla', NULL, 'C.M.Weiller', 283),
(21244, 'Sextonia', NULL, 'van der Werff', 91),
(21245, 'Alicia', NULL, 'W.R.Anderson', 101),
(21246, 'Bikinia', NULL, 'Wieringa', 68),
(21247, 'Gabonius', NULL, 'Mackinder & Wieringa', 68),
(21248, 'Semiliquidambar', NULL, 'H.T.Chang', 330),
(21249, 'Isidodendron', NULL, 'Fern. Alonso, Perez Zab. & Idarr', 168),
(21250, 'Libidibia', NULL, '(DC.) Schltdl.', 68),
(21251, 'Cynophalla', NULL, '(DC.) Schltdl.', 32),
(21252, 'Preslianthus', NULL, 'Iltis & Cornejo', 32);

-- --------------------------------------------------------

--
-- Table structure for table `genusWood`
--

DROP TABLE IF EXISTS `genusWood`;
CREATE TABLE IF NOT EXISTS `genusWood` (
  `wsgGenID` int(11) NOT NULL AUTO_INCREMENT,
  `GenusID` int(11) DEFAULT NULL,
  `meanwsg` decimal(10,6) DEFAULT NULL,
  `locale` char(20) DEFAULT NULL,
  PRIMARY KEY (`wsgGenID`),
  KEY `GenusID` (`GenusID`),
  KEY `locale` (`locale`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=796 ;

--
-- Dumping data for table `genusWood`
--

INSERT INTO `genusWood` (`wsgGenID`, `GenusID`, `meanwsg`, `locale`) VALUES
(1, 1, '0.566750', 'world'),
(2, 2, '0.774541', 'world'),
(3, 3, '0.300000', 'world'),
(4, 11, '0.656667', 'world'),
(5, 13, '0.543720', 'world'),
(6, 14, '0.412496', 'world'),
(7, 15, '0.738000', 'world'),
(8, 17, '0.513308', 'world'),
(9, 18, '0.404833', 'world'),
(10, 19, '0.643000', 'world'),
(11, 20, '0.625000', 'world'),
(12, 21, '0.831800', 'world'),
(13, 22, '0.705000', 'world'),
(14, 23, '0.460000', 'world'),
(15, 24, '0.975000', 'world'),
(16, 25, '0.449233', 'world'),
(17, 26, '0.530000', 'world'),
(18, 27, '0.714190', 'world'),
(19, 28, '0.665902', 'world'),
(20, 29, '0.517667', 'world'),
(21, 30, '0.278333', 'world'),
(22, 31, '0.652000', 'world'),
(23, 33, '0.599315', 'world'),
(24, 34, '0.482914', 'world'),
(25, 35, '0.747795', 'world'),
(26, 36, '0.508000', 'world'),
(27, 37, '0.871486', 'world'),
(28, 38, '0.326000', 'world'),
(29, 42, '0.496667', 'world'),
(30, 44, '0.533000', 'world'),
(31, 45, '0.810462', 'world'),
(32, 46, '0.573508', 'world'),
(33, 47, '0.557143', 'world'),
(34, 50, '0.690000', 'world'),
(35, 51, '0.358333', 'world'),
(36, 53, '0.520000', 'world'),
(37, 54, '0.730000', 'world'),
(38, 56, '0.670833', 'world'),
(39, 57, '1.210000', 'world'),
(40, 58, '0.783083', 'world'),
(41, 59, '0.702625', 'world'),
(42, 61, '0.654333', 'world'),
(43, 62, '0.316231', 'world'),
(44, 63, '0.631931', 'world'),
(45, 64, '0.994409', 'world'),
(46, 65, '0.630333', 'world'),
(47, 66, '0.816000', 'world'),
(48, 67, '0.350000', 'world'),
(49, 68, '0.576706', 'world'),
(50, 69, '0.800000', 'world'),
(51, 70, '0.729133', 'world'),
(52, 71, '0.783333', 'world'),
(53, 73, '0.359800', 'world'),
(54, 74, '0.695577', 'world'),
(55, 75, '0.560182', 'world'),
(56, 76, '0.187500', 'world'),
(57, 78, '0.629928', 'world'),
(58, 79, '0.738828', 'world'),
(59, 80, '0.637409', 'world'),
(60, 81, '0.437000', 'world'),
(61, 83, '0.336226', 'world'),
(62, 84, '0.438375', 'world'),
(63, 85, '0.331552', 'world'),
(64, 86, '0.593831', 'world'),
(65, 89, '0.735971', 'world'),
(66, 93, '0.711500', 'world'),
(67, 94, '0.714118', 'world'),
(68, 96, '0.550000', 'world'),
(69, 99, '0.430000', 'world'),
(70, 100, '0.656460', 'world'),
(71, 101, '0.472422', 'world'),
(72, 102, '0.660086', 'world'),
(73, 103, '0.662500', 'world'),
(74, 104, '0.577783', 'world'),
(75, 106, '0.530333', 'world'),
(76, 109, '0.665444', 'world'),
(77, 111, '0.671864', 'world'),
(78, 116, '0.745462', 'world'),
(79, 118, '0.478167', 'world'),
(80, 123, '0.611079', 'world'),
(81, 124, '0.514618', 'world'),
(82, 126, '0.786133', 'world'),
(83, 127, '0.536533', 'world'),
(84, 128, '0.425200', 'world'),
(85, 129, '0.618200', 'world'),
(86, 131, '0.466778', 'world'),
(87, 135, '0.516150', 'world'),
(88, 136, '0.783130', 'world'),
(89, 137, '0.400000', 'world'),
(90, 138, '0.578345', 'world'),
(91, 139, '0.608708', 'world'),
(92, 142, '0.593000', 'world'),
(93, 143, '0.535000', 'world'),
(94, 144, '0.802815', 'world'),
(95, 146, '0.785491', 'world'),
(96, 147, '0.410341', 'world'),
(97, 149, '0.420214', 'world'),
(98, 150, '0.764000', 'world'),
(99, 151, '0.822510', 'world'),
(100, 152, '0.761000', 'world'),
(101, 154, '0.697263', 'world'),
(102, 155, '0.914333', 'world'),
(103, 156, '0.737750', 'world'),
(104, 157, '0.912600', 'world'),
(105, 158, '0.560000', 'world'),
(106, 159, '0.706452', 'world'),
(107, 160, '0.724118', 'world'),
(108, 161, '0.552333', 'world'),
(109, 163, '0.669100', 'world'),
(110, 167, '0.503909', 'world'),
(111, 168, '0.523156', 'world'),
(112, 170, '0.535800', 'world'),
(113, 171, '0.287567', 'world'),
(114, 172, '0.720481', 'world'),
(115, 173, '0.828119', 'world'),
(116, 174, '1.048500', 'world'),
(117, 175, '0.725951', 'world'),
(118, 177, '0.387667', 'world'),
(119, 178, '0.939000', 'world'),
(120, 179, '0.587889', 'world'),
(121, 181, '0.423956', 'world'),
(122, 184, '0.580000', 'world'),
(123, 186, '0.735309', 'world'),
(124, 187, '0.649783', 'world'),
(125, 193, '0.693723', 'world'),
(126, 194, '0.590200', 'world'),
(127, 197, '0.620000', 'world'),
(128, 198, '0.599400', 'world'),
(129, 199, '0.560551', 'world'),
(130, 200, '0.564970', 'world'),
(131, 202, '0.725165', 'world'),
(132, 203, '0.641417', 'world'),
(133, 204, '0.370000', 'world'),
(134, 205, '0.626833', 'world'),
(135, 206, '0.317500', 'world'),
(136, 207, '0.530000', 'world'),
(137, 208, '0.450000', 'world'),
(138, 209, '0.696250', 'world'),
(139, 210, '0.643000', 'world'),
(140, 211, '0.499000', 'world'),
(141, 213, '0.619966', 'world'),
(142, 214, '0.480000', 'world'),
(143, 215, '0.295727', 'world'),
(144, 217, '0.504136', 'world'),
(145, 220, '0.781668', 'world'),
(146, 221, '0.709500', 'world'),
(147, 222, '0.901333', 'world'),
(148, 223, '0.667636', 'world'),
(149, 225, '0.670000', 'world'),
(150, 226, '0.792775', 'world'),
(151, 227, '0.652778', 'world'),
(152, 229, '0.569156', 'world'),
(153, 230, '0.580505', 'world'),
(154, 232, '0.597423', 'world'),
(155, 234, '0.783929', 'world'),
(156, 235, '0.413321', 'world'),
(157, 236, '0.265000', 'world'),
(158, 242, '0.668000', 'world'),
(159, 243, '0.509333', 'world'),
(160, 244, '0.504800', 'world'),
(161, 245, '0.490000', 'world'),
(162, 246, '0.639988', 'world'),
(163, 248, '0.596905', 'world'),
(164, 253, '0.893333', 'world'),
(165, 254, '0.818491', 'world'),
(166, 256, '0.616667', 'world'),
(167, 257, '0.809515', 'world'),
(168, 258, '0.808783', 'world'),
(169, 259, '0.560000', 'world'),
(170, 260, '0.740872', 'world'),
(171, 262, '0.551400', 'world'),
(172, 263, '0.607500', 'world'),
(173, 264, '0.440000', 'world'),
(174, 265, '0.615727', 'world'),
(175, 266, '0.804767', 'world'),
(176, 268, '0.414333', 'world'),
(177, 269, '0.450000', 'world'),
(178, 270, '0.602500', 'world'),
(179, 272, '0.526667', 'world'),
(180, 273, '0.569233', 'world'),
(181, 274, '0.681792', 'world'),
(182, 275, '0.512897', 'world'),
(183, 277, '0.887636', 'world'),
(184, 278, '0.588000', 'world'),
(185, 279, '0.563500', 'world'),
(186, 280, '0.817294', 'world'),
(187, 281, '0.637600', 'world'),
(188, 283, '0.743000', 'world'),
(189, 284, '0.484778', 'world'),
(190, 286, '0.709996', 'world'),
(191, 287, '0.980000', 'world'),
(192, 288, '0.504310', 'world'),
(193, 289, '0.618877', 'world'),
(194, 290, '0.653069', 'world'),
(195, 291, '0.823500', 'world'),
(196, 293, '0.786714', 'world'),
(197, 296, '0.558000', 'world'),
(198, 298, '0.510000', 'world'),
(199, 301, '0.833636', 'world'),
(200, 303, '0.814458', 'world'),
(201, 304, '0.700000', 'world'),
(202, 308, '0.734405', 'world'),
(203, 309, '0.650500', 'world'),
(204, 310, '0.571690', 'world'),
(205, 311, '0.629889', 'world'),
(206, 313, '0.525773', 'world'),
(207, 314, '0.681500', 'world'),
(208, 316, '0.520000', 'world'),
(209, 317, '0.589595', 'world'),
(210, 320, '0.408929', 'world'),
(211, 321, '0.727000', 'world'),
(212, 322, '0.727981', 'world'),
(213, 323, '0.439000', 'world'),
(214, 324, '0.526670', 'world'),
(215, 325, '0.509000', 'world'),
(216, 326, '0.620000', 'world'),
(217, 327, '0.701764', 'world'),
(218, 328, '0.451791', 'world'),
(219, 335, '0.646889', 'world'),
(220, 336, '0.487833', 'world'),
(221, 338, '0.514821', 'world'),
(222, 339, '0.544235', 'world'),
(223, 340, '0.737400', 'world'),
(224, 341, '0.617778', 'world'),
(225, 343, '0.382514', 'world'),
(226, 344, '0.554815', 'world'),
(227, 346, '0.784048', 'world'),
(228, 349, '0.470000', 'world'),
(229, 350, '0.950000', 'world'),
(230, 352, '0.477576', 'world'),
(231, 355, '0.553167', 'world'),
(232, 358, '0.386250', 'world'),
(233, 359, '0.714372', 'world'),
(234, 360, '0.279657', 'world'),
(235, 364, '0.575724', 'world'),
(236, 367, '0.642731', 'world'),
(237, 369, '0.810091', 'world'),
(238, 370, '0.524742', 'world'),
(239, 371, '0.580347', 'world'),
(240, 372, '0.646811', 'world'),
(241, 373, '0.500629', 'world'),
(242, 374, '0.351833', 'world'),
(243, 376, '0.861500', 'world'),
(244, 377, '0.658965', 'world'),
(245, 380, '0.474359', 'world'),
(246, 382, '0.670538', 'world'),
(247, 383, '0.360400', 'world'),
(248, 384, '0.637500', 'world'),
(249, 386, '0.848000', 'world'),
(250, 387, '0.820000', 'world'),
(251, 388, '0.570000', 'world'),
(252, 392, '0.800579', 'world'),
(253, 393, '0.760000', 'world'),
(254, 395, '0.735455', 'world'),
(255, 396, '0.412806', 'world'),
(256, 397, '0.615000', 'world'),
(257, 398, '0.398667', 'world'),
(258, 399, '0.427102', 'world'),
(259, 403, '0.540586', 'world'),
(260, 404, '0.631154', 'world'),
(261, 406, '0.419333', 'world'),
(262, 408, '0.656200', 'world'),
(263, 409, '0.624723', 'world'),
(264, 410, '0.230000', 'world'),
(265, 411, '0.421683', 'world'),
(266, 412, '0.608333', 'world'),
(267, 413, '0.595000', 'world'),
(268, 415, '0.364781', 'world'),
(269, 418, '0.490000', 'world'),
(270, 419, '0.425600', 'world'),
(271, 420, '0.695947', 'world'),
(272, 421, '0.482500', 'world'),
(273, 422, '0.844349', 'world'),
(274, 423, '0.538868', 'world'),
(275, 424, '0.618323', 'world'),
(276, 425, '0.533524', 'world'),
(277, 427, '0.649163', 'world'),
(278, 428, '0.752586', 'world'),
(279, 429, '0.524667', 'world'),
(280, 430, '0.557333', 'world'),
(281, 433, '0.849889', 'world'),
(282, 434, '0.438778', 'world'),
(283, 435, '0.660250', 'world'),
(284, 438, '0.554754', 'world'),
(285, 439, '0.618091', 'world'),
(286, 440, '0.701843', 'world'),
(287, 441, '0.620000', 'world'),
(288, 442, '0.454500', 'world'),
(289, 443, '0.529714', 'world'),
(290, 444, '0.605500', 'world'),
(291, 445, '0.635000', 'world'),
(292, 447, '0.620000', 'world'),
(293, 448, '0.678571', 'world'),
(294, 449, '0.458895', 'world'),
(295, 450, '0.335088', 'world'),
(296, 452, '0.635772', 'world'),
(297, 454, '0.514056', 'world'),
(298, 456, '0.602333', 'world'),
(299, 458, '0.394042', 'world'),
(300, 459, '0.540000', 'world'),
(301, 460, '0.331193', 'world'),
(302, 461, '0.835000', 'world'),
(303, 463, '0.674300', 'world'),
(304, 466, '0.473016', 'world'),
(305, 467, '0.490875', 'world'),
(306, 468, '0.549453', 'world'),
(307, 469, '0.466377', 'world'),
(308, 477, '0.621719', 'world'),
(309, 478, '0.719491', 'world'),
(310, 480, '0.609392', 'world'),
(311, 481, '0.774588', 'world'),
(312, 483, '0.809857', 'world'),
(313, 490, '0.575000', 'world'),
(314, 497, '0.440400', 'world'),
(315, 498, '0.818714', 'world'),
(316, 499, '0.370000', 'world'),
(317, 501, '0.571129', 'world'),
(318, 502, '0.450000', 'world'),
(319, 503, '0.630333', 'world'),
(320, 504, '0.537917', 'world'),
(321, 505, '0.541905', 'world'),
(322, 507, '0.517636', 'world'),
(323, 509, '0.692149', 'world'),
(324, 510, '0.752667', 'world'),
(325, 511, '0.425400', 'world'),
(326, 512, '0.617100', 'world'),
(327, 514, '0.646364', 'world'),
(328, 518, '0.382667', 'world'),
(329, 520, '0.738000', 'world'),
(330, 521, '0.573077', 'world'),
(331, 524, '0.616769', 'world'),
(332, 531, '0.447222', 'world'),
(333, 537, '0.531667', 'world'),
(334, 538, '0.690000', 'world'),
(335, 539, '0.716600', 'world'),
(336, 542, '0.501692', 'world'),
(337, 543, '0.806500', 'world'),
(338, 544, '0.390000', 'world'),
(339, 545, '0.576667', 'world'),
(340, 546, '0.588400', 'world'),
(341, 547, '0.594667', 'world'),
(342, 551, '0.347286', 'world'),
(343, 555, '0.413000', 'world'),
(344, 561, '0.460000', 'world'),
(345, 562, '0.665000', 'world'),
(346, 563, '0.564000', 'world'),
(347, 568, '0.623529', 'world'),
(348, 570, '0.715455', 'world'),
(349, 572, '0.701000', 'world'),
(350, 573, '0.487053', 'world'),
(351, 575, '0.640000', 'world'),
(352, 577, '0.616600', 'world'),
(353, 579, '0.618333', 'world'),
(354, 580, '0.595909', 'world'),
(355, 581, '0.710000', 'world'),
(356, 583, '0.723281', 'world'),
(357, 584, '0.576250', 'world'),
(358, 585, '0.364000', 'world'),
(359, 592, '0.315000', 'world'),
(360, 593, '0.411000', 'world'),
(361, 596, '0.650000', 'world'),
(362, 599, '0.550000', 'world'),
(363, 600, '0.817400', 'world'),
(364, 602, '0.319333', 'world'),
(365, 605, '0.647875', 'world'),
(366, 606, '0.731333', 'world'),
(367, 608, '0.450000', 'world'),
(368, 609, '0.698065', 'world'),
(369, 610, '0.650000', 'world'),
(370, 611, '0.721667', 'world'),
(371, 612, '0.549783', 'world'),
(372, 614, '0.503800', 'world'),
(373, 617, '0.510000', 'world'),
(374, 621, '0.560000', 'world'),
(375, 622, '0.626141', 'world'),
(376, 623, '0.499286', 'world'),
(377, 626, '0.548200', 'world'),
(378, 628, '0.540000', 'world'),
(379, 629, '0.827000', 'world'),
(380, 631, '0.355000', 'world'),
(381, 632, '0.482000', 'world'),
(382, 633, '0.516667', 'world'),
(383, 634, '0.660800', 'world'),
(384, 635, '0.320889', 'world'),
(385, 636, '0.574667', 'world'),
(386, 638, '0.491217', 'world'),
(387, 639, '0.585000', 'world'),
(388, 640, '0.630000', 'world'),
(389, 641, '0.601273', 'world'),
(390, 642, '0.358600', 'world'),
(391, 647, '0.479000', 'world'),
(392, 648, '0.619500', 'world'),
(393, 650, '0.663000', 'world'),
(394, 651, '0.633050', 'world'),
(395, 652, '0.578500', 'world'),
(396, 657, '0.602250', 'world'),
(397, 661, '0.510000', 'world'),
(398, 664, '0.563151', 'world'),
(399, 666, '0.511167', 'world'),
(400, 667, '0.640000', 'world'),
(401, 670, '0.722000', 'world'),
(402, 671, '0.565692', 'world'),
(403, 673, '0.635333', 'world'),
(404, 674, '0.207000', 'world'),
(405, 677, '0.427364', 'world'),
(406, 679, '0.510000', 'world'),
(407, 680, '0.706385', 'world'),
(408, 681, '0.659018', 'world'),
(409, 682, '0.705000', 'world'),
(410, 683, '0.439782', 'world'),
(411, 684, '0.738556', 'world'),
(412, 685, '0.649538', 'world'),
(413, 686, '0.370000', 'world'),
(414, 688, '0.655000', 'world'),
(415, 689, '0.371267', 'world'),
(416, 690, '0.566063', 'world'),
(417, 692, '0.482409', 'world'),
(418, 693, '0.695250', 'world'),
(419, 694, '0.672471', 'world'),
(420, 696, '0.777500', 'world'),
(421, 697, '0.633429', 'world'),
(422, 698, '0.573500', 'world'),
(423, 700, '0.612432', 'world'),
(424, 701, '0.645411', 'world'),
(425, 702, '0.546786', 'world'),
(426, 703, '0.590547', 'world'),
(427, 704, '0.488577', 'world'),
(428, 705, '0.554333', 'world'),
(429, 706, '0.520000', 'world'),
(430, 707, '0.738667', 'world'),
(431, 710, '0.562500', 'world'),
(432, 711, '0.439000', 'world'),
(433, 712, '0.456000', 'world'),
(434, 713, '0.440000', 'world'),
(435, 716, '0.708860', 'world'),
(436, 717, '0.442588', 'world'),
(437, 719, '0.634200', 'world'),
(438, 721, '0.790000', 'world'),
(439, 723, '0.570000', 'world'),
(440, 725, '0.860273', 'world'),
(441, 726, '0.425045', 'world'),
(442, 728, '0.380789', 'world'),
(443, 729, '0.681415', 'world'),
(444, 730, '0.676000', 'world'),
(445, 731, '0.502655', 'world'),
(446, 732, '0.471667', 'world'),
(447, 733, '0.440000', 'world'),
(448, 734, '0.767900', 'world'),
(449, 735, '0.720500', 'world'),
(450, 736, '0.540000', 'world'),
(451, 737, '0.458676', 'world'),
(452, 739, '0.533250', 'world'),
(453, 742, '0.555000', 'world'),
(454, 743, '0.579753', 'world'),
(455, 746, '0.635643', 'world'),
(456, 748, '0.581868', 'world'),
(457, 750, '0.734167', 'world'),
(458, 751, '0.357143', 'world'),
(459, 753, '0.746680', 'world'),
(460, 755, '0.593667', 'world'),
(461, 756, '0.100000', 'world'),
(462, 758, '0.480000', 'world'),
(463, 759, '0.868000', 'world'),
(464, 760, '0.692750', 'world'),
(465, 761, '0.669143', 'world'),
(466, 762, '0.919000', 'world'),
(467, 767, '0.600000', 'world'),
(468, 770, '0.715000', 'world'),
(469, 772, '0.700000', 'world'),
(470, 773, '0.820000', 'world'),
(471, 777, '0.765000', 'world'),
(472, 779, '0.700000', 'world'),
(473, 786, '0.579000', 'world'),
(474, 787, '0.418250', 'world'),
(475, 789, '0.453000', 'world'),
(476, 790, '0.840000', 'world'),
(477, 791, '0.609231', 'world'),
(478, 794, '0.569000', 'world'),
(479, 795, '0.772000', 'world'),
(480, 797, '0.506000', 'world'),
(481, 802, '0.656417', 'world'),
(482, 805, '0.349769', 'world'),
(483, 809, '0.493333', 'world'),
(484, 813, '0.790250', 'world'),
(485, 814, '0.523000', 'world'),
(486, 815, '0.703000', 'world'),
(487, 816, '0.454000', 'world'),
(488, 817, '0.607100', 'world'),
(489, 821, '0.819026', 'world'),
(490, 824, '0.470278', 'world'),
(491, 828, '0.786667', 'world'),
(492, 832, '0.505000', 'world'),
(493, 833, '0.367400', 'world'),
(494, 834, '0.773400', 'world'),
(495, 835, '0.640000', 'world'),
(496, 836, '0.545235', 'world'),
(497, 838, '0.696000', 'world'),
(498, 839, '0.424000', 'world'),
(499, 841, '0.635000', 'world'),
(500, 843, '0.670786', 'world'),
(501, 845, '0.568833', 'world'),
(502, 848, '0.659533', 'world'),
(503, 849, '0.461000', 'world'),
(504, 851, '0.582931', 'world'),
(505, 855, '0.610000', 'world'),
(506, 857, '0.661500', 'world'),
(507, 858, '0.549130', 'world'),
(508, 861, '0.556588', 'world'),
(509, 862, '0.548250', 'world'),
(510, 863, '0.551111', 'world'),
(511, 865, '0.520000', 'world'),
(512, 868, '0.621000', 'world'),
(513, 869, '0.810000', 'world'),
(514, 870, '0.610500', 'world'),
(515, 874, '0.607850', 'world'),
(516, 875, '0.476667', 'world'),
(517, 876, '0.657420', 'world'),
(518, 878, '0.438196', 'world'),
(519, 880, '0.533900', 'world'),
(520, 885, '0.720000', 'world'),
(521, 888, '0.702000', 'world'),
(522, 890, '0.833750', 'world'),
(523, 892, '0.528000', 'world'),
(524, 899, '0.803400', 'world'),
(525, 902, '0.635400', 'world'),
(526, 903, '0.760000', 'world'),
(527, 907, '0.681667', 'world'),
(528, 909, '0.520629', 'world'),
(529, 910, '0.530000', 'world'),
(530, 911, '0.387500', 'world'),
(531, 914, '0.924385', 'world'),
(532, 915, '0.533316', 'world'),
(533, 921, '0.258000', 'world'),
(534, 923, '0.804333', 'world'),
(535, 924, '0.421000', 'world'),
(536, 925, '0.753333', 'world'),
(537, 927, '0.784000', 'world'),
(538, 929, '0.823091', 'world'),
(539, 931, '0.688000', 'world'),
(540, 936, '0.514875', 'world'),
(541, 938, '0.668292', 'world'),
(542, 940, '0.515800', 'world'),
(543, 941, '0.600000', 'world'),
(544, 942, '0.465429', 'world'),
(545, 948, '0.383500', 'world'),
(546, 950, '0.499926', 'world'),
(547, 956, '0.844300', 'world'),
(548, 960, '0.390000', 'world'),
(549, 962, '0.586250', 'world'),
(550, 964, '0.449583', 'world'),
(551, 965, '0.482045', 'world'),
(552, 968, '0.490000', 'world'),
(553, 971, '0.754235', 'world'),
(554, 972, '0.536667', 'world'),
(555, 973, '0.503621', 'world'),
(556, 974, '0.500200', 'world'),
(557, 976, '0.660000', 'world'),
(558, 979, '0.649833', 'world'),
(559, 980, '0.715210', 'world'),
(560, 981, '0.731222', 'world'),
(561, 983, '0.680000', 'world'),
(562, 985, '0.480000', 'world'),
(563, 986, '0.490000', 'world'),
(564, 988, '0.638792', 'world'),
(565, 995, '0.755750', 'world'),
(566, 996, '0.449500', 'world'),
(567, 997, '0.583000', 'world'),
(568, 999, '0.607683', 'world'),
(569, 1000, '0.427500', 'world'),
(570, 1001, '0.760000', 'world'),
(571, 1002, '0.330000', 'world'),
(572, 1005, '0.655818', 'world'),
(573, 1006, '0.614800', 'world'),
(574, 1012, '0.762412', 'world'),
(575, 1013, '0.654588', 'world'),
(576, 1014, '0.573708', 'world'),
(577, 1016, '0.380000', 'world'),
(578, 1017, '0.443333', 'world'),
(579, 1019, '0.746375', 'world'),
(580, 1021, '0.688000', 'world'),
(581, 1022, '0.301000', 'world'),
(582, 1023, '0.771000', 'world'),
(583, 1024, '0.754444', 'world'),
(584, 1025, '0.477500', 'world'),
(585, 1026, '0.550000', 'world'),
(586, 1027, '0.580000', 'world'),
(587, 1035, '0.715000', 'world'),
(588, 1036, '0.742000', 'world'),
(589, 1039, '0.841500', 'world'),
(590, 1040, '0.370000', 'world'),
(591, 1043, '0.525000', 'world'),
(592, 1044, '0.738000', 'world'),
(593, 1048, '0.331000', 'world'),
(594, 1051, '0.826667', 'world'),
(595, 1052, '0.404000', 'world'),
(596, 1053, '0.550000', 'world'),
(597, 1054, '0.873600', 'world'),
(598, 1055, '0.530000', 'world'),
(599, 1056, '0.675000', 'world'),
(600, 1062, '0.590000', 'world'),
(601, 1063, '0.596714', 'world'),
(602, 1064, '0.650333', 'world'),
(603, 1066, '0.436667', 'world'),
(604, 1068, '0.599000', 'world'),
(605, 1069, '0.708095', 'world'),
(606, 1070, '0.770571', 'world'),
(607, 1074, '0.680000', 'world'),
(608, 1082, '0.450000', 'world'),
(609, 1084, '0.497000', 'world'),
(610, 1086, '0.819154', 'world'),
(611, 1089, '0.330000', 'world'),
(612, 1091, '0.793000', 'world'),
(613, 1093, '0.671200', 'world'),
(614, 1094, '0.401000', 'world'),
(615, 1099, '0.566758', 'world'),
(616, 1101, '0.561111', 'world'),
(617, 1103, '0.545000', 'world'),
(618, 1104, '0.550000', 'world'),
(619, 1106, '0.731333', 'world'),
(620, 1107, '0.633333', 'world'),
(621, 1109, '0.638182', 'world'),
(622, 1119, '0.581000', 'world'),
(623, 1121, '0.689000', 'world'),
(624, 1122, '0.762750', 'world'),
(625, 1125, '0.525000', 'world'),
(626, 1127, '0.521000', 'world'),
(627, 1128, '0.535833', 'world'),
(628, 1129, '0.662500', 'world'),
(629, 1130, '0.565000', 'world'),
(630, 1133, '0.561500', 'world'),
(631, 1134, '0.700737', 'world'),
(632, 1135, '0.506750', 'world'),
(633, 1137, '0.649500', 'world'),
(634, 1138, '0.780000', 'world'),
(635, 1143, '0.777500', 'world'),
(636, 1144, '0.495500', 'world'),
(637, 1145, '0.395000', 'world'),
(638, 1146, '0.585143', 'world'),
(639, 1147, '0.576667', 'world'),
(640, 1150, '0.641500', 'world'),
(641, 1151, '0.601000', 'world'),
(642, 1152, '0.470000', 'world'),
(643, 1155, '0.584444', 'world'),
(644, 1160, '0.756121', 'world'),
(645, 1161, '0.438833', 'world'),
(646, 1162, '0.581381', 'world'),
(647, 1164, '0.551857', 'world'),
(648, 1165, '0.498000', 'world'),
(649, 1166, '0.610000', 'world'),
(650, 1168, '0.503750', 'world'),
(651, 1171, '0.550143', 'world'),
(652, 1173, '0.911000', 'world'),
(653, 1174, '0.733333', 'world'),
(654, 1175, '0.706250', 'world'),
(655, 1178, '0.723333', 'world'),
(656, 1179, '0.572000', 'world'),
(657, 1182, '0.625000', 'world'),
(658, 1184, '0.656875', 'world'),
(659, 1185, '0.576061', 'world'),
(660, 1188, '0.560000', 'world'),
(661, 1193, '0.790526', 'world'),
(662, 1194, '0.550000', 'world'),
(663, 1195, '0.524286', 'world'),
(664, 1197, '0.656455', 'world'),
(665, 1199, '0.736462', 'world'),
(666, 1200, '0.633000', 'world'),
(667, 1202, '0.557200', 'world'),
(668, 1203, '0.423250', 'world'),
(669, 1205, '0.644333', 'world'),
(670, 1206, '0.627444', 'world'),
(671, 1208, '0.677500', 'world'),
(672, 1210, '0.686000', 'world'),
(673, 1212, '0.588625', 'world'),
(674, 1213, '0.799000', 'world'),
(675, 1215, '0.538053', 'world'),
(676, 1216, '0.232000', 'world'),
(677, 1226, '0.470000', 'world'),
(678, 1231, '0.630333', 'world'),
(679, 1235, '0.696667', 'world'),
(680, 1241, '0.848500', 'world'),
(681, 1243, '0.649600', 'world'),
(682, 1244, '0.493455', 'world'),
(683, 1245, '0.633828', 'world'),
(684, 1246, '0.533636', 'world'),
(685, 1253, '0.696250', 'world'),
(686, 1254, '0.659000', 'world'),
(687, 1255, '0.345625', 'world'),
(688, 1256, '0.631000', 'world'),
(689, 1260, '0.840000', 'world'),
(690, 1263, '0.633867', 'world'),
(691, 1266, '0.434000', 'world'),
(692, 1267, '0.704286', 'world'),
(693, 1271, '0.770000', 'world'),
(694, 1277, '0.722600', 'world'),
(695, 1296, '0.366208', 'world'),
(696, 1417, '0.784000', 'world'),
(697, 1556, '0.746444', 'world'),
(698, 1869, '0.521000', 'world'),
(699, 1894, '0.660000', 'world'),
(700, 1897, '0.834500', 'world'),
(701, 1956, '0.710000', 'world'),
(702, 2375, '0.720000', 'world'),
(703, 2709, '0.548000', 'world'),
(704, 2780, '0.666800', 'world'),
(705, 3045, '0.537643', 'world'),
(706, 3161, '0.640200', 'world'),
(707, 3162, '0.883200', 'world'),
(708, 3358, '0.300000', 'world'),
(709, 3422, '0.458667', 'world'),
(710, 3526, '0.722000', 'world'),
(711, 3615, '0.452000', 'world'),
(712, 3844, '0.553407', 'world'),
(713, 3848, '0.834000', 'world'),
(714, 3873, '0.583000', 'world'),
(715, 3899, '0.607462', 'world'),
(716, 3969, '0.565769', 'world'),
(717, 3991, '0.685000', 'world'),
(718, 4079, '0.634000', 'world'),
(719, 4356, '0.487000', 'world'),
(720, 4489, '0.650000', 'world'),
(721, 4498, '0.588182', 'world'),
(722, 4565, '0.342031', 'world'),
(723, 4754, '0.791333', 'world'),
(724, 4800, '0.500000', 'world'),
(725, 4831, '0.748800', 'world'),
(726, 4880, '0.587500', 'world'),
(727, 4895, '0.550000', 'world'),
(728, 4916, '0.754667', 'world'),
(729, 4949, '0.490400', 'world'),
(730, 4990, '0.660000', 'world'),
(731, 5103, '0.752750', 'world'),
(732, 5707, '0.591200', 'world'),
(733, 5736, '0.577231', 'world'),
(734, 5790, '0.746077', 'world'),
(735, 5912, '0.330000', 'world'),
(736, 6005, '0.432750', 'world'),
(737, 6469, '0.739524', 'world'),
(738, 6799, '0.484700', 'world'),
(739, 7018, '0.559200', 'world'),
(740, 7070, '0.742667', 'world'),
(741, 7188, '0.776750', 'world'),
(742, 7305, '0.664714', 'world'),
(743, 7383, '0.780000', 'world'),
(744, 7745, '0.788000', 'world'),
(745, 7898, '0.627500', 'world'),
(746, 8096, '0.344000', 'world'),
(747, 8310, '0.543000', 'world'),
(748, 8740, '0.487500', 'world'),
(749, 8785, '0.620000', 'world'),
(750, 8941, '0.595000', 'world'),
(751, 9143, '0.463211', 'world'),
(752, 9620, '0.710000', 'world'),
(753, 9872, '0.310000', 'world'),
(754, 9978, '0.600600', 'world'),
(755, 10002, '0.409857', 'world'),
(756, 10060, '0.945000', 'world'),
(757, 10349, '0.722889', 'world'),
(758, 10783, '0.740000', 'world'),
(759, 11313, '0.514667', 'world'),
(760, 11338, '0.730000', 'world'),
(761, 11674, '0.399500', 'world'),
(762, 11761, '0.715000', 'world'),
(763, 12176, '0.791314', 'world'),
(764, 12635, '0.258000', 'world'),
(765, 12640, '0.369573', 'world'),
(766, 12691, '0.927500', 'world'),
(767, 12708, '0.446431', 'world'),
(768, 12718, '0.650000', 'world'),
(769, 12833, '0.675000', 'world'),
(770, 13120, '0.376955', 'world'),
(771, 13124, '0.762833', 'world'),
(772, 13462, '0.370000', 'world'),
(773, 13672, '0.632000', 'world'),
(774, 13810, '0.483333', 'world'),
(775, 13888, '0.559200', 'world'),
(776, 13942, '0.779000', 'world'),
(777, 14132, '0.825000', 'world'),
(778, 14152, '0.350000', 'world'),
(779, 14164, '0.601900', 'world'),
(780, 14259, '0.403750', 'world'),
(781, 14289, '0.446333', 'world'),
(782, 14358, '0.442167', 'world'),
(783, 14595, '0.616917', 'world'),
(784, 14630, '0.913000', 'world'),
(785, 14718, '0.380000', 'world'),
(786, 14990, '0.611333', 'world'),
(787, 16053, '0.421588', 'world'),
(788, 16445, '0.663000', 'world'),
(789, 16646, '0.980000', 'world'),
(790, 17483, '0.641000', 'world'),
(791, 18184, '0.698333', 'world'),
(792, 18784, '0.579000', 'world'),
(793, 19027, '0.814000', 'world'),
(794, 19663, '0.620600', 'world'),
(795, 19971, '0.730000', 'world');

-- --------------------------------------------------------

--
-- Table structure for table `Plots`
--

DROP TABLE IF EXISTS `Plots`;
CREATE TABLE IF NOT EXISTS `Plots` (
  `Plots_ID` int(11) NOT NULL AUTO_INCREMENT,
  `PlotName` varchar(40) NOT NULL,
  `DatabaseName` varchar(40) NOT NULL,
  `DatabaseVersion` varchar(40) NOT NULL DEFAULT 'new',
  PRIMARY KEY (`Plots_ID`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;


-- --------------------------------------------------------

--
-- Table structure for table `speciesWood`
--

DROP TABLE IF EXISTS `speciesWood`;
CREATE TABLE IF NOT EXISTS `speciesWood` (
  `wsgSpID` int(11) NOT NULL AUTO_INCREMENT,
  `GenusID` int(11) DEFAULT NULL,
  `species` char(64) DEFAULT NULL,
  `subspecies` char(64) DEFAULT NULL,
  `infra` enum('species','genus','family','none','local') DEFAULT NULL,
  `locale` char(20) DEFAULT NULL,
  `wsg` decimal(10,6) DEFAULT NULL,
  PRIMARY KEY (`wsgSpID`),
  KEY `GenusID` (`GenusID`),
  KEY `species` (`species`),
  KEY `subspecies` (`subspecies`),
  KEY `locale` (`locale`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `speciesWood`
--

INSERT INTO `speciesWood` (`wsgSpID`, `GenusID`, `species`, `subspecies`, `infra`, `locale`, `wsg`) VALUES
(1, 1, 'jupunba', NULL, NULL, 'world', '0.585143'),
(2, 1, 'macradenia', NULL, NULL, 'world', '0.438000'),
(3, 1296, 'alba', NULL, NULL, 'world', '0.353000'),
(4, 1296, 'amabilis', NULL, NULL, 'world', '0.400000'),
(5, 1296, 'balsamea', NULL, NULL, 'world', '0.330000'),
(6, 1296, 'concolor', NULL, NULL, 'world', '0.370000'),
(7, 1296, 'grandis', NULL, NULL, 'world', '0.350000'),
(8, 1296, 'holophylla', NULL, NULL, 'world', '0.336000'),
(9, 1296, 'magnifica', NULL, NULL, 'world', '0.360000'),
(10, 1296, 'nephrolepis', NULL, NULL, 'world', '0.323500'),
(11, 1296, 'procera', NULL, NULL, 'world', '0.370000'),
(12, 2, 'auriculiformis', NULL, NULL, 'world', '0.680000'),
(13, 2, 'gerrardii', NULL, NULL, 'world', '0.775000'),
(14, 2, 'mellifera', NULL, NULL, 'world', '0.947000'),
(15, 2, 'nilotica', NULL, NULL, 'world', '0.723333'),
(16, 2, 'xanthophloea', NULL, NULL, 'world', '0.758000'),
(17, 504, 'campestre', NULL, NULL, 'world', '0.525000'),
(18, 504, 'macrophyllum', NULL, NULL, 'world', '0.440000'),
(19, 504, 'mandshuricum', NULL, NULL, 'world', '0.585000'),
(20, 504, 'mono', NULL, NULL, 'world', '0.639250'),
(21, 504, 'oblongum', NULL, NULL, 'world', '0.603000'),
(22, 504, 'pennsylvanicum', NULL, NULL, 'world', '0.440000'),
(23, 504, 'pensylvanicum', NULL, NULL, 'world', '0.440000'),
(24, 504, 'platanoides', NULL, NULL, 'world', '0.516500'),
(25, 504, 'pseudoplatanus', NULL, NULL, 'world', '0.509000'),
(26, 504, 'rubrum', NULL, NULL, 'world', '0.490000'),
(27, 504, 'saccharum', NULL, NULL, 'world', '0.560000'),
(28, 1408, 'acuminatissima', NULL, NULL, 'world', '0.630000'),
(29, 1438, 'fraxinifolius', NULL, NULL, 'world', '0.591500'),
(30, 505, 'pedunculata', NULL, NULL, 'world', '0.458667'),
(31, 679, 'glomerata', NULL, NULL, 'world', '0.410000'),
(32, 679, 'maingayi', NULL, NULL, 'world', '0.590000'),
(33, 679, 'malaccensis', NULL, NULL, 'world', '0.550000'),
(34, 679, 'sesquipedalis', NULL, NULL, 'world', '0.650000'),
(35, 679, 'SESQUIPEDALIS', NULL, NULL, 'world', '0.650000'),
(36, 679, 'sphaerocarpa', NULL, NULL, 'world', '0.460000'),
(37, 8, 'triloba', NULL, NULL, 'world', '0.604500'),
(38, 680, 'bicolor', NULL, NULL, 'world', '0.850000'),
(39, 680, 'BICOLOR', NULL, NULL, 'world', '0.850000'),
(40, 680, 'pavonina', NULL, NULL, 'world', '0.687000'),
(41, 507, 'acuminata', NULL, NULL, 'world', '0.480000'),
(42, 507, 'cordifolia', NULL, NULL, 'world', '0.500000'),
(43, 507, 'dumosa', NULL, NULL, 'world', '0.540000'),
(44, 507, 'integerrima', NULL, NULL, 'world', '0.560000'),
(45, 507, 'millettii', NULL, NULL, 'world', '0.440000'),
(46, 1556, 'pilulifera', NULL, NULL, 'world', '0.891000'),
(47, 11, 'integrifolia', NULL, NULL, 'world', '0.860000'),
(48, 509, 'bella', NULL, NULL, 'world', '0.637000'),
(49, 509, 'bipindensis', NULL, NULL, 'world', '0.731364'),
(50, 509, 'rhomboidea', NULL, NULL, 'world', '0.590000'),
(51, 681, 'argentea', NULL, NULL, 'world', '0.630000'),
(52, 681, 'cordata', NULL, NULL, 'world', '0.780000'),
(53, 681, 'CORDATA', NULL, NULL, 'world', '0.780000'),
(54, 681, 'edulis', NULL, NULL, 'world', '0.710000'),
(55, 681, 'elaeagnoidea', NULL, NULL, 'world', '0.630000'),
(56, 681, 'elliptica', NULL, NULL, 'world', '0.660000'),
(57, 681, 'exstipulata', NULL, NULL, 'world', '0.800000'),
(58, 681, 'EXSTIPULATA', NULL, NULL, 'world', '0.800000'),
(59, 681, 'forbesii', NULL, NULL, 'world', '0.660000'),
(60, 681, 'FORBESII', NULL, NULL, 'world', '0.660000'),
(61, 681, 'hiernii', NULL, NULL, 'world', '0.500000'),
(62, 681, 'lanceolata', NULL, NULL, 'world', '0.690000'),
(63, 681, 'lawii', NULL, NULL, 'world', '0.595000'),
(64, 681, 'leucophylla', NULL, NULL, 'world', '0.720000'),
(65, 681, 'luzoniensis', NULL, NULL, 'world', '0.650000'),
(66, 681, 'macrocarpa', NULL, NULL, 'world', '0.550000'),
(67, 681, 'maingayi', NULL, NULL, 'world', '0.790000'),
(68, 681, 'malaccensis', NULL, NULL, 'world', '0.640000'),
(69, 681, 'odoratissima', NULL, NULL, 'world', '0.715000'),
(70, 681, 'ODORATISSIMA', NULL, NULL, 'world', '0.715000'),
(71, 681, 'perviridis', NULL, NULL, 'world', '0.810000'),
(72, 681, 'simplicifolia', NULL, NULL, 'world', '0.770000'),
(73, 681, 'spectabilis', NULL, NULL, 'world', '0.575000'),
(74, 681, 'tomentosa', NULL, NULL, 'world', '0.675000'),
(75, 498, 'brasiliensis', NULL, NULL, 'world', '0.817750'),
(76, 498, 'silvatica', NULL, NULL, 'world', '0.830500'),
(77, 682, 'gaudichaudii', NULL, NULL, 'world', '0.590000'),
(78, 510, 'micrantha', NULL, NULL, 'world', '0.663000'),
(79, 511, 'integrifolia', NULL, NULL, 'world', '0.305000'),
(80, 511, 'triphysa', NULL, NULL, 'world', '0.358200'),
(81, 512, 'chinense', NULL, NULL, 'world', '0.401667'),
(82, 512, 'griffithii', NULL, NULL, 'world', '0.700000'),
(83, 512, 'GRIFFITHII', NULL, NULL, 'world', '0.700000'),
(84, 512, 'javanicum', NULL, NULL, 'world', '0.730000'),
(85, 512, 'kurzii', NULL, NULL, 'world', '0.420000'),
(86, 512, 'longiflorum', NULL, NULL, 'world', '0.683000'),
(87, 512, 'nobile', NULL, NULL, 'world', '0.750000'),
(88, 512, 'NOBILE', NULL, NULL, 'world', '0.750000'),
(89, 512, 'salviifolium', NULL, NULL, 'world', '0.800000'),
(90, 13, 'chinensis', NULL, NULL, 'world', '0.300000'),
(91, 13, 'ferruginea', NULL, NULL, 'world', '0.494333'),
(92, 13, 'glaberrima', NULL, NULL, 'world', '0.567500'),
(93, 13, 'kalkora', NULL, NULL, 'world', '0.489500'),
(94, 13, 'lucidior', NULL, NULL, 'world', '0.758000'),
(95, 13, 'niopoides', NULL, NULL, 'world', '0.555000'),
(96, 13, 'odoratissima', NULL, NULL, 'world', '0.638500'),
(97, 13, 'procera', NULL, NULL, 'world', '0.573000'),
(98, 13, 'splendens', NULL, NULL, 'world', '0.540000'),
(99, 13, 'zygia', NULL, NULL, 'world', '0.493667'),
(100, 14, 'costaricensis', NULL, NULL, 'world', '0.301000'),
(101, 14, 'glandulosa', NULL, NULL, 'world', '0.378000'),
(102, 14, 'latifolia', NULL, NULL, 'world', '0.420263'),
(103, 14, 'triplinervia', NULL, NULL, 'world', '0.466667'),
(104, 513, 'floribunda', NULL, NULL, 'world', '0.426667'),
(105, 1743, 'montana', NULL, NULL, 'world', '0.318500'),
(106, 15, 'edulis', NULL, NULL, 'world', '0.760000'),
(107, 514, 'floribunda', NULL, NULL, 'world', '0.687000'),
(108, 17, 'africanus', NULL, NULL, 'world', '0.450000'),
(109, 17, 'amazonicus', NULL, NULL, 'world', '0.550000'),
(110, 17, 'cobbe', NULL, NULL, 'world', '0.385000'),
(111, 17, 'COBBE', NULL, NULL, 'world', '0.385000'),
(112, 518, 'fortunei', NULL, NULL, 'world', '0.382667'),
(113, 18, 'incana', NULL, NULL, 'world', '0.439000'),
(114, 18, 'rubra', NULL, NULL, 'world', '0.370000'),
(115, 519, 'excelsa', NULL, NULL, 'world', '0.539333'),
(116, 520, 'javanica', NULL, NULL, 'world', '0.540000'),
(117, 19, 'blackiana', NULL, NULL, 'world', '0.536000'),
(118, 521, 'bancana', NULL, NULL, 'world', '0.590000'),
(119, 521, 'insignis', NULL, NULL, 'world', '0.710000'),
(120, 521, 'longipes', NULL, NULL, 'world', '0.509000'),
(121, 521, 'oblanceolata', NULL, NULL, 'world', '0.430000'),
(122, 683, 'angustifolia', NULL, NULL, 'world', '0.613333'),
(123, 683, 'angustiloba', NULL, NULL, 'world', '0.346667'),
(124, 683, 'ANGUSTILOBA', NULL, NULL, 'world', '0.346667'),
(125, 683, 'boonei', NULL, NULL, 'world', '0.321400'),
(126, 683, 'macrophylla', NULL, NULL, 'world', '0.640000'),
(127, 683, 'scholaris', NULL, NULL, 'world', '0.382000'),
(128, 17228, 'chinensis', NULL, NULL, 'world', '0.626000'),
(129, 17228, 'excelsa', NULL, NULL, 'world', '0.652500'),
(130, 1869, 'acida', NULL, NULL, 'world', '0.524667'),
(131, 1894, 'canadensis', NULL, NULL, 'world', '0.660000'),
(132, 22, 'edentula', NULL, NULL, 'world', '0.699500'),
(133, 524, 'ferrugineus', NULL, NULL, 'world', '0.672500'),
(134, 524, 'pterocarpoides', NULL, NULL, 'world', '0.617429'),
(135, 1956, 'longifolia', NULL, NULL, 'world', '0.710000'),
(136, 525, 'pluricornis', NULL, NULL, 'world', '0.630000'),
(137, 25, 'excelsum', NULL, NULL, 'world', '0.391286'),
(138, 25, 'parvifolium', NULL, NULL, 'world', '0.525333'),
(139, 25, 'spruceanum', NULL, NULL, 'world', '0.479167'),
(140, 27, 'anthelmia', NULL, NULL, 'world', '0.778000'),
(141, 27, 'inermis', NULL, NULL, 'world', '0.641952'),
(142, 27, 'micrantha', NULL, NULL, 'world', '1.000000'),
(143, 27, 'parviflora', NULL, NULL, 'world', '0.716750'),
(144, 27, 'unifoliolata', NULL, NULL, 'world', '0.760000'),
(145, 28, 'canelilla', NULL, NULL, 'world', '0.952429'),
(146, 28, 'guianensis', NULL, NULL, 'world', '0.520000'),
(147, 28, 'hostmanniana', NULL, NULL, 'world', '0.619000'),
(148, 28, 'panurensis', NULL, NULL, 'world', '0.610000'),
(149, 28, 'parviflora', NULL, NULL, 'world', '0.540000'),
(150, 28, 'puchury-minor', NULL, NULL, 'world', '0.533333'),
(151, 28, 'riparia', NULL, NULL, 'world', '0.570000'),
(152, 28, 'rosaeodora', NULL, NULL, 'world', '0.732571'),
(153, 28, 'terminalis', NULL, NULL, 'world', '0.540000'),
(154, 28, 'williamsii', NULL, NULL, 'world', '0.637500'),
(155, 684, 'beccariana', NULL, NULL, 'world', '0.670000'),
(156, 684, 'disticha', NULL, NULL, 'world', '0.670000'),
(157, 684, 'manausensis', NULL, NULL, 'world', '0.860000'),
(158, 529, 'costata', NULL, NULL, 'world', '0.553333'),
(159, 529, 'COSTATA', NULL, NULL, 'world', '0.553333'),
(160, 529, 'grossivenia', NULL, NULL, 'world', '0.585000'),
(161, 529, 'laevis', NULL, NULL, 'world', '0.520000'),
(162, 529, 'LAEVIS', NULL, NULL, 'world', '0.520000'),
(163, 529, 'megistocarpa', NULL, NULL, 'world', '0.575000'),
(164, 529, 'MEGISTOCARPA', NULL, NULL, 'world', '0.575000'),
(165, 2133, 'fragrans', NULL, NULL, 'world', '0.684333'),
(166, 531, 'chlorantha', NULL, NULL, 'world', '0.437286'),
(167, 29, 'foetida', NULL, NULL, 'world', '0.572000'),
(168, 29, 'purpurea', NULL, NULL, 'world', '0.570000'),
(169, 29, 'spraguei', NULL, NULL, 'world', '0.559000'),
(170, 532, 'acuminata', NULL, NULL, 'world', '0.880000'),
(171, 532, 'latifolia', NULL, NULL, 'world', '0.780000'),
(172, 533, 'mannii', NULL, NULL, 'world', '0.291000'),
(173, 534, 'klaineana', NULL, NULL, 'world', '0.799909'),
(174, 538, 'amazonicus', NULL, NULL, 'world', '0.715000'),
(175, 539, 'fragrans', NULL, NULL, 'world', '0.529000'),
(176, 539, 'macrophylla', NULL, NULL, 'world', '0.841667'),
(177, 2200, 'aubryanum', NULL, NULL, 'world', '0.330000'),
(178, 540, 'toxicaria', NULL, NULL, 'world', '0.383053'),
(179, 685, 'bunius', NULL, NULL, 'world', '0.629333'),
(180, 685, 'coriaceum', NULL, NULL, 'world', '0.720000'),
(181, 685, 'CORIACEUM', NULL, NULL, 'world', '0.720000'),
(182, 685, 'montanum', NULL, NULL, 'world', '0.590000'),
(183, 685, 'pleuricum', NULL, NULL, 'world', '0.624000'),
(184, 541, 'obtusifolia', NULL, NULL, 'world', '0.602687'),
(185, 542, 'micraster', NULL, NULL, 'world', '0.487667'),
(186, 543, 'cladantha', NULL, NULL, 'world', '0.806500'),
(187, 544, 'cordatum', NULL, NULL, 'world', '0.390000'),
(188, 30, 'aspera', NULL, NULL, 'world', '0.303167'),
(189, 30, 'tibourbou', NULL, NULL, 'world', '0.200000'),
(190, 545, 'polystachya', NULL, NULL, 'world', '0.576500'),
(191, 545, 'POLYSTACHYA', NULL, NULL, 'world', '0.576500'),
(192, 546, 'aspera', NULL, NULL, 'world', '0.520000'),
(193, 546, 'cuspidata', NULL, NULL, 'world', '0.690000'),
(194, 547, 'dimidiata', NULL, NULL, 'world', '0.610000'),
(195, NULL, 'falcifera', NULL, NULL, 'world', '0.560000'),
(196, NULL, 'FALCIFERA', NULL, NULL, 'world', '0.560000'),
(197, NULL, 'lunatum', NULL, NULL, 'world', '0.685000'),
(198, NULL, 'microstachya', NULL, NULL, 'world', '0.670000'),
(199, NULL, 'MICROSTACHYA', NULL, NULL, 'world', '0.670000'),
(200, NULL, 'symplocoides', NULL, NULL, 'world', '0.640000'),
(201, NULL, 'SYMPLOCOIDES', NULL, NULL, 'world', '0.640000'),
(202, 549, 'tubicina', NULL, NULL, 'world', '0.765000'),
(203, 550, 'leiocarpa', NULL, NULL, 'world', '0.799250'),
(204, 551, 'malaccensis', NULL, NULL, 'world', '0.320000'),
(205, 551, 'MALACCENSIS', NULL, NULL, 'world', '0.320000'),
(206, 2351, 'menziesii', NULL, NULL, 'world', '0.570000'),
(207, 555, 'bubalinum', NULL, NULL, 'world', '0.380000'),
(208, 555, 'BUBALINUM', NULL, NULL, 'world', '0.380000'),
(209, 555, 'clypearia', NULL, NULL, 'world', '0.323333'),
(210, 555, 'CLYPEARIA', NULL, NULL, 'world', '0.323333'),
(211, 555, 'ellipticum', NULL, NULL, 'world', '0.450000'),
(212, 555, 'jiringa', NULL, NULL, 'world', '0.317000'),
(213, 2375, 'tomentosa', NULL, NULL, 'world', '0.720000'),
(214, 33, 'glauciflora', NULL, NULL, 'world', '0.560000'),
(215, 33, 'guianensis', NULL, NULL, 'world', '0.620000'),
(216, 33, 'lanceolata', NULL, NULL, 'world', '0.440000'),
(217, 33, 'LANCEOLATA', NULL, NULL, 'world', '0.440000'),
(218, 33, 'macrophylla', NULL, NULL, 'world', '0.510000'),
(219, 33, 'solanacea', NULL, NULL, 'world', '0.620000'),
(220, 559, 'diversifolium', NULL, NULL, 'world', '0.365000'),
(221, 559, 'DIVERSIFOLIUM', NULL, NULL, 'world', '0.365000'),
(222, 34, 'altilis', NULL, NULL, 'world', '0.424024'),
(223, 34, 'anisophyllus', NULL, NULL, 'world', '0.605000'),
(224, 34, 'ANISOPHYLLUS', NULL, NULL, 'world', '0.605000'),
(225, 34, 'chaplasha', NULL, NULL, 'world', '0.459000'),
(226, 34, 'elasticus', NULL, NULL, 'world', '0.363333'),
(227, 34, 'gomezianus', NULL, NULL, 'world', '0.540000'),
(228, 34, 'heterophyllus', NULL, NULL, 'world', '0.491667'),
(229, 34, 'integer', NULL, NULL, 'world', '0.551000'),
(230, 34, 'INTEGER', NULL, NULL, 'world', '0.551000'),
(231, 34, 'kemando', NULL, NULL, 'world', '0.447500'),
(232, 34, 'KEMANDO', NULL, NULL, 'world', '0.447500'),
(233, 34, 'lakoocha', NULL, NULL, 'world', '0.640000'),
(234, 34, 'lowii', NULL, NULL, 'world', '0.540000'),
(235, 34, 'LOWII', NULL, NULL, 'world', '0.540000'),
(236, 34, 'nitidus', NULL, NULL, 'world', '0.480000'),
(237, 34, 'odoratissimus', NULL, NULL, 'world', '0.550000'),
(238, 34, 'rigidus', NULL, NULL, 'world', '0.512667'),
(239, 34, 'RIGIDUS', NULL, NULL, 'world', '0.512667'),
(240, 34, 'scortechinii', NULL, NULL, 'world', '0.440000'),
(241, 34, 'SCORTECHINII', NULL, NULL, 'world', '0.440000'),
(242, 34, 'styracifolius', NULL, NULL, 'world', '0.507667'),
(243, 34, 'tamaran', NULL, NULL, 'world', '0.370000'),
(244, 34, 'tonkinensis', NULL, NULL, 'world', '0.466667'),
(245, 560, 'littoralis', NULL, NULL, 'world', '0.770000'),
(246, 35, 'capitatum', NULL, NULL, 'world', '0.730000'),
(247, 35, 'megalocarpon', NULL, NULL, 'world', '0.777400'),
(248, 35, 'nitidum', NULL, NULL, 'world', '0.763500'),
(249, 35, 'rigidum', NULL, NULL, 'world', '0.460000'),
(250, 35, 'spruceanum', NULL, NULL, 'world', '0.753333'),
(251, 36, 'murumuru', NULL, NULL, 'world', '0.508000'),
(252, 37, 'graveolens', NULL, NULL, 'world', '0.868143'),
(253, 38, 'butyracea', NULL, NULL, 'world', '0.326000'),
(254, 2658, 'klaineana', NULL, NULL, 'world', '0.377852'),
(255, 565, 'congolensis', NULL, NULL, 'world', '0.751778'),
(256, 567, 'excelsa', NULL, NULL, 'world', '0.505000'),
(257, 568, 'kunstleri', NULL, NULL, 'world', '0.645000'),
(258, 568, 'KUNSTLERI', NULL, NULL, 'world', '0.645000'),
(259, 568, 'macrocarpa', NULL, NULL, 'world', '0.540000'),
(260, 568, 'minor', NULL, NULL, 'world', '0.720000'),
(261, 568, 'MINOR', NULL, NULL, 'world', '0.720000'),
(262, 568, 'motleyana', NULL, NULL, 'world', '0.510000'),
(263, 568, 'parviflora', NULL, NULL, 'world', '0.720000'),
(264, 568, 'PARVIFLORA', NULL, NULL, 'world', '0.720000'),
(265, 568, 'polyneura', NULL, NULL, 'world', '0.560000'),
(266, 568, 'racemosa', NULL, NULL, 'world', '0.580000'),
(267, 568, 'RACEMOSA', NULL, NULL, 'world', '0.580000'),
(268, 568, 'reticulata', NULL, NULL, 'world', '0.780000'),
(269, 568, 'RETICULATA', NULL, NULL, 'world', '0.780000'),
(270, 568, 'sumatrana', NULL, NULL, 'world', '0.605000'),
(271, 568, 'SUMATRANA', NULL, NULL, 'world', '0.605000'),
(272, 2745, 'pilularis', NULL, NULL, 'world', '0.590000'),
(273, 2758, 'frutescens', NULL, NULL, 'world', '0.810000'),
(274, 569, 'insignis', NULL, NULL, 'world', '0.686500'),
(275, 570, 'toxisperma', NULL, NULL, 'world', '0.724900'),
(276, 42, 'pedicellaris', NULL, NULL, 'world', '0.497000'),
(277, 43, 'guianensis', NULL, NULL, 'world', '0.610000'),
(278, 43, 'nitida', NULL, NULL, 'world', '0.601500'),
(279, 573, 'acutangula', NULL, NULL, 'world', '0.524667'),
(280, 573, 'macrostachya', NULL, NULL, 'world', '0.600000'),
(281, 573, 'MACROSTACHYA', NULL, NULL, 'world', '0.600000'),
(282, 573, 'pendula', NULL, NULL, 'world', '0.520000'),
(283, 573, 'PENDULA', NULL, NULL, 'world', '0.520000'),
(284, 573, 'scortechinii', NULL, NULL, 'world', '0.575000'),
(285, 44, 'amazonicus', NULL, NULL, 'world', '0.533000'),
(286, 45, 'purpurea', NULL, NULL, 'world', '0.720000'),
(287, 45, 'racemosa', NULL, NULL, 'world', '0.634000'),
(288, 46, 'insignis', NULL, NULL, 'world', '0.500000'),
(289, 46, 'kunstleri', NULL, NULL, 'world', '0.490000'),
(290, 46, 'KUNSTLERI', NULL, NULL, 'world', '0.490000'),
(291, 46, 'lucidula', NULL, NULL, 'world', '0.500000'),
(292, 46, 'LUCIDULA', NULL, NULL, 'world', '0.500000'),
(293, 46, 'madang', NULL, NULL, 'world', '0.470000'),
(294, 46, 'MADANG', NULL, NULL, 'world', '0.470000'),
(295, 46, 'mannii', NULL, NULL, 'world', '0.569667'),
(296, 46, 'micrantha', NULL, NULL, 'world', '0.380000'),
(297, 46, 'pahangensis', NULL, NULL, 'world', '0.600000'),
(298, 46, 'pendula', NULL, NULL, 'world', '0.507000'),
(299, 47, 'grossularioides', NULL, NULL, 'world', '0.597500'),
(300, 47, 'pentamera', NULL, NULL, 'world', '0.485000'),
(301, 577, 'auriculata', NULL, NULL, 'world', '0.660500'),
(302, 577, 'confusa', NULL, NULL, 'world', '0.602000'),
(303, 578, 'cordifolia', NULL, NULL, 'world', '0.770000'),
(304, 579, 'abyssinica', NULL, NULL, 'world', '0.617500'),
(305, 3045, 'alleghaniensis', NULL, NULL, 'world', '0.550000'),
(306, 3045, 'costata', NULL, NULL, 'world', '0.601000'),
(307, 3045, 'lenta', NULL, NULL, 'world', '0.600000'),
(308, 3045, 'luminifera', NULL, NULL, 'world', '0.549250'),
(309, 3045, 'neoalaskana', NULL, NULL, 'world', '0.530000'),
(310, 3045, 'papyrifera', NULL, NULL, 'world', '0.480000'),
(311, 3045, 'platyphylla', NULL, NULL, 'world', '0.517800'),
(312, 3045, 'populifolia', NULL, NULL, 'world', '0.450000'),
(313, 688, 'paniculata', NULL, NULL, 'world', '0.655000'),
(314, 688, 'PANICULATA', NULL, NULL, 'world', '0.655000'),
(315, 580, 'javanica', NULL, NULL, 'world', '0.601700'),
(316, 3140, 'eggersii', NULL, NULL, 'world', '0.726000'),
(317, 3140, 'salicifolius', NULL, NULL, 'world', '0.708250'),
(318, 583, 'unijugata', NULL, NULL, 'world', '0.508000'),
(319, 584, 'tokbrai', NULL, NULL, 'world', '0.555000'),
(320, 584, 'TOKBRAI', NULL, NULL, 'world', '0.555000'),
(321, 3161, 'multiflora', NULL, NULL, 'world', '0.640200'),
(322, 3162, 'viridiflora', NULL, NULL, 'world', '0.835000'),
(323, 585, 'caudata', NULL, NULL, 'world', '0.364000'),
(324, 497, 'quinata', NULL, NULL, 'world', '0.380000'),
(325, 689, 'ceiba', NULL, NULL, 'world', '0.313500'),
(326, 586, 'macrophylla', NULL, NULL, 'world', '0.680000'),
(327, 586, 'MACROPHYLLA', NULL, NULL, 'world', '0.680000'),
(328, 586, 'oppositifolia', NULL, NULL, 'world', '0.745000'),
(329, 586, 'OPPOSITIFOLIA', NULL, NULL, 'world', '0.745000'),
(330, 587, 'hookeri', NULL, NULL, 'world', '0.600000'),
(331, 587, 'HOOKERI', NULL, NULL, 'world', '0.600000'),
(332, 17562, 'sinensis', NULL, NULL, 'world', '0.537000'),
(333, 589, 'sericea', NULL, NULL, 'world', '0.481000'),
(334, 690, 'glauca', NULL, NULL, 'world', '0.440000'),
(335, 690, 'insulana', NULL, NULL, 'world', '0.542000'),
(336, 690, 'micrantha', NULL, NULL, 'world', '0.508143'),
(337, 690, 'retusa', NULL, NULL, 'world', '0.608000'),
(338, 690, 'tomentosa', NULL, NULL, 'world', '0.665000'),
(339, 56, 'acutifolium', NULL, NULL, 'world', '0.640286'),
(340, 56, 'alicastrum', NULL, NULL, 'world', '0.607750'),
(341, 56, 'costaricanum', NULL, NULL, 'world', '0.665000'),
(342, 56, 'guianense', NULL, NULL, 'world', '0.843500'),
(343, 56, 'lactescens', NULL, NULL, 'world', '0.655600'),
(344, 56, 'parinarioides', NULL, NULL, 'world', '0.630625'),
(345, 56, 'potabile', NULL, NULL, 'world', '0.542500'),
(346, 56, 'rubescens', NULL, NULL, 'world', '0.825143'),
(347, 56, 'utile', NULL, NULL, 'world', '0.505786'),
(348, 3419, 'papyrifera', NULL, NULL, 'world', '0.290000'),
(349, 58, 'portoricensis', NULL, NULL, 'world', '0.783083'),
(350, 593, 'arborescens', NULL, NULL, 'world', '0.450600'),
(351, 59, 'grandis', NULL, NULL, 'world', '0.755000'),
(352, 59, 'parvifolia', NULL, NULL, 'world', '0.818000'),
(353, 59, 'tetraphylla', NULL, NULL, 'world', '0.619444'),
(354, 61, 'argentea', NULL, NULL, 'world', '0.650000'),
(355, 62, 'simaruba', NULL, NULL, 'world', '0.305286'),
(356, 594, 'monosperma', NULL, NULL, 'world', '0.433333'),
(357, 63, 'crassifolia', NULL, NULL, 'world', '0.594167'),
(358, 63, 'crispa', NULL, NULL, 'world', '0.580000'),
(359, 63, 'spicata', NULL, NULL, 'world', '0.613732'),
(360, 63, 'wadsworthii', NULL, NULL, 'world', '0.580272'),
(361, 595, 'canjerana', NULL, NULL, 'world', '0.532167'),
(362, 65, 'costaricensis', NULL, NULL, 'world', '0.565500'),
(363, 66, 'guildingii', NULL, NULL, 'world', '0.850000'),
(364, 66, 'trinervia', NULL, NULL, 'world', '0.820000'),
(365, 67, 'pentandra', NULL, NULL, 'world', '0.340000'),
(366, 68, 'blancoi', NULL, NULL, 'world', '0.460000'),
(367, 68, 'brasiliense', NULL, NULL, 'world', '0.589067'),
(368, 68, 'calaba', NULL, NULL, 'world', '0.643417'),
(369, 68, 'dryobalanoides', NULL, NULL, 'world', '0.650000'),
(370, 68, 'inophylloide', NULL, NULL, 'world', '0.610000'),
(371, 68, 'longifolium', NULL, NULL, 'world', '0.542000'),
(372, 68, 'macrocarpum', NULL, NULL, 'world', '0.640000'),
(373, 68, 'MACROCARPUM', NULL, NULL, 'world', '0.640000'),
(374, 68, 'polyanthum', NULL, NULL, 'world', '0.439000'),
(375, 68, 'pulcherrimum', NULL, NULL, 'world', '0.616667'),
(376, 68, 'retusum', NULL, NULL, 'world', '0.570000'),
(377, 68, 'soulattri', NULL, NULL, 'world', '0.430000'),
(378, 68, 'SOULATTRI', NULL, NULL, 'world', '0.430000'),
(379, 1277, 'heitzii', NULL, NULL, 'world', '0.726600'),
(380, 597, 'squamulosum', NULL, NULL, 'world', '0.751667'),
(381, 70, 'candidissimum', NULL, NULL, 'world', '0.718000'),
(382, 71, 'concinna', NULL, NULL, 'world', '0.770000'),
(383, 71, 'speciosa', NULL, NULL, 'world', '0.860000'),
(384, 599, 'lanceolata', NULL, NULL, 'world', '0.550000'),
(385, 73, 'auriculata', NULL, NULL, 'world', '0.326667'),
(386, 73, 'squamatum', NULL, NULL, 'world', '0.390000'),
(387, 602, 'latifolia', NULL, NULL, 'world', '0.280000'),
(388, 692, 'album', NULL, NULL, 'world', '0.417000'),
(389, 692, 'apertum', NULL, NULL, 'world', '0.525000'),
(390, 692, 'APERTUM', NULL, NULL, 'world', '0.525000'),
(391, 692, 'asperum', NULL, NULL, 'world', '0.470000'),
(392, 692, 'denticulatum', NULL, NULL, 'world', '0.525000'),
(393, 692, 'dichotomum', NULL, NULL, 'world', '0.460000'),
(394, 692, 'euphyllum', NULL, NULL, 'world', '0.350000'),
(395, 692, 'hirsutum', NULL, NULL, 'world', '0.490000'),
(396, 692, 'littorale', NULL, NULL, 'world', '0.495000'),
(397, 692, 'patentinervium', NULL, NULL, 'world', '0.545000'),
(398, 692, 'PATENTINERVIUM', NULL, NULL, 'world', '0.545000'),
(399, 692, 'pilosum', NULL, NULL, 'world', '0.465000'),
(400, 692, 'PILOSUM', NULL, NULL, 'world', '0.465000'),
(401, 692, 'pseudopatentinervium', NULL, NULL, 'world', '0.440000'),
(402, 692, 'rufum', NULL, NULL, 'world', '0.510000'),
(403, 692, 'schweinfurthii', NULL, NULL, 'world', '0.408938'),
(404, 692, 'tonkinense', NULL, NULL, 'world', '0.491000'),
(405, 693, 'dicoccum', NULL, NULL, 'world', '0.711400'),
(406, 693, 'glabrum', NULL, NULL, 'world', '0.465000'),
(407, 603, 'corniculata', NULL, NULL, 'world', '0.860000'),
(408, 604, 'decorticans', NULL, NULL, 'world', '0.593000'),
(409, 74, 'frondosa', NULL, NULL, 'world', '0.823000'),
(410, 74, 'osmantha', NULL, NULL, 'world', '0.663000'),
(411, 605, 'grandifolia', NULL, NULL, 'world', '0.780000'),
(412, 694, 'brachiata', NULL, NULL, 'world', '0.665857'),
(413, 694, 'BRACHIATA', NULL, NULL, 'world', '0.665857'),
(414, 75, 'guianensis', NULL, NULL, 'world', '0.530000'),
(415, 75, 'procera', NULL, NULL, 'world', '0.563812'),
(416, 606, 'arborea', NULL, NULL, 'world', '0.731333'),
(417, 3844, 'decandra', NULL, NULL, 'world', '0.579667'),
(418, 3844, 'micrantha', NULL, NULL, 'world', '0.586600'),
(419, 3873, 'caroliniana', NULL, NULL, 'world', '0.580000'),
(420, 3873, 'londoniana', NULL, NULL, 'world', '0.529000'),
(421, 608, 'longifolia', NULL, NULL, 'world', '0.450000'),
(422, 3899, 'cordiformis', NULL, NULL, 'world', '0.600000'),
(423, 3899, 'glabra', NULL, NULL, 'world', '0.660000'),
(424, 3899, 'laciniosa', NULL, NULL, 'world', '0.620000'),
(425, 3899, 'ovata', NULL, NULL, 'world', '0.640000'),
(426, 3899, 'tomentosa', NULL, NULL, 'world', '0.640000'),
(427, 609, 'glabrum', NULL, NULL, 'world', '0.653571'),
(428, 609, 'villosum', NULL, NULL, 'world', '0.758000'),
(429, 78, 'aculeata', NULL, NULL, 'world', '0.660000'),
(430, 78, 'arborea', NULL, NULL, 'world', '0.573826'),
(431, 78, 'arguta', NULL, NULL, 'world', '0.517000'),
(432, 78, 'decandra', NULL, NULL, 'world', '0.667433'),
(433, 78, 'esculenta', NULL, NULL, 'world', '0.500000'),
(434, 78, 'graveolens', NULL, NULL, 'world', '0.606000'),
(435, 78, 'grewiaefolia', NULL, NULL, 'world', '0.560000'),
(436, 78, 'grewiifolia', NULL, NULL, 'world', '0.491000'),
(437, 78, 'guianensis', NULL, NULL, 'world', '0.754810'),
(438, 78, 'javitensis', NULL, NULL, 'world', '0.753000'),
(439, 78, 'membranacea', NULL, NULL, 'world', '0.650000'),
(440, 78, 'pitumba', NULL, NULL, 'world', '0.730000'),
(441, 78, 'sylvestris', NULL, NULL, 'world', '0.703346'),
(442, 79, 'cowanii', NULL, NULL, 'world', '0.620000'),
(443, 79, 'fistula', NULL, NULL, 'world', '0.798167'),
(444, 79, 'moschata', NULL, NULL, 'world', '0.805000'),
(445, 80, 'guianensis', NULL, NULL, 'world', '0.759750'),
(446, 3926, 'dentata', NULL, NULL, 'world', '0.400000'),
(447, 612, 'acuminatissima', NULL, NULL, 'world', '0.583500'),
(448, 612, 'argentea', NULL, NULL, 'world', '0.590000'),
(449, 612, 'carlesii', NULL, NULL, 'world', '0.440750'),
(450, 612, 'eyrei', NULL, NULL, 'world', '0.494250'),
(451, 612, 'fabri', NULL, NULL, 'world', '0.500000'),
(452, 612, 'fargesii', NULL, NULL, 'world', '0.486333'),
(453, 612, 'fissa', NULL, NULL, 'world', '0.444600'),
(454, 612, 'fordii', NULL, NULL, 'world', '0.457500'),
(455, 612, 'hystrix', NULL, NULL, 'world', '0.565000'),
(456, 612, 'indica', NULL, NULL, 'world', '0.595750'),
(457, 612, 'kawakamii', NULL, NULL, 'world', '0.590000'),
(458, 612, 'lucida', NULL, NULL, 'world', '0.530000'),
(459, 612, 'malaccensis', NULL, NULL, 'world', '0.600000'),
(460, 612, 'megacarpa', NULL, NULL, 'world', '0.630000'),
(461, 612, 'MEGACARPA', NULL, NULL, 'world', '0.630000'),
(462, 612, 'tibetana', NULL, NULL, 'world', '0.536000'),
(463, 612, 'tribuloides', NULL, NULL, 'world', '0.595000'),
(464, 81, 'elastica', NULL, NULL, 'world', '0.437000'),
(465, 3969, 'albuquerquei', NULL, NULL, 'world', '0.690000'),
(466, 3972, 'spinosa', NULL, NULL, 'world', '0.688000'),
(467, 82, 'platanifolia', NULL, NULL, 'world', '0.360000'),
(468, 82, 'umbellata', NULL, NULL, 'world', '0.150000'),
(469, 83, 'engleriana', NULL, NULL, 'world', '0.490000'),
(470, 83, 'ficifolia', NULL, NULL, 'world', '0.266000'),
(471, 83, 'insignis', NULL, NULL, 'world', '0.317500'),
(472, 83, 'membranacea', NULL, NULL, 'world', '0.330000'),
(473, 83, 'obtusifolia', NULL, NULL, 'world', '0.307333'),
(474, 83, 'pachystachya', NULL, NULL, 'world', '0.410000'),
(475, 83, 'peltata', NULL, NULL, 'world', '0.298000'),
(476, 83, 'purpurascens', NULL, NULL, 'world', '0.320000'),
(477, 83, 'schreberiana', NULL, NULL, 'world', '0.262000'),
(478, 83, 'sciadophylla', NULL, NULL, 'world', '0.386857'),
(479, 84, 'fissilis', NULL, NULL, 'world', '0.466600'),
(480, 84, 'montana', NULL, NULL, 'world', '0.340000'),
(481, 84, 'odorata', NULL, NULL, 'world', '0.445867'),
(482, 614, 'cateniformis', NULL, NULL, 'world', '0.503800'),
(483, 85, 'pentandra', NULL, NULL, 'world', '0.305149'),
(484, 86, 'adolfi-friderici', NULL, NULL, 'world', '0.470000'),
(485, 86, 'brieyi', NULL, NULL, 'world', '0.607000'),
(486, 86, 'luzonica', NULL, NULL, 'world', '0.550000'),
(487, 86, 'mildbraedii', NULL, NULL, 'world', '0.617571'),
(488, 86, 'prantlii', NULL, NULL, 'world', '0.669667'),
(489, 86, 'schippii', NULL, NULL, 'world', '0.616000'),
(490, 86, 'tetrandra', NULL, NULL, 'world', '0.520000'),
(491, 86, 'timorensis', NULL, NULL, 'world', '0.580000'),
(492, 4108, 'canadensis', NULL, NULL, 'world', '0.650000'),
(493, 88, 'macrophylla', NULL, NULL, 'world', '0.587500'),
(494, 88, 'spathulata', NULL, NULL, 'world', '0.613250'),
(495, 89, 'macrophyllum', NULL, NULL, 'world', '0.735971'),
(496, 696, 'castanocarpus', NULL, NULL, 'world', '0.750000'),
(497, 618, 'manillana', NULL, NULL, 'world', '0.690000'),
(498, 618, 'MANILLANA', NULL, NULL, 'world', '0.690000'),
(499, 94, 'domingensis', NULL, NULL, 'world', '0.865000'),
(500, 94, 'ramiflorus', NULL, NULL, 'world', '0.753000'),
(501, 94, 'RAMIFLORUS', NULL, NULL, 'world', '0.753000'),
(502, 622, 'venosa', NULL, NULL, 'world', '0.626141'),
(503, 623, 'ceramicus', NULL, NULL, 'world', '0.450000'),
(504, 623, 'CERAMICUS', NULL, NULL, 'world', '0.450000'),
(505, 623, 'cumingianus', NULL, NULL, 'world', '0.545000'),
(506, 623, 'macrophyllus', NULL, NULL, 'world', '0.445000'),
(507, 623, 'patens', NULL, NULL, 'world', '0.480000'),
(508, 623, 'PATENS', NULL, NULL, 'world', '0.480000'),
(509, 623, 'pentandrus', NULL, NULL, 'world', '0.505000'),
(510, 623, 'sarawakanus', NULL, NULL, 'world', '0.600000'),
(511, 623, 'SARAWAKANUS', NULL, NULL, 'world', '0.600000'),
(512, 4356, 'axillaris', NULL, NULL, 'world', '0.487000'),
(513, 96, 'spinosa', NULL, NULL, 'world', '0.530000'),
(514, 98, 'icaco', NULL, NULL, 'world', '0.753333'),
(515, 99, 'weberbaueri', NULL, NULL, 'world', '0.430000'),
(516, 100, 'amazonicum', NULL, NULL, 'world', '0.826000'),
(517, 100, 'argenteum', NULL, NULL, 'world', '0.764833'),
(518, 100, 'cainito', NULL, NULL, 'world', '0.655000'),
(519, 100, 'cuneifolium', NULL, NULL, 'world', '0.929000'),
(520, 100, 'lacourtianum', NULL, NULL, 'world', '0.630500'),
(521, 100, 'lanceolatum', NULL, NULL, 'world', '0.523000'),
(522, 100, 'LANCEOLATUM', NULL, NULL, 'world', '0.523000'),
(523, 100, 'pomiferum', NULL, NULL, 'world', '0.766000'),
(524, 100, 'roxburghii', NULL, NULL, 'world', '0.528500'),
(525, 100, 'sanguinolentum', NULL, NULL, 'world', '0.671400'),
(526, 626, 'tabularis', NULL, NULL, 'world', '0.548200'),
(527, 101, 'camphora', NULL, NULL, 'world', '0.487400'),
(528, 101, 'elongatum', NULL, NULL, 'world', '0.640000'),
(529, 101, 'glanduliferum', NULL, NULL, 'world', '0.500000'),
(530, 101, 'iners', NULL, NULL, 'world', '0.498750'),
(531, 101, 'INERS', NULL, NULL, 'world', '0.498750'),
(532, 101, 'javanicum', NULL, NULL, 'world', '0.445000'),
(533, 101, 'JAVANICUM', NULL, NULL, 'world', '0.445000'),
(534, 101, 'montanum', NULL, NULL, 'world', '0.560000'),
(535, 101, 'porrectum', NULL, NULL, 'world', '0.447333'),
(536, 101, 'PORRECTUM', NULL, NULL, 'world', '0.447333'),
(537, 101, 'subavenium', NULL, NULL, 'world', '0.500000'),
(538, 101, 'tamala', NULL, NULL, 'world', '0.575000'),
(539, 101, 'tavoyanum', NULL, NULL, 'world', '0.491000'),
(540, 101, 'verum', NULL, NULL, 'world', '0.498000'),
(541, 102, 'caudatum', NULL, NULL, 'world', '0.646687'),
(542, 102, 'fruticosum', NULL, NULL, 'world', '0.785000'),
(543, 103, 'paradisi', NULL, NULL, 'world', '0.430000'),
(544, 103, 'sinensis', NULL, NULL, 'world', '0.780000'),
(545, 631, 'longifolium', NULL, NULL, 'world', '0.350000'),
(546, 104, 'biflora', NULL, NULL, 'world', '0.497500'),
(547, 104, 'racemosa', NULL, NULL, 'world', '0.585429'),
(548, 633, 'spiciflorum', NULL, NULL, 'world', '0.710000'),
(549, 697, 'myrianthus', NULL, NULL, 'world', '0.535000'),
(550, 697, 'MYRIANTHUS', NULL, NULL, 'world', '0.535000'),
(551, 697, 'sumatranus', NULL, NULL, 'world', '0.640000'),
(552, 697, 'SUMATRANUS', NULL, NULL, 'world', '0.640000'),
(553, 635, 'glauca', NULL, NULL, 'world', '0.309200'),
(554, 635, 'patens', NULL, NULL, 'world', '0.335500'),
(555, 106, 'lanata', NULL, NULL, 'world', '0.550000'),
(556, 106, 'scabra', NULL, NULL, 'world', '0.486000'),
(557, 636, 'japonica', NULL, NULL, 'world', '0.547000'),
(558, 4565, 'erosum', NULL, NULL, 'world', '0.342031'),
(559, 109, 'clusioides', NULL, NULL, 'world', '0.650000'),
(560, 109, 'rosea', NULL, NULL, 'world', '0.624815'),
(561, 111, 'densifrons', NULL, NULL, 'world', '0.580000'),
(562, 111, 'diversifolia', NULL, NULL, 'world', '0.745893'),
(563, 111, 'mollis', NULL, NULL, 'world', '0.675000'),
(564, 111, 'padiformis', NULL, NULL, 'world', '0.800000'),
(565, 111, 'pyrifolia', NULL, NULL, 'world', '0.478217'),
(566, 638, 'preussii', NULL, NULL, 'world', '0.495263'),
(567, 639, 'borneensis', NULL, NULL, 'world', '0.580000'),
(568, 639, 'griffithii', NULL, NULL, 'world', '0.586667'),
(569, 639, 'GRIFFITHII', NULL, NULL, 'world', '0.586667'),
(570, 640, 'arabica', NULL, NULL, 'world', '0.618333'),
(571, 641, 'acuminata', NULL, NULL, 'world', '0.507667'),
(572, 641, 'lateritia', NULL, NULL, 'world', '0.507000'),
(573, 642, 'javanica', NULL, NULL, 'world', '0.380000'),
(574, 642, 'thorelii', NULL, NULL, 'world', '0.353000'),
(575, 116, 'glandulosa', NULL, NULL, 'world', '0.738667'),
(576, 116, 'heteroneura', NULL, NULL, 'world', '0.970000'),
(577, 644, 'glabra', NULL, NULL, 'world', '0.760457'),
(578, 118, 'guianensis', NULL, NULL, 'world', '0.543250'),
(579, 118, 'martiana', NULL, NULL, 'world', '0.430000'),
(580, 118, 'pleiostemona', NULL, NULL, 'world', '0.266000'),
(581, 123, 'aromatica', NULL, NULL, 'world', '0.620000'),
(582, 123, 'mildbraedii', NULL, NULL, 'world', '0.659750'),
(583, 124, 'alliodora', NULL, NULL, 'world', '0.517429'),
(584, 124, 'bicolor', NULL, NULL, 'world', '0.475000'),
(585, 124, 'borinquensis', NULL, NULL, 'world', '0.706250'),
(586, 124, 'collococca', NULL, NULL, 'world', '0.420000'),
(587, 124, 'dichotoma', NULL, NULL, 'world', '0.451200'),
(588, 124, 'exaltata', NULL, NULL, 'world', '0.398500'),
(589, 124, 'fallax', NULL, NULL, 'world', '0.373500'),
(590, 124, 'goeldiana', NULL, NULL, 'world', '0.498000'),
(591, 124, 'lasiocalyx', NULL, NULL, 'world', '0.397000'),
(592, 124, 'nodosa', NULL, NULL, 'world', '0.390000'),
(593, 124, 'panamensis', NULL, NULL, 'world', '0.330000'),
(594, 124, 'sulcata', NULL, NULL, 'world', '0.604000'),
(595, 124, 'ucayaliensis', NULL, NULL, 'world', '0.410000'),
(596, 4880, 'florida', NULL, NULL, 'world', '0.640000'),
(597, 4880, 'nuttallii', NULL, NULL, 'world', '0.580000'),
(598, 4895, 'avellana', NULL, NULL, 'world', '0.517000'),
(599, 4916, 'alta', NULL, NULL, 'world', '0.713667'),
(600, 645, 'melanoxylon', NULL, NULL, 'world', '0.825000'),
(601, 126, 'elata', NULL, NULL, 'world', '0.769000'),
(602, 126, 'guianensis', NULL, NULL, 'world', '0.755200'),
(603, 126, 'longipendula', NULL, NULL, 'world', '0.938000'),
(604, 126, 'robusta', NULL, NULL, 'world', '0.830000'),
(605, 126, 'ulei', NULL, NULL, 'world', '0.789500'),
(606, 646, 'edulis', NULL, NULL, 'world', '0.894667'),
(607, 4949, 'guianensis', NULL, NULL, 'world', '0.466667'),
(608, 4949, 'macrocarpa', NULL, NULL, 'world', '0.474000'),
(609, 127, 'guianensis', NULL, NULL, 'world', '0.507125'),
(610, 127, 'longipedicellata', NULL, NULL, 'world', '0.540000'),
(611, 127, 'multiflora', NULL, NULL, 'world', '0.448000'),
(612, 127, 'stellata', NULL, NULL, 'world', '0.633143'),
(613, 128, 'guianensis', NULL, NULL, 'world', '0.434000'),
(614, 128, 'subsessilis', NULL, NULL, 'world', '0.390000'),
(615, 647, 'asperifolia', NULL, NULL, 'world', '0.451500'),
(616, 647, 'microcarpa', NULL, NULL, 'world', '0.590000'),
(617, 647, 'parviceps', NULL, NULL, 'world', '0.490000'),
(618, 130, 'hexandra', NULL, NULL, 'world', '0.600000'),
(619, 131, 'nurvala', NULL, NULL, 'world', '0.340000'),
(620, 131, 'tapia', NULL, NULL, 'world', '0.518500'),
(621, 651, 'arborescens', NULL, NULL, 'world', '0.433333'),
(622, 651, 'ARBORESCENS', NULL, NULL, 'world', '0.433333'),
(623, 651, 'cochinchinense', NULL, NULL, 'world', '0.670000'),
(624, 651, 'COCHINCHINENSE', NULL, NULL, 'world', '0.670000'),
(625, 651, 'formosum', NULL, NULL, 'world', '0.715000'),
(626, 651, 'FORMOSUM', NULL, NULL, 'world', '0.715000'),
(627, 651, 'sumatranum', NULL, NULL, 'world', '0.591333'),
(628, 652, 'rhoifolium', NULL, NULL, 'world', '0.578500'),
(629, 135, 'laevifolius', NULL, NULL, 'world', '0.430000'),
(630, 135, 'LAEVIFOLIUS', NULL, NULL, 'world', '0.430000'),
(631, 135, 'lanjouwensis', NULL, NULL, 'world', '0.620000'),
(632, 135, 'poecilanthus', NULL, NULL, 'world', '0.587742'),
(633, 137, 'warscewiczii', NULL, NULL, 'world', '0.400000'),
(634, 657, 'cumingii', NULL, NULL, 'world', '0.410000'),
(635, 657, 'griffithii', NULL, NULL, 'world', '0.584667'),
(636, 657, 'GRIFFITHII', NULL, NULL, 'world', '0.584667'),
(637, 657, 'paniculata', NULL, NULL, 'world', '0.663500'),
(638, 138, 'aschersoniana', NULL, NULL, 'world', '0.570000'),
(639, 138, 'chinensis', NULL, NULL, 'world', '0.500000'),
(640, 138, 'crassinervia', NULL, NULL, 'world', '0.486500'),
(641, 138, 'ferrea', NULL, NULL, 'world', '0.630000'),
(642, 138, 'FERREA', NULL, NULL, 'world', '0.630000'),
(643, 138, 'impressa', NULL, NULL, 'world', '0.500000'),
(644, 658, 'parvifolius', NULL, NULL, 'world', '0.743333'),
(645, 658, 'PARVIFOLIUS', NULL, NULL, 'world', '0.743333'),
(646, 5160, 'lanceolata', NULL, NULL, 'world', '0.315692'),
(647, 139, 'americana', NULL, NULL, 'world', '0.544167'),
(648, 139, 'cinerea', NULL, NULL, 'world', '0.500000'),
(649, 139, 'guatemalensis', NULL, NULL, 'world', '0.688000'),
(650, 139, 'scrobiculata', NULL, NULL, 'world', '0.628000'),
(651, 661, 'carinatus', NULL, NULL, 'world', '0.320000'),
(652, 144, 'alexandri', NULL, NULL, 'world', '0.744200'),
(653, 144, 'inaequifolia', NULL, NULL, 'world', '0.800000'),
(654, 144, 'malaccensis', NULL, NULL, 'world', '0.790000'),
(655, 144, 'MALACCENSIS', NULL, NULL, 'world', '0.790000'),
(656, 145, 'racemiflora', NULL, NULL, 'world', '0.586190'),
(657, 664, 'buettneri', NULL, NULL, 'world', '0.512550'),
(658, 664, 'costata', NULL, NULL, 'world', '0.695000'),
(659, 664, 'COSTATA', NULL, NULL, 'world', '0.695000'),
(660, 664, 'edulis', NULL, NULL, 'world', '0.516333'),
(661, 664, 'excelsa', NULL, NULL, 'world', '0.493168'),
(662, 664, 'igaganga', NULL, NULL, 'world', '0.537364'),
(663, 664, 'incurvata', NULL, NULL, 'world', '0.590000'),
(664, 664, 'INCURVATA', NULL, NULL, 'world', '0.590000'),
(665, 664, 'klaineana', NULL, NULL, 'world', '0.724500'),
(666, 664, 'laxa', NULL, NULL, 'world', '0.693333'),
(667, 664, 'LAXA', NULL, NULL, 'world', '0.693333'),
(668, 664, 'peruviana', NULL, NULL, 'world', '0.530000'),
(669, 664, 'rostrata', NULL, NULL, 'world', '0.550000'),
(670, 664, 'ROSTRATA', NULL, NULL, 'world', '0.550000'),
(671, 664, 'rubiginosa', NULL, NULL, 'world', '0.580000'),
(672, 664, 'RUBIGINOSA', NULL, NULL, 'world', '0.580000'),
(673, 664, 'rugosa', NULL, NULL, 'world', '0.735000'),
(674, 664, 'RUGOSA', NULL, NULL, 'world', '0.735000'),
(675, 146, 'cochinchinensis', NULL, NULL, 'world', '0.880000'),
(676, 146, 'fusca', NULL, NULL, 'world', '0.835000'),
(677, 146, 'hupeana', NULL, NULL, 'world', '0.752250'),
(678, 146, 'latifolia', NULL, NULL, 'world', '0.750000'),
(679, 146, 'oliveri', NULL, NULL, 'world', '0.879500'),
(680, 146, 'retusa', NULL, NULL, 'world', '0.876000'),
(681, 666, 'glaucescens', NULL, NULL, 'world', '0.530000'),
(682, 666, 'oldhamii', NULL, NULL, 'world', '0.536000'),
(683, 147, 'philippiana', NULL, NULL, 'world', '0.300683'),
(684, 671, 'caesia', NULL, NULL, 'world', '0.660000'),
(685, 671, 'cuneata', NULL, NULL, 'world', '0.564667'),
(686, 671, 'CUNEATA', NULL, NULL, 'world', '0.564667'),
(687, 671, 'firma', NULL, NULL, 'world', '0.555000'),
(688, 671, 'incrassata', NULL, NULL, 'world', '0.460000'),
(689, 671, 'INCRASSATA', NULL, NULL, 'world', '0.460000'),
(690, 673, 'boliviana', NULL, NULL, 'world', '0.635333'),
(691, 149, 'arboreus', NULL, NULL, 'world', '0.420594'),
(692, 761, 'dalbergioides', NULL, NULL, 'world', '0.680000'),
(693, 762, 'glaucescens', NULL, NULL, 'world', '0.915000'),
(694, 150, 'panamensis', NULL, NULL, 'world', '0.764000'),
(695, 151, 'corbisieri', NULL, NULL, 'world', '0.876000'),
(696, 151, 'dinklagei', NULL, NULL, 'world', '0.683000'),
(697, 151, 'excelsum', NULL, NULL, 'world', '0.824000'),
(698, 151, 'guianense', NULL, NULL, 'world', '0.896385'),
(699, 151, 'indum', NULL, NULL, 'world', '0.820000'),
(700, 151, 'kunstleri', NULL, NULL, 'world', '0.720000'),
(701, 151, 'pachyphyllum', NULL, NULL, 'world', '0.922500'),
(702, 151, 'platysepalum', NULL, NULL, 'world', '0.772500'),
(703, 151, 'PLATYSEPALUM', NULL, NULL, 'world', '0.772500'),
(704, 5736, 'africana', NULL, NULL, 'world', '0.661500'),
(705, 5736, 'brevipaniculata', NULL, NULL, 'world', '0.553000'),
(706, 700, 'excelsa', NULL, NULL, 'world', '0.680000'),
(707, 700, 'grandifolia', NULL, NULL, 'world', '0.650000'),
(708, 700, 'GRANDIFOLIA', NULL, NULL, 'world', '0.650000'),
(709, 700, 'indica', NULL, NULL, 'world', '0.700000'),
(710, 700, 'luzoniensis', NULL, NULL, 'world', '0.685000'),
(711, 700, 'megalantha', NULL, NULL, 'world', '0.739000'),
(712, 700, 'obovata', NULL, NULL, 'world', '0.630000'),
(713, 700, 'philippinensis', NULL, NULL, 'world', '0.626500'),
(714, 700, 'reticulata', NULL, NULL, 'world', '0.610000'),
(715, 700, 'RETICULATA', NULL, NULL, 'world', '0.610000'),
(716, 700, 'suffruticosa', NULL, NULL, 'world', '0.450000'),
(717, 700, 'sumatrana', NULL, NULL, 'world', '0.680000'),
(718, 700, 'SUMATRANA', NULL, NULL, 'world', '0.680000'),
(719, 772, 'longan', NULL, NULL, 'world', '0.700000'),
(720, 775, 'zenkeri', NULL, NULL, 'world', '0.695500'),
(721, 154, 'andamanica', NULL, NULL, 'world', '0.600000'),
(722, 154, 'ANDAMANICA', NULL, NULL, 'world', '0.600000'),
(723, 154, 'argentea', NULL, NULL, 'world', '0.690000'),
(724, 154, 'ARGENTEA', NULL, NULL, 'world', '0.690000'),
(725, 154, 'borneensis', NULL, NULL, 'world', '0.550000'),
(726, 154, 'buxifolia', NULL, NULL, 'world', '0.775000'),
(727, 154, 'BUXIFOLIA', NULL, NULL, 'world', '0.775000'),
(728, 154, 'capreifolia', NULL, NULL, 'world', '0.730000'),
(729, 154, 'cauliflora', NULL, NULL, 'world', '0.540000'),
(730, 154, 'CAULIFLORA', NULL, NULL, 'world', '0.540000'),
(731, 154, 'clavigera', NULL, NULL, 'world', '0.770000'),
(732, 154, 'confertiflora', NULL, NULL, 'world', '0.660000'),
(733, 154, 'crassiflora', NULL, NULL, 'world', '0.858200'),
(734, 154, 'decipiens', NULL, NULL, 'world', '0.650000'),
(735, 154, 'densa', NULL, NULL, 'world', '0.710000'),
(736, 154, 'diepenhorstii', NULL, NULL, 'world', '0.570000'),
(737, 154, 'DIEPENHORSTII', NULL, NULL, 'world', '0.570000'),
(738, 154, 'elmeri', NULL, NULL, 'world', '0.770000'),
(739, 154, 'eriantha', NULL, NULL, 'world', '0.702600'),
(740, 154, 'ferrea', NULL, NULL, 'world', '0.940000'),
(741, 154, 'ferruginescens', NULL, NULL, 'world', '0.620000'),
(742, 154, 'hasseltii', NULL, NULL, 'world', '0.553000'),
(743, 154, 'kurzii', NULL, NULL, 'world', '0.800000'),
(744, 154, 'maingayi', NULL, NULL, 'world', '0.545000'),
(745, 154, 'MAINGAYI', NULL, NULL, 'world', '0.545000'),
(746, 154, 'malabarica', NULL, NULL, 'world', '0.715000'),
(747, 154, 'malaccensis', NULL, NULL, 'world', '0.830000'),
(748, 154, 'mannii', NULL, NULL, 'world', '0.813000'),
(749, 154, 'maritima', NULL, NULL, 'world', '0.560000'),
(750, 154, 'montana', NULL, NULL, 'world', '0.719000'),
(751, 154, 'oblonga', NULL, NULL, 'world', '0.750000'),
(752, 154, 'pendula', NULL, NULL, 'world', '0.685000'),
(753, 154, 'PENDULA', NULL, NULL, 'world', '0.685000'),
(754, 154, 'pilosanthera', NULL, NULL, 'world', '0.645000'),
(755, 154, 'puncticulosa', NULL, NULL, 'world', '0.660000'),
(756, 154, 'rigida', NULL, NULL, 'world', '0.716667'),
(757, 154, 'sumatrana', NULL, NULL, 'world', '0.605000'),
(758, 154, 'SUMATRANA', NULL, NULL, 'world', '0.605000'),
(759, 154, 'toposia', NULL, NULL, 'world', '0.700000'),
(760, 154, 'toposioides', NULL, NULL, 'world', '0.710000'),
(761, 154, 'transitoria', NULL, NULL, 'world', '0.840000'),
(762, 154, 'virginiana', NULL, NULL, 'world', '0.670000'),
(763, 154, 'wallichii', NULL, NULL, 'world', '0.600000'),
(764, 154, 'WALLICHII', NULL, NULL, 'world', '0.600000'),
(765, 778, 'cuspidatum', NULL, NULL, 'world', '0.850000'),
(766, 156, 'purpurea', NULL, NULL, 'world', '0.761846'),
(767, 701, 'acutangulus', NULL, NULL, 'world', '0.635000'),
(768, 701, 'alatus', NULL, NULL, 'world', '0.599000'),
(769, 701, 'caudatus', NULL, NULL, 'world', '0.690000'),
(770, 701, 'confertus', NULL, NULL, 'world', '0.640000'),
(771, 701, 'cornutus', NULL, NULL, 'world', '0.676667'),
(772, 701, 'CORNUTUS', NULL, NULL, 'world', '0.676667'),
(773, 701, 'costatus', NULL, NULL, 'world', '0.755000'),
(774, 701, 'crinitus', NULL, NULL, 'world', '0.745000'),
(775, 701, 'CRINITUS', NULL, NULL, 'world', '0.745000'),
(776, 701, 'geniculatus', NULL, NULL, 'world', '0.590000'),
(777, 701, 'globosus', NULL, NULL, 'world', '0.700000'),
(778, 701, 'gracilis', NULL, NULL, 'world', '0.603333'),
(779, 701, 'grandiflorus', NULL, NULL, 'world', '0.670000'),
(780, 701, 'hasseltii', NULL, NULL, 'world', '0.555000'),
(781, 701, 'kunstleri', NULL, NULL, 'world', '0.600000'),
(782, 701, 'KUNSTLERI', NULL, NULL, 'world', '0.600000'),
(783, 701, 'obtusifolius', NULL, NULL, 'world', '0.650000'),
(784, 701, 'palembanicus', NULL, NULL, 'world', '0.573333'),
(785, 701, 'sublamellatus', NULL, NULL, 'world', '0.650000'),
(786, 701, 'SUBLAMELLATUS', NULL, NULL, 'world', '0.650000'),
(787, 701, 'tempehes', NULL, NULL, 'world', '0.545000'),
(788, 701, 'validus', NULL, NULL, 'world', '0.540000'),
(789, 701, 'zeylanicus', NULL, NULL, 'world', '0.690000'),
(790, 157, 'micrantha', NULL, NULL, 'world', '0.871000'),
(791, 157, 'odorata', NULL, NULL, 'world', '0.922750'),
(792, 157, 'oleifera', NULL, NULL, 'world', '0.848333'),
(793, 157, 'punctata', NULL, NULL, 'world', '0.920000'),
(794, 782, 'caloneura', NULL, NULL, 'world', '0.339600'),
(795, 158, 'guianensis', NULL, NULL, 'world', '0.560000'),
(796, 18184, 'racemosum', NULL, NULL, 'world', '0.712500'),
(797, 784, 'myricoides', NULL, NULL, 'world', '0.356778'),
(798, 786, 'macrocalyx', NULL, NULL, 'world', '0.482000'),
(799, 787, 'angustifolia', NULL, NULL, 'world', '0.350000'),
(800, 789, 'dao', NULL, NULL, 'world', '0.400000'),
(801, 789, 'DAO', NULL, NULL, 'world', '0.400000'),
(802, 790, 'racemosus', NULL, NULL, 'world', '0.840000'),
(803, 791, 'aromatica', NULL, NULL, 'world', '0.680000'),
(804, 791, 'lanceolata', NULL, NULL, 'world', '0.620000'),
(805, 159, 'alba', NULL, NULL, 'world', '0.696821'),
(806, 159, 'amazonica', NULL, NULL, 'world', '0.670000'),
(807, 159, 'crassipes', NULL, NULL, 'world', '0.550000'),
(808, 159, 'glauca', NULL, NULL, 'world', '0.673058'),
(809, 159, 'longifolia', NULL, NULL, 'world', '0.620000'),
(810, 159, 'LONGIFOLIA', NULL, NULL, 'world', '0.620000'),
(811, 159, 'pendula', NULL, NULL, 'world', '0.750000'),
(812, 159, 'PENDULA', NULL, NULL, 'world', '0.750000'),
(813, 159, 'polyneura', NULL, NULL, 'world', '0.670000'),
(814, 159, 'POLYNEURA', NULL, NULL, 'world', '0.670000'),
(815, 159, 'roxburghii', NULL, NULL, 'world', '0.675000'),
(816, 159, 'sibuyanensis', NULL, NULL, 'world', '0.630000'),
(817, 159, 'standleyi', NULL, NULL, 'world', '0.675000'),
(818, 159, 'variabilis', NULL, NULL, 'world', '0.736667'),
(819, 792, 'grandiflora', NULL, NULL, 'world', '0.379000'),
(820, 6126, 'cestroides', NULL, NULL, 'world', '0.634333'),
(821, 6128, 'verrucosa', NULL, NULL, 'world', '0.818000'),
(822, 160, 'chrysea', NULL, NULL, 'world', '0.845000'),
(823, 160, 'confinis', NULL, NULL, 'world', '0.621000'),
(824, 160, 'megalocarpa', NULL, NULL, 'world', '0.910000'),
(825, 160, 'quitarensis', NULL, NULL, 'world', '0.800000'),
(826, 160, 'spixiana', NULL, NULL, 'world', '0.580000'),
(827, 160, 'stelechantha', NULL, NULL, 'world', '0.849000'),
(828, 160, 'surinamensis', NULL, NULL, 'world', '0.800000'),
(829, 702, 'excelsus', NULL, NULL, 'world', '0.530000'),
(830, 702, 'graveolens', NULL, NULL, 'world', '0.560000'),
(831, 702, 'griffithii', NULL, NULL, 'world', '0.613333'),
(832, 702, 'GRIFFITHII', NULL, NULL, 'world', '0.613333'),
(833, 702, 'lowianus', NULL, NULL, 'world', '0.570000'),
(834, 702, 'oxleyanus', NULL, NULL, 'world', '0.525000'),
(835, 702, 'OXLEYANUS', NULL, NULL, 'world', '0.525000'),
(836, 702, 'singaporensis', NULL, NULL, 'world', '0.600000'),
(837, 702, 'SINGAPORENSIS', NULL, NULL, 'world', '0.600000'),
(838, 702, 'zibethinus', NULL, NULL, 'world', '0.516000'),
(839, 795, 'eriopila', NULL, NULL, 'world', '0.796000'),
(840, 795, 'hirsuta', NULL, NULL, 'world', '0.770000'),
(841, 161, 'discolor', NULL, NULL, 'world', '0.550333'),
(842, 161, 'lehmannii', NULL, NULL, 'world', '0.590000'),
(843, 161, 'macroprophyllata', NULL, NULL, 'world', '0.563000'),
(844, 796, 'costulata', NULL, NULL, 'world', '0.337500'),
(845, 796, 'COSTULATA', NULL, NULL, 'world', '0.337500'),
(846, 703, 'acutangulum', NULL, NULL, 'world', '0.740000'),
(847, 703, 'ACUTANGULUM', NULL, NULL, 'world', '0.740000'),
(848, 703, 'alliaceum', NULL, NULL, 'world', '0.565000'),
(849, 703, 'ALLIACEUM', NULL, NULL, 'world', '0.565000'),
(850, 703, 'arborescens', NULL, NULL, 'world', '0.470000'),
(851, 703, 'binectariferum', NULL, NULL, 'world', '0.606000'),
(852, 703, 'cauliflorum', NULL, NULL, 'world', '0.715000'),
(853, 703, 'CAULIFLORUM', NULL, NULL, 'world', '0.715000'),
(854, 703, 'densiflorum', NULL, NULL, 'world', '0.570000'),
(855, 703, 'excelsum', NULL, NULL, 'world', '0.470000'),
(856, 703, 'flavescens', NULL, NULL, 'world', '0.690000'),
(857, 703, 'FLAVESCENS', NULL, NULL, 'world', '0.690000'),
(858, 703, 'gaudichaudianum', NULL, NULL, 'world', '0.556500'),
(859, 703, 'grande', NULL, NULL, 'world', '0.647000'),
(860, 703, 'oppositifolium', NULL, NULL, 'world', '0.758000'),
(861, 703, 'parasiticum', NULL, NULL, 'world', '0.600000'),
(862, 163, 'guianensis', NULL, NULL, 'world', '0.627429'),
(863, 163, 'lanceolata', NULL, NULL, 'world', '0.580000'),
(864, 163, 'ramiflora', NULL, NULL, 'world', '0.961000'),
(865, 797, 'acuminata', NULL, NULL, 'world', '0.497000'),
(866, 797, 'laevis', NULL, NULL, 'world', '0.560000'),
(867, 704, 'apiculatus', NULL, NULL, 'world', '0.560000'),
(868, 704, 'chinensis', NULL, NULL, 'world', '0.442000'),
(869, 704, 'ferrugineus', NULL, NULL, 'world', '0.517000'),
(870, 704, 'FERRUGINEUS', NULL, NULL, 'world', '0.517000'),
(871, 704, 'floribundus', NULL, NULL, 'world', '0.580000'),
(872, 704, 'mastersii', NULL, NULL, 'world', '0.550000'),
(873, 704, 'parvifolius', NULL, NULL, 'world', '0.500000'),
(874, 704, 'petiolatus', NULL, NULL, 'world', '0.455000'),
(875, 704, 'PETIOLATUS', NULL, NULL, 'world', '0.455000'),
(876, 704, 'robustus', NULL, NULL, 'world', '0.516500'),
(877, 704, 'sphaericus', NULL, NULL, 'world', '0.327000'),
(878, 704, 'stipularis', NULL, NULL, 'world', '0.445000'),
(879, 704, 'STIPULARIS', NULL, NULL, 'world', '0.445000'),
(880, 704, 'sylvestris', NULL, NULL, 'world', '0.475000'),
(881, 799, 'tapos', NULL, NULL, 'world', '0.785000'),
(882, 799, 'TAPOS', NULL, NULL, 'world', '0.785000'),
(883, 802, 'maingayi', NULL, NULL, 'world', '0.740000'),
(884, 802, 'MAINGAYI', NULL, NULL, 'world', '0.740000'),
(885, 167, 'formosa', NULL, NULL, 'world', '0.421000'),
(886, 167, 'paniculata', NULL, NULL, 'world', '0.631000'),
(887, 167, 'sericea', NULL, NULL, 'world', '0.470000'),
(888, 804, 'calophylloides', NULL, NULL, 'world', '0.679000'),
(889, 6427, 'uchi', NULL, NULL, 'world', '0.794429'),
(890, 805, 'diadenum', NULL, NULL, 'world', '0.366667'),
(891, 805, 'peltatum', NULL, NULL, 'world', '0.300000'),
(892, 809, 'fuscum', NULL, NULL, 'world', '0.525000');
INSERT INTO `speciesWood` (`wsgSpID`, `GenusID`, `species`, `subspecies`, `infra`, `locale`, `wsg`) VALUES
(893, 809, 'FUSCUM', NULL, NULL, 'world', '0.525000'),
(894, 810, 'angolense', NULL, NULL, 'world', '0.483375'),
(895, 810, 'candollei', NULL, NULL, 'world', '0.574000'),
(896, 810, 'cylindricum', NULL, NULL, 'world', '0.571500'),
(897, 810, 'utile', NULL, NULL, 'world', '0.536944'),
(898, 168, 'cyclocarpum', NULL, NULL, 'world', '0.401000'),
(899, 168, 'schomburgkii', NULL, NULL, 'world', '0.698917'),
(900, 6469, 'duckeana', NULL, NULL, 'world', '0.791000'),
(901, 6469, 'glabriflora', NULL, NULL, 'world', '0.759000'),
(902, 6471, 'amazonicus', NULL, NULL, 'world', '0.816000'),
(903, 813, 'bengalensis', NULL, NULL, 'world', '0.730000'),
(904, 813, 'deflexa', NULL, NULL, 'world', '0.775500'),
(905, 814, 'microspermum', NULL, NULL, 'world', '0.523000'),
(906, 816, 'globosa', NULL, NULL, 'world', '0.410000'),
(907, 170, 'calcaratum', NULL, NULL, 'world', '0.680000'),
(908, 817, 'exsul', NULL, NULL, 'world', '0.607100'),
(909, 170, 'uncinatum', NULL, NULL, 'world', '0.523083'),
(910, 171, 'indica', NULL, NULL, 'world', '0.320000'),
(911, 171, 'stricta', NULL, NULL, 'world', '0.220000'),
(912, 171, 'subumbrans', NULL, NULL, 'world', '0.230000'),
(913, 171, 'variegata', NULL, NULL, 'world', '0.280000'),
(914, 821, 'ivorense', NULL, NULL, 'world', '0.774000'),
(915, 821, 'suaveolens', NULL, NULL, 'world', '0.824286'),
(916, 172, 'citrifolium', NULL, NULL, 'world', '0.710000'),
(917, 172, 'cuneatum', NULL, NULL, 'world', '0.695000'),
(918, 172, 'CUNEATUM', NULL, NULL, 'world', '0.695000'),
(919, 172, 'macrophyllum', NULL, NULL, 'world', '0.710000'),
(920, 172, 'mannii', NULL, NULL, 'world', '0.546778'),
(921, 172, 'squamatum', NULL, NULL, 'world', '0.710000'),
(922, 173, 'amazoniciformis', NULL, NULL, 'world', '0.823000'),
(923, 173, 'atropetiolata', NULL, NULL, 'world', '0.753000'),
(924, 173, 'carinata', NULL, NULL, 'world', '0.782000'),
(925, 173, 'coriacea', NULL, NULL, 'world', '0.852083'),
(926, 173, 'gigantea', NULL, NULL, 'world', '0.780000'),
(927, 173, 'grandiflora', NULL, NULL, 'world', '0.876000'),
(928, 173, 'juruensis', NULL, NULL, 'world', '0.960000'),
(929, 173, 'parvifolia', NULL, NULL, 'world', '0.860000'),
(930, 173, 'pedicellata', NULL, NULL, 'world', '0.908667'),
(931, 173, 'pittieri', NULL, NULL, 'world', '0.860000'),
(932, 173, 'tessmannii', NULL, NULL, 'world', '0.789000'),
(933, 173, 'wachenheimii', NULL, NULL, 'world', '0.805500'),
(934, 6694, 'divinorum', NULL, NULL, 'world', '0.775000'),
(935, 175, 'anastomosans', NULL, NULL, 'world', '0.770000'),
(936, 175, 'citrifolia', NULL, NULL, 'world', '0.664000'),
(937, 175, 'coffeifolia', NULL, NULL, 'world', '0.757000'),
(938, 175, 'domingensis', NULL, NULL, 'world', '0.590000'),
(939, 175, 'eggersii', NULL, NULL, 'world', '0.697500'),
(940, 175, 'feijoi', NULL, NULL, 'world', '0.789000'),
(941, 175, 'florida', NULL, NULL, 'world', '0.681333'),
(942, 175, 'illepida', NULL, NULL, 'world', '0.690000'),
(943, 175, 'patrisii', NULL, NULL, 'world', '0.830500'),
(944, 175, 'pseudopsidium', NULL, NULL, 'world', '0.868500'),
(945, 175, 'salamensis', NULL, NULL, 'world', '0.582000'),
(946, 175, 'stahlii', NULL, NULL, 'world', '0.709979'),
(947, 175, 'syzygioides', NULL, NULL, 'world', '0.750000'),
(948, 175, 'SYZYGIOIDES', NULL, NULL, 'world', '0.750000'),
(949, 175, 'venezuelensis', NULL, NULL, 'world', '0.820000'),
(950, 706, 'acuminata', NULL, NULL, 'world', '0.500000'),
(951, 706, 'japonica', NULL, NULL, 'world', '0.620000'),
(952, 706, 'nitida', NULL, NULL, 'world', '0.530000'),
(953, 826, 'longifolia', NULL, NULL, 'world', '0.505000'),
(954, 826, 'LONGIFOLIA', NULL, NULL, 'world', '0.505000'),
(955, 828, 'zwageri', NULL, NULL, 'world', '0.786667'),
(956, 177, 'precatoria', NULL, NULL, 'world', '0.387667'),
(957, 18388, 'tonkinensis', NULL, NULL, 'world', '0.548000'),
(958, 707, 'elliptica', NULL, NULL, 'world', '0.810000'),
(959, 707, 'fragrans', NULL, NULL, 'world', '0.688000'),
(960, 707, 'racemosa', NULL, NULL, 'world', '0.643333'),
(961, 707, 'RACEMOSA', NULL, NULL, 'world', '0.643333'),
(962, 6840, 'grandifolia', NULL, NULL, 'world', '0.560000'),
(963, 6840, 'sylvatica', NULL, NULL, 'world', '0.585000'),
(964, 179, 'occidentalis', NULL, NULL, 'world', '0.587889'),
(965, 832, 'adenophylla', NULL, NULL, 'world', '0.490000'),
(966, 181, 'altissima', NULL, NULL, 'world', '0.473000'),
(967, 181, 'americana', NULL, NULL, 'world', '0.402500'),
(968, 181, 'annulata', NULL, NULL, 'world', '0.330000'),
(969, 181, 'aurea', NULL, NULL, 'world', '0.440000'),
(970, 181, 'auriculata', NULL, NULL, 'world', '0.468000'),
(971, 181, 'benghalensis', NULL, NULL, 'world', '0.493667'),
(972, 181, 'benjamina', NULL, NULL, 'world', '0.459333'),
(973, 181, 'botryocarpa', NULL, NULL, 'world', '0.430000'),
(974, 181, 'callosa', NULL, NULL, 'world', '0.290000'),
(975, 181, 'citrifolia', NULL, NULL, 'world', '0.400000'),
(976, 181, 'consociata', NULL, NULL, 'world', '0.460000'),
(977, 181, 'crassinervia', NULL, NULL, 'world', '0.420000'),
(978, 181, 'drupacea', NULL, NULL, 'world', '0.210000'),
(979, 181, 'erecta', NULL, NULL, 'world', '0.470000'),
(980, 181, 'exasperata', NULL, NULL, 'world', '0.344000'),
(981, 181, 'eximia', NULL, NULL, 'world', '0.455000'),
(982, 181, 'fistulosa', NULL, NULL, 'world', '0.380000'),
(983, 181, 'FISTULOSA', NULL, NULL, 'world', '0.380000'),
(984, 181, 'fulva', NULL, NULL, 'world', '0.390000'),
(985, 181, 'FULVA', NULL, NULL, 'world', '0.390000'),
(986, 181, 'grossularioides', NULL, NULL, 'world', '0.420000'),
(987, 181, 'GROSSULARIOIDES', NULL, NULL, 'world', '0.420000'),
(988, 181, 'hispida', NULL, NULL, 'world', '0.381500'),
(989, 181, 'insipida', NULL, NULL, 'world', '0.376556'),
(990, 181, 'lacor', NULL, NULL, 'world', '0.340000'),
(991, 181, 'maxima', NULL, NULL, 'world', '0.360500'),
(992, 181, 'minahassae', NULL, NULL, 'world', '0.320000'),
(993, 181, 'mucuso', NULL, NULL, 'world', '0.409000'),
(994, 181, 'nervosa', NULL, NULL, 'world', '0.280000'),
(995, 181, 'nymphaeifolia', NULL, NULL, 'world', '0.415000'),
(996, 181, 'pertusa', NULL, NULL, 'world', '0.420000'),
(997, 181, 'racemosa', NULL, NULL, 'world', '0.362600'),
(998, 181, 'religiosa', NULL, NULL, 'world', '0.443000'),
(999, 181, 'retusa', NULL, NULL, 'world', '0.542200'),
(1000, 181, 'septica', NULL, NULL, 'world', '0.421000'),
(1001, 181, 'sintensii', NULL, NULL, 'world', '0.390000'),
(1002, 181, 'variegata', NULL, NULL, 'world', '0.327000'),
(1003, 181, 'VARIEGATA', NULL, NULL, 'world', '0.327000'),
(1004, 181, 'vasculosa', NULL, NULL, 'world', '0.300000'),
(1005, 181, 'VASCULOSA', NULL, NULL, 'world', '0.300000'),
(1006, 181, 'virens', NULL, NULL, 'world', '0.344000'),
(1007, 708, 'decipiens', NULL, NULL, 'world', '0.960000'),
(1008, 833, 'simplex', NULL, NULL, 'world', '0.436000'),
(1009, 834, 'indica', NULL, NULL, 'world', '0.737000'),
(1010, 834, 'jangomas', NULL, NULL, 'world', '0.923000'),
(1011, 834, 'rukam', NULL, NULL, 'world', '0.750000'),
(1012, 835, 'splendidissima', NULL, NULL, 'world', '0.640000'),
(1013, 836, 'americana', NULL, NULL, 'world', '0.550000'),
(1014, 836, 'excelsior', NULL, NULL, 'world', '0.570000'),
(1015, 836, 'griffithii', NULL, NULL, 'world', '0.600000'),
(1016, 836, 'mandshurica', NULL, NULL, 'world', '0.551333'),
(1017, 836, 'nigra', NULL, NULL, 'world', '0.450000'),
(1018, 839, 'africana', NULL, NULL, 'world', '0.424000'),
(1019, 7070, 'longifolia', NULL, NULL, 'world', '0.742667'),
(1020, 186, 'cowa', NULL, NULL, 'world', '0.551000'),
(1021, 186, 'dulcis', NULL, NULL, 'world', '0.715000'),
(1022, 186, 'epunctata', NULL, NULL, 'world', '0.843000'),
(1023, 186, 'gaudichaudii', NULL, NULL, 'world', '0.720000'),
(1024, 186, 'havilandii', NULL, NULL, 'world', '0.710000'),
(1025, 186, 'hombroniana', NULL, NULL, 'world', '0.680000'),
(1026, 186, 'intermedia', NULL, NULL, 'world', '0.662500'),
(1027, 186, 'kola', NULL, NULL, 'world', '0.727333'),
(1028, 186, 'macrophylla', NULL, NULL, 'world', '0.770000'),
(1029, 186, 'madruno', NULL, NULL, 'world', '0.726667'),
(1030, 186, 'mangostana', NULL, NULL, 'world', '0.810000'),
(1031, 186, 'mannii', NULL, NULL, 'world', '0.824000'),
(1032, 186, 'merguensis', NULL, NULL, 'world', '0.780000'),
(1033, 186, 'nervosa', NULL, NULL, 'world', '0.785000'),
(1034, 186, 'NERVOSA', NULL, NULL, 'world', '0.785000'),
(1035, 186, 'parvifolia', NULL, NULL, 'world', '0.435000'),
(1036, 186, 'PARVIFOLIA', NULL, NULL, 'world', '0.435000'),
(1037, 186, 'penangiana', NULL, NULL, 'world', '0.860000'),
(1038, 186, 'portoricensis', NULL, NULL, 'world', '0.833585'),
(1039, 186, 'scortechinii', NULL, NULL, 'world', '0.640000'),
(1040, 186, 'SCORTECHINII', NULL, NULL, 'world', '0.640000'),
(1041, 186, 'speciosa', NULL, NULL, 'world', '0.840000'),
(1042, 186, 'xanthochymus', NULL, NULL, 'world', '0.785000'),
(1043, 843, 'tubifera', NULL, NULL, 'world', '0.670000'),
(1044, 843, 'TUBIFERA', NULL, NULL, 'world', '0.670000'),
(1045, 845, 'floribunda', NULL, NULL, 'world', '0.547000'),
(1046, 845, 'pinnata', NULL, NULL, 'world', '0.640000'),
(1047, 187, 'americana', NULL, NULL, 'world', '0.632074'),
(1048, 848, 'dewevrei', NULL, NULL, 'world', '0.706500'),
(1049, 848, 'klainei', NULL, NULL, 'world', '0.659000'),
(1050, 849, 'hirta', NULL, NULL, 'world', '0.480000'),
(1051, 849, 'nervosa', NULL, NULL, 'world', '0.450000'),
(1052, 849, 'NERVOSA', NULL, NULL, 'world', '0.450000'),
(1053, 849, 'subaequalis', NULL, NULL, 'world', '0.461750'),
(1054, 849, 'SUBAEQUALIS', NULL, NULL, 'world', '0.461750'),
(1055, 710, 'glomerulatum', NULL, NULL, 'world', '0.430000'),
(1056, 710, 'lutescens', NULL, NULL, 'world', '0.610000'),
(1057, 710, 'philippicum', NULL, NULL, 'world', '0.570000'),
(1058, 710, 'rubrum', NULL, NULL, 'world', '0.640000'),
(1059, 710, 'zeylanicum', NULL, NULL, 'world', '0.480000'),
(1060, 851, 'elegans', NULL, NULL, 'world', '0.505600'),
(1061, 851, 'malayana', NULL, NULL, 'world', '0.590000'),
(1062, 851, 'MALAYANA', NULL, NULL, 'world', '0.590000'),
(1063, 851, 'wallichii', NULL, NULL, 'world', '0.534000'),
(1064, 711, 'citrifolia', NULL, NULL, 'world', '0.439000'),
(1065, 852, 'amazonicum', NULL, NULL, 'world', '0.680750'),
(1066, 191, 'arborea', NULL, NULL, 'world', '0.429750'),
(1067, 855, 'gnemon', NULL, NULL, 'world', '0.610000'),
(1068, 855, 'GNEMON', NULL, NULL, 'world', '0.610000'),
(1069, 7383, 'affinis', NULL, NULL, 'world', '0.780000'),
(1070, 856, 'serrata', NULL, NULL, 'world', '0.700000'),
(1071, 856, 'SERRATA', NULL, NULL, 'world', '0.700000'),
(1072, 713, 'giganteus', NULL, NULL, 'world', '0.380000'),
(1073, 857, 'calleryanum', NULL, NULL, 'world', '0.673000'),
(1074, 858, 'affinis', NULL, NULL, 'world', '0.616667'),
(1075, 858, 'confusus', NULL, NULL, 'world', '0.560000'),
(1076, 858, 'forbesii', NULL, NULL, 'world', '0.530000'),
(1077, 193, 'spicata', NULL, NULL, 'world', '0.693723'),
(1078, 194, 'fruticosa', NULL, NULL, 'world', '0.518500'),
(1079, 18521, 'glabra', NULL, NULL, 'world', '0.727188'),
(1080, 861, 'oligoneura', NULL, NULL, 'world', '0.415000'),
(1081, 197, 'neuberthii', NULL, NULL, 'world', '0.620000'),
(1082, 198, 'opposita', NULL, NULL, 'world', '0.830000'),
(1083, 199, 'cedrata', NULL, NULL, 'world', '0.509933'),
(1084, 199, 'glabra', NULL, NULL, 'world', '0.477806'),
(1085, 199, 'gomma', NULL, NULL, 'world', '0.650000'),
(1086, 199, 'grandifolia', NULL, NULL, 'world', '0.545000'),
(1087, 199, 'guidonia', NULL, NULL, 'world', '0.567514'),
(1088, 199, 'humaitensis', NULL, NULL, 'world', '0.764500'),
(1089, 199, 'kunthiana', NULL, NULL, 'world', '0.616167'),
(1090, 199, 'laurentii', NULL, NULL, 'world', '0.563333'),
(1091, 199, 'macrophylla', NULL, NULL, 'world', '0.645000'),
(1092, 199, 'pterorhachis', NULL, NULL, 'world', '0.770000'),
(1093, 199, 'pubescens', NULL, NULL, 'world', '0.530500'),
(1094, 199, 'purusana', NULL, NULL, 'world', '0.770000'),
(1095, 199, 'thompsonii', NULL, NULL, 'world', '0.551889'),
(1096, 200, 'amplifolia', NULL, NULL, 'world', '0.511000'),
(1097, 200, 'caribaea', NULL, NULL, 'world', '0.707667'),
(1098, 200, 'dumetorum', NULL, NULL, 'world', '0.466000'),
(1099, 200, 'olivacea', NULL, NULL, 'world', '0.455667'),
(1100, 200, 'puncticulata', NULL, NULL, 'world', '0.540000'),
(1101, 201, 'ulmifolia', NULL, NULL, 'world', '0.522209'),
(1102, 202, 'acreana', NULL, NULL, 'world', '0.870000'),
(1103, 202, 'valenzuelana', NULL, NULL, 'world', '0.627409'),
(1104, 7547, 'ehie', NULL, NULL, 'world', '0.711786'),
(1105, 862, 'bijuga', NULL, NULL, 'world', '0.460000'),
(1106, 203, 'hexapetala', NULL, NULL, 'world', '0.716000'),
(1107, 203, 'longifolia', NULL, NULL, 'world', '0.670000'),
(1108, 203, 'superba', NULL, NULL, 'world', '0.580000'),
(1109, 863, 'bancana', NULL, NULL, 'world', '0.570000'),
(1110, 863, 'contracta', NULL, NULL, 'world', '0.500000'),
(1111, 863, 'farquhariana', NULL, NULL, 'world', '0.580000'),
(1112, 863, 'forbesii', NULL, NULL, 'world', '0.540000'),
(1113, 863, 'FORBESII', NULL, NULL, 'world', '0.540000'),
(1114, 865, 'axillaris', NULL, NULL, 'world', '0.520000'),
(1115, 865, 'AXILLARIS', NULL, NULL, 'world', '0.520000'),
(1116, 866, 'ledermannii', NULL, NULL, 'world', '0.468143'),
(1117, 866, 'stipulosa', NULL, NULL, 'world', '0.478714'),
(1118, 18594, 'virginiana', NULL, NULL, 'world', '0.560000'),
(1119, 205, 'axillaris', NULL, NULL, 'world', '0.617500'),
(1120, 205, 'patens', NULL, NULL, 'world', '0.763000'),
(1121, 206, 'appendiculata', NULL, NULL, 'world', '0.245000'),
(1122, 870, 'arborea', NULL, NULL, 'world', '0.540000'),
(1123, 7808, 'madagascariensis', NULL, NULL, 'world', '0.467000'),
(1124, 207, 'floribunda', NULL, NULL, 'world', '0.530000'),
(1125, 209, 'concinna', NULL, NULL, 'world', '0.640000'),
(1126, 7898, 'sprucei', NULL, NULL, 'world', '0.627500'),
(1127, 874, 'cochinchinensis', NULL, NULL, 'world', '0.551000'),
(1128, 875, 'artocarpoides', NULL, NULL, 'world', '0.550000'),
(1129, 210, 'scabra', NULL, NULL, 'world', '0.735000'),
(1130, 210, 'tomentosa', NULL, NULL, 'world', '0.614667'),
(1131, 213, 'fascicularis', NULL, NULL, 'world', '0.479899'),
(1132, 214, 'caudata', NULL, NULL, 'world', '0.500000'),
(1133, 214, 'tuberculosa', NULL, NULL, 'world', '0.470000'),
(1134, 876, 'elata', NULL, NULL, 'world', '0.695000'),
(1135, 876, 'ELATA', NULL, NULL, 'world', '0.695000'),
(1136, 876, 'javanica', NULL, NULL, 'world', '0.620000'),
(1137, 876, 'JAVANICA', NULL, NULL, 'world', '0.620000'),
(1138, 876, 'simplicifolia', NULL, NULL, 'world', '0.673333'),
(1139, 876, 'SIMPLICIFOLIA', NULL, NULL, 'world', '0.673333'),
(1140, 876, 'sumatrana', NULL, NULL, 'world', '0.530000'),
(1141, 215, 'didymantha', NULL, NULL, 'world', '0.279500'),
(1142, 8096, 'fragrans', NULL, NULL, 'world', '0.344000'),
(1143, 8120, 'cymosum', NULL, NULL, 'world', '0.600000'),
(1144, 217, 'brasiliensis', NULL, NULL, 'world', '0.466625'),
(1145, 217, 'guianensis', NULL, NULL, 'world', '0.571000'),
(1146, 878, 'macrophyllus', NULL, NULL, 'world', '0.375000'),
(1147, 878, 'pernambucensis', NULL, NULL, 'world', '0.412718'),
(1148, 880, 'articulatus', NULL, NULL, 'world', '0.536250'),
(1149, 880, 'sucuuba', NULL, NULL, 'world', '0.462000'),
(1150, 220, 'bicornis', NULL, NULL, 'world', '0.900000'),
(1151, 220, 'hebeclada', NULL, NULL, 'world', '0.720000'),
(1152, 220, 'racemosa', NULL, NULL, 'world', '0.754250'),
(1153, 220, 'rugosa', NULL, NULL, 'world', '0.885519'),
(1154, 220, 'triandra', NULL, NULL, 'world', '0.682750'),
(1155, 8233, 'discolor', NULL, NULL, 'world', '0.710000'),
(1156, 881, 'integrifolia', NULL, NULL, 'world', '0.515500'),
(1157, 882, 'populneus', NULL, NULL, 'world', '0.290000'),
(1158, 221, 'ceylanicum', NULL, NULL, 'world', '0.660000'),
(1159, 221, 'grandiflorum', NULL, NULL, 'world', '0.770000'),
(1160, 221, 'letestui', NULL, NULL, 'world', '0.714250'),
(1161, 221, 'longifolium', NULL, NULL, 'world', '0.760000'),
(1162, 221, 'LONGIFOLIUM', NULL, NULL, 'world', '0.760000'),
(1163, 221, 'racemosum', NULL, NULL, 'world', '0.793889'),
(1164, 716, 'acuminata', NULL, NULL, 'world', '0.540000'),
(1165, 716, 'beccariana', NULL, NULL, 'world', '0.653333'),
(1166, 716, 'bracteata', NULL, NULL, 'world', '0.555000'),
(1167, 716, 'dryobalanoides', NULL, NULL, 'world', '0.610000'),
(1168, 716, 'DRYOBALANOIDES', NULL, NULL, 'world', '0.610000'),
(1169, 716, 'ferrea', NULL, NULL, 'world', '0.890000'),
(1170, 716, 'griffithii', NULL, NULL, 'world', '0.665000'),
(1171, 716, 'helferi', NULL, NULL, 'world', '0.880000'),
(1172, 716, 'mengarawan', NULL, NULL, 'world', '0.560000'),
(1173, 716, 'micrantha', NULL, NULL, 'world', '0.630000'),
(1174, 716, 'odorata', NULL, NULL, 'world', '0.635000'),
(1175, 716, 'vesquei', NULL, NULL, 'world', '0.570000'),
(1176, 717, 'amygdalina', NULL, NULL, 'world', '0.460000'),
(1177, 717, 'crassifolia', NULL, NULL, 'world', '0.480000'),
(1178, 717, 'CRASSIFOLIA', NULL, NULL, 'world', '0.480000'),
(1179, 717, 'glabra', NULL, NULL, 'world', '0.460000'),
(1180, 717, 'grandis', NULL, NULL, 'world', '0.390000'),
(1181, 717, 'irya', NULL, NULL, 'world', '0.369000'),
(1182, 717, 'sucosa', NULL, NULL, 'world', '0.550000'),
(1183, 717, 'SUCOSA', NULL, NULL, 'world', '0.550000'),
(1184, 717, 'superba', NULL, NULL, 'world', '0.560000'),
(1185, 717, 'SUPERBA', NULL, NULL, 'world', '0.560000'),
(1186, 717, 'wallichii', NULL, NULL, 'world', '0.500000'),
(1187, 717, 'WALLICHII', NULL, NULL, 'world', '0.500000'),
(1188, 884, 'glandulosa', NULL, NULL, 'world', '0.428500'),
(1189, 885, 'zeylanica', NULL, NULL, 'world', '0.720000'),
(1190, 885, 'ZEYLANICA', NULL, NULL, 'world', '0.720000'),
(1191, 8360, 'biaristatum', NULL, NULL, 'world', '0.594000'),
(1192, 224, 'crepitans', NULL, NULL, 'world', '0.367333'),
(1193, 225, 'prunifolius', NULL, NULL, 'world', '0.670000'),
(1194, 719, 'castanea', NULL, NULL, 'world', '0.700000'),
(1195, 719, 'kurzii', NULL, NULL, 'world', '0.599000'),
(1196, 719, 'woodii', NULL, NULL, 'world', '0.640000'),
(1197, 887, 'gabunense', NULL, NULL, 'world', '0.787000'),
(1198, 226, 'courbaril', NULL, NULL, 'world', '0.791048'),
(1199, 226, 'intermedia', NULL, NULL, 'world', '0.820000'),
(1200, 226, 'oblongifolia', NULL, NULL, 'world', '0.736667'),
(1201, 226, 'parvifolia', NULL, NULL, 'world', '0.877400'),
(1202, 889, 'orixense', NULL, NULL, 'world', '0.430000'),
(1203, 890, 'afzelii', NULL, NULL, 'world', '0.824000'),
(1204, 892, 'racemosum', NULL, NULL, 'world', '0.496000'),
(1205, 892, 'RACEMOSUM', NULL, NULL, 'world', '0.496000'),
(1206, 8512, 'polycarpa', NULL, NULL, 'world', '0.419000'),
(1207, 229, 'chapaensis', NULL, NULL, 'world', '0.732000'),
(1208, 229, 'cymosa', NULL, NULL, 'world', '0.487500'),
(1209, 229, 'opaca', NULL, NULL, 'world', '0.500000'),
(1210, 229, 'purpurea', NULL, NULL, 'world', '0.631500'),
(1211, 229, 'sideroxyloides', NULL, NULL, 'world', '0.755488'),
(1212, 230, 'acrocephala', NULL, NULL, 'world', '0.512500'),
(1213, 230, 'alba', NULL, NULL, 'world', '0.586111'),
(1214, 230, 'bourgonii', NULL, NULL, 'world', '0.545000'),
(1215, 230, 'capitata', NULL, NULL, 'world', '0.592333'),
(1216, 230, 'cayennensis', NULL, NULL, 'world', '0.530000'),
(1217, 230, 'chartacea', NULL, NULL, 'world', '0.512333'),
(1218, 230, 'cinnamomea', NULL, NULL, 'world', '0.640333'),
(1219, 230, 'cylindrica', NULL, NULL, 'world', '0.480000'),
(1220, 230, 'edulis', NULL, NULL, 'world', '0.587400'),
(1221, 230, 'fagifolia', NULL, NULL, 'world', '0.620000'),
(1222, 230, 'heterophylla', NULL, NULL, 'world', '0.560000'),
(1223, 230, 'huberi', NULL, NULL, 'world', '0.530000'),
(1224, 230, 'laurina', NULL, NULL, 'world', '0.653333'),
(1225, 230, 'leiocalycina', NULL, NULL, 'world', '0.560000'),
(1226, 230, 'marginata', NULL, NULL, 'world', '0.551800'),
(1227, 230, 'melinonis', NULL, NULL, 'world', '0.540000'),
(1228, 230, 'nobilis', NULL, NULL, 'world', '0.560000'),
(1229, 230, 'oerstediana', NULL, NULL, 'world', '0.425000'),
(1230, 230, 'paraensis', NULL, NULL, 'world', '0.820000'),
(1231, 230, 'pezizifera', NULL, NULL, 'world', '0.606500'),
(1232, 230, 'punctata', NULL, NULL, 'world', '0.560000'),
(1233, 230, 'rubiginosa', NULL, NULL, 'world', '0.662333'),
(1234, 230, 'sertulifera', NULL, NULL, 'world', '0.650000'),
(1235, 230, 'stipularis', NULL, NULL, 'world', '0.530000'),
(1236, 230, 'umbellifera', NULL, NULL, 'world', '0.724000'),
(1237, 230, 'vera', NULL, NULL, 'world', '0.580000'),
(1238, 898, 'palembanica', NULL, NULL, 'world', '0.658667'),
(1239, 898, 'PALEMBANICA', NULL, NULL, 'world', '0.658667'),
(1240, 231, 'deltoidea', NULL, NULL, 'world', '0.267000'),
(1241, 899, 'gabonensis', NULL, NULL, 'world', '0.774875'),
(1242, 899, 'grandifolia', NULL, NULL, 'world', '0.800500'),
(1243, 899, 'malayana', NULL, NULL, 'world', '0.883333'),
(1244, 899, 'MALAYANA', NULL, NULL, 'world', '0.883333'),
(1245, 232, 'grandis', NULL, NULL, 'world', '0.630000'),
(1246, 232, 'hostmannii', NULL, NULL, 'world', '0.575000'),
(1247, 232, 'juruensis', NULL, NULL, 'world', '0.633333'),
(1248, 232, 'laevis', NULL, NULL, 'world', '0.615000'),
(1249, 232, 'paraensis', NULL, NULL, 'world', '0.650000'),
(1250, 232, 'ulei', NULL, NULL, 'world', '0.618500'),
(1251, 720, 'lanceolata', NULL, NULL, 'world', '0.930000'),
(1252, 902, 'chinensis', NULL, NULL, 'world', '0.624500'),
(1253, 902, 'icosandra', NULL, NULL, 'world', '0.696500'),
(1254, 902, 'ICOSANDRA', NULL, NULL, 'world', '0.696500'),
(1255, 902, 'reticulata', NULL, NULL, 'world', '0.626500'),
(1256, 902, 'RETICULATA', NULL, NULL, 'world', '0.626500'),
(1257, 234, 'blumei', NULL, NULL, 'world', '0.720000'),
(1258, 234, 'ferrea', NULL, NULL, 'world', '0.650000'),
(1259, 234, 'grandifolia', NULL, NULL, 'world', '0.690000'),
(1260, 235, 'copaia', NULL, NULL, 'world', '0.350667'),
(1261, 235, 'obtusifolia', NULL, NULL, 'world', '0.482750'),
(1262, 235, 'puberula', NULL, NULL, 'world', '0.580000'),
(1263, 236, 'digitata', NULL, NULL, 'world', '0.265000'),
(1264, 8740, 'cinerea', NULL, NULL, 'world', '0.360000'),
(1265, 8740, 'nigra', NULL, NULL, 'world', '0.510000'),
(1266, 905, 'seretii', NULL, NULL, 'world', '0.689000'),
(1267, 8750, 'communis', NULL, NULL, 'world', '0.517000'),
(1268, 8750, 'virginiana', NULL, NULL, 'world', '0.440000'),
(1269, 8785, 'latifolia', NULL, NULL, 'world', '0.620000'),
(1270, 907, 'racemosa', NULL, NULL, 'world', '0.630000'),
(1271, 910, 'coriacea', NULL, NULL, 'world', '0.530000'),
(1272, 910, 'CORIACEA', NULL, NULL, 'world', '0.530000'),
(1273, 911, 'maingayi', NULL, NULL, 'world', '0.500000'),
(1274, 911, 'MAINGAYI', NULL, NULL, 'world', '0.500000'),
(1275, 240, 'africana', NULL, NULL, 'world', '0.564000'),
(1276, 914, 'gabonensis', NULL, NULL, 'world', '0.925583'),
(1277, 8911, 'hospita', NULL, NULL, 'world', '0.428667'),
(1278, 915, 'conferta', NULL, NULL, 'world', '0.527000'),
(1279, 915, 'CONFERTA', NULL, NULL, 'world', '0.527000'),
(1280, 915, 'furfuracea', NULL, NULL, 'world', '0.550000'),
(1281, 915, 'FURFURACEA', NULL, NULL, 'world', '0.550000'),
(1282, 915, 'glauca', NULL, NULL, 'world', '0.440000'),
(1283, 915, 'glomerata', NULL, NULL, 'world', '0.520000'),
(1284, 915, 'hookeriana', NULL, NULL, 'world', '0.550000'),
(1285, 915, 'HOOKERIANA', NULL, NULL, 'world', '0.550000'),
(1286, 915, 'latifolia', NULL, NULL, 'world', '0.500000'),
(1287, 915, 'laurina', NULL, NULL, 'world', '0.470000'),
(1288, 915, 'LAURINA', NULL, NULL, 'world', '0.470000'),
(1289, 721, 'littoralis', NULL, NULL, 'world', '0.790000'),
(1290, 721, 'reflexa', NULL, NULL, 'world', '0.790000'),
(1291, 721, 'REFLEXA', NULL, NULL, 'world', '0.790000'),
(1292, 917, 'excelsa', NULL, NULL, 'world', '0.685000'),
(1293, 917, 'malaccensis', NULL, NULL, 'world', '0.760000'),
(1294, 917, 'MALACCENSIS', NULL, NULL, 'world', '0.760000'),
(1295, 921, 'calycina', NULL, NULL, 'world', '0.258000'),
(1296, 243, 'aggregatum', NULL, NULL, 'world', '0.505500'),
(1297, 243, 'grandifolium', NULL, NULL, 'world', '0.517000'),
(1298, 244, 'lactescens', NULL, NULL, 'world', '0.600000'),
(1299, 244, 'panamensis', NULL, NULL, 'world', '0.471500'),
(1300, 923, 'crenata', NULL, NULL, 'world', '0.806500'),
(1301, 246, 'procera', NULL, NULL, 'world', '0.647255'),
(1302, 246, 'thamnia', NULL, NULL, 'world', '0.660000'),
(1303, 247, 'punicifolia', NULL, NULL, 'world', '0.705000'),
(1304, 248, 'calyculata', NULL, NULL, 'world', '0.720000'),
(1305, 248, 'floribunda', NULL, NULL, 'world', '0.610000'),
(1306, 248, 'macrocarpa', NULL, NULL, 'world', '0.647000'),
(1307, 248, 'microcarpa', NULL, NULL, 'world', '0.500000'),
(1308, 248, 'parviflora', NULL, NULL, 'world', '0.658000'),
(1309, 248, 'subcostata', NULL, NULL, 'world', '0.550000'),
(1310, 248, 'tomentosa', NULL, NULL, 'world', '0.543000'),
(1311, 248, 'villosa', NULL, NULL, 'world', '0.689000'),
(1312, 924, 'coromandelica', NULL, NULL, 'world', '0.397333'),
(1313, 924, 'welwitschii', NULL, NULL, 'world', '0.405333'),
(1314, 925, 'domesticum', NULL, NULL, 'world', '0.705000'),
(1315, 925, 'DOMESTICUM', NULL, NULL, 'world', '0.705000'),
(1316, 9143, 'laricina', NULL, NULL, 'world', '0.490000'),
(1317, 253, 'amazonica', NULL, NULL, 'world', '0.893333'),
(1318, 929, 'klaineana', NULL, NULL, 'world', '0.823091'),
(1319, 254, 'ampla', NULL, NULL, 'world', '0.750000'),
(1320, 254, 'gracieana', NULL, NULL, 'world', '0.826000'),
(1321, 254, 'prancei', NULL, NULL, 'world', '0.875000'),
(1322, 254, 'zabucajo', NULL, NULL, 'world', '0.849667'),
(1323, 723, 'indica', NULL, NULL, 'world', '0.460000'),
(1324, 256, 'crassa', NULL, NULL, 'world', '0.650000'),
(1325, 256, 'cymosa', NULL, NULL, 'world', '0.650000'),
(1326, 256, 'glycycarpa', NULL, NULL, 'world', '0.600000'),
(1327, 9358, 'sylvestris', NULL, NULL, 'world', '0.260000'),
(1328, 931, 'rubiginosa', NULL, NULL, 'world', '0.630000'),
(1329, 931, 'senegalensis', NULL, NULL, 'world', '0.630000'),
(1330, 931, 'SENEGALENSIS', NULL, NULL, 'world', '0.630000'),
(1331, 931, 'tetraphylla', NULL, NULL, 'world', '0.810000'),
(1332, 931, 'TETRAPHYLLA', NULL, NULL, 'world', '0.810000'),
(1333, 9517, 'klainei', NULL, NULL, 'world', '0.938200'),
(1334, 257, 'apetala', NULL, NULL, 'world', '0.763400'),
(1335, 257, 'arborea', NULL, NULL, 'world', '0.627500'),
(1336, 257, 'canescens', NULL, NULL, 'world', '0.880000'),
(1337, 257, 'coriacea', NULL, NULL, 'world', '0.880000'),
(1338, 257, 'heteromorpha', NULL, NULL, 'world', '0.816400'),
(1339, 257, 'hypoleuca', NULL, NULL, 'world', '0.908800'),
(1340, 257, 'kunthiana', NULL, NULL, 'world', '0.880000'),
(1341, 257, 'laxiflora', NULL, NULL, 'world', '1.033000'),
(1342, 257, 'macrophylla', NULL, NULL, 'world', '0.752500'),
(1343, 257, 'membranacea', NULL, NULL, 'world', '0.880000'),
(1344, 257, 'micrantha', NULL, NULL, 'world', '0.836000'),
(1345, 257, 'octandra', NULL, NULL, 'world', '0.825000'),
(1346, 257, 'pallida', NULL, NULL, 'world', '0.880000'),
(1347, 257, 'platypus', NULL, NULL, 'world', '0.620000'),
(1348, 257, 'rodriguesii', NULL, NULL, 'world', '0.844000'),
(1349, 257, 'sandwithii', NULL, NULL, 'world', '0.882000'),
(1350, 257, 'splendens', NULL, NULL, 'world', '0.815000'),
(1351, 257, 'SPLENDENS', NULL, NULL, 'world', '0.815000'),
(1352, 257, 'unguiculata', NULL, NULL, 'world', '0.880000'),
(1353, 257, 'urceolaris', NULL, NULL, 'world', '0.880000'),
(1354, 258, 'cannella', NULL, NULL, 'world', '0.938500'),
(1355, 258, 'guianensis', NULL, NULL, 'world', '0.747500'),
(1356, 259, 'paludosa', NULL, NULL, 'world', '0.560000'),
(1357, 18990, 'formosana', NULL, NULL, 'world', '0.488833'),
(1358, 18990, 'styraciflua', NULL, NULL, 'world', '0.460000'),
(1359, 9591, 'tulipifera', NULL, NULL, 'world', '0.350000'),
(1360, 725, 'chinensis', NULL, NULL, 'world', '0.854143'),
(1361, 938, 'amygdalifolius', NULL, NULL, 'world', '0.758000'),
(1362, 938, 'corneus', NULL, NULL, 'world', '0.818000'),
(1363, 938, 'dealbatus', NULL, NULL, 'world', '0.742500'),
(1364, 938, 'densiflorus', NULL, NULL, 'world', '0.580000'),
(1365, 938, 'elegans', NULL, NULL, 'world', '0.799000'),
(1366, 938, 'glaber', NULL, NULL, 'world', '0.550750'),
(1367, 938, 'gracilis', NULL, NULL, 'world', '0.490000'),
(1368, 938, 'rassa', NULL, NULL, 'world', '0.815000'),
(1369, 938, 'RASSA', NULL, NULL, 'world', '0.815000'),
(1370, 938, 'vestitus', NULL, NULL, 'world', '0.720000'),
(1371, 726, 'accedens', NULL, NULL, 'world', '0.470000'),
(1372, 726, 'albayana', NULL, NULL, 'world', '0.360000'),
(1373, 726, 'angulata', NULL, NULL, 'world', '0.360000'),
(1374, 726, 'baviensis', NULL, NULL, 'world', '0.435250'),
(1375, 726, 'castanea', NULL, NULL, 'world', '0.410000'),
(1376, 726, 'CASTANEA', NULL, NULL, 'world', '0.410000'),
(1377, 726, 'costalis', NULL, NULL, 'world', '0.340000'),
(1378, 726, 'cubeba', NULL, NULL, 'world', '0.310000'),
(1379, 726, 'elliptica', NULL, NULL, 'world', '0.450000'),
(1380, 726, 'ELLIPTICA', NULL, NULL, 'world', '0.450000'),
(1381, 726, 'ferruginea', NULL, NULL, 'world', '0.453333'),
(1382, 726, 'FERRUGINEA', NULL, NULL, 'world', '0.453333'),
(1383, 726, 'firma', NULL, NULL, 'world', '0.407500'),
(1384, 726, 'FIRMA', NULL, NULL, 'world', '0.407500'),
(1385, 726, 'fulva', NULL, NULL, 'world', '0.510000'),
(1386, 726, 'garciae', NULL, NULL, 'world', '0.356000'),
(1387, 726, 'glutinosa', NULL, NULL, 'world', '0.501500'),
(1388, 726, 'grandis', NULL, NULL, 'world', '0.433333'),
(1389, 726, 'GRANDIS', NULL, NULL, 'world', '0.433333'),
(1390, 726, 'lancilimba', NULL, NULL, 'world', '0.531667'),
(1391, 726, 'machilifolia', NULL, NULL, 'world', '0.335000'),
(1392, 726, 'MACHILIFOLIA', NULL, NULL, 'world', '0.335000'),
(1393, 726, 'monopetala', NULL, NULL, 'world', '0.422833'),
(1394, 726, 'myristicaefolia', NULL, NULL, 'world', '0.420000'),
(1395, 726, 'oppositifolia', NULL, NULL, 'world', '0.510000'),
(1396, 726, 'resinosa', NULL, NULL, 'world', '0.335000'),
(1397, 726, 'RESINOSA', NULL, NULL, 'world', '0.335000'),
(1398, 726, 'robusta', NULL, NULL, 'world', '0.370000'),
(1399, 726, 'tomentosa', NULL, NULL, 'world', '0.545000'),
(1400, 726, 'TOMENTOSA', NULL, NULL, 'world', '0.545000'),
(1401, 726, 'umbellata', NULL, NULL, 'world', '0.340000'),
(1402, 260, 'heptaphyllus', NULL, NULL, 'world', '0.686750'),
(1403, 260, 'latifolius', NULL, NULL, 'world', '0.685125'),
(1404, 939, 'alata', NULL, NULL, 'world', '0.896900'),
(1405, 940, 'beccarianum', NULL, NULL, 'world', '0.510000'),
(1406, 940, 'wallichii', NULL, NULL, 'world', '0.427000'),
(1407, 940, 'wightianum', NULL, NULL, 'world', '0.370000'),
(1408, 19027, 'chinense', NULL, NULL, 'world', '0.814000'),
(1409, 262, 'seemannii', NULL, NULL, 'world', '0.417000'),
(1410, 262, 'speciosa', NULL, NULL, 'world', '0.440000'),
(1411, 9746, 'rosea', NULL, NULL, 'world', '0.330000'),
(1412, 263, 'parviflora', NULL, NULL, 'world', '0.635000'),
(1413, 265, 'piriri', NULL, NULL, 'world', '0.597667'),
(1414, 265, 'subsessilis', NULL, NULL, 'world', '0.600000'),
(1415, 728, 'beccariana', NULL, NULL, 'world', '0.290000'),
(1416, 728, 'bicolor', NULL, NULL, 'world', '0.299000'),
(1417, 728, 'brevipetiolata', NULL, NULL, 'world', '0.600000'),
(1418, 728, 'conifera', NULL, NULL, 'world', '0.330000'),
(1419, 728, 'CONIFERA', NULL, NULL, 'world', '0.330000'),
(1420, 728, 'denticulata', NULL, NULL, 'world', '0.433500'),
(1421, 728, 'gigantea', NULL, NULL, 'world', '0.295000'),
(1422, 728, 'GIGANTEA', NULL, NULL, 'world', '0.295000'),
(1423, 728, 'hosei', NULL, NULL, 'world', '0.276667'),
(1424, 728, 'HOSEI', NULL, NULL, 'world', '0.276667'),
(1425, 728, 'hullettii', NULL, NULL, 'world', '0.320000'),
(1426, 728, 'hypoleuca', NULL, NULL, 'world', '0.263333'),
(1427, 728, 'HYPOLEUCA', NULL, NULL, 'world', '0.263333'),
(1428, 728, 'kingii', NULL, NULL, 'world', '0.600000'),
(1429, 728, 'lowii', NULL, NULL, 'world', '0.675000'),
(1430, 728, 'LOWII', NULL, NULL, 'world', '0.675000'),
(1431, 728, 'sampsonii', NULL, NULL, 'world', '0.340000'),
(1432, 728, 'tanarius', NULL, NULL, 'world', '0.456000'),
(1433, 728, 'triloba', NULL, NULL, 'world', '0.320000'),
(1434, 267, 'tinctoria', NULL, NULL, 'world', '0.791562'),
(1435, 945, 'porteri', NULL, NULL, 'world', '0.550000'),
(1436, 269, 'roseum', NULL, NULL, 'world', '0.450000'),
(1437, 270, 'angustifolium', NULL, NULL, 'world', '0.675000'),
(1438, 270, 'limbatum', NULL, NULL, 'world', '0.580000'),
(1439, 729, 'crassipes', NULL, NULL, 'world', '0.930000'),
(1440, 729, 'hainanensis', NULL, NULL, 'world', '0.925667'),
(1441, 729, 'kingiana', NULL, NULL, 'world', '0.600000'),
(1442, 729, 'korthalsii', NULL, NULL, 'world', '0.540000'),
(1443, 729, 'malaccensis', NULL, NULL, 'world', '0.635000'),
(1444, 729, 'MALACCENSIS', NULL, NULL, 'world', '0.635000'),
(1445, 729, 'sessilis', NULL, NULL, 'world', '0.650000'),
(1446, 729, 'utilis', NULL, NULL, 'world', '0.960000'),
(1447, 948, 'eminii', NULL, NULL, 'world', '0.383500'),
(1448, 950, 'elegans', NULL, NULL, 'world', '0.483333'),
(1449, 950, 'gigantifolia', NULL, NULL, 'world', '0.560000'),
(1450, 950, 'splendens', NULL, NULL, 'world', '0.585000'),
(1451, 731, 'floribundus', NULL, NULL, 'world', '0.620000'),
(1452, 731, 'macrostachyus', NULL, NULL, 'world', '0.320000'),
(1453, 731, 'mollissimus', NULL, NULL, 'world', '0.412000'),
(1454, 731, 'paniculatus', NULL, NULL, 'world', '0.345000'),
(1455, 731, 'peltatus', NULL, NULL, 'world', '0.470000'),
(1456, 731, 'penangensis', NULL, NULL, 'world', '0.590000'),
(1457, 731, 'PENANGENSIS', NULL, NULL, 'world', '0.590000'),
(1458, 731, 'philippensis', NULL, NULL, 'world', '0.603333'),
(1459, 731, 'philippinensis', NULL, NULL, 'world', '0.688000'),
(1460, 731, 'subpeltatus', NULL, NULL, 'world', '0.560000'),
(1461, 273, 'furcata', NULL, NULL, 'world', '0.583465'),
(1462, 9978, 'baccata', NULL, NULL, 'world', '0.560000'),
(1463, 274, 'africana', NULL, NULL, 'world', '0.626625'),
(1464, 275, 'altissima', NULL, NULL, 'world', '0.590000'),
(1465, 275, 'caloneura', NULL, NULL, 'world', '0.482000'),
(1466, 275, 'foetida', NULL, NULL, 'world', '0.525000'),
(1467, 275, 'FOETIDA', NULL, NULL, 'world', '0.525000'),
(1468, 275, 'griffithii', NULL, NULL, 'world', '0.470000'),
(1469, 275, 'GRIFFITHII', NULL, NULL, 'world', '0.470000'),
(1470, 275, 'indica', NULL, NULL, 'world', '0.555828'),
(1471, 275, 'INDICA', NULL, NULL, 'world', '0.555828'),
(1472, 275, 'odorata', NULL, NULL, 'world', '0.470000'),
(1473, 275, 'pajang', NULL, NULL, 'world', '0.490000'),
(1474, 275, 'sylvatica', NULL, NULL, 'world', '0.517000'),
(1475, 10002, 'fordiana', NULL, NULL, 'world', '0.423500'),
(1476, 277, 'bidentata', NULL, NULL, 'world', '0.872014'),
(1477, 277, 'huberi', NULL, NULL, 'world', '0.921364'),
(1478, 277, 'obovata', NULL, NULL, 'world', '0.860875'),
(1479, 277, 'zapota', NULL, NULL, 'world', '0.810000'),
(1480, 278, 'guianensis', NULL, NULL, 'world', '0.588000'),
(1481, 279, 'calophylla', NULL, NULL, 'world', '0.620000'),
(1482, 279, 'guianensis', NULL, NULL, 'world', '0.766000'),
(1483, 279, 'sclerophylla', NULL, NULL, 'world', '0.513500'),
(1484, 280, 'corymbosa', NULL, NULL, 'world', '0.798667'),
(1485, 280, 'glabra', NULL, NULL, 'world', '0.875000'),
(1486, 281, 'discoidea', NULL, NULL, 'world', '0.719500'),
(1487, 281, 'indica', NULL, NULL, 'world', '0.680000'),
(1488, 281, 'nobilis', NULL, NULL, 'world', '0.596360'),
(1489, 955, 'stipulata', NULL, NULL, 'world', '0.675500'),
(1490, 732, 'pentandra', NULL, NULL, 'world', '0.495000'),
(1491, 732, 'PENTANDRA', NULL, NULL, 'world', '0.495000'),
(1492, 732, 'rostrata', NULL, NULL, 'world', '0.440000'),
(1493, 732, 'trichotoma', NULL, NULL, 'world', '0.390000'),
(1494, 732, 'TRICHOTOMA', NULL, NULL, 'world', '0.390000'),
(1495, 283, 'arborescens', NULL, NULL, 'world', '0.696667'),
(1496, 283, 'domingensis', NULL, NULL, 'world', '0.697000'),
(1497, 283, 'guianensis', NULL, NULL, 'world', '0.820000'),
(1498, 284, 'cordata', NULL, NULL, 'world', '0.372750'),
(1499, 286, 'elongata', NULL, NULL, 'world', '0.710898'),
(1500, 286, 'robusta', NULL, NULL, 'world', '0.770000'),
(1501, 962, 'auriculata', NULL, NULL, 'world', '0.580000'),
(1502, 962, 'AURICULATA', NULL, NULL, 'world', '0.580000'),
(1503, 962, 'bracteata', NULL, NULL, 'world', '0.480000'),
(1504, 963, 'multiglandulosa', NULL, NULL, 'world', '0.340000'),
(1505, 733, 'malabathricum', NULL, NULL, 'world', '0.440000'),
(1506, 733, 'MALABATHRICUM', NULL, NULL, 'world', '0.440000'),
(1507, 964, 'azedarach', NULL, NULL, 'world', '0.437778'),
(1508, 965, 'confusa', NULL, NULL, 'world', '0.380000'),
(1509, 965, 'glabra', NULL, NULL, 'world', '0.330000'),
(1510, 288, 'herbertii', NULL, NULL, 'world', '0.435000'),
(1511, 288, 'pinnata', NULL, NULL, 'world', '0.320000'),
(1512, 288, 'simplicifolia', NULL, NULL, 'world', '0.455000'),
(1513, 288, 'squamulata', NULL, NULL, 'world', '0.498500'),
(1514, 288, 'sumatrana', NULL, NULL, 'world', '0.400000'),
(1515, 734, 'campanulatum', NULL, NULL, 'world', '0.880000'),
(1516, 734, 'garcinioides', NULL, NULL, 'world', '0.750000'),
(1517, 734, 'lilacinum', NULL, NULL, 'world', '0.820000'),
(1518, 734, 'LILACINUM', NULL, NULL, 'world', '0.820000'),
(1519, 734, 'paniculatum', NULL, NULL, 'world', '0.720000'),
(1520, 734, 'PANICULATUM', NULL, NULL, 'world', '0.720000'),
(1521, 734, 'pubescens', NULL, NULL, 'world', '0.820000'),
(1522, 734, 'PUBESCENS', NULL, NULL, 'world', '0.820000'),
(1523, 735, 'ferrea', NULL, NULL, 'world', '0.920000'),
(1524, 735, 'FERREA', NULL, NULL, 'world', '0.920000'),
(1525, 969, 'trichotoma', NULL, NULL, 'world', '0.720000'),
(1526, 969, 'TRICHOTOMA', NULL, NULL, 'world', '0.720000'),
(1527, 971, 'duckei', NULL, NULL, 'world', '0.674500'),
(1528, 971, 'itauba', NULL, NULL, 'world', '0.744300'),
(1529, 972, 'parviflora', NULL, NULL, 'world', '0.522500'),
(1530, 973, 'baillonii', NULL, NULL, 'world', '0.544667'),
(1531, 973, 'champaca', NULL, NULL, 'world', '0.527500'),
(1532, 973, 'foveolata', NULL, NULL, 'world', '0.515333'),
(1533, 289, 'argentea', NULL, NULL, 'world', '0.589000'),
(1534, 289, 'elata', NULL, NULL, 'world', '0.470000'),
(1535, 289, 'impetiolaris', NULL, NULL, 'world', '0.747025'),
(1536, 289, 'laevigata', NULL, NULL, 'world', '0.481145'),
(1537, 289, 'lepidota', NULL, NULL, 'world', '0.750000'),
(1538, 289, 'longifolia', NULL, NULL, 'world', '0.750000'),
(1539, 289, 'mirabilis', NULL, NULL, 'world', '0.603167'),
(1540, 289, 'poeppigii', NULL, NULL, 'world', '0.596667'),
(1541, 289, 'prasina', NULL, NULL, 'world', '0.688234'),
(1542, 289, 'racemosa', NULL, NULL, 'world', '0.449723'),
(1543, 289, 'reducens', NULL, NULL, 'world', '0.620000'),
(1544, 289, 'tetrandra', NULL, NULL, 'world', '0.703000'),
(1545, 289, 'tomentosa', NULL, NULL, 'world', '0.710000'),
(1546, 289, 'trinervia', NULL, NULL, 'world', '0.620000'),
(1547, 974, 'antidesmifolia', NULL, NULL, 'world', '0.470000'),
(1548, 974, 'cinnamomifolia', NULL, NULL, 'world', '0.490000'),
(1549, 974, 'laurifolia', NULL, NULL, 'world', '0.360000'),
(1550, 974, 'paniculata', NULL, NULL, 'world', '0.619333'),
(1551, 974, 'stylocarpa', NULL, NULL, 'world', '0.412000'),
(1552, 974, 'tomentosa', NULL, NULL, 'world', '0.640000'),
(1553, 976, 'minutum', NULL, NULL, 'world', '0.660000'),
(1554, 976, 'MINUTUM', NULL, NULL, 'world', '0.660000'),
(1555, 290, 'egensis', NULL, NULL, 'world', '0.600000'),
(1556, 290, 'garciniifolia', NULL, NULL, 'world', '0.670000'),
(1557, 290, 'guayanensis', NULL, NULL, 'world', '0.700000'),
(1558, 290, 'guyanensis', NULL, NULL, 'world', '0.657273'),
(1559, 290, 'melinoniana', NULL, NULL, 'world', '0.530000'),
(1560, 290, 'venulosa', NULL, NULL, 'world', '0.670000'),
(1561, 978, 'excelsa', NULL, NULL, 'world', '0.574440'),
(1562, 979, 'horsfieldii', NULL, NULL, 'world', '0.610000'),
(1563, 980, 'atropurpurea', NULL, NULL, 'world', '0.610000'),
(1564, 980, 'ATROPURPUREA', NULL, NULL, 'world', '0.610000'),
(1565, 293, 'guianensis', NULL, NULL, 'world', '0.786714'),
(1566, 982, 'parvifolia', NULL, NULL, 'world', '0.640000'),
(1567, 983, 'maingayi', NULL, NULL, 'world', '0.760000'),
(1568, 983, 'MAINGAYI', NULL, NULL, 'world', '0.760000'),
(1569, 983, 'thorelii', NULL, NULL, 'world', '0.620000'),
(1570, 984, 'gracilis', NULL, NULL, 'world', '0.490000'),
(1571, 985, 'euneura', NULL, NULL, 'world', '0.480000'),
(1572, 296, 'elliptica', NULL, NULL, 'world', '0.560000'),
(1573, 988, 'macroura', NULL, NULL, 'world', '0.550000'),
(1574, 988, 'mesozygia', NULL, NULL, 'world', '0.723556'),
(1575, 990, 'leembruggianus', NULL, NULL, 'world', '0.680000'),
(1576, 301, 'acutiflora', NULL, NULL, 'world', '0.810000'),
(1577, 301, 'grandiflora', NULL, NULL, 'world', '0.900000'),
(1578, 991, 'paniculata', NULL, NULL, 'world', '0.871333'),
(1579, 992, 'cecropioides', NULL, NULL, 'world', '0.242833'),
(1580, 994, 'beccariana', NULL, NULL, 'world', '0.770000'),
(1581, 994, 'BECCARIANA', NULL, NULL, 'world', '0.770000'),
(1582, 303, 'deflexa', NULL, NULL, 'world', '0.800000'),
(1583, 303, 'fallax', NULL, NULL, 'world', '0.885141'),
(1584, 303, 'leptoclada', NULL, NULL, 'world', '0.804132'),
(1585, 303, 'paivae', NULL, NULL, 'world', '0.774000'),
(1586, 304, 'floribunda', NULL, NULL, 'world', '0.785000'),
(1587, 303, 'rostrata', NULL, NULL, 'world', '0.870000'),
(1588, 303, 'splendens', NULL, NULL, 'world', '0.767770'),
(1589, 997, 'rubra', NULL, NULL, 'world', '0.696000'),
(1590, 737, 'cinnamomea', NULL, NULL, 'world', '0.570000'),
(1591, 737, 'CINNAMOMEA', NULL, NULL, 'world', '0.570000'),
(1592, 737, 'crassa', NULL, NULL, 'world', '0.425000'),
(1593, 737, 'elliptica', NULL, NULL, 'world', '0.400000'),
(1594, 737, 'lowiana', NULL, NULL, 'world', '0.440000'),
(1595, 737, 'maxima', NULL, NULL, 'world', '0.410000'),
(1596, 737, 'MAXIMA', NULL, NULL, 'world', '0.410000'),
(1597, 737, 'philippensis', NULL, NULL, 'world', '0.360000'),
(1598, 737, 'villosa', NULL, NULL, 'world', '0.590000'),
(1599, 306, 'frutescens', NULL, NULL, 'world', '0.830000'),
(1600, 307, 'balsamum', NULL, NULL, 'world', '0.776429'),
(1601, 308, 'coriacea', NULL, NULL, 'world', '0.643556'),
(1602, 19261, 'laosensis', NULL, NULL, 'world', '0.492000'),
(1603, 999, 'diderrichii', NULL, NULL, 'world', '0.674087'),
(1604, 999, 'officinalis', NULL, NULL, 'world', '0.646000'),
(1605, 999, 'OFFICINALIS', NULL, NULL, 'world', '0.646000'),
(1606, 999, 'orientalis', NULL, NULL, 'world', '0.483111'),
(1607, 309, 'concinna', NULL, NULL, 'world', '0.670000'),
(1608, 309, 'ulei', NULL, NULL, 'world', '0.670000'),
(1609, 10893, 'yapurensis', NULL, NULL, 'world', '0.613333'),
(1610, 310, 'antillana', NULL, NULL, 'world', '0.425000'),
(1611, 310, 'cissiflora', NULL, NULL, 'world', '0.590000'),
(1612, 310, 'cuspidata', NULL, NULL, 'world', '0.518000'),
(1613, 310, 'globosa', NULL, NULL, 'world', '0.390000'),
(1614, 310, 'grandiflora', NULL, NULL, 'world', '0.610000'),
(1615, 310, 'purpurea', NULL, NULL, 'world', '0.431000'),
(1616, 311, 'madeirana', NULL, NULL, 'world', '0.548000'),
(1617, 311, 'oppositifolia', NULL, NULL, 'world', '0.893000'),
(1618, 1000, 'malayana', NULL, NULL, 'world', '0.460000'),
(1619, 739, 'phanerophlebia', NULL, NULL, 'world', '0.590000'),
(1620, 1005, 'gigantea', NULL, NULL, 'world', '0.590000'),
(1621, 1006, 'forbesii', NULL, NULL, 'world', '0.627000'),
(1622, 1006, 'kingii', NULL, NULL, 'world', '0.585000'),
(1623, 1006, 'KINGII', NULL, NULL, 'world', '0.585000'),
(1624, 1009, 'cumingii', NULL, NULL, 'world', '0.490000'),
(1625, 1012, 'cuspidatum', NULL, NULL, 'world', '0.755000'),
(1626, 1012, 'lappaceum', NULL, NULL, 'world', '0.710200'),
(1627, 1012, 'ramboutan-ake', NULL, NULL, 'world', '0.720000'),
(1628, 1012, 'uncinatum', NULL, NULL, 'world', '0.630000'),
(1629, 1014, 'leucocarpa', NULL, NULL, 'world', '0.603700'),
(1630, 11313, 'sinensis', NULL, NULL, 'world', '0.604000'),
(1631, 11313, 'sylvatica', NULL, NULL, 'world', '0.460000'),
(1632, 1018, 'amentacea', NULL, NULL, 'world', '0.770000'),
(1633, 1018, 'AMENTACEA', NULL, NULL, 'world', '0.770000'),
(1634, 312, 'pyramidale', NULL, NULL, 'world', '0.158128'),
(1635, 313, 'aciphylla', NULL, NULL, 'world', '0.510500'),
(1636, 313, 'amazonica', NULL, NULL, 'world', '0.443000'),
(1637, 313, 'atirrensis', NULL, NULL, 'world', '0.480000'),
(1638, 313, 'cernua', NULL, NULL, 'world', '0.453500'),
(1639, 313, 'dendrodaphne', NULL, NULL, 'world', '0.530000'),
(1640, 313, 'floribunda', NULL, NULL, 'world', '0.401425'),
(1641, 313, 'glomerata', NULL, NULL, 'world', '0.508000'),
(1642, 313, 'leucoxylon', NULL, NULL, 'world', '0.461750'),
(1643, 313, 'moschata', NULL, NULL, 'world', '0.595333'),
(1644, 313, 'oblonga', NULL, NULL, 'world', '0.385500'),
(1645, 313, 'percurrens', NULL, NULL, 'world', '0.519000'),
(1646, 313, 'portoricensis', NULL, NULL, 'world', '0.590000'),
(1647, 313, 'puberula', NULL, NULL, 'world', '0.432500'),
(1648, 313, 'pulchella', NULL, NULL, 'world', '0.650000'),
(1649, 313, 'rhynchophylla', NULL, NULL, 'world', '0.431000'),
(1650, 313, 'sintensis', NULL, NULL, 'world', '0.580669'),
(1651, 313, 'spathulata', NULL, NULL, 'world', '0.620759'),
(1652, 313, 'splendens', NULL, NULL, 'world', '0.450000'),
(1653, 313, 'veraguensis', NULL, NULL, 'world', '0.735000'),
(1654, 11383, 'gabonensis', NULL, NULL, 'world', '0.325667'),
(1655, 314, 'bacaba', NULL, NULL, 'world', '0.650000'),
(1656, 314, 'mapora', NULL, NULL, 'world', '0.713000'),
(1657, 1024, 'brachiata', NULL, NULL, 'world', '0.630000'),
(1658, 1026, 'elatum', NULL, NULL, 'world', '0.550000'),
(1659, 11489, 'amazonicum', NULL, NULL, 'world', '0.623500'),
(1660, 317, 'arborea', NULL, NULL, 'world', '0.700000'),
(1661, 317, 'bancana', NULL, NULL, 'world', '0.560000'),
(1662, 317, 'calavensis', NULL, NULL, 'world', '0.430000'),
(1663, 317, 'coccinea', NULL, NULL, 'world', '0.625000'),
(1664, 317, 'krugii', NULL, NULL, 'world', '0.491429'),
(1665, 317, 'paraensis', NULL, NULL, 'world', '0.663500'),
(1666, 317, 'sumatrana', NULL, NULL, 'world', '0.593333'),
(1667, 1038, 'indicum', NULL, NULL, 'world', '0.411000'),
(1668, 742, 'philippina', NULL, NULL, 'world', '0.520000'),
(1669, 319, 'platyspermum', NULL, NULL, 'world', '0.465857'),
(1670, 11676, 'virginiana', NULL, NULL, 'world', '0.630000'),
(1671, 320, 'lehmannii', NULL, NULL, 'world', '0.390000'),
(1672, 320, 'novogranatensis', NULL, NULL, 'world', '0.350000'),
(1673, 320, 'parvifolia', NULL, NULL, 'world', '0.425833'),
(1674, 321, 'coccinea', NULL, NULL, 'world', '0.770000'),
(1675, 321, 'discophora', NULL, NULL, 'world', '0.791000'),
(1676, 322, 'laurifolia', NULL, NULL, 'world', '0.588845'),
(1677, 322, 'riedeliana', NULL, NULL, 'world', '0.770000'),
(1678, 322, 'xylopioides', NULL, NULL, 'world', '0.770000'),
(1679, 1043, 'speciosus', NULL, NULL, 'world', '0.525000'),
(1680, 323, 'aquatica', NULL, NULL, 'world', '0.376667'),
(1681, 323, 'insignis', NULL, NULL, 'world', '0.384000'),
(1682, 323, 'minor', NULL, NULL, 'world', '0.560000'),
(1683, 323, 'quinata', NULL, NULL, 'world', '0.415000'),
(1684, 323, 'sessilis', NULL, NULL, 'world', '0.420000'),
(1685, 11835, 'longifolia', NULL, NULL, 'world', '0.280000'),
(1686, 743, 'bataanense', NULL, NULL, 'world', '0.520000'),
(1687, 743, 'beccarianum', NULL, NULL, 'world', '0.490000'),
(1688, 743, 'calophyllum', NULL, NULL, 'world', '0.510000'),
(1689, 743, 'dasyphyllum', NULL, NULL, 'world', '0.505000'),
(1690, 743, 'gutta', NULL, NULL, 'world', '0.615000'),
(1691, 743, 'GUTTA', NULL, NULL, 'world', '0.615000'),
(1692, 743, 'hexandrum', NULL, NULL, 'world', '0.526667'),
(1693, 743, 'HEXANDRUM', NULL, NULL, 'world', '0.526667'),
(1694, 743, 'leiocarpum', NULL, NULL, 'world', '0.710000'),
(1695, 743, 'maingayi', NULL, NULL, 'world', '0.600000'),
(1696, 743, 'MAINGAYI', NULL, NULL, 'world', '0.600000'),
(1697, 743, 'microphyllum', NULL, NULL, 'world', '0.615000'),
(1698, 743, 'obovatum', NULL, NULL, 'world', '0.550000'),
(1699, 743, 'OBOVATUM', NULL, NULL, 'world', '0.550000'),
(1700, 743, 'rostratum', NULL, NULL, 'world', '0.520000'),
(1701, 743, 'sumatranum', NULL, NULL, 'world', '0.520000'),
(1702, 324, 'guianensis', NULL, NULL, 'world', '0.540000'),
(1703, 324, 'riparia', NULL, NULL, 'world', '0.466680'),
(1704, 1047, 'oleosa', NULL, NULL, 'world', '0.565000'),
(1705, 1052, 'bracteata', NULL, NULL, 'world', '0.340000'),
(1706, 12021, 'falcataria', NULL, NULL, 'world', '0.295500'),
(1707, 1053, 'parvifolia', NULL, NULL, 'world', '0.610000'),
(1708, 1053, 'smythiesii', NULL, NULL, 'world', '0.600000'),
(1709, 1053, 'stellata', NULL, NULL, 'world', '0.630000'),
(1710, 1054, 'urophyllus', NULL, NULL, 'world', '0.870000'),
(1711, 1054, 'UROPHYLLUS', NULL, NULL, 'world', '0.870000'),
(1712, 327, 'excelsa', NULL, NULL, 'world', '0.701937'),
(1713, 327, 'montana', NULL, NULL, 'world', '0.710000'),
(1714, 327, 'oblongifolia', NULL, NULL, 'world', '0.625000'),
(1715, 327, 'OBLONGIFOLIA', NULL, NULL, 'world', '0.625000'),
(1716, 1055, 'insignis', NULL, NULL, 'world', '0.556667'),
(1717, 1055, 'INSIGNIS', NULL, NULL, 'world', '0.556667'),
(1718, 1055, 'maingayi', NULL, NULL, 'world', '0.506667'),
(1719, 1055, 'paucijuga', NULL, NULL, 'world', '0.550000'),
(1720, 1055, 'PAUCIJUGA', NULL, NULL, 'world', '0.550000'),
(1721, 1055, 'sericea', NULL, NULL, 'world', '0.550000'),
(1722, 328, 'bicolor', NULL, NULL, 'world', '0.463500'),
(1723, 328, 'decussata', NULL, NULL, 'world', '0.775000'),
(1724, 328, 'filicoidea', NULL, NULL, 'world', '0.457500'),
(1725, 328, 'igneiflora', NULL, NULL, 'world', '0.470000'),
(1726, 328, 'multijuga', NULL, NULL, 'world', '0.399000'),
(1727, 328, 'nitida', NULL, NULL, 'world', '0.383000'),
(1728, 328, 'singularis', NULL, NULL, 'world', '0.520000'),
(1729, 328, 'speciosa', NULL, NULL, 'world', '0.395000'),
(1730, 328, 'SPECIOSA', NULL, NULL, 'world', '0.395000'),
(1731, 328, 'timoriana', NULL, NULL, 'world', '0.340000'),
(1732, 328, 'velutina', NULL, NULL, 'world', '0.435000'),
(1733, 1062, 'trianae', NULL, NULL, 'world', '0.590000'),
(1734, 1063, 'macroceras', NULL, NULL, 'world', '0.588000'),
(1735, 1064, 'lanceolata', NULL, NULL, 'world', '0.670000'),
(1736, 1064, 'lucida', NULL, NULL, 'world', '0.632500'),
(1737, 1064, 'LUCIDA', NULL, NULL, 'world', '0.632500'),
(1738, 1064, 'maingayi', NULL, NULL, 'world', '0.625000'),
(1739, 1064, 'MAINGAYI', NULL, NULL, 'world', '0.625000'),
(1740, 1064, 'microphylla', NULL, NULL, 'world', '0.770000'),
(1741, 1064, 'obscura', NULL, NULL, 'world', '0.765000'),
(1742, 1066, 'axillaris', NULL, NULL, 'world', '0.380000'),
(1743, 1066, 'saccardianus', NULL, NULL, 'world', '0.465000'),
(1744, 12176, 'paniculata', NULL, NULL, 'world', '0.796143'),
(1745, 12176, 'venosa', NULL, NULL, 'world', '0.765000'),
(1746, 1068, 'triptera', NULL, NULL, 'world', '0.520000'),
(1747, 1068, 'TRIPTERA', NULL, NULL, 'world', '0.520000'),
(1748, 1069, 'macrophylla', NULL, NULL, 'world', '0.841000'),
(1749, 1070, 'butyracea', NULL, NULL, 'world', '0.805667'),
(1750, 19565, 'euryoides', NULL, NULL, 'world', '0.534000'),
(1751, 1072, 'motleyi', NULL, NULL, 'world', '0.500000'),
(1752, 1072, 'MOTLEYI', NULL, NULL, 'world', '0.500000'),
(1753, 1072, 'velutinus', NULL, NULL, 'world', '0.585000'),
(1754, 1072, 'VELUTINUS', NULL, NULL, 'world', '0.585000'),
(1755, 335, 'arborea', NULL, NULL, 'world', '0.730000'),
(1756, 335, 'bicolor', NULL, NULL, 'world', '0.627000'),
(1757, 335, 'glabrata', NULL, NULL, 'world', '0.670000'),
(1758, 336, 'angustifolia', NULL, NULL, 'world', '0.517000'),
(1759, 336, 'guianensis', NULL, NULL, 'world', '0.560000'),
(1760, 336, 'mollis', NULL, NULL, 'world', '0.365000'),
(1761, 336, 'xanthochyma', NULL, NULL, 'world', '0.560000'),
(1762, 338, 'declinata', NULL, NULL, 'world', '0.590000'),
(1763, 338, 'macrantha', NULL, NULL, 'world', '0.440000'),
(1764, 338, 'pyrifolia', NULL, NULL, 'world', '0.680000'),
(1765, 1074, 'eurhyncha', NULL, NULL, 'world', '0.680000'),
(1766, 1074, 'EURHYNCHA', NULL, NULL, 'world', '0.680000'),
(1767, 1075, 'macrocarpus', NULL, NULL, 'world', '0.676500'),
(1768, 12465, 'amurense', NULL, NULL, 'world', '0.387000');
INSERT INTO `speciesWood` (`wsgSpID`, `GenusID`, `species`, `subspecies`, `infra`, `locale`, `wsg`) VALUES
(1769, 339, 'grandis', NULL, NULL, 'world', '0.493333'),
(1770, 339, 'lanceolata', NULL, NULL, 'world', '0.689000'),
(1771, 339, 'macrophylla', NULL, NULL, 'world', '0.460000'),
(1772, 339, 'paniculata', NULL, NULL, 'world', '0.661000'),
(1773, 339, 'sterculioides', NULL, NULL, 'world', '0.410000'),
(1774, 340, 'serrulata', NULL, NULL, 'world', '0.793000'),
(1775, 341, 'emblica', NULL, NULL, 'world', '0.636000'),
(1776, 341, 'EMBLICA', NULL, NULL, 'world', '0.636000'),
(1777, 1080, 'africanus', NULL, NULL, 'world', '0.780000'),
(1778, 12640, 'glauca', NULL, NULL, 'world', '0.330000'),
(1779, 12640, 'rubens', NULL, NULL, 'world', '0.370000'),
(1780, 1081, 'nitida', NULL, NULL, 'world', '0.775000'),
(1781, 1082, 'javanica', NULL, NULL, 'world', '0.450000'),
(1782, 12708, 'banksiana', NULL, NULL, 'world', '0.400000'),
(1783, 12708, 'koraiensis', NULL, NULL, 'world', '0.379000'),
(1784, 12708, 'lambertiana', NULL, NULL, 'world', '0.340000'),
(1785, 12708, 'massoniana', NULL, NULL, 'world', '0.484857'),
(1786, 12708, 'monticola', NULL, NULL, 'world', '0.350000'),
(1787, 12708, 'ponderosa', NULL, NULL, 'world', '0.380000'),
(1788, 12708, 'resinosa', NULL, NULL, 'world', '0.410000'),
(1789, 12708, 'strobus', NULL, NULL, 'world', '0.340000'),
(1790, 343, 'aduncum', NULL, NULL, 'world', '0.400000'),
(1791, 343, 'amalago', NULL, NULL, 'world', '0.401667'),
(1792, 343, 'blattarum', NULL, NULL, 'world', '0.455534'),
(1793, 343, 'glabrescens', NULL, NULL, 'world', '0.288269'),
(1794, 343, 'hispidum', NULL, NULL, 'world', '0.392696'),
(1795, 343, 'jacquemontianum', NULL, NULL, 'world', '0.390000'),
(1796, 343, 'reticulatum', NULL, NULL, 'world', '0.330000'),
(1797, 343, 'umbellatum', NULL, NULL, 'world', '0.308309'),
(1798, 1087, 'africanum', NULL, NULL, 'world', '0.605087'),
(1799, 12720, 'discolor', NULL, NULL, 'world', '0.470000'),
(1800, 1090, 'subcordata', NULL, NULL, 'world', '0.510630'),
(1801, 1090, 'umbellifera', NULL, NULL, 'world', '0.280667'),
(1802, 19663, 'pentandrum', NULL, NULL, 'world', '0.536000'),
(1803, 12793, 'africana', NULL, NULL, 'world', '0.741333'),
(1804, 1093, 'valida', NULL, NULL, 'world', '0.640000'),
(1805, 1094, 'latifolia', NULL, NULL, 'world', '0.340000'),
(1806, 1094, 'LATIFOLIA', NULL, NULL, 'world', '0.340000'),
(1807, 12816, 'strobilacea', NULL, NULL, 'world', '0.599000'),
(1808, 346, 'pinnatum', NULL, NULL, 'world', '0.721250'),
(1809, 12833, 'macrocarpa', NULL, NULL, 'world', '0.610000'),
(1810, 347, 'elegans', NULL, NULL, 'world', '0.805750'),
(1811, 348, 'lindenii', NULL, NULL, 'world', '0.680000'),
(1812, 1096, 'alternifolium', NULL, NULL, 'world', '0.840000'),
(1813, 352, 'neriifolius', NULL, NULL, 'world', '0.476875'),
(1814, 352, 'oleifolius', NULL, NULL, 'world', '0.453333'),
(1815, 352, 'wallichianus', NULL, NULL, 'world', '0.460000'),
(1816, 1098, 'oleosa', NULL, NULL, 'world', '0.393000'),
(1817, 1099, 'beccarii', NULL, NULL, 'world', '0.650000'),
(1818, 1099, 'cerasoides', NULL, NULL, 'world', '0.755000'),
(1819, 1099, 'glauca', NULL, NULL, 'world', '0.450000'),
(1820, 1099, 'GLAUCA', NULL, NULL, 'world', '0.450000'),
(1821, 1099, 'hypoleuca', NULL, NULL, 'world', '0.593333'),
(1822, 1099, 'HYPOLEUCA', NULL, NULL, 'world', '0.593333'),
(1823, 1099, 'insignis', NULL, NULL, 'world', '0.430000'),
(1824, 1099, 'lateriflora', NULL, NULL, 'world', '0.500000'),
(1825, 1099, 'LATERIFLORA', NULL, NULL, 'world', '0.500000'),
(1826, 1099, 'macropoda', NULL, NULL, 'world', '0.470000'),
(1827, 1099, 'rumphii', NULL, NULL, 'world', '0.580000'),
(1828, 1099, 'RUMPHII', NULL, NULL, 'world', '0.580000'),
(1829, 1099, 'simiarum', NULL, NULL, 'world', '0.594000'),
(1830, 1099, 'suberosa', NULL, NULL, 'world', '0.680000'),
(1831, 1099, 'sumatrana', NULL, NULL, 'world', '0.520000'),
(1832, 1099, 'SUMATRANA', NULL, NULL, 'world', '0.520000'),
(1833, 1101, 'integrifolia', NULL, NULL, 'world', '0.530000'),
(1834, 746, 'pinnata', NULL, NULL, 'world', '0.633000'),
(1835, 746, 'ridleyi', NULL, NULL, 'world', '0.720000'),
(1836, 746, 'tomentosa', NULL, NULL, 'world', '0.596750'),
(1837, 13120, 'davidiana', NULL, NULL, 'world', '0.400000'),
(1838, 13120, 'grandidentata', NULL, NULL, 'world', '0.360000'),
(1839, 13120, 'koreana', NULL, NULL, 'world', '0.330000'),
(1840, 13120, 'tremula', NULL, NULL, 'world', '0.373500'),
(1841, 13120, 'tremuloides', NULL, NULL, 'world', '0.350000'),
(1842, 13120, 'ussuriensis', NULL, NULL, 'world', '0.340000'),
(1843, 13124, 'guianensis', NULL, NULL, 'world', '0.742333'),
(1844, 13124, 'sericea', NULL, NULL, 'world', '0.783333'),
(1845, 1104, 'anisophylla', NULL, NULL, 'world', '0.550000'),
(1846, 1104, 'ANISOPHYLLA', NULL, NULL, 'world', '0.550000'),
(1847, 355, 'latifolia', NULL, NULL, 'world', '0.569667'),
(1848, 355, 'longiflora', NULL, NULL, 'world', '0.455000'),
(1849, 357, 'armata', NULL, NULL, 'world', '0.350429'),
(1850, 358, 'bicolor', NULL, NULL, 'world', '0.353167'),
(1851, 358, 'cecropiifolia', NULL, NULL, 'world', '0.355667'),
(1852, 358, 'guianensis', NULL, NULL, 'world', '0.380000'),
(1853, 358, 'melinonii', NULL, NULL, 'world', '0.320000'),
(1854, 358, 'minor', NULL, NULL, 'world', '0.436000'),
(1855, 358, 'tomentosa', NULL, NULL, 'world', '0.395000'),
(1856, 359, 'altissima', NULL, NULL, 'world', '0.441750'),
(1857, 359, 'ambelaniifolia', NULL, NULL, 'world', '0.697000'),
(1858, 359, 'anomala', NULL, NULL, 'world', '0.693833'),
(1859, 359, 'bilocularis', NULL, NULL, 'world', '0.708000'),
(1860, 359, 'buenaventurensis', NULL, NULL, 'world', '0.560000'),
(1861, 359, 'caimito', NULL, NULL, 'world', '0.805000'),
(1862, 359, 'campechiana', NULL, NULL, 'world', '0.790000'),
(1863, 359, 'cladantha', NULL, NULL, 'world', '0.942333'),
(1864, 359, 'coriacea', NULL, NULL, 'world', '0.895000'),
(1865, 359, 'cuspidata', NULL, NULL, 'world', '0.900000'),
(1866, 359, 'durlandii', NULL, NULL, 'world', '0.690000'),
(1867, 359, 'engleri', NULL, NULL, 'world', '0.774333'),
(1868, 359, 'eugeniifolia', NULL, NULL, 'world', '1.112500'),
(1869, 359, 'filipes', NULL, NULL, 'world', '0.964000'),
(1870, 359, 'glomerata', NULL, NULL, 'world', '0.679000'),
(1871, 359, 'guianensis', NULL, NULL, 'world', '0.929500'),
(1872, 359, 'hispida', NULL, NULL, 'world', '0.874000'),
(1873, 359, 'linggensis', NULL, NULL, 'world', '0.860000'),
(1874, 359, 'macrophylla', NULL, NULL, 'world', '0.737000'),
(1875, 359, 'maingayi', NULL, NULL, 'world', '0.635000'),
(1876, 359, 'malaccensis', NULL, NULL, 'world', '0.660000'),
(1877, 359, 'MALACCENSIS', NULL, NULL, 'world', '0.660000'),
(1878, 359, 'minima', NULL, NULL, 'world', '0.756000'),
(1879, 359, 'multiflora', NULL, NULL, 'world', '0.770000'),
(1880, 359, 'oblanceolata', NULL, NULL, 'world', '0.790000'),
(1881, 359, 'reticulata', NULL, NULL, 'world', '0.794000'),
(1882, 359, 'torta', NULL, NULL, 'world', '0.768500'),
(1883, 359, 'trilocularis', NULL, NULL, 'world', '0.672000'),
(1884, 359, 'venosa', NULL, NULL, 'world', '0.920000'),
(1885, 359, 'vernicosa', NULL, NULL, 'world', '0.737000'),
(1886, 1109, 'pyramidata', NULL, NULL, 'world', '0.634000'),
(1887, 1109, 'serratifolia', NULL, NULL, 'world', '0.550000'),
(1888, 1109, 'tomentosa', NULL, NULL, 'world', '0.570000'),
(1889, 360, 'decurrens', NULL, NULL, 'world', '0.250000'),
(1890, 361, 'copaifera', NULL, NULL, 'world', '0.413571'),
(1891, 362, 'crucis', NULL, NULL, 'world', '0.580000'),
(1892, 364, 'altsonii', NULL, NULL, 'world', '0.684000'),
(1893, 364, 'amazonicum', NULL, NULL, 'world', '0.599000'),
(1894, 364, 'aracouchini', NULL, NULL, 'world', '0.490000'),
(1895, 364, 'crassipetalum', NULL, NULL, 'world', '0.650000'),
(1896, 364, 'decandrum', NULL, NULL, 'world', '0.512000'),
(1897, 364, 'grandifolium', NULL, NULL, 'world', '0.638000'),
(1898, 364, 'guianense', NULL, NULL, 'world', '0.711000'),
(1899, 364, 'heptaphyllum', NULL, NULL, 'world', '0.629300'),
(1900, 364, 'nodulosum', NULL, NULL, 'world', '0.490000'),
(1901, 364, 'opacum', NULL, NULL, 'world', '0.570000'),
(1902, 364, 'panamense', NULL, NULL, 'world', '0.452333'),
(1903, 364, 'paniculatum', NULL, NULL, 'world', '0.490000'),
(1904, 364, 'sagotianum', NULL, NULL, 'world', '0.557500'),
(1905, 364, 'subserratum', NULL, NULL, 'world', '0.550000'),
(1906, 364, 'tenuifolium', NULL, NULL, 'world', '0.569750'),
(1907, 364, 'trifoliolatum', NULL, NULL, 'world', '0.685000'),
(1908, 364, 'unifoliolatum', NULL, NULL, 'world', '0.330000'),
(1909, 1110, 'stapfiana', NULL, NULL, 'world', '0.602000'),
(1910, 748, 'arborea', NULL, NULL, 'world', '0.456000'),
(1911, 748, 'ARBOREA', NULL, NULL, 'world', '0.456000'),
(1912, 748, 'avium', NULL, NULL, 'world', '0.474000'),
(1913, 748, 'grisea', NULL, NULL, 'world', '0.550000'),
(1914, 748, 'GRISEA', NULL, NULL, 'world', '0.550000'),
(1915, 748, 'javanica', NULL, NULL, 'world', '0.670000'),
(1916, 748, 'padus', NULL, NULL, 'world', '0.465000'),
(1917, 748, 'pensylvanica', NULL, NULL, 'world', '0.360000'),
(1918, 748, 'polystachya', NULL, NULL, 'world', '0.500000'),
(1919, 748, 'serotina', NULL, NULL, 'world', '0.470000'),
(1920, 366, 'septenatum', NULL, NULL, 'world', '0.211667'),
(1921, 367, 'laevigata', NULL, NULL, 'world', '0.629000'),
(1922, 367, 'laevis', NULL, NULL, 'world', '0.618444'),
(1923, 367, 'macrophylla', NULL, NULL, 'world', '0.660250'),
(1924, 367, 'rigida', NULL, NULL, 'world', '0.640000'),
(1925, 367, 'spuria', NULL, NULL, 'world', '0.675000'),
(1926, 1115, 'diclina', NULL, NULL, 'world', '0.808000'),
(1927, 1117, 'suaveolens', NULL, NULL, 'world', '0.679714'),
(1928, 370, 'brachiata', NULL, NULL, 'world', '0.376259'),
(1929, 370, 'deflexa', NULL, NULL, 'world', '0.480397'),
(1930, 370, 'grandis', NULL, NULL, 'world', '0.294816'),
(1931, 1123, 'lamponga', NULL, NULL, 'world', '0.630000'),
(1932, 1123, 'LAMPONGA', NULL, NULL, 'world', '0.630000'),
(1933, 1124, 'hylodendron', NULL, NULL, 'world', '0.678500'),
(1934, 1125, 'coerulescens', NULL, NULL, 'world', '0.530000'),
(1935, 1125, 'COERULESCENS', NULL, NULL, 'world', '0.530000'),
(1936, 1125, 'echinata', NULL, NULL, 'world', '0.580000'),
(1937, 1125, 'ECHINATA', NULL, NULL, 'world', '0.580000'),
(1938, 371, 'indicus', NULL, NULL, 'world', '0.636250'),
(1939, 371, 'macrocarpus', NULL, NULL, 'world', '0.700000'),
(1940, 371, 'marsupium', NULL, NULL, 'world', '0.620000'),
(1941, 371, 'officinalis', NULL, NULL, 'world', '0.379868'),
(1942, 371, 'rohrii', NULL, NULL, 'world', '0.449286'),
(1943, 371, 'soyauxii', NULL, NULL, 'world', '0.657786'),
(1944, 1126, 'javanicum', NULL, NULL, 'world', '0.400000'),
(1945, 1126, 'tinctorium', NULL, NULL, 'world', '0.250000'),
(1946, 1126, 'tubulatum', NULL, NULL, 'world', '0.340000'),
(1947, 1126, 'TUBULATUM', NULL, NULL, 'world', '0.340000'),
(1948, 1127, 'celebicum', NULL, NULL, 'world', '0.350000'),
(1949, 1127, 'diversifolium', NULL, NULL, 'world', '0.565000'),
(1950, 1127, 'heterophyllum', NULL, NULL, 'world', '0.446000'),
(1951, 1127, 'javanicum', NULL, NULL, 'world', '0.400000'),
(1952, 1128, 'bequaertii', NULL, NULL, 'world', '0.534000'),
(1953, 1130, 'costata', NULL, NULL, 'world', '0.560000'),
(1954, 1130, 'COSTATA', NULL, NULL, 'world', '0.560000'),
(1955, 1130, 'grandis', NULL, NULL, 'world', '0.560000'),
(1956, 1131, 'angolensis', NULL, NULL, 'world', '0.408900'),
(1957, 372, 'paraensis', NULL, NULL, 'world', '0.689333'),
(1958, 373, 'asterolepis', NULL, NULL, 'world', '0.454000'),
(1959, 373, 'turbinata', NULL, NULL, 'world', '0.578290'),
(1960, 373, 'wittii', NULL, NULL, 'world', '0.465000'),
(1961, 374, 'amara', NULL, NULL, 'world', '0.470000'),
(1962, 374, 'borneensis', NULL, NULL, 'world', '0.430000'),
(1963, 1134, 'alba', NULL, NULL, 'world', '0.630000'),
(1964, 1134, 'argentata', NULL, NULL, 'world', '0.740000'),
(1965, 1134, 'ARGENTATA', NULL, NULL, 'world', '0.740000'),
(1966, 1134, 'coccinea', NULL, NULL, 'world', '0.620000'),
(1967, 1134, 'kelloggii', NULL, NULL, 'world', '0.510000'),
(1968, 1134, 'mongolica', NULL, NULL, 'world', '0.635667'),
(1969, 1134, 'robur', NULL, NULL, 'world', '0.574714'),
(1970, 1134, 'rubra', NULL, NULL, 'world', '0.560000'),
(1971, 1134, 'semiserrata', NULL, NULL, 'world', '0.712333'),
(1972, 1134, 'velutina', NULL, NULL, 'world', '0.560000'),
(1973, 376, 'amazonica', NULL, NULL, 'world', '0.920000'),
(1974, 376, 'florida', NULL, NULL, 'world', '0.728000'),
(1975, 376, 'obovata', NULL, NULL, 'world', '0.851000'),
(1976, 1135, 'glandulosa', NULL, NULL, 'world', '0.450000'),
(1977, 1135, 'pinnata', NULL, NULL, 'world', '0.460000'),
(1978, 1135, 'PINNATA', NULL, NULL, 'world', '0.460000'),
(1979, 377, 'armata', NULL, NULL, 'world', '0.668000'),
(1980, 377, 'spinosa', NULL, NULL, 'world', '0.716000'),
(1981, 1137, 'neriifolia', NULL, NULL, 'world', '0.638000'),
(1982, 1137, 'umbellata', NULL, NULL, 'world', '0.705000'),
(1983, 380, 'caffra', NULL, NULL, 'world', '0.458750'),
(1984, 380, 'nitida', NULL, NULL, 'world', '0.465000'),
(1985, 380, 'praecox', NULL, NULL, 'world', '0.459667'),
(1986, 1138, 'humile', NULL, NULL, 'world', '0.810000'),
(1987, 13888, 'californica', NULL, NULL, 'world', '0.500000'),
(1988, 13888, 'frangula', NULL, NULL, 'world', '0.499000'),
(1989, 13888, 'purshiana', NULL, NULL, 'world', '0.500500'),
(1990, 1143, 'cinerea', NULL, NULL, 'world', '0.870000'),
(1991, 1143, 'CINEREA', NULL, NULL, 'world', '0.870000'),
(1992, 1145, 'grandis', NULL, NULL, 'world', '0.390000'),
(1993, 1146, 'longipes', NULL, NULL, 'world', '0.702000'),
(1994, 1146, 'succedanea', NULL, NULL, 'world', '0.441000'),
(1995, 1148, 'heudelotii', NULL, NULL, 'world', '0.210600'),
(1996, 382, 'guianensis', NULL, NULL, 'world', '0.780000'),
(1997, 382, 'racemosa', NULL, NULL, 'world', '0.682000'),
(1998, 382, 'viridifolia', NULL, NULL, 'world', '0.515000'),
(1999, 14049, 'pseudoacacia', NULL, NULL, 'world', '0.674600'),
(2000, 383, 'insignis', NULL, NULL, 'world', '0.425000'),
(2001, 383, 'pittieri', NULL, NULL, 'world', '0.270000'),
(2002, 383, 'sericea', NULL, NULL, 'world', '0.470000'),
(2003, 384, 'portoricensis', NULL, NULL, 'world', '0.775000'),
(2004, 1150, 'urcelliformis', NULL, NULL, 'world', '0.538000'),
(2005, 386, 'montana', NULL, NULL, 'world', '0.780000'),
(2006, 387, 'borinquena', NULL, NULL, 'world', '0.820000'),
(2007, 1152, 'insignis', NULL, NULL, 'world', '0.470000'),
(2008, 14164, 'albiflora', NULL, NULL, 'world', '0.576125'),
(2009, 1155, 'hullettii', NULL, NULL, 'world', '0.610000'),
(2010, 1155, 'javanica', NULL, NULL, 'world', '0.450000'),
(2011, 392, 'gabonensis', NULL, NULL, 'world', '0.796333'),
(2012, 392, 'guianensis', NULL, NULL, 'world', '0.835857'),
(2013, 392, 'mattogrossensis', NULL, NULL, 'world', '0.770000'),
(2014, 1158, 'elliptica', NULL, NULL, 'world', '0.670000'),
(2015, 1159, 'racemosa', NULL, NULL, 'world', '0.580000'),
(2016, 14259, 'caprea', NULL, NULL, 'world', '0.396000'),
(2017, 14259, 'lasiandra', NULL, NULL, 'world', '0.390000'),
(2018, 1161, 'beccarianum', NULL, NULL, 'world', '0.380000'),
(2019, 1161, 'BECCARIANUM', NULL, NULL, 'world', '0.380000'),
(2020, 1161, 'koetjape', NULL, NULL, 'world', '0.473333'),
(2021, 1161, 'KOETJAPE', NULL, NULL, 'world', '0.473333'),
(2022, 1162, 'apiculata', NULL, NULL, 'world', '0.580000'),
(2023, 1162, 'APICULATA', NULL, NULL, 'world', '0.580000'),
(2024, 1162, 'griffithii', NULL, NULL, 'world', '0.675000'),
(2025, 1162, 'GRIFFITHII', NULL, NULL, 'world', '0.675000'),
(2026, 1162, 'laevigata', NULL, NULL, 'world', '0.525000'),
(2027, 1162, 'LAEVIGATA', NULL, NULL, 'world', '0.525000'),
(2028, 1162, 'oblongifolia', NULL, NULL, 'world', '0.530000'),
(2029, 1162, 'OBLONGIFOLIA', NULL, NULL, 'world', '0.530000'),
(2030, 1162, 'rubiginosa', NULL, NULL, 'world', '0.683333'),
(2031, 1162, 'RUBIGINOSA', NULL, NULL, 'world', '0.683333'),
(2032, 1162, 'tomentosa', NULL, NULL, 'world', '0.580000'),
(2033, 1162, 'TOMENTOSA', NULL, NULL, 'world', '0.580000'),
(2034, 1162, 'trimera', NULL, NULL, 'world', '0.546333'),
(2035, 395, 'rarak', NULL, NULL, 'world', '0.510000'),
(2036, 395, 'saponaria', NULL, NULL, 'world', '0.712250'),
(2037, 396, 'discolor', NULL, NULL, 'world', '0.344000'),
(2038, 396, 'DISCOLOR', NULL, NULL, 'world', '0.344000'),
(2039, 396, 'ellipticum', NULL, NULL, 'world', '0.551000'),
(2040, 396, 'glandulosum', NULL, NULL, 'world', '0.415250'),
(2041, 396, 'insigne', NULL, NULL, 'world', '0.372000'),
(2042, 396, 'laurocerasus', NULL, NULL, 'world', '0.380714'),
(2043, 396, 'marmieri', NULL, NULL, 'world', '0.410000'),
(2044, 396, 'stylare', NULL, NULL, 'world', '0.470000'),
(2045, 1164, 'declinata', NULL, NULL, 'world', '0.440000'),
(2046, 1164, 'DECLINATA', NULL, NULL, 'world', '0.440000'),
(2047, 1164, 'indica', NULL, NULL, 'world', '0.648000'),
(2048, 397, 'brasiliensis', NULL, NULL, 'world', '0.615000'),
(2049, 14358, 'arboreum', NULL, NULL, 'world', '0.413000'),
(2050, 1166, 'diversifolia', NULL, NULL, 'world', '0.610000'),
(2051, 1166, 'glauca', NULL, NULL, 'world', '0.610000'),
(2052, 14381, 'albidum', NULL, NULL, 'world', '0.420000'),
(2053, 14381, 'tzumu', NULL, NULL, 'world', '0.469667'),
(2054, 398, 'roxburghii', NULL, NULL, 'world', '0.579000'),
(2055, 398, 'tristyla', NULL, NULL, 'world', '0.339000'),
(2056, 1168, 'macropodum', NULL, NULL, 'world', '0.530000'),
(2057, 1168, 'MACROPODUM', NULL, NULL, 'world', '0.530000'),
(2058, 399, 'morototoni', NULL, NULL, 'world', '0.453891'),
(2059, 399, 'octophylla', NULL, NULL, 'world', '0.370600'),
(2060, 1171, 'superba', NULL, NULL, 'world', '0.537500'),
(2061, 1171, 'wallichii', NULL, NULL, 'world', '0.557750'),
(2062, 400, 'parahyba', NULL, NULL, 'world', '0.346500'),
(2063, 1172, 'oleosa', NULL, NULL, 'world', '0.896750'),
(2064, 1174, 'accrescens', NULL, NULL, 'world', '0.770000'),
(2065, 1174, 'ACCRESCENS', NULL, NULL, 'world', '0.770000'),
(2066, 1175, 'swietenioides', NULL, NULL, 'world', '0.754000'),
(2067, 402, 'excelsum', NULL, NULL, 'world', '0.530000'),
(2068, 403, 'chrysophyllum', NULL, NULL, 'world', '0.615000'),
(2069, 403, 'melanocarpum', NULL, NULL, 'world', '0.610000'),
(2070, 403, 'melinonii', NULL, NULL, 'world', '0.499500'),
(2071, 403, 'micranthum', NULL, NULL, 'world', '0.440000'),
(2072, 403, 'micropetalum', NULL, NULL, 'world', '0.451667'),
(2073, 403, 'setiferum', NULL, NULL, 'world', '0.510000'),
(2074, 14595, 'micranthum', NULL, NULL, 'world', '0.624778'),
(2075, 750, 'spinosa', NULL, NULL, 'world', '0.740000'),
(2076, 750, 'SPINOSA', NULL, NULL, 'world', '0.740000'),
(2077, 1178, 'borneensis', NULL, NULL, 'world', '0.723333'),
(2078, 1179, 'klaineana', NULL, NULL, 'world', '0.575750'),
(2079, 1180, 'brunnea', NULL, NULL, 'world', '0.560000'),
(2080, 1181, 'mannii', NULL, NULL, 'world', '0.507444'),
(2081, 751, 'albescens', NULL, NULL, 'world', '0.260000'),
(2082, 751, 'anacardium', NULL, NULL, 'world', '0.425000'),
(2083, 404, 'siamea', NULL, NULL, 'world', '0.660000'),
(2084, NULL, 'rubra', NULL, NULL, 'world', '0.552286'),
(2085, 501, 'almon', NULL, NULL, 'world', '0.390000'),
(2086, 501, 'amplexicaulis', NULL, NULL, 'world', '0.440000'),
(2087, 501, 'argentifolia', NULL, NULL, 'world', '0.520000'),
(2088, 501, 'assamica', NULL, NULL, 'world', '0.464333'),
(2089, 501, 'atrinervosa', NULL, NULL, 'world', '0.770000'),
(2090, 501, 'beccariana', NULL, NULL, 'world', '0.470000'),
(2091, 501, 'contorta', NULL, NULL, 'world', '0.430000'),
(2092, 501, 'curtisii', NULL, NULL, 'world', '0.526667'),
(2093, 501, 'dasyphylla', NULL, NULL, 'world', '0.435000'),
(2094, 501, 'DASYPHYLLA', NULL, NULL, 'world', '0.435000'),
(2095, 501, 'exelliptica', NULL, NULL, 'world', '0.770000'),
(2096, 501, 'faguetiana', NULL, NULL, 'world', '0.480000'),
(2097, 501, 'falciferoides', NULL, NULL, 'world', '0.720000'),
(2098, 501, 'ferruginea', NULL, NULL, 'world', '0.390000'),
(2099, 501, 'flemmichii', NULL, NULL, 'world', '0.680000'),
(2100, 501, 'foxworthyi', NULL, NULL, 'world', '0.816667'),
(2101, 501, 'gibbosa', NULL, NULL, 'world', '0.455000'),
(2102, 501, 'gratissima', NULL, NULL, 'world', '0.640000'),
(2103, 501, 'guiso', NULL, NULL, 'world', '0.705000'),
(2104, 501, 'GUISO', NULL, NULL, 'world', '0.705000'),
(2105, 501, 'havilandii', NULL, NULL, 'world', '0.880000'),
(2106, 501, 'henryana', NULL, NULL, 'world', '0.660000'),
(2107, 501, 'hopeifolia', NULL, NULL, 'world', '0.485000'),
(2108, 501, 'HOPEIFOLIA', NULL, NULL, 'world', '0.485000'),
(2109, 501, 'hypochra', NULL, NULL, 'world', '0.615000'),
(2110, 501, 'inappendiculata', NULL, NULL, 'world', '0.785000'),
(2111, 501, 'johorensis', NULL, NULL, 'world', '0.393333'),
(2112, 501, 'kunstleri', NULL, NULL, 'world', '0.716667'),
(2113, 501, 'leprosula', NULL, NULL, 'world', '0.440000'),
(2114, 501, 'LEPROSULA', NULL, NULL, 'world', '0.440000'),
(2115, 501, 'macrophylla', NULL, NULL, 'world', '0.320000'),
(2116, 501, 'macroptera', NULL, NULL, 'world', '0.425000'),
(2117, 501, 'MACROPTERA', NULL, NULL, 'world', '0.425000'),
(2118, 501, 'multiflora', NULL, NULL, 'world', '0.510000'),
(2119, 501, 'MULTIFLORA', NULL, NULL, 'world', '0.510000'),
(2120, 501, 'negrosensis', NULL, NULL, 'world', '0.510000'),
(2121, 501, 'ochracea', NULL, NULL, 'world', '0.450000'),
(2122, 501, 'ochrophloia', NULL, NULL, 'world', '0.725000'),
(2123, 501, 'OCHROPHLOIA', NULL, NULL, 'world', '0.725000'),
(2124, 501, 'ovalis', NULL, NULL, 'world', '0.430000'),
(2125, 501, 'OVALIS', NULL, NULL, 'world', '0.430000'),
(2126, 501, 'ovata', NULL, NULL, 'world', '0.640000'),
(2127, 501, 'palosapis', NULL, NULL, 'world', '0.420000'),
(2128, 501, 'parvifolia', NULL, NULL, 'world', '0.405000'),
(2129, 501, 'PARVIFOLIA', NULL, NULL, 'world', '0.405000'),
(2130, 501, 'pauciflora', NULL, NULL, 'world', '0.532500'),
(2131, 501, 'PAUCIFLORA', NULL, NULL, 'world', '0.532500'),
(2132, 501, 'polysperma', NULL, NULL, 'world', '0.505000'),
(2133, 501, 'quadrinervis', NULL, NULL, 'world', '0.435000'),
(2134, 501, 'roxburghii', NULL, NULL, 'world', '0.700000'),
(2135, 501, 'scaberrima', NULL, NULL, 'world', '0.470000'),
(2136, 501, 'scabrida', NULL, NULL, 'world', '0.460000'),
(2137, 501, 'scrobiculata', NULL, NULL, 'world', '0.810000'),
(2138, 501, 'siamensis', NULL, NULL, 'world', '0.860000'),
(2139, 501, 'smithiana', NULL, NULL, 'world', '0.355000'),
(2140, 501, 'superba', NULL, NULL, 'world', '0.690000'),
(2141, 501, 'xanthophylla', NULL, NULL, 'world', '0.520000'),
(2142, 406, 'cedron', NULL, NULL, 'world', '0.474333'),
(2143, 406, 'orinocensis', NULL, NULL, 'world', '0.420000'),
(2144, 407, 'amara', NULL, NULL, 'world', '0.384643'),
(2145, 407, 'glauca', NULL, NULL, 'world', '0.442000'),
(2146, 1184, 'rubescens', NULL, NULL, 'world', '0.800000'),
(2147, 1185, 'beccariana', NULL, NULL, 'world', '0.545000'),
(2148, 1185, 'coriacea', NULL, NULL, 'world', '0.550000'),
(2149, 1185, 'CORIACEA', NULL, NULL, 'world', '0.550000'),
(2150, 1185, 'echinocalyx', NULL, NULL, 'world', '0.610000'),
(2151, 1185, 'ECHINOCALYX', NULL, NULL, 'world', '0.610000'),
(2152, 1185, 'klaineana', NULL, NULL, 'world', '0.577500'),
(2153, 1185, 'leiocarpa', NULL, NULL, 'world', '0.510000'),
(2154, 1185, 'velutina', NULL, NULL, 'world', '0.540000'),
(2155, 1185, 'VELUTINA', NULL, NULL, 'world', '0.540000'),
(2156, 1185, 'wallichii', NULL, NULL, 'world', '0.540000'),
(2157, 1185, 'WALLICHII', NULL, NULL, 'world', '0.540000'),
(2158, 408, 'cuspidata', NULL, NULL, 'world', '0.655000'),
(2159, 408, 'decipiens', NULL, NULL, 'world', '0.640500'),
(2160, 408, 'poeppigii', NULL, NULL, 'world', '0.690000'),
(2161, 1186, 'celastrineus', NULL, NULL, 'world', '0.619500'),
(2162, 409, 'berteriana', NULL, NULL, 'world', '0.800000'),
(2163, 409, 'fragrans', NULL, NULL, 'world', '0.470000'),
(2164, 409, 'guianensis', NULL, NULL, 'world', '0.821200'),
(2165, 409, 'javanica', NULL, NULL, 'world', '0.545000'),
(2166, 409, 'JAVANICA', NULL, NULL, 'world', '0.545000'),
(2167, 409, 'laurifolia', NULL, NULL, 'world', '0.815500'),
(2168, 409, 'schomburgkii', NULL, NULL, 'world', '0.865500'),
(2169, 409, 'sigun', NULL, NULL, 'world', '0.490000'),
(2170, 409, 'sinensis', NULL, NULL, 'world', '0.478500'),
(2171, 409, 'synandra', NULL, NULL, 'world', '0.653000'),
(2172, 410, 'exorrhiza', NULL, NULL, 'world', '0.230000'),
(2173, 411, 'grandiflorum', NULL, NULL, 'world', '0.350000'),
(2174, 411, 'rugosum', NULL, NULL, 'world', '0.492500'),
(2175, 411, 'torvum', NULL, NULL, 'world', '0.463333'),
(2176, 14990, 'aucuparia', NULL, NULL, 'world', '0.629000'),
(2177, 14990, 'folgneri', NULL, NULL, 'world', '0.620000'),
(2178, 14990, 'pohuashanensis', NULL, NULL, 'world', '0.525000'),
(2179, 414, 'campanulata', NULL, NULL, 'world', '0.343960'),
(2180, 415, 'dulcis', NULL, NULL, 'world', '0.370000'),
(2181, 415, 'mombin', NULL, NULL, 'world', '0.390706'),
(2182, 415, 'pinnata', NULL, NULL, 'world', '0.294400'),
(2183, 415, 'radlkoferi', NULL, NULL, 'world', '0.430667'),
(2184, 1193, 'gabonensis', NULL, NULL, 'world', '0.749000'),
(2185, 1193, 'kamerunensis', NULL, NULL, 'world', '0.796529'),
(2186, 1195, 'secundiflorus', NULL, NULL, 'world', '0.510000'),
(2187, 1195, 'umbellatus', NULL, NULL, 'world', '0.610000'),
(2188, 1195, 'UMBELLATUS', NULL, NULL, 'world', '0.610000'),
(2189, 419, 'apeibophylla', NULL, NULL, 'world', '0.470000'),
(2190, 419, 'apetala', NULL, NULL, 'world', '0.388091'),
(2191, 419, 'coccinea', NULL, NULL, 'world', '0.234000'),
(2192, 419, 'COCCINEA', NULL, NULL, 'world', '0.234000'),
(2193, 419, 'cordata', NULL, NULL, 'world', '0.320000'),
(2194, 419, 'CORDATA', NULL, NULL, 'world', '0.320000'),
(2195, 419, 'frondosa', NULL, NULL, 'world', '0.470000'),
(2196, 419, 'lanceolata', NULL, NULL, 'world', '0.500000'),
(2197, 419, 'macrophylla', NULL, NULL, 'world', '0.283333'),
(2198, 419, 'MACROPHYLLA', NULL, NULL, 'world', '0.283333'),
(2199, 419, 'oblonga', NULL, NULL, 'world', '0.620000'),
(2200, 419, 'pruriens', NULL, NULL, 'world', '0.486200'),
(2201, 419, 'recordiana', NULL, NULL, 'world', '0.490000'),
(2202, 1197, 'cylindricum', NULL, NULL, 'world', '0.990000'),
(2203, 1197, 'fimbriatum', NULL, NULL, 'world', '0.710000'),
(2204, 1199, 'elongatus', NULL, NULL, 'world', '0.825000'),
(2205, 1199, 'ELONGATUS', NULL, NULL, 'world', '0.825000'),
(2206, 753, 'ceylanica', NULL, NULL, 'world', '0.730000'),
(2207, 753, 'grandifolia', NULL, NULL, 'world', '0.824500'),
(2208, 753, 'javanica', NULL, NULL, 'world', '0.526667'),
(2209, 753, 'JAVANICA', NULL, NULL, 'world', '0.526667'),
(2210, 753, 'pustulata', NULL, NULL, 'world', '0.830286'),
(2211, 753, 'scheffleri', NULL, NULL, 'world', '0.584000'),
(2212, 1201, 'tetrandra', NULL, NULL, 'world', '0.663000'),
(2213, 1202, 'guianense', NULL, NULL, 'world', '0.567500'),
(2214, 1202, 'polystachyum', NULL, NULL, 'world', '0.463000'),
(2215, 1202, 'pulcherrimum', NULL, NULL, 'world', '0.475000'),
(2216, 1202, 'racemiferum', NULL, NULL, 'world', '0.752000'),
(2217, 1203, 'guyanensis', NULL, NULL, 'world', '0.340000'),
(2218, 1205, 'glomerulata', NULL, NULL, 'world', '0.610000'),
(2219, 422, 'arborescens', NULL, NULL, 'world', '0.834500'),
(2220, 422, 'benthamiana', NULL, NULL, 'world', '0.737167'),
(2221, 422, 'corrugata', NULL, NULL, 'world', '1.056500'),
(2222, 422, 'cuspidata', NULL, NULL, 'world', '0.678000'),
(2223, 422, 'ingifolia', NULL, NULL, 'world', '0.815000'),
(2224, 422, 'oblanceolata', NULL, NULL, 'world', '0.860000'),
(2225, 422, 'panacoco', NULL, NULL, 'world', '0.920000'),
(2226, 422, 'polyphylla', NULL, NULL, 'world', '0.691000'),
(2227, 422, 'recurva', NULL, NULL, 'world', '0.890000'),
(2228, 423, 'macrophylla', NULL, NULL, 'world', '0.522409'),
(2229, 424, 'globulifera', NULL, NULL, 'world', '0.600400'),
(2230, 425, 'adenophylla', NULL, NULL, 'world', '0.650000'),
(2231, 425, 'anomala', NULL, NULL, 'world', '0.481500'),
(2232, 425, 'caudata', NULL, NULL, 'world', '0.568500'),
(2233, 425, 'cochinchinensis', NULL, NULL, 'world', '0.515000'),
(2234, 425, 'COCHINCHINENSIS', NULL, NULL, 'world', '0.515000'),
(2235, 425, 'fasciculata', NULL, NULL, 'world', '0.300000'),
(2236, 425, 'lancifolia', NULL, NULL, 'world', '0.463500'),
(2237, 425, 'martinicensis', NULL, NULL, 'world', '0.726609'),
(2238, 1208, 'msolo', NULL, NULL, 'world', '0.540000'),
(2239, 427, 'claviflorum', NULL, NULL, 'world', '0.623500'),
(2240, 427, 'cumini', NULL, NULL, 'world', '0.672667'),
(2241, 427, 'filiforme', NULL, NULL, 'world', '0.660000'),
(2242, 427, 'griffithii', NULL, NULL, 'world', '0.560000'),
(2243, 427, 'guineense', NULL, NULL, 'world', '0.609667'),
(2244, 427, 'jambos', NULL, NULL, 'world', '0.682282'),
(2245, 427, 'polyanthum', NULL, NULL, 'world', '0.557500'),
(2246, 428, 'cassinoides', NULL, NULL, 'world', '0.390000'),
(2247, 428, 'guayacan', NULL, NULL, 'world', '0.835000'),
(2248, 428, 'heterophylla', NULL, NULL, 'world', '0.589445'),
(2249, 428, 'ochracea', NULL, NULL, 'world', '0.846975'),
(2250, 428, 'rosea', NULL, NULL, 'world', '0.530500'),
(2251, 428, 'serratifolia', NULL, NULL, 'world', '0.924000'),
(2252, 429, 'corymbosa', NULL, NULL, 'world', '0.590000'),
(2253, 429, 'CORYMBOSA', NULL, NULL, 'world', '0.590000'),
(2254, 429, 'crassa', NULL, NULL, 'world', '0.550000'),
(2255, 429, 'flavicans', NULL, NULL, 'world', '0.487000'),
(2256, 429, 'macrocarpa', NULL, NULL, 'world', '0.440000'),
(2257, 429, 'undulata', NULL, NULL, 'world', '0.585000'),
(2258, 430, 'chrysophylla', NULL, NULL, 'world', '0.540500'),
(2259, 430, 'guianensis', NULL, NULL, 'world', '0.625000'),
(2260, 430, 'myrmecophila', NULL, NULL, 'world', '0.476000'),
(2261, 430, 'paniculata', NULL, NULL, 'world', '0.554500'),
(2262, 430, 'versicolor', NULL, NULL, 'world', '0.521000'),
(2263, 15673, 'indica', NULL, NULL, 'world', '0.978400'),
(2264, 434, 'guianensis', NULL, NULL, 'world', '0.457000'),
(2265, 434, 'obtusa', NULL, NULL, 'world', '0.293000'),
(2266, 435, 'guianensis', NULL, NULL, 'world', '0.580000'),
(2267, 20367, 'brevifolia', NULL, NULL, 'world', '0.600000'),
(2268, 15739, 'nobilis', NULL, NULL, 'world', '0.745000'),
(2269, 437, 'grandis', NULL, NULL, 'world', '0.601444'),
(2270, 1212, 'hollrungii', NULL, NULL, 'world', '0.426000'),
(2271, 1212, 'pteropodum', NULL, NULL, 'world', '0.390000'),
(2272, 1212, 'simplicifolium', NULL, NULL, 'world', '0.700000'),
(2273, 1212, 'SIMPLICIFOLIUM', NULL, NULL, 'world', '0.700000'),
(2274, 438, 'amazonia', NULL, NULL, 'world', '0.673500'),
(2275, 438, 'catappa', NULL, NULL, 'world', '0.478000'),
(2276, 438, 'chebula', NULL, NULL, 'world', '0.880000'),
(2277, 438, 'dichotoma', NULL, NULL, 'world', '0.707667'),
(2278, 438, 'foetidissima', NULL, NULL, 'world', '0.600000'),
(2279, 438, 'microcarpa', NULL, NULL, 'world', '0.522000'),
(2280, 438, 'oblonga', NULL, NULL, 'world', '0.694167'),
(2281, 438, 'subspathulata', NULL, NULL, 'world', '0.540000'),
(2282, 438, 'SUBSPATHULATA', NULL, NULL, 'world', '0.540000'),
(2283, 439, 'bancana', NULL, NULL, 'world', '0.650000'),
(2284, 439, 'brasiliensis', NULL, NULL, 'world', '0.470000'),
(2285, 439, 'gymnanthera', NULL, NULL, 'world', '0.646333'),
(2286, 1213, 'africana', NULL, NULL, 'world', '0.824000'),
(2287, 1215, 'bifoliolata', NULL, NULL, 'world', '0.511923'),
(2288, 440, 'balsamifera', NULL, NULL, 'world', '0.591348'),
(2289, 440, 'panamensis', NULL, NULL, 'world', '0.717333'),
(2290, 1217, 'nudiflora', NULL, NULL, 'world', '0.307000'),
(2291, 1218, 'glabra', NULL, NULL, 'world', '0.600000'),
(2292, 1219, 'tetraptera', NULL, NULL, 'world', '0.570000'),
(2293, 441, 'macrophyllum', NULL, NULL, 'world', '0.620000'),
(2294, 443, 'cacao', NULL, NULL, 'world', '0.420000'),
(2295, 443, 'obovatum', NULL, NULL, 'world', '0.470000'),
(2296, 443, 'speciosum', NULL, NULL, 'world', '0.630000'),
(2297, 443, 'subincanum', NULL, NULL, 'world', '0.470000'),
(2298, 443, 'sylvestre', NULL, NULL, 'world', '0.668000'),
(2299, 16004, 'occidentalis', NULL, NULL, 'world', '0.290000'),
(2300, 16004, 'plicata', NULL, NULL, 'world', '0.310000'),
(2301, 1223, 'africana', NULL, NULL, 'world', '0.651556'),
(2302, 16053, 'americana', NULL, NULL, 'world', '0.320000'),
(2303, 16053, 'amurensis', NULL, NULL, 'world', '0.391000'),
(2304, 16053, 'endochrysea', NULL, NULL, 'world', '0.527000'),
(2305, 16053, 'mandshurica', NULL, NULL, 'world', '0.347500'),
(2306, 755, 'borneensis', NULL, NULL, 'world', '0.555000'),
(2307, 755, 'wallichianus', NULL, NULL, 'world', '0.760000'),
(2308, 755, 'WALLICHIANUS', NULL, NULL, 'world', '0.760000'),
(2309, 447, 'williamsii', NULL, NULL, 'world', '0.620000'),
(2310, 1224, 'ciliata', NULL, NULL, 'world', '0.376333'),
(2311, 1224, 'sureni', NULL, NULL, 'world', '0.375333'),
(2312, 16130, 'guianensis', NULL, NULL, 'world', '0.760000'),
(2313, 449, 'aspera', NULL, NULL, 'world', '0.424000'),
(2314, 449, 'burserifolia', NULL, NULL, 'world', '0.460000'),
(2315, 449, 'glaziovii', NULL, NULL, 'world', '0.520500'),
(2316, 449, 'lawrancei', NULL, NULL, 'world', '0.450000'),
(2317, 449, 'peruviana', NULL, NULL, 'world', '0.560000'),
(2318, 450, 'micrantha', NULL, NULL, 'world', '0.319417'),
(2319, 450, 'orientalis', NULL, NULL, 'world', '0.345333'),
(2320, 450, 'tomentosa', NULL, NULL, 'world', '0.330667'),
(2321, 450, 'TOMENTOSA', NULL, NULL, 'world', '0.330667'),
(2322, 1229, 'nudiflora', NULL, NULL, 'world', '0.440000'),
(2323, 1230, 'philippinensis', NULL, NULL, 'world', '0.705000'),
(2324, 451, 'gigantea', NULL, NULL, 'world', '0.450000'),
(2325, 452, 'hirta', NULL, NULL, 'world', '0.606667'),
(2326, 452, 'martiana', NULL, NULL, 'world', '0.470000'),
(2327, 452, 'maynasiana', NULL, NULL, 'world', '0.690000'),
(2328, 452, 'micrantha', NULL, NULL, 'world', '0.612500'),
(2329, 452, 'pallida', NULL, NULL, 'world', '0.698125'),
(2330, 452, 'pleeana', NULL, NULL, 'world', '0.675000'),
(2331, 452, 'prieuriana', NULL, NULL, 'world', '0.663000'),
(2332, 452, 'quadrijuga', NULL, NULL, 'world', '0.548250'),
(2333, 452, 'rubra', NULL, NULL, 'world', '0.585000'),
(2334, 452, 'schomburgkii', NULL, NULL, 'world', '0.686667'),
(2335, 452, 'tuberculata', NULL, NULL, 'world', '0.627500'),
(2336, 453, 'galeottii', NULL, NULL, 'world', '0.270000'),
(2337, 1235, 'hypoleucum', NULL, NULL, 'world', '0.696667'),
(2338, 1235, 'HYPOLEUCUM', NULL, NULL, 'world', '0.696667'),
(2339, 1236, 'malayana', NULL, NULL, 'world', '0.500000'),
(2340, 1236, 'MALAYANA', NULL, NULL, 'world', '0.500000'),
(2341, 1239, 'madagascariense', NULL, NULL, 'world', '0.499000'),
(2342, 1240, 'malaccensis', NULL, NULL, 'world', '0.583333'),
(2343, 1240, 'MALACCENSIS', NULL, NULL, 'world', '0.583333'),
(2344, 454, 'cumingiana', NULL, NULL, 'world', '0.520000'),
(2345, 1241, 'merguensis', NULL, NULL, 'world', '0.940000'),
(2346, 456, 'caucana', NULL, NULL, 'world', '0.470000'),
(2347, 456, 'racemosa', NULL, NULL, 'world', '0.659250'),
(2348, 1243, 'amazonicus', NULL, NULL, 'world', '0.659500'),
(2349, 16419, 'canadensis', NULL, NULL, 'world', '0.380000'),
(2350, 16419, 'heterophylla', NULL, NULL, 'world', '0.420000'),
(2351, 458, 'occidentalis', NULL, NULL, 'world', '0.354805'),
(2352, 1245, 'guineensis', NULL, NULL, 'world', '0.611857'),
(2353, 1246, 'americana', NULL, NULL, 'world', '0.460000'),
(2354, 1246, 'glabra', NULL, NULL, 'world', '0.550500'),
(2355, 1246, 'laciniata', NULL, NULL, 'world', '0.464000'),
(2356, 1246, 'rubra', NULL, NULL, 'world', '0.480000'),
(2357, 16502, 'californica', NULL, NULL, 'world', '0.510000'),
(2358, 459, 'floribunda', NULL, NULL, 'world', '0.420000'),
(2359, 459, 'pittieri', NULL, NULL, 'world', '0.368000'),
(2360, 459, 'spectabilis', NULL, NULL, 'world', '0.620000'),
(2361, 459, 'veneficiorum', NULL, NULL, 'world', '0.436000'),
(2362, 460, 'baccifera', NULL, NULL, 'world', '0.275078'),
(2363, 758, 'arboreum', NULL, NULL, 'world', '0.480000'),
(2364, 461, 'macrocarpa', NULL, NULL, 'world', '0.832000'),
(2365, 461, 'micrantha', NULL, NULL, 'world', '0.975000'),
(2366, 461, 'parviflora', NULL, NULL, 'world', '0.833500'),
(2367, 1253, 'maingayi', NULL, NULL, 'world', '0.775000'),
(2368, 1253, 'MAINGAYI', NULL, NULL, 'world', '0.775000'),
(2369, 1253, 'mangachapoi', NULL, NULL, 'world', '0.750000'),
(2370, 1253, 'micrantha', NULL, NULL, 'world', '0.750000'),
(2371, 1253, 'nitens', NULL, NULL, 'world', '0.700000'),
(2372, 1253, 'oblongifolia', NULL, NULL, 'world', '0.700000'),
(2373, 1253, 'odorata', NULL, NULL, 'world', '0.790000'),
(2374, 1253, 'ODORATA', NULL, NULL, 'world', '0.790000'),
(2375, 465, 'patens', NULL, NULL, 'world', '0.540000'),
(2376, 1255, 'arborea', NULL, NULL, 'world', '0.330000'),
(2377, 1255, 'ARBOREA', NULL, NULL, 'world', '0.330000'),
(2378, 466, 'caducifolia', NULL, NULL, 'world', '0.461000'),
(2379, 466, 'calophylla', NULL, NULL, 'world', '0.472333'),
(2380, 466, 'elongata', NULL, NULL, 'world', '0.523333'),
(2381, 466, 'flexuosa', NULL, NULL, 'world', '0.510000'),
(2382, 466, 'koschnyi', NULL, NULL, 'world', '0.407750'),
(2383, 466, 'michelii', NULL, NULL, 'world', '0.470125'),
(2384, 466, 'multiflora', NULL, NULL, 'world', '0.458000'),
(2385, 466, 'multinervia', NULL, NULL, 'world', '0.615000'),
(2386, 466, 'pavonis', NULL, NULL, 'world', '0.586667'),
(2387, 466, 'sebifera', NULL, NULL, 'world', '0.445375'),
(2388, 466, 'surinamensis', NULL, NULL, 'world', '0.417909'),
(2389, 467, 'baccifera', NULL, NULL, 'world', '0.430000'),
(2390, 467, 'guianensis', NULL, NULL, 'world', '0.475000'),
(2391, 467, 'macrophylla', NULL, NULL, 'world', '0.493500'),
(2392, 468, 'cymosa', NULL, NULL, 'world', '0.562500'),
(2393, 468, 'divaricata', NULL, NULL, 'world', '0.623750'),
(2394, 468, 'doniana', NULL, NULL, 'world', '0.400000'),
(2395, 468, 'glabrata', NULL, NULL, 'world', '0.579667'),
(2396, 468, 'grandifolia', NULL, NULL, 'world', '0.424000'),
(2397, 468, 'orinocensis', NULL, NULL, 'world', '0.526667'),
(2398, 468, 'quinata', NULL, NULL, 'world', '0.451333'),
(2399, 468, 'QUINATA', NULL, NULL, 'world', '0.451333'),
(2400, 469, 'braceliniae', NULL, NULL, 'world', '0.390000'),
(2401, 469, 'ferruginea', NULL, NULL, 'world', '0.410167'),
(2402, 469, 'guatemalensis', NULL, NULL, 'world', '0.353000'),
(2403, 16758, 'pallidior', NULL, NULL, 'world', '0.900000'),
(2404, 1260, 'guianensis', NULL, NULL, 'world', '0.840000'),
(2405, 759, 'robusta', NULL, NULL, 'world', '0.868000'),
(2406, 471, 'coccinea', NULL, NULL, 'world', '0.556500'),
(2407, 471, 'cordata', NULL, NULL, 'world', '0.580000'),
(2408, 472, 'regia', NULL, NULL, 'world', '0.400000'),
(2409, 1264, 'moultonianum', NULL, NULL, 'world', '0.785000'),
(2410, 1266, 'laevis', NULL, NULL, 'world', '0.312000'),
(2411, 1266, 'tinctoria', NULL, NULL, 'world', '0.800000'),
(2412, 1267, 'affine', NULL, NULL, 'world', '0.613333'),
(2413, 1267, 'AFFINE', NULL, NULL, 'world', '0.613333'),
(2414, 1267, 'amoenum', NULL, NULL, 'world', '0.770000'),
(2415, 1267, 'AMOENUM', NULL, NULL, 'world', '0.770000'),
(2416, 1267, 'flavescens', NULL, NULL, 'world', '0.686000'),
(2417, 1267, 'hainanense', NULL, NULL, 'world', '0.686667'),
(2418, 1267, 'havilandii', NULL, NULL, 'world', '0.660000'),
(2419, 1267, 'obscurum', NULL, NULL, 'world', '0.800000'),
(2420, 1267, 'rufum', NULL, NULL, 'world', '0.740000'),
(2421, 1267, 'RUFUM', NULL, NULL, 'world', '0.740000'),
(2422, 1267, 'stipitatum', NULL, NULL, 'world', '0.810000'),
(2423, 1267, 'STIPITATUM', NULL, NULL, 'world', '0.810000'),
(2424, 1271, 'laevigatum', NULL, NULL, 'world', '0.770000'),
(2425, 476, 'americana', NULL, NULL, 'world', '0.825000'),
(2426, 477, 'aethiopica', NULL, NULL, 'world', '0.442000'),
(2427, 477, 'amazonica', NULL, NULL, 'world', '0.787000'),
(2428, 477, 'aromatica', NULL, NULL, 'world', '0.561250'),
(2429, 477, 'brasiliensis', NULL, NULL, 'world', '0.700000'),
(2430, 477, 'caudata', NULL, NULL, 'world', '0.720000'),
(2431, 477, 'CAUDATA', NULL, NULL, 'world', '0.720000'),
(2432, 477, 'cuspidata', NULL, NULL, 'world', '0.510000'),
(2433, 477, 'ferruginea', NULL, NULL, 'world', '0.350000'),
(2434, 477, 'frutescens', NULL, NULL, 'world', '0.593333'),
(2435, 477, 'fusca', NULL, NULL, 'world', '0.340000'),
(2436, 477, 'FUSCA', NULL, NULL, 'world', '0.340000'),
(2437, 477, 'macrantha', NULL, NULL, 'world', '0.874000'),
(2438, 477, 'magna', NULL, NULL, 'world', '0.640000'),
(2439, 477, 'MAGNA', NULL, NULL, 'world', '0.640000'),
(2440, 477, 'malayana', NULL, NULL, 'world', '0.585000'),
(2441, 477, 'MALAYANA', NULL, NULL, 'world', '0.585000'),
(2442, 477, 'quintasii', NULL, NULL, 'world', '0.762600'),
(2443, 478, 'schwaneckeanum', NULL, NULL, 'world', '0.893963'),
(2444, 1272, 'golungensis', NULL, NULL, 'world', '0.732000'),
(2445, 480, 'belizense', NULL, NULL, 'world', '0.480000'),
(2446, 480, 'gilletii', NULL, NULL, 'world', '0.686091'),
(2447, 480, 'martinicense', NULL, NULL, 'world', '0.584250'),
(2448, 480, 'panamense', NULL, NULL, 'world', '0.490000'),
(2449, 480, 'setulosum', NULL, NULL, 'world', '0.469000'),
(2450, 481, 'cinnamomum', NULL, NULL, 'world', '0.835000'),
(2451, 481, 'mauritiana', NULL, NULL, 'world', '0.618333'),
(2452, 481, 'xylopyrus', NULL, NULL, 'world', '0.663000'),
(2453, 482, 'guidonia', NULL, NULL, 'world', '0.602000'),
(2454, 483, 'juruana', NULL, NULL, 'world', '0.690000'),
(2455, 483, 'latifolia', NULL, NULL, 'world', '0.750000'),
(2456, 483, 'racemosa', NULL, NULL, 'world', '0.748000');

-- --------------------------------------------------------

--
-- Table structure for table `Users`
--

DROP TABLE IF EXISTS `Users`;
CREATE TABLE IF NOT EXISTS `Users` (
  `UserID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `UserName` char(32) NOT NULL,
  `Pwd` char(41) NOT NULL,
  `DatabaseName` char(32) NOT NULL,
  `ExpirationDate` date DEFAULT NULL,
  `Path` char(64) DEFAULT NULL,
  PRIMARY KEY (`UserID`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=46 ;
